import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ApiServiceV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#metadata ApiServiceV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: ApiServiceV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#spec ApiServiceV1#spec}
     *
     * @stability stable
     */
    readonly spec: ApiServiceV1Spec;
}
/**
 * @stability stable
 */
export interface ApiServiceV1Metadata {
    /**
     * An unstructured key value map stored with the api_service that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#annotations ApiServiceV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#generate_name ApiServiceV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the api_service.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#labels ApiServiceV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the api_service, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#name ApiServiceV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function apiServiceV1MetadataToTerraform(struct?: ApiServiceV1MetadataOutputReference | ApiServiceV1Metadata): any;
/**
 * @stability stable
 */
export declare class ApiServiceV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApiServiceV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApiServiceV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ApiServiceV1SpecService {
    /**
     * Name is the name of the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#name ApiServiceV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Namespace is the namespace of the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#namespace ApiServiceV1#namespace}
     *
     * @stability stable
     */
    readonly namespace: string;
    /**
     * If specified, the port on the service that is hosting the service.
     *
     * Defaults to 443 for backward compatibility. Should be a valid port number (1-65535, inclusive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#port ApiServiceV1#port}
     *
     * @stability stable
     */
    readonly port?: number;
}
export declare function apiServiceV1SpecServiceToTerraform(struct?: ApiServiceV1SpecServiceOutputReference | ApiServiceV1SpecService): any;
/**
 * @stability stable
 */
export declare class ApiServiceV1SpecServiceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApiServiceV1SpecService | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApiServiceV1SpecService | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ApiServiceV1Spec {
    /**
     * CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate.
     *
     * If unspecified, system trust roots on the apiserver are used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#ca_bundle ApiServiceV1#ca_bundle}
     *
     * @stability stable
     */
    readonly caBundle?: string;
    /**
     * Group is the API group name this server hosts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#group ApiServiceV1#group}
     *
     * @stability stable
     */
    readonly group: string;
    /**
     * GroupPriorityMinimum is the priority this group should have at least.
     *
     * Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMininum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object. (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#group_priority_minimum ApiServiceV1#group_priority_minimum}
     *
     * @stability stable
     */
    readonly groupPriorityMinimum: number;
    /**
     * InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server.
     *
     * This is strongly discouraged. You should use the CABundle instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#insecure_skip_tls_verify ApiServiceV1#insecure_skip_tls_verify}
     *
     * @stability stable
     */
    readonly insecureSkipTlsVerify?: boolean | cdktf.IResolvable;
    /**
     * Version is the API version this server hosts. For example, `v1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#version ApiServiceV1#version}
     *
     * @stability stable
     */
    readonly version: string;
    /**
     * VersionPriority controls the ordering of this API version inside of its group.
     *
     * Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is `kube-like`, it will sort above non `kube-like` version strings, which are ordered lexicographically. `Kube-like` versions start with a `v`, then are followed by a number (the major version), then optionally the string `alpha` or `beta` and another number (the minor version). These are sorted first by GA > `beta` > `alpha` (where GA is a version with no suffix such as `beta` or `alpha`), and then by comparing major version, then minor version. An example sorted list of versions: `v10`, `v2`, `v1`, `v11beta2`, `v10beta3`, `v3beta1`, `v12alpha1`, `v11alpha2`, `foo1`, `foo10`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#version_priority ApiServiceV1#version_priority}
     *
     * @stability stable
     */
    readonly versionPriority: number;
    /**
     * service block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html#service ApiServiceV1#service}
     *
     * @stability stable
     */
    readonly service?: ApiServiceV1SpecService;
}
export declare function apiServiceV1SpecToTerraform(struct?: ApiServiceV1SpecOutputReference | ApiServiceV1Spec): any;
/**
 * @stability stable
 */
export declare class ApiServiceV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApiServiceV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApiServiceV1Spec | undefined);
    private _caBundle?;
    /**
     * @stability stable
     */
    get caBundle(): string;
    /**
     * @stability stable
     */
    set caBundle(value: string);
    /**
     * @stability stable
     */
    resetCaBundle(): void;
    /**
     * @stability stable
     */
    get caBundleInput(): string | undefined;
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _groupPriorityMinimum?;
    /**
     * @stability stable
     */
    get groupPriorityMinimum(): number;
    /**
     * @stability stable
     */
    set groupPriorityMinimum(value: number);
    /**
     * @stability stable
     */
    get groupPriorityMinimumInput(): number | undefined;
    private _insecureSkipTlsVerify?;
    /**
     * @stability stable
     */
    get insecureSkipTlsVerify(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set insecureSkipTlsVerify(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInsecureSkipTlsVerify(): void;
    /**
     * @stability stable
     */
    get insecureSkipTlsVerifyInput(): boolean | cdktf.IResolvable | undefined;
    private _version?;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    get versionInput(): string | undefined;
    private _versionPriority?;
    /**
     * @stability stable
     */
    get versionPriority(): number;
    /**
     * @stability stable
     */
    set versionPriority(value: number);
    /**
     * @stability stable
     */
    get versionPriorityInput(): number | undefined;
    private _service;
    /**
     * @stability stable
     */
    get service(): ApiServiceV1SpecServiceOutputReference;
    /**
     * @stability stable
     */
    putService(value: ApiServiceV1SpecService): void;
    /**
     * @stability stable
     */
    resetService(): void;
    /**
     * @stability stable
     */
    get serviceInput(): ApiServiceV1SpecService | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html kubernetes_api_service_v1}.
 *
 * @stability stable
 */
export declare class ApiServiceV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/api_service_v1.html kubernetes_api_service_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiServiceV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ApiServiceV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ApiServiceV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ApiServiceV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): ApiServiceV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: ApiServiceV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): ApiServiceV1Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
