import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CertificateSigningRequestV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Automatically approve the CertificateSigningRequest.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#auto_approve CertificateSigningRequestV1#auto_approve}
     *
     * @stability stable
     */
    readonly autoApprove?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#metadata CertificateSigningRequestV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: CertificateSigningRequestV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#spec CertificateSigningRequestV1#spec}
     *
     * @stability stable
     */
    readonly spec: CertificateSigningRequestV1Spec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#timeouts CertificateSigningRequestV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CertificateSigningRequestV1Timeouts;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestV1Metadata {
    /**
     * An unstructured key value map stored with the certificate signing request that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#annotations CertificateSigningRequestV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#generate_name CertificateSigningRequestV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the certificate signing request.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#labels CertificateSigningRequestV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the certificate signing request, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#name CertificateSigningRequestV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function certificateSigningRequestV1MetadataToTerraform(struct?: CertificateSigningRequestV1MetadataOutputReference | CertificateSigningRequestV1Metadata): any;
/**
 * @stability stable
 */
export declare class CertificateSigningRequestV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateSigningRequestV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateSigningRequestV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestV1Spec {
    /**
     * request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block.
     *
     * When serialized as JSON or YAML, the data is additionally base64-encoded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#request CertificateSigningRequestV1#request}
     *
     * @stability stable
     */
    readonly request: string;
    /**
     * signerName indicates the requested signer, and is a qualified name.
     *
     * List/watch requests for CertificateSigningRequests can filter on this field using a "spec.signerName=NAME" fieldSelector.
     *
     * Well-known Kubernetes signers are:
     * 1. "kubernetes.io/kube-apiserver-client": issues client certificates that can be used to authenticate to kube-apiserver.
     * Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the "csrsigning" controller in kube-controller-manager.
     * 2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates that kubelets use to authenticate to kube-apiserver.
     * Requests for this signer can be auto-approved by the "csrapproving" controller in kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
     * 3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.
     * Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
     *
     * More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers
     *
     * Custom signerNames can also be specified. The signer defines:
     * 1. Trust distribution: how trust (CA bundles) are distributed.
     * 2. Permitted subjects: and behavior when a disallowed subject is requested.
     * 3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.
     * 4. Required, permitted, or forbidden key usages / extended key usages.
     * 5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.
     * 6. Whether or not requests for CA certificates are allowed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#signer_name CertificateSigningRequestV1#signer_name}
     *
     * @stability stable
     */
    readonly signerName: string;
    /**
     * usages specifies a set of key usages requested in the issued certificate.
     *
     * Requests for TLS client certificates typically request: "digital signature", "key encipherment", "client auth".
     *
     * Requests for TLS serving certificates typically request: "key encipherment", "digital signature", "server auth".
     *
     * Valid values are:
     * "signing", "digital signature", "content commitment",
     * "key encipherment", "key agreement", "data encipherment",
     * "cert sign", "crl sign", "encipher only", "decipher only", "any",
     * "server auth", "client auth",
     * "code signing", "email protection", "s/mime",
     * "ipsec end system", "ipsec tunnel", "ipsec user",
     * "timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#usages CertificateSigningRequestV1#usages}
     *
     * @stability stable
     */
    readonly usages?: string[];
}
export declare function certificateSigningRequestV1SpecToTerraform(struct?: CertificateSigningRequestV1SpecOutputReference | CertificateSigningRequestV1Spec): any;
/**
 * @stability stable
 */
export declare class CertificateSigningRequestV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateSigningRequestV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateSigningRequestV1Spec | undefined);
    private _request?;
    /**
     * @stability stable
     */
    get request(): string;
    /**
     * @stability stable
     */
    set request(value: string);
    /**
     * @stability stable
     */
    get requestInput(): string | undefined;
    private _signerName?;
    /**
     * @stability stable
     */
    get signerName(): string;
    /**
     * @stability stable
     */
    set signerName(value: string);
    /**
     * @stability stable
     */
    get signerNameInput(): string | undefined;
    private _usages?;
    /**
     * @stability stable
     */
    get usages(): string[];
    /**
     * @stability stable
     */
    set usages(value: string[]);
    /**
     * @stability stable
     */
    resetUsages(): void;
    /**
     * @stability stable
     */
    get usagesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html#create CertificateSigningRequestV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function certificateSigningRequestV1TimeoutsToTerraform(struct?: CertificateSigningRequestV1TimeoutsOutputReference | CertificateSigningRequestV1Timeouts): any;
/**
 * @stability stable
 */
export declare class CertificateSigningRequestV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateSigningRequestV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateSigningRequestV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html kubernetes_certificate_signing_request_v1}.
 *
 * @stability stable
 */
export declare class CertificateSigningRequestV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request_v1.html kubernetes_certificate_signing_request_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CertificateSigningRequestV1Config);
    private _autoApprove?;
    /**
     * @stability stable
     */
    get autoApprove(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoApprove(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutoApprove(): void;
    /**
     * @stability stable
     */
    get autoApproveInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get certificate(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): CertificateSigningRequestV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: CertificateSigningRequestV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): CertificateSigningRequestV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): CertificateSigningRequestV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: CertificateSigningRequestV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): CertificateSigningRequestV1Spec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): CertificateSigningRequestV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: CertificateSigningRequestV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CertificateSigningRequestV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
