import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CertificateSigningRequestConfig extends cdktf.TerraformMetaArguments {
    /**
     * Automatically approve the CertificateSigningRequest.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#auto_approve CertificateSigningRequest#auto_approve}
     *
     * @stability stable
     */
    readonly autoApprove?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#metadata CertificateSigningRequest#metadata}
     *
     * @stability stable
     */
    readonly metadata: CertificateSigningRequestMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#spec CertificateSigningRequest#spec}
     *
     * @stability stable
     */
    readonly spec: CertificateSigningRequestSpec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#timeouts CertificateSigningRequest#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CertificateSigningRequestTimeouts;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestMetadata {
    /**
     * An unstructured key value map stored with the certificate signing request that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#annotations CertificateSigningRequest#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#generate_name CertificateSigningRequest#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the certificate signing request.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#labels CertificateSigningRequest#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the certificate signing request, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#name CertificateSigningRequest#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function certificateSigningRequestMetadataToTerraform(struct?: CertificateSigningRequestMetadataOutputReference | CertificateSigningRequestMetadata): any;
/**
 * @stability stable
 */
export declare class CertificateSigningRequestMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateSigningRequestMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateSigningRequestMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestSpec {
    /**
     * Base64-encoded PKCS#10 CSR data.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#request CertificateSigningRequest#request}
     *
     * @stability stable
     */
    readonly request: string;
    /**
     * Requested signer for the request.
     *
     * It is a qualified name in the form: `scope-hostname.io/name`.If empty, it will be defaulted: 1. If it's a kubelet client certificate, it is assigned `kubernetes.io/kube-apiserver-client-kubelet`.2. If it's a kubelet serving certificate, it is assigned `kubernetes.io/kubelet-serving`.3. Otherwise, it is assigned `kubernetes.io/legacy-unknown`. Distribution of trust for signers happens out of band.You can select on this field using `spec.signerName`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#signer_name CertificateSigningRequest#signer_name}
     *
     * @stability stable
     */
    readonly signerName?: string;
    /**
     * allowedUsages specifies a set of usage contexts the key will be valid for.
     *
     * See: https://tools.ietf.org/html/rfc5280#section-4.2.1.3
     *   https://tools.ietf.org/html/rfc5280#section-4.2.1.12
     * Valid values are:
     * "signing",
     * "digital signature",
     * "content commitment",
     * "key encipherment",
     * "key agreement",
     * "data encipherment",
     * "cert sign",
     * "crl sign",
     * "encipher only",
     * "decipher only",
     * "any",
     * "server auth",
     * "client auth",
     * "code signing",
     * "email protection",
     * "s/mime",
     * "ipsec end system",
     * "ipsec tunnel",
     * "ipsec user",
     * "timestamping",
     * "ocsp signing",
     * "microsoft sgc",
     * "netscape sgc"
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#usages CertificateSigningRequest#usages}
     *
     * @stability stable
     */
    readonly usages?: string[];
}
export declare function certificateSigningRequestSpecToTerraform(struct?: CertificateSigningRequestSpecOutputReference | CertificateSigningRequestSpec): any;
/**
 * @stability stable
 */
export declare class CertificateSigningRequestSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateSigningRequestSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateSigningRequestSpec | undefined);
    private _request?;
    /**
     * @stability stable
     */
    get request(): string;
    /**
     * @stability stable
     */
    set request(value: string);
    /**
     * @stability stable
     */
    get requestInput(): string | undefined;
    private _signerName?;
    /**
     * @stability stable
     */
    get signerName(): string;
    /**
     * @stability stable
     */
    set signerName(value: string);
    /**
     * @stability stable
     */
    resetSignerName(): void;
    /**
     * @stability stable
     */
    get signerNameInput(): string | undefined;
    private _usages?;
    /**
     * @stability stable
     */
    get usages(): string[];
    /**
     * @stability stable
     */
    set usages(value: string[]);
    /**
     * @stability stable
     */
    resetUsages(): void;
    /**
     * @stability stable
     */
    get usagesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html#create CertificateSigningRequest#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function certificateSigningRequestTimeoutsToTerraform(struct?: CertificateSigningRequestTimeoutsOutputReference | CertificateSigningRequestTimeouts): any;
/**
 * @stability stable
 */
export declare class CertificateSigningRequestTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateSigningRequestTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateSigningRequestTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html kubernetes_certificate_signing_request}.
 *
 * @stability stable
 */
export declare class CertificateSigningRequest extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/certificate_signing_request.html kubernetes_certificate_signing_request} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CertificateSigningRequestConfig);
    private _autoApprove?;
    /**
     * @stability stable
     */
    get autoApprove(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoApprove(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutoApprove(): void;
    /**
     * @stability stable
     */
    get autoApproveInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get certificate(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): CertificateSigningRequestMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: CertificateSigningRequestMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): CertificateSigningRequestMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): CertificateSigningRequestSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: CertificateSigningRequestSpec): void;
    /**
     * @stability stable
     */
    get specInput(): CertificateSigningRequestSpec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): CertificateSigningRequestTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: CertificateSigningRequestTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CertificateSigningRequestTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
