import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ClusterRoleBindingV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#metadata ClusterRoleBindingV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: ClusterRoleBindingV1Metadata;
    /**
     * role_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#role_ref ClusterRoleBindingV1#role_ref}
     *
     * @stability stable
     */
    readonly roleRef: ClusterRoleBindingV1RoleRef;
    /**
     * subject block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#subject ClusterRoleBindingV1#subject}
     *
     * @stability stable
     */
    readonly subject: ClusterRoleBindingV1Subject[];
}
/**
 * @stability stable
 */
export interface ClusterRoleBindingV1Metadata {
    /**
     * An unstructured key value map stored with the clusterRoleBinding that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#annotations ClusterRoleBindingV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the clusterRoleBinding.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#labels ClusterRoleBindingV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the clusterRoleBinding, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#name ClusterRoleBindingV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function clusterRoleBindingV1MetadataToTerraform(struct?: ClusterRoleBindingV1MetadataOutputReference | ClusterRoleBindingV1Metadata): any;
/**
 * @stability stable
 */
export declare class ClusterRoleBindingV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ClusterRoleBindingV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ClusterRoleBindingV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ClusterRoleBindingV1RoleRef {
    /**
     * The API group of the user. The only value possible at the moment is `rbac.authorization.k8s.io`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#api_group ClusterRoleBindingV1#api_group}
     *
     * @stability stable
     */
    readonly apiGroup: string;
    /**
     * The kind of resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#kind ClusterRoleBindingV1#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the User to bind to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#name ClusterRoleBindingV1#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function clusterRoleBindingV1RoleRefToTerraform(struct?: ClusterRoleBindingV1RoleRefOutputReference | ClusterRoleBindingV1RoleRef): any;
/**
 * @stability stable
 */
export declare class ClusterRoleBindingV1RoleRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ClusterRoleBindingV1RoleRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ClusterRoleBindingV1RoleRef | undefined);
    private _apiGroup?;
    /**
     * @stability stable
     */
    get apiGroup(): string;
    /**
     * @stability stable
     */
    set apiGroup(value: string);
    /**
     * @stability stable
     */
    get apiGroupInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ClusterRoleBindingV1Subject {
    /**
     * The API group of the subject resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#api_group ClusterRoleBindingV1#api_group}
     *
     * @stability stable
     */
    readonly apiGroup?: string;
    /**
     * The kind of resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#kind ClusterRoleBindingV1#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the resource to bind to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#name ClusterRoleBindingV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The Namespace of the subject resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html#namespace ClusterRoleBindingV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function clusterRoleBindingV1SubjectToTerraform(struct?: ClusterRoleBindingV1Subject): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html kubernetes_cluster_role_binding_v1}.
 *
 * @stability stable
 */
export declare class ClusterRoleBindingV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_binding_v1.html kubernetes_cluster_role_binding_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ClusterRoleBindingV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ClusterRoleBindingV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ClusterRoleBindingV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ClusterRoleBindingV1Metadata | undefined;
    private _roleRef;
    /**
     * @stability stable
     */
    get roleRef(): ClusterRoleBindingV1RoleRefOutputReference;
    /**
     * @stability stable
     */
    putRoleRef(value: ClusterRoleBindingV1RoleRef): void;
    /**
     * @stability stable
     */
    get roleRefInput(): ClusterRoleBindingV1RoleRef | undefined;
    private _subject?;
    /**
     * @stability stable
     */
    get subject(): ClusterRoleBindingV1Subject[];
    /**
     * @stability stable
     */
    set subject(value: ClusterRoleBindingV1Subject[]);
    /**
     * @stability stable
     */
    get subjectInput(): ClusterRoleBindingV1Subject[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
