import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ClusterRoleV1Config extends cdktf.TerraformMetaArguments {
    /**
     * aggregation_rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#aggregation_rule ClusterRoleV1#aggregation_rule}
     *
     * @stability stable
     */
    readonly aggregationRule?: ClusterRoleV1AggregationRule;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#metadata ClusterRoleV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: ClusterRoleV1Metadata;
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#rule ClusterRoleV1#rule}
     *
     * @stability stable
     */
    readonly rule?: ClusterRoleV1Rule[];
}
/**
 * @stability stable
 */
export interface ClusterRoleV1AggregationRuleClusterRoleSelectorsMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#key ClusterRoleV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#operator ClusterRoleV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#values ClusterRoleV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function clusterRoleV1AggregationRuleClusterRoleSelectorsMatchExpressionsToTerraform(struct?: ClusterRoleV1AggregationRuleClusterRoleSelectorsMatchExpressions): any;
/**
 * @stability stable
 */
export interface ClusterRoleV1AggregationRuleClusterRoleSelectors {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#match_labels ClusterRoleV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#match_expressions ClusterRoleV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: ClusterRoleV1AggregationRuleClusterRoleSelectorsMatchExpressions[];
}
export declare function clusterRoleV1AggregationRuleClusterRoleSelectorsToTerraform(struct?: ClusterRoleV1AggregationRuleClusterRoleSelectors): any;
/**
 * @stability stable
 */
export interface ClusterRoleV1AggregationRule {
    /**
     * cluster_role_selectors block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#cluster_role_selectors ClusterRoleV1#cluster_role_selectors}
     *
     * @stability stable
     */
    readonly clusterRoleSelectors?: ClusterRoleV1AggregationRuleClusterRoleSelectors[];
}
export declare function clusterRoleV1AggregationRuleToTerraform(struct?: ClusterRoleV1AggregationRuleOutputReference | ClusterRoleV1AggregationRule): any;
/**
 * @stability stable
 */
export declare class ClusterRoleV1AggregationRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ClusterRoleV1AggregationRule | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ClusterRoleV1AggregationRule | undefined);
    private _clusterRoleSelectors?;
    /**
     * @stability stable
     */
    get clusterRoleSelectors(): ClusterRoleV1AggregationRuleClusterRoleSelectors[];
    /**
     * @stability stable
     */
    set clusterRoleSelectors(value: ClusterRoleV1AggregationRuleClusterRoleSelectors[]);
    /**
     * @stability stable
     */
    resetClusterRoleSelectors(): void;
    /**
     * @stability stable
     */
    get clusterRoleSelectorsInput(): ClusterRoleV1AggregationRuleClusterRoleSelectors[] | undefined;
}
/**
 * @stability stable
 */
export interface ClusterRoleV1Metadata {
    /**
     * An unstructured key value map stored with the clusterRole that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#annotations ClusterRoleV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the clusterRole.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#labels ClusterRoleV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the clusterRole, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#name ClusterRoleV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function clusterRoleV1MetadataToTerraform(struct?: ClusterRoleV1MetadataOutputReference | ClusterRoleV1Metadata): any;
/**
 * @stability stable
 */
export declare class ClusterRoleV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ClusterRoleV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ClusterRoleV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ClusterRoleV1Rule {
    /**
     * APIGroups is the name of the APIGroup that contains the resources.
     *
     * If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#api_groups ClusterRoleV1#api_groups}
     *
     * @stability stable
     */
    readonly apiGroups?: string[];
    /**
     * NonResourceURLs is a set of partial urls that a user should have access to.
     *
     * *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"), but not both.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#non_resource_urls ClusterRoleV1#non_resource_urls}
     *
     * @stability stable
     */
    readonly nonResourceUrls?: string[];
    /**
     * ResourceNames is an optional white list of names that the rule applies to.
     *
     * An empty set means that everything is allowed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#resource_names ClusterRoleV1#resource_names}
     *
     * @stability stable
     */
    readonly resourceNames?: string[];
    /**
     * Resources is a list of resources this rule applies to. ResourceAll represents all resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#resources ClusterRoleV1#resources}
     *
     * @stability stable
     */
    readonly resources?: string[];
    /**
     * Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.
     *
     * VerbAll represents all kinds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html#verbs ClusterRoleV1#verbs}
     *
     * @stability stable
     */
    readonly verbs: string[];
}
export declare function clusterRoleV1RuleToTerraform(struct?: ClusterRoleV1Rule): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html kubernetes_cluster_role_v1}.
 *
 * @stability stable
 */
export declare class ClusterRoleV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/cluster_role_v1.html kubernetes_cluster_role_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ClusterRoleV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _aggregationRule;
    /**
     * @stability stable
     */
    get aggregationRule(): ClusterRoleV1AggregationRuleOutputReference;
    /**
     * @stability stable
     */
    putAggregationRule(value: ClusterRoleV1AggregationRule): void;
    /**
     * @stability stable
     */
    resetAggregationRule(): void;
    /**
     * @stability stable
     */
    get aggregationRuleInput(): ClusterRoleV1AggregationRule | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ClusterRoleV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ClusterRoleV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ClusterRoleV1Metadata | undefined;
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): ClusterRoleV1Rule[];
    /**
     * @stability stable
     */
    set rule(value: ClusterRoleV1Rule[]);
    /**
     * @stability stable
     */
    resetRule(): void;
    /**
     * @stability stable
     */
    get ruleInput(): ClusterRoleV1Rule[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
