import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CsiDriverV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#metadata CsiDriverV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: CsiDriverV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#spec CsiDriverV1#spec}
     *
     * @stability stable
     */
    readonly spec?: CsiDriverV1Spec;
}
/**
 * @stability stable
 */
export interface CsiDriverV1Metadata {
    /**
     * An unstructured key value map stored with the csi driver that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#annotations CsiDriverV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#generate_name CsiDriverV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the csi driver.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#labels CsiDriverV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the csi driver, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#name CsiDriverV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function csiDriverV1MetadataToTerraform(struct?: CsiDriverV1MetadataOutputReference | CsiDriverV1Metadata): any;
/**
 * @stability stable
 */
export declare class CsiDriverV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CsiDriverV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CsiDriverV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CsiDriverV1Spec {
    /**
     * Indicates if the CSI volume driver requires an attach operation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#attach_required CsiDriverV1#attach_required}
     *
     * @stability stable
     */
    readonly attachRequired: boolean | cdktf.IResolvable;
    /**
     * Indicates that the CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#pod_info_on_mount CsiDriverV1#pod_info_on_mount}
     *
     * @stability stable
     */
    readonly podInfoOnMount?: boolean | cdktf.IResolvable;
    /**
     * Defines what kind of volumes this CSI volume driver supports.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html#volume_lifecycle_modes CsiDriverV1#volume_lifecycle_modes}
     *
     * @stability stable
     */
    readonly volumeLifecycleModes?: string[];
}
export declare function csiDriverV1SpecToTerraform(struct?: CsiDriverV1SpecOutputReference | CsiDriverV1Spec): any;
/**
 * @stability stable
 */
export declare class CsiDriverV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CsiDriverV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CsiDriverV1Spec | undefined);
    private _attachRequired?;
    /**
     * @stability stable
     */
    get attachRequired(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set attachRequired(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get attachRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _podInfoOnMount?;
    /**
     * @stability stable
     */
    get podInfoOnMount(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set podInfoOnMount(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPodInfoOnMount(): void;
    /**
     * @stability stable
     */
    get podInfoOnMountInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeLifecycleModes?;
    /**
     * @stability stable
     */
    get volumeLifecycleModes(): string[];
    /**
     * @stability stable
     */
    set volumeLifecycleModes(value: string[]);
    /**
     * @stability stable
     */
    resetVolumeLifecycleModes(): void;
    /**
     * @stability stable
     */
    get volumeLifecycleModesInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html kubernetes_csi_driver_v1}.
 *
 * @stability stable
 */
export declare class CsiDriverV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1.html kubernetes_csi_driver_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CsiDriverV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): CsiDriverV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: CsiDriverV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): CsiDriverV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): CsiDriverV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: CsiDriverV1Spec): void;
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): CsiDriverV1Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
