import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesIngressConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress.html#metadata DataKubernetesIngress#metadata}
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesIngressMetadata;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressSpecBackend extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    get servicePort(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressSpecRuleHttpPathBackend extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    get servicePort(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressSpecRuleHttpPath extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get backend(): any;
    /**
     * @stability stable
     */
    get path(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressSpecRuleHttp extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get path(): any;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressSpecRule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    get http(): any;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressSpecTls extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hosts(): string[];
    /**
     * @stability stable
     */
    get secretName(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressSpec extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get backend(): any;
    /**
     * @stability stable
     */
    get ingressClassName(): string;
    /**
     * @stability stable
     */
    get rule(): any;
    /**
     * @stability stable
     */
    get tls(): any;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressStatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class DataKubernetesIngressStatus extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface DataKubernetesIngressMetadata {
    /**
     * An unstructured key value map stored with the ingress that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress.html#annotations DataKubernetesIngress#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress.html#labels DataKubernetesIngress#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the ingress, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress.html#name DataKubernetesIngress#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the ingress must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress.html#namespace DataKubernetesIngress#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function dataKubernetesIngressMetadataToTerraform(struct?: DataKubernetesIngressMetadataOutputReference | DataKubernetesIngressMetadata): any;
/**
 * @stability stable
 */
export declare class DataKubernetesIngressMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataKubernetesIngressMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataKubernetesIngressMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress.html kubernetes_ingress}.
 *
 * @stability stable
 */
export declare class DataKubernetesIngress extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress.html kubernetes_ingress} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesIngressConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    spec(index: string): DataKubernetesIngressSpec;
    /**
     * @stability stable
     */
    status(index: string): DataKubernetesIngressStatus;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesIngressMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: DataKubernetesIngressMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesIngressMetadata | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
