import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesServiceV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1.html#metadata DataKubernetesServiceV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesServiceV1Metadata;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceV1SpecPort extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get nodePort(): number;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    get targetPort(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceV1Spec extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get clusterIp(): string;
    /**
     * @stability stable
     */
    get externalIps(): string[];
    /**
     * @stability stable
     */
    get externalName(): string;
    /**
     * @stability stable
     */
    get externalTrafficPolicy(): string;
    /**
     * @stability stable
     */
    get healthCheckNodePort(): number;
    /**
     * @stability stable
     */
    get loadBalancerIp(): string;
    /**
     * @stability stable
     */
    get loadBalancerSourceRanges(): string[];
    /**
     * @stability stable
     */
    get port(): any;
    /**
     * @stability stable
     */
    get publishNotReadyAddresses(): any;
    /**
     * @stability stable
     */
    get selector(): any;
    /**
     * @stability stable
     */
    get sessionAffinity(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceV1StatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceV1StatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceV1Status extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface DataKubernetesServiceV1Metadata {
    /**
     * An unstructured key value map stored with the service that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1.html#annotations DataKubernetesServiceV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1.html#labels DataKubernetesServiceV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the service, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1.html#name DataKubernetesServiceV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1.html#namespace DataKubernetesServiceV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function dataKubernetesServiceV1MetadataToTerraform(struct?: DataKubernetesServiceV1MetadataOutputReference | DataKubernetesServiceV1Metadata): any;
/**
 * @stability stable
 */
export declare class DataKubernetesServiceV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataKubernetesServiceV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataKubernetesServiceV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1.html kubernetes_service_v1}.
 *
 * @stability stable
 */
export declare class DataKubernetesServiceV1 extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1.html kubernetes_service_v1} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesServiceV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    spec(index: string): DataKubernetesServiceV1Spec;
    /**
     * @stability stable
     */
    status(index: string): DataKubernetesServiceV1Status;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesServiceV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: DataKubernetesServiceV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesServiceV1Metadata | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
