import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassConfig extends cdktf.TerraformMetaArguments {
    /**
     * Indicates whether the storage class allow volume expand.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#allow_volume_expansion DataKubernetesStorageClass#allow_volume_expansion}
     *
     * @stability stable
     */
    readonly allowVolumeExpansion?: boolean | cdktf.IResolvable;
    /**
     * Persistent Volumes that are dynamically created by a storage class will have the mount options specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#mount_options DataKubernetesStorageClass#mount_options}
     *
     * @stability stable
     */
    readonly mountOptions?: string[];
    /**
     * The parameters for the provisioner that should create volumes of this storage class.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#parameters DataKubernetesStorageClass#parameters}
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Indicates the type of the reclaim policy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#reclaim_policy DataKubernetesStorageClass#reclaim_policy}
     *
     * @stability stable
     */
    readonly reclaimPolicy?: string;
    /**
     * Indicates when volume binding and dynamic provisioning should occur.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#volume_binding_mode DataKubernetesStorageClass#volume_binding_mode}
     *
     * @stability stable
     */
    readonly volumeBindingMode?: string;
    /**
     * allowed_topologies block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#allowed_topologies DataKubernetesStorageClass#allowed_topologies}
     *
     * @stability stable
     */
    readonly allowedTopologies?: DataKubernetesStorageClassAllowedTopologies;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#metadata DataKubernetesStorageClass#metadata}
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesStorageClassMetadata;
}
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#key DataKubernetesStorageClass#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * An array of string values. One value must match the label to be selected.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#values DataKubernetesStorageClass#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function dataKubernetesStorageClassAllowedTopologiesMatchLabelExpressionsToTerraform(struct?: DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions): any;
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassAllowedTopologies {
    /**
     * match_label_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#match_label_expressions DataKubernetesStorageClass#match_label_expressions}
     *
     * @stability stable
     */
    readonly matchLabelExpressions?: DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions[];
}
export declare function dataKubernetesStorageClassAllowedTopologiesToTerraform(struct?: DataKubernetesStorageClassAllowedTopologiesOutputReference | DataKubernetesStorageClassAllowedTopologies): any;
/**
 * @stability stable
 */
export declare class DataKubernetesStorageClassAllowedTopologiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataKubernetesStorageClassAllowedTopologies | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataKubernetesStorageClassAllowedTopologies | undefined);
    private _matchLabelExpressions?;
    /**
     * @stability stable
     */
    get matchLabelExpressions(): DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions[];
    /**
     * @stability stable
     */
    set matchLabelExpressions(value: DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions[]);
    /**
     * @stability stable
     */
    resetMatchLabelExpressions(): void;
    /**
     * @stability stable
     */
    get matchLabelExpressionsInput(): DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassMetadata {
    /**
     * An unstructured key value map stored with the storage class that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#annotations DataKubernetesStorageClass#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the storage class.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#labels DataKubernetesStorageClass#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the storage class, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html#name DataKubernetesStorageClass#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function dataKubernetesStorageClassMetadataToTerraform(struct?: DataKubernetesStorageClassMetadataOutputReference | DataKubernetesStorageClassMetadata): any;
/**
 * @stability stable
 */
export declare class DataKubernetesStorageClassMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataKubernetesStorageClassMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataKubernetesStorageClassMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html kubernetes_storage_class}.
 *
 * @stability stable
 */
export declare class DataKubernetesStorageClass extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/storage_class.html kubernetes_storage_class} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesStorageClassConfig);
    private _allowVolumeExpansion?;
    /**
     * @stability stable
     */
    get allowVolumeExpansion(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowVolumeExpansion(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowVolumeExpansion(): void;
    /**
     * @stability stable
     */
    get allowVolumeExpansionInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _mountOptions?;
    /**
     * @stability stable
     */
    get mountOptions(): string[];
    /**
     * @stability stable
     */
    set mountOptions(value: string[]);
    /**
     * @stability stable
     */
    resetMountOptions(): void;
    /**
     * @stability stable
     */
    get mountOptionsInput(): string[] | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _reclaimPolicy?;
    /**
     * @stability stable
     */
    get reclaimPolicy(): string;
    /**
     * @stability stable
     */
    set reclaimPolicy(value: string);
    /**
     * @stability stable
     */
    resetReclaimPolicy(): void;
    /**
     * @stability stable
     */
    get reclaimPolicyInput(): string | undefined;
    /**
     * @stability stable
     */
    get storageProvisioner(): string;
    private _volumeBindingMode?;
    /**
     * @stability stable
     */
    get volumeBindingMode(): string;
    /**
     * @stability stable
     */
    set volumeBindingMode(value: string);
    /**
     * @stability stable
     */
    resetVolumeBindingMode(): void;
    /**
     * @stability stable
     */
    get volumeBindingModeInput(): string | undefined;
    private _allowedTopologies;
    /**
     * @stability stable
     */
    get allowedTopologies(): DataKubernetesStorageClassAllowedTopologiesOutputReference;
    /**
     * @stability stable
     */
    putAllowedTopologies(value: DataKubernetesStorageClassAllowedTopologies): void;
    /**
     * @stability stable
     */
    resetAllowedTopologies(): void;
    /**
     * @stability stable
     */
    get allowedTopologiesInput(): DataKubernetesStorageClassAllowedTopologies | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesStorageClassMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: DataKubernetesStorageClassMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesStorageClassMetadata | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
