import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DefaultServiceAccountV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Enable automatic mounting of the service account token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#automount_service_account_token DefaultServiceAccountV1#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean | cdktf.IResolvable;
    /**
     * image_pull_secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#image_pull_secret DefaultServiceAccountV1#image_pull_secret}
     *
     * @stability stable
     */
    readonly imagePullSecret?: DefaultServiceAccountV1ImagePullSecret[];
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#metadata DefaultServiceAccountV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: DefaultServiceAccountV1Metadata;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#secret DefaultServiceAccountV1#secret}
     *
     * @stability stable
     */
    readonly secret?: DefaultServiceAccountV1Secret[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#timeouts DefaultServiceAccountV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DefaultServiceAccountV1Timeouts;
}
/**
 * @stability stable
 */
export interface DefaultServiceAccountV1ImagePullSecret {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#name DefaultServiceAccountV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function defaultServiceAccountV1ImagePullSecretToTerraform(struct?: DefaultServiceAccountV1ImagePullSecret): any;
/**
 * @stability stable
 */
export interface DefaultServiceAccountV1Metadata {
    /**
     * An unstructured key value map stored with the service account that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#annotations DefaultServiceAccountV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service account.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#labels DefaultServiceAccountV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the service account, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#name DefaultServiceAccountV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service account must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#namespace DefaultServiceAccountV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function defaultServiceAccountV1MetadataToTerraform(struct?: DefaultServiceAccountV1MetadataOutputReference | DefaultServiceAccountV1Metadata): any;
/**
 * @stability stable
 */
export declare class DefaultServiceAccountV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DefaultServiceAccountV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DefaultServiceAccountV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DefaultServiceAccountV1Secret {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#name DefaultServiceAccountV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function defaultServiceAccountV1SecretToTerraform(struct?: DefaultServiceAccountV1Secret): any;
/**
 * @stability stable
 */
export interface DefaultServiceAccountV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html#create DefaultServiceAccountV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function defaultServiceAccountV1TimeoutsToTerraform(struct?: DefaultServiceAccountV1TimeoutsOutputReference | DefaultServiceAccountV1Timeouts): any;
/**
 * @stability stable
 */
export declare class DefaultServiceAccountV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DefaultServiceAccountV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DefaultServiceAccountV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html kubernetes_default_service_account_v1}.
 *
 * @stability stable
 */
export declare class DefaultServiceAccountV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/default_service_account_v1.html kubernetes_default_service_account_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DefaultServiceAccountV1Config);
    private _automountServiceAccountToken?;
    /**
     * @stability stable
     */
    get automountServiceAccountToken(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set automountServiceAccountToken(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutomountServiceAccountToken(): void;
    /**
     * @stability stable
     */
    get automountServiceAccountTokenInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get defaultSecretName(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _imagePullSecret?;
    /**
     * @stability stable
     */
    get imagePullSecret(): DefaultServiceAccountV1ImagePullSecret[];
    /**
     * @stability stable
     */
    set imagePullSecret(value: DefaultServiceAccountV1ImagePullSecret[]);
    /**
     * @stability stable
     */
    resetImagePullSecret(): void;
    /**
     * @stability stable
     */
    get imagePullSecretInput(): DefaultServiceAccountV1ImagePullSecret[] | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DefaultServiceAccountV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: DefaultServiceAccountV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): DefaultServiceAccountV1Metadata | undefined;
    private _secret?;
    /**
     * @stability stable
     */
    get secret(): DefaultServiceAccountV1Secret[];
    /**
     * @stability stable
     */
    set secret(value: DefaultServiceAccountV1Secret[]);
    /**
     * @stability stable
     */
    resetSecret(): void;
    /**
     * @stability stable
     */
    get secretInput(): DefaultServiceAccountV1Secret[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DefaultServiceAccountV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DefaultServiceAccountV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DefaultServiceAccountV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
