import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EndpointsV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#metadata EndpointsV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: EndpointsV1Metadata;
    /**
     * subset block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#subset EndpointsV1#subset}
     *
     * @stability stable
     */
    readonly subset?: EndpointsV1Subset[];
}
/**
 * @stability stable
 */
export interface EndpointsV1Metadata {
    /**
     * An unstructured key value map stored with the endpoints that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#annotations EndpointsV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#generate_name EndpointsV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the endpoints.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#labels EndpointsV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the endpoints, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#name EndpointsV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the endpoints must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#namespace EndpointsV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function endpointsV1MetadataToTerraform(struct?: EndpointsV1MetadataOutputReference | EndpointsV1Metadata): any;
/**
 * @stability stable
 */
export declare class EndpointsV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EndpointsV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EndpointsV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EndpointsV1SubsetAddress {
    /**
     * The Hostname of this endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#hostname EndpointsV1#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * The IP of this endpoint. May not be loopback (127.0.0.0/8), link-local (169.254.0.0/16), or link-local multicast ((224.0.0.0/24).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#ip EndpointsV1#ip}
     *
     * @stability stable
     */
    readonly ip: string;
    /**
     * Node hosting this endpoint. This can be used to determine endpoints local to a node.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#node_name EndpointsV1#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
}
export declare function endpointsV1SubsetAddressToTerraform(struct?: EndpointsV1SubsetAddress): any;
/**
 * @stability stable
 */
export interface EndpointsV1SubsetNotReadyAddress {
    /**
     * The Hostname of this endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#hostname EndpointsV1#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * The IP of this endpoint. May not be loopback (127.0.0.0/8), link-local (169.254.0.0/16), or link-local multicast ((224.0.0.0/24).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#ip EndpointsV1#ip}
     *
     * @stability stable
     */
    readonly ip: string;
    /**
     * Node hosting this endpoint. This can be used to determine endpoints local to a node.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#node_name EndpointsV1#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
}
export declare function endpointsV1SubsetNotReadyAddressToTerraform(struct?: EndpointsV1SubsetNotReadyAddress): any;
/**
 * @stability stable
 */
export interface EndpointsV1SubsetPort {
    /**
     * The name of this port within the endpoint.
     *
     * Must be a DNS_LABEL. Optional if only one Port is defined on this endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#name EndpointsV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The port that will be exposed by this endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#port EndpointsV1#port}
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * The IP protocol for this port. Supports `TCP` and `UDP`. Default is `TCP`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#protocol EndpointsV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function endpointsV1SubsetPortToTerraform(struct?: EndpointsV1SubsetPort): any;
/**
 * @stability stable
 */
export interface EndpointsV1Subset {
    /**
     * address block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#address EndpointsV1#address}
     *
     * @stability stable
     */
    readonly address?: EndpointsV1SubsetAddress[];
    /**
     * not_ready_address block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#not_ready_address EndpointsV1#not_ready_address}
     *
     * @stability stable
     */
    readonly notReadyAddress?: EndpointsV1SubsetNotReadyAddress[];
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html#port EndpointsV1#port}
     *
     * @stability stable
     */
    readonly port?: EndpointsV1SubsetPort[];
}
export declare function endpointsV1SubsetToTerraform(struct?: EndpointsV1Subset): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html kubernetes_endpoints_v1}.
 *
 * @stability stable
 */
export declare class EndpointsV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/endpoints_v1.html kubernetes_endpoints_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EndpointsV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): EndpointsV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: EndpointsV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): EndpointsV1Metadata | undefined;
    private _subset?;
    /**
     * @stability stable
     */
    get subset(): EndpointsV1Subset[];
    /**
     * @stability stable
     */
    set subset(value: EndpointsV1Subset[]);
    /**
     * @stability stable
     */
    resetSubset(): void;
    /**
     * @stability stable
     */
    get subsetInput(): EndpointsV1Subset[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
