import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#metadata HorizontalPodAutoscalerV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: HorizontalPodAutoscalerV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#spec HorizontalPodAutoscalerV1#spec}
     *
     * @stability stable
     */
    readonly spec: HorizontalPodAutoscalerV1Spec;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV1Metadata {
    /**
     * An unstructured key value map stored with the horizontal pod autoscaler that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#annotations HorizontalPodAutoscalerV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#generate_name HorizontalPodAutoscalerV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the horizontal pod autoscaler.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#labels HorizontalPodAutoscalerV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the horizontal pod autoscaler, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#name HorizontalPodAutoscalerV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the horizontal pod autoscaler must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#namespace HorizontalPodAutoscalerV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function horizontalPodAutoscalerV1MetadataToTerraform(struct?: HorizontalPodAutoscalerV1MetadataOutputReference | HorizontalPodAutoscalerV1Metadata): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV1SpecScaleTargetRef {
    /**
     * API version of the referent.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#api_version HorizontalPodAutoscalerV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Kind of the referent. e.g. `ReplicationController`. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#types-kinds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#kind HorizontalPodAutoscalerV1#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#name HorizontalPodAutoscalerV1#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function horizontalPodAutoscalerV1SpecScaleTargetRefToTerraform(struct?: HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference | HorizontalPodAutoscalerV1SpecScaleTargetRef): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV1SpecScaleTargetRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV1SpecScaleTargetRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV1Spec {
    /**
     * Upper limit for the number of pods that can be set by the autoscaler.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#max_replicas HorizontalPodAutoscalerV1#max_replicas}
     *
     * @stability stable
     */
    readonly maxReplicas: number;
    /**
     * Lower limit for the number of pods that can be set by the autoscaler, defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#min_replicas HorizontalPodAutoscalerV1#min_replicas}
     *
     * @stability stable
     */
    readonly minReplicas?: number;
    /**
     * Target average CPU utilization (represented as a percentage of requested CPU) over all the pods.
     *
     * If not specified the default autoscaling policy will be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#target_cpu_utilization_percentage HorizontalPodAutoscalerV1#target_cpu_utilization_percentage}
     *
     * @stability stable
     */
    readonly targetCpuUtilizationPercentage?: number;
    /**
     * scale_target_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html#scale_target_ref HorizontalPodAutoscalerV1#scale_target_ref}
     *
     * @stability stable
     */
    readonly scaleTargetRef: HorizontalPodAutoscalerV1SpecScaleTargetRef;
}
export declare function horizontalPodAutoscalerV1SpecToTerraform(struct?: HorizontalPodAutoscalerV1SpecOutputReference | HorizontalPodAutoscalerV1Spec): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV1Spec | undefined);
    private _maxReplicas?;
    /**
     * @stability stable
     */
    get maxReplicas(): number;
    /**
     * @stability stable
     */
    set maxReplicas(value: number);
    /**
     * @stability stable
     */
    get maxReplicasInput(): number | undefined;
    private _minReplicas?;
    /**
     * @stability stable
     */
    get minReplicas(): number;
    /**
     * @stability stable
     */
    set minReplicas(value: number);
    /**
     * @stability stable
     */
    resetMinReplicas(): void;
    /**
     * @stability stable
     */
    get minReplicasInput(): number | undefined;
    private _targetCpuUtilizationPercentage?;
    /**
     * @stability stable
     */
    get targetCpuUtilizationPercentage(): number;
    /**
     * @stability stable
     */
    set targetCpuUtilizationPercentage(value: number);
    /**
     * @stability stable
     */
    resetTargetCpuUtilizationPercentage(): void;
    /**
     * @stability stable
     */
    get targetCpuUtilizationPercentageInput(): number | undefined;
    private _scaleTargetRef;
    /**
     * @stability stable
     */
    get scaleTargetRef(): HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference;
    /**
     * @stability stable
     */
    putScaleTargetRef(value: HorizontalPodAutoscalerV1SpecScaleTargetRef): void;
    /**
     * @stability stable
     */
    get scaleTargetRefInput(): HorizontalPodAutoscalerV1SpecScaleTargetRef | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html kubernetes_horizontal_pod_autoscaler_v1}.
 *
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1.html kubernetes_horizontal_pod_autoscaler_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HorizontalPodAutoscalerV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): HorizontalPodAutoscalerV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: HorizontalPodAutoscalerV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): HorizontalPodAutoscalerV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): HorizontalPodAutoscalerV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: HorizontalPodAutoscalerV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): HorizontalPodAutoscalerV1Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
