import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#metadata HorizontalPodAutoscalerV2Beta2#metadata}
     *
     * @stability stable
     */
    readonly metadata: HorizontalPodAutoscalerV2Beta2Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#spec HorizontalPodAutoscalerV2Beta2#spec}
     *
     * @stability stable
     */
    readonly spec: HorizontalPodAutoscalerV2Beta2Spec;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2Metadata {
    /**
     * An unstructured key value map stored with the horizontal pod autoscaler that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#annotations HorizontalPodAutoscalerV2Beta2#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#generate_name HorizontalPodAutoscalerV2Beta2#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the horizontal pod autoscaler.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#labels HorizontalPodAutoscalerV2Beta2#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the horizontal pod autoscaler, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#name HorizontalPodAutoscalerV2Beta2#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the horizontal pod autoscaler must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#namespace HorizontalPodAutoscalerV2Beta2#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function horizontalPodAutoscalerV2Beta2MetadataToTerraform(struct?: HorizontalPodAutoscalerV2Beta2MetadataOutputReference | HorizontalPodAutoscalerV2Beta2Metadata): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDownPolicy {
    /**
     * Period specifies the window of time for which the policy should hold true.
     *
     * PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#period_seconds HorizontalPodAutoscalerV2Beta2#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds: number;
    /**
     * Type is used to specify the scaling policy: Percent or Pods.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#type HorizontalPodAutoscalerV2Beta2#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Value contains the amount of change which is permitted by the policy. It must be greater than zero.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#value HorizontalPodAutoscalerV2Beta2#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function horizontalPodAutoscalerV2Beta2SpecBehaviorScaleDownPolicyToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDownPolicy): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDown {
    /**
     * Used to specify which policy should be used. If not set, the default value Max is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#select_policy HorizontalPodAutoscalerV2Beta2#select_policy}
     *
     * @stability stable
     */
    readonly selectPolicy?: string;
    /**
     * Number of seconds for which past recommendations should be considered while scaling up or scaling down.
     *
     * This value must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#stabilization_window_seconds HorizontalPodAutoscalerV2Beta2#stabilization_window_seconds}
     *
     * @stability stable
     */
    readonly stabilizationWindowSeconds?: number;
    /**
     * policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#policy HorizontalPodAutoscalerV2Beta2#policy}
     *
     * @stability stable
     */
    readonly policy: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDownPolicy[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecBehaviorScaleDownToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDown): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUpPolicy {
    /**
     * Period specifies the window of time for which the policy should hold true.
     *
     * PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#period_seconds HorizontalPodAutoscalerV2Beta2#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds: number;
    /**
     * Type is used to specify the scaling policy: Percent or Pods.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#type HorizontalPodAutoscalerV2Beta2#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Value contains the amount of change which is permitted by the policy. It must be greater than zero.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#value HorizontalPodAutoscalerV2Beta2#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function horizontalPodAutoscalerV2Beta2SpecBehaviorScaleUpPolicyToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUpPolicy): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUp {
    /**
     * Used to specify which policy should be used. If not set, the default value Max is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#select_policy HorizontalPodAutoscalerV2Beta2#select_policy}
     *
     * @stability stable
     */
    readonly selectPolicy?: string;
    /**
     * Number of seconds for which past recommendations should be considered while scaling up or scaling down.
     *
     * This value must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#stabilization_window_seconds HorizontalPodAutoscalerV2Beta2#stabilization_window_seconds}
     *
     * @stability stable
     */
    readonly stabilizationWindowSeconds?: number;
    /**
     * policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#policy HorizontalPodAutoscalerV2Beta2#policy}
     *
     * @stability stable
     */
    readonly policy: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUpPolicy[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecBehaviorScaleUpToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUp): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecBehavior {
    /**
     * scale_down block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#scale_down HorizontalPodAutoscalerV2Beta2#scale_down}
     *
     * @stability stable
     */
    readonly scaleDown?: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDown[];
    /**
     * scale_up block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#scale_up HorizontalPodAutoscalerV2Beta2#scale_up}
     *
     * @stability stable
     */
    readonly scaleUp?: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUp[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecBehaviorToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecBehaviorOutputReference | HorizontalPodAutoscalerV2Beta2SpecBehavior): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecBehaviorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecBehavior | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecBehavior | undefined);
    private _scaleDown?;
    /**
     * @stability stable
     */
    get scaleDown(): HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDown[];
    /**
     * @stability stable
     */
    set scaleDown(value: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDown[]);
    /**
     * @stability stable
     */
    resetScaleDown(): void;
    /**
     * @stability stable
     */
    get scaleDownInput(): HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleDown[] | undefined;
    private _scaleUp?;
    /**
     * @stability stable
     */
    get scaleUp(): HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUp[];
    /**
     * @stability stable
     */
    set scaleUp(value: HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUp[]);
    /**
     * @stability stable
     */
    resetScaleUp(): void;
    /**
     * @stability stable
     */
    get scaleUpInput(): HorizontalPodAutoscalerV2Beta2SpecBehaviorScaleUp[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#key HorizontalPodAutoscalerV2Beta2#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#operator HorizontalPodAutoscalerV2Beta2#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#values HorizontalPodAutoscalerV2Beta2#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelectorMatchExpressionsToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#match_labels HorizontalPodAutoscalerV2Beta2#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#match_expressions HorizontalPodAutoscalerV2Beta2#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelectorMatchExpressions[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelectorToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelector): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetric {
    /**
     * name is the name of the given metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#name HorizontalPodAutoscalerV2Beta2#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#selector HorizontalPodAutoscalerV2Beta2#selector}
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelector[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricExternalMetricToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetric): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetric | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetric | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelector[];
    /**
     * @stability stable
     */
    set selector(value: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelector[]);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricExternalTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_utilization HorizontalPodAutoscalerV2Beta2#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_value HorizontalPodAutoscalerV2Beta2#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#type HorizontalPodAutoscalerV2Beta2#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#value HorizontalPodAutoscalerV2Beta2#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricExternalTargetToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalTargetOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricExternalTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricExternalTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricExternalTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricExternal {
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#metric HorizontalPodAutoscalerV2Beta2#metric}
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetric;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#target HorizontalPodAutoscalerV2Beta2#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalTarget;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricExternalToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricExternalOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricExternal): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricExternalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricExternal | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricExternal | undefined);
    private _metric;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetricOutputReference;
    /**
     * @stability stable
     */
    putMetric(value: HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetric): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalMetric | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerV2Beta2SpecMetricExternalTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerV2Beta2SpecMetricExternalTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObject {
    /**
     * API version of the referent.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#api_version HorizontalPodAutoscalerV2Beta2#api_version}
     *
     * @stability stable
     */
    readonly apiVersion: string;
    /**
     * Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#kind HorizontalPodAutoscalerV2Beta2#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#name HorizontalPodAutoscalerV2Beta2#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObjectToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObjectOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObject): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObject | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObject | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#key HorizontalPodAutoscalerV2Beta2#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#operator HorizontalPodAutoscalerV2Beta2#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#values HorizontalPodAutoscalerV2Beta2#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelectorMatchExpressionsToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#match_labels HorizontalPodAutoscalerV2Beta2#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#match_expressions HorizontalPodAutoscalerV2Beta2#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelectorMatchExpressions[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelectorToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelector): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetric {
    /**
     * name is the name of the given metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#name HorizontalPodAutoscalerV2Beta2#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#selector HorizontalPodAutoscalerV2Beta2#selector}
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelector[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricObjectMetricToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetric): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetric | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetric | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelector[];
    /**
     * @stability stable
     */
    set selector(value: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelector[]);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricObjectTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_utilization HorizontalPodAutoscalerV2Beta2#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_value HorizontalPodAutoscalerV2Beta2#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#type HorizontalPodAutoscalerV2Beta2#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#value HorizontalPodAutoscalerV2Beta2#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricObjectTargetToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectTargetOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricObjectTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricObjectTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricObjectTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricObject {
    /**
     * described_object block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#described_object HorizontalPodAutoscalerV2Beta2#described_object}
     *
     * @stability stable
     */
    readonly describedObject: HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObject;
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#metric HorizontalPodAutoscalerV2Beta2#metric}
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetric;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#target HorizontalPodAutoscalerV2Beta2#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectTarget;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricObjectToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricObjectOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricObject): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricObjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricObject | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricObject | undefined);
    private _describedObject;
    /**
     * @stability stable
     */
    get describedObject(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObjectOutputReference;
    /**
     * @stability stable
     */
    putDescribedObject(value: HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObject): void;
    /**
     * @stability stable
     */
    get describedObjectInput(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectDescribedObject | undefined;
    private _metric;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetricOutputReference;
    /**
     * @stability stable
     */
    putMetric(value: HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetric): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectMetric | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerV2Beta2SpecMetricObjectTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerV2Beta2SpecMetricObjectTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#key HorizontalPodAutoscalerV2Beta2#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#operator HorizontalPodAutoscalerV2Beta2#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#values HorizontalPodAutoscalerV2Beta2#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelectorMatchExpressionsToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#match_labels HorizontalPodAutoscalerV2Beta2#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#match_expressions HorizontalPodAutoscalerV2Beta2#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelectorMatchExpressions[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelectorToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelector): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetric {
    /**
     * name is the name of the given metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#name HorizontalPodAutoscalerV2Beta2#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#selector HorizontalPodAutoscalerV2Beta2#selector}
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelector[];
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricPodsMetricToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetric): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetric | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetric | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelector[];
    /**
     * @stability stable
     */
    set selector(value: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelector[]);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricPodsTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_utilization HorizontalPodAutoscalerV2Beta2#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_value HorizontalPodAutoscalerV2Beta2#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#type HorizontalPodAutoscalerV2Beta2#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#value HorizontalPodAutoscalerV2Beta2#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricPodsTargetToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsTargetOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricPodsTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricPodsTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricPodsTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricPods {
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#metric HorizontalPodAutoscalerV2Beta2#metric}
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetric;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#target HorizontalPodAutoscalerV2Beta2#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsTarget;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricPodsToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricPodsOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricPods): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricPodsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricPods | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricPods | undefined);
    private _metric;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetricOutputReference;
    /**
     * @stability stable
     */
    putMetric(value: HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetric): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsMetric | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerV2Beta2SpecMetricPodsTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerV2Beta2SpecMetricPodsTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricResourceTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_utilization HorizontalPodAutoscalerV2Beta2#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#average_value HorizontalPodAutoscalerV2Beta2#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#type HorizontalPodAutoscalerV2Beta2#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#value HorizontalPodAutoscalerV2Beta2#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricResourceTargetToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricResourceTargetOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricResourceTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricResourceTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricResourceTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricResourceTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetricResource {
    /**
     * name is the name of the resource in question.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#name HorizontalPodAutoscalerV2Beta2#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#target HorizontalPodAutoscalerV2Beta2#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerV2Beta2SpecMetricResourceTarget;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricResourceToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetricResourceOutputReference | HorizontalPodAutoscalerV2Beta2SpecMetricResource): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecMetricResourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecMetricResource | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecMetricResource | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerV2Beta2SpecMetricResourceTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerV2Beta2SpecMetricResourceTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerV2Beta2SpecMetricResourceTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecMetric {
    /**
     * type is the type of metric source.
     *
     * It should be one of "Object", "Pods", "External" or "Resource", each mapping to a matching field in the object.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#type HorizontalPodAutoscalerV2Beta2#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * external block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#external HorizontalPodAutoscalerV2Beta2#external}
     *
     * @stability stable
     */
    readonly external?: HorizontalPodAutoscalerV2Beta2SpecMetricExternal;
    /**
     * object block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#object HorizontalPodAutoscalerV2Beta2#object}
     *
     * @stability stable
     */
    readonly object?: HorizontalPodAutoscalerV2Beta2SpecMetricObject;
    /**
     * pods block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#pods HorizontalPodAutoscalerV2Beta2#pods}
     *
     * @stability stable
     */
    readonly pods?: HorizontalPodAutoscalerV2Beta2SpecMetricPods;
    /**
     * resource block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#resource HorizontalPodAutoscalerV2Beta2#resource}
     *
     * @stability stable
     */
    readonly resource?: HorizontalPodAutoscalerV2Beta2SpecMetricResource;
}
export declare function horizontalPodAutoscalerV2Beta2SpecMetricToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecMetric): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2SpecScaleTargetRef {
    /**
     * API version of the referent.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#api_version HorizontalPodAutoscalerV2Beta2#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Kind of the referent. e.g. `ReplicationController`. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#types-kinds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#kind HorizontalPodAutoscalerV2Beta2#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#name HorizontalPodAutoscalerV2Beta2#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function horizontalPodAutoscalerV2Beta2SpecScaleTargetRefToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecScaleTargetRefOutputReference | HorizontalPodAutoscalerV2Beta2SpecScaleTargetRef): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecScaleTargetRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2SpecScaleTargetRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2SpecScaleTargetRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerV2Beta2Spec {
    /**
     * Upper limit for the number of pods that can be set by the autoscaler.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#max_replicas HorizontalPodAutoscalerV2Beta2#max_replicas}
     *
     * @stability stable
     */
    readonly maxReplicas: number;
    /**
     * Lower limit for the number of pods that can be set by the autoscaler, defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#min_replicas HorizontalPodAutoscalerV2Beta2#min_replicas}
     *
     * @stability stable
     */
    readonly minReplicas?: number;
    /**
     * Target average CPU utilization (represented as a percentage of requested CPU) over all the pods.
     *
     * If not specified the default autoscaling policy will be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#target_cpu_utilization_percentage HorizontalPodAutoscalerV2Beta2#target_cpu_utilization_percentage}
     *
     * @stability stable
     */
    readonly targetCpuUtilizationPercentage?: number;
    /**
     * behavior block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#behavior HorizontalPodAutoscalerV2Beta2#behavior}
     *
     * @stability stable
     */
    readonly behavior?: HorizontalPodAutoscalerV2Beta2SpecBehavior;
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#metric HorizontalPodAutoscalerV2Beta2#metric}
     *
     * @stability stable
     */
    readonly metric?: HorizontalPodAutoscalerV2Beta2SpecMetric[];
    /**
     * scale_target_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html#scale_target_ref HorizontalPodAutoscalerV2Beta2#scale_target_ref}
     *
     * @stability stable
     */
    readonly scaleTargetRef: HorizontalPodAutoscalerV2Beta2SpecScaleTargetRef;
}
export declare function horizontalPodAutoscalerV2Beta2SpecToTerraform(struct?: HorizontalPodAutoscalerV2Beta2SpecOutputReference | HorizontalPodAutoscalerV2Beta2Spec): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerV2Beta2Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerV2Beta2Spec | undefined);
    private _maxReplicas?;
    /**
     * @stability stable
     */
    get maxReplicas(): number;
    /**
     * @stability stable
     */
    set maxReplicas(value: number);
    /**
     * @stability stable
     */
    get maxReplicasInput(): number | undefined;
    private _minReplicas?;
    /**
     * @stability stable
     */
    get minReplicas(): number;
    /**
     * @stability stable
     */
    set minReplicas(value: number);
    /**
     * @stability stable
     */
    resetMinReplicas(): void;
    /**
     * @stability stable
     */
    get minReplicasInput(): number | undefined;
    private _targetCpuUtilizationPercentage?;
    /**
     * @stability stable
     */
    get targetCpuUtilizationPercentage(): number;
    /**
     * @stability stable
     */
    set targetCpuUtilizationPercentage(value: number);
    /**
     * @stability stable
     */
    resetTargetCpuUtilizationPercentage(): void;
    /**
     * @stability stable
     */
    get targetCpuUtilizationPercentageInput(): number | undefined;
    private _behavior;
    /**
     * @stability stable
     */
    get behavior(): HorizontalPodAutoscalerV2Beta2SpecBehaviorOutputReference;
    /**
     * @stability stable
     */
    putBehavior(value: HorizontalPodAutoscalerV2Beta2SpecBehavior): void;
    /**
     * @stability stable
     */
    resetBehavior(): void;
    /**
     * @stability stable
     */
    get behaviorInput(): HorizontalPodAutoscalerV2Beta2SpecBehavior | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerV2Beta2SpecMetric[];
    /**
     * @stability stable
     */
    set metric(value: HorizontalPodAutoscalerV2Beta2SpecMetric[]);
    /**
     * @stability stable
     */
    resetMetric(): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerV2Beta2SpecMetric[] | undefined;
    private _scaleTargetRef;
    /**
     * @stability stable
     */
    get scaleTargetRef(): HorizontalPodAutoscalerV2Beta2SpecScaleTargetRefOutputReference;
    /**
     * @stability stable
     */
    putScaleTargetRef(value: HorizontalPodAutoscalerV2Beta2SpecScaleTargetRef): void;
    /**
     * @stability stable
     */
    get scaleTargetRefInput(): HorizontalPodAutoscalerV2Beta2SpecScaleTargetRef | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html kubernetes_horizontal_pod_autoscaler_v2beta2}.
 *
 * @stability stable
 */
export declare class HorizontalPodAutoscalerV2Beta2 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v2beta2.html kubernetes_horizontal_pod_autoscaler_v2beta2} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HorizontalPodAutoscalerV2Beta2Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): HorizontalPodAutoscalerV2Beta2MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: HorizontalPodAutoscalerV2Beta2Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): HorizontalPodAutoscalerV2Beta2Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): HorizontalPodAutoscalerV2Beta2SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: HorizontalPodAutoscalerV2Beta2Spec): void;
    /**
     * @stability stable
     */
    get specInput(): HorizontalPodAutoscalerV2Beta2Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
