import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#metadata HorizontalPodAutoscaler#metadata}
     *
     * @stability stable
     */
    readonly metadata: HorizontalPodAutoscalerMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#spec HorizontalPodAutoscaler#spec}
     *
     * @stability stable
     */
    readonly spec: HorizontalPodAutoscalerSpec;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerMetadata {
    /**
     * An unstructured key value map stored with the horizontal pod autoscaler that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#annotations HorizontalPodAutoscaler#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#generate_name HorizontalPodAutoscaler#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the horizontal pod autoscaler.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#labels HorizontalPodAutoscaler#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the horizontal pod autoscaler, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#name HorizontalPodAutoscaler#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the horizontal pod autoscaler must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#namespace HorizontalPodAutoscaler#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function horizontalPodAutoscalerMetadataToTerraform(struct?: HorizontalPodAutoscalerMetadataOutputReference | HorizontalPodAutoscalerMetadata): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecBehaviorScaleDownPolicy {
    /**
     * Period specifies the window of time for which the policy should hold true.
     *
     * PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#period_seconds HorizontalPodAutoscaler#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds: number;
    /**
     * Type is used to specify the scaling policy: Percent or Pods.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#type HorizontalPodAutoscaler#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Value contains the amount of change which is permitted by the policy. It must be greater than zero.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#value HorizontalPodAutoscaler#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function horizontalPodAutoscalerSpecBehaviorScaleDownPolicyToTerraform(struct?: HorizontalPodAutoscalerSpecBehaviorScaleDownPolicy): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecBehaviorScaleDown {
    /**
     * Used to specify which policy should be used. If not set, the default value Max is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#select_policy HorizontalPodAutoscaler#select_policy}
     *
     * @stability stable
     */
    readonly selectPolicy?: string;
    /**
     * Number of seconds for which past recommendations should be considered while scaling up or scaling down.
     *
     * This value must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#stabilization_window_seconds HorizontalPodAutoscaler#stabilization_window_seconds}
     *
     * @stability stable
     */
    readonly stabilizationWindowSeconds?: number;
    /**
     * policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#policy HorizontalPodAutoscaler#policy}
     *
     * @stability stable
     */
    readonly policy: HorizontalPodAutoscalerSpecBehaviorScaleDownPolicy[];
}
export declare function horizontalPodAutoscalerSpecBehaviorScaleDownToTerraform(struct?: HorizontalPodAutoscalerSpecBehaviorScaleDown): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecBehaviorScaleUpPolicy {
    /**
     * Period specifies the window of time for which the policy should hold true.
     *
     * PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#period_seconds HorizontalPodAutoscaler#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds: number;
    /**
     * Type is used to specify the scaling policy: Percent or Pods.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#type HorizontalPodAutoscaler#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Value contains the amount of change which is permitted by the policy. It must be greater than zero.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#value HorizontalPodAutoscaler#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function horizontalPodAutoscalerSpecBehaviorScaleUpPolicyToTerraform(struct?: HorizontalPodAutoscalerSpecBehaviorScaleUpPolicy): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecBehaviorScaleUp {
    /**
     * Used to specify which policy should be used. If not set, the default value Max is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#select_policy HorizontalPodAutoscaler#select_policy}
     *
     * @stability stable
     */
    readonly selectPolicy?: string;
    /**
     * Number of seconds for which past recommendations should be considered while scaling up or scaling down.
     *
     * This value must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#stabilization_window_seconds HorizontalPodAutoscaler#stabilization_window_seconds}
     *
     * @stability stable
     */
    readonly stabilizationWindowSeconds?: number;
    /**
     * policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#policy HorizontalPodAutoscaler#policy}
     *
     * @stability stable
     */
    readonly policy: HorizontalPodAutoscalerSpecBehaviorScaleUpPolicy[];
}
export declare function horizontalPodAutoscalerSpecBehaviorScaleUpToTerraform(struct?: HorizontalPodAutoscalerSpecBehaviorScaleUp): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecBehavior {
    /**
     * scale_down block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#scale_down HorizontalPodAutoscaler#scale_down}
     *
     * @stability stable
     */
    readonly scaleDown?: HorizontalPodAutoscalerSpecBehaviorScaleDown[];
    /**
     * scale_up block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#scale_up HorizontalPodAutoscaler#scale_up}
     *
     * @stability stable
     */
    readonly scaleUp?: HorizontalPodAutoscalerSpecBehaviorScaleUp[];
}
export declare function horizontalPodAutoscalerSpecBehaviorToTerraform(struct?: HorizontalPodAutoscalerSpecBehaviorOutputReference | HorizontalPodAutoscalerSpecBehavior): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecBehaviorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecBehavior | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecBehavior | undefined);
    private _scaleDown?;
    /**
     * @stability stable
     */
    get scaleDown(): HorizontalPodAutoscalerSpecBehaviorScaleDown[];
    /**
     * @stability stable
     */
    set scaleDown(value: HorizontalPodAutoscalerSpecBehaviorScaleDown[]);
    /**
     * @stability stable
     */
    resetScaleDown(): void;
    /**
     * @stability stable
     */
    get scaleDownInput(): HorizontalPodAutoscalerSpecBehaviorScaleDown[] | undefined;
    private _scaleUp?;
    /**
     * @stability stable
     */
    get scaleUp(): HorizontalPodAutoscalerSpecBehaviorScaleUp[];
    /**
     * @stability stable
     */
    set scaleUp(value: HorizontalPodAutoscalerSpecBehaviorScaleUp[]);
    /**
     * @stability stable
     */
    resetScaleUp(): void;
    /**
     * @stability stable
     */
    get scaleUpInput(): HorizontalPodAutoscalerSpecBehaviorScaleUp[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#key HorizontalPodAutoscaler#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#operator HorizontalPodAutoscaler#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#values HorizontalPodAutoscaler#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function horizontalPodAutoscalerSpecMetricExternalMetricSelectorMatchExpressionsToTerraform(struct?: HorizontalPodAutoscalerSpecMetricExternalMetricSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#match_labels HorizontalPodAutoscaler#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#match_expressions HorizontalPodAutoscaler#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerSpecMetricExternalMetricSelectorMatchExpressions[];
}
export declare function horizontalPodAutoscalerSpecMetricExternalMetricSelectorToTerraform(struct?: HorizontalPodAutoscalerSpecMetricExternalMetricSelector): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalMetric {
    /**
     * name is the name of the given metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#name HorizontalPodAutoscaler#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#selector HorizontalPodAutoscaler#selector}
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerSpecMetricExternalMetricSelector[];
}
export declare function horizontalPodAutoscalerSpecMetricExternalMetricToTerraform(struct?: HorizontalPodAutoscalerSpecMetricExternalMetricOutputReference | HorizontalPodAutoscalerSpecMetricExternalMetric): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricExternalMetricOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricExternalMetric | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricExternalMetric | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): HorizontalPodAutoscalerSpecMetricExternalMetricSelector[];
    /**
     * @stability stable
     */
    set selector(value: HorizontalPodAutoscalerSpecMetricExternalMetricSelector[]);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): HorizontalPodAutoscalerSpecMetricExternalMetricSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_utilization HorizontalPodAutoscaler#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_value HorizontalPodAutoscaler#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#type HorizontalPodAutoscaler#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#value HorizontalPodAutoscaler#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerSpecMetricExternalTargetToTerraform(struct?: HorizontalPodAutoscalerSpecMetricExternalTargetOutputReference | HorizontalPodAutoscalerSpecMetricExternalTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricExternalTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricExternalTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricExternalTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternal {
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#metric HorizontalPodAutoscaler#metric}
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerSpecMetricExternalMetric;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#target HorizontalPodAutoscaler#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricExternalTarget;
}
export declare function horizontalPodAutoscalerSpecMetricExternalToTerraform(struct?: HorizontalPodAutoscalerSpecMetricExternalOutputReference | HorizontalPodAutoscalerSpecMetricExternal): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricExternalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricExternal | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricExternal | undefined);
    private _metric;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerSpecMetricExternalMetricOutputReference;
    /**
     * @stability stable
     */
    putMetric(value: HorizontalPodAutoscalerSpecMetricExternalMetric): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerSpecMetricExternalMetric | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerSpecMetricExternalTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerSpecMetricExternalTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerSpecMetricExternalTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectDescribedObject {
    /**
     * API version of the referent.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#api_version HorizontalPodAutoscaler#api_version}
     *
     * @stability stable
     */
    readonly apiVersion: string;
    /**
     * Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#kind HorizontalPodAutoscaler#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#name HorizontalPodAutoscaler#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function horizontalPodAutoscalerSpecMetricObjectDescribedObjectToTerraform(struct?: HorizontalPodAutoscalerSpecMetricObjectDescribedObjectOutputReference | HorizontalPodAutoscalerSpecMetricObjectDescribedObject): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricObjectDescribedObjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricObjectDescribedObject | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricObjectDescribedObject | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#key HorizontalPodAutoscaler#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#operator HorizontalPodAutoscaler#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#values HorizontalPodAutoscaler#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function horizontalPodAutoscalerSpecMetricObjectMetricSelectorMatchExpressionsToTerraform(struct?: HorizontalPodAutoscalerSpecMetricObjectMetricSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#match_labels HorizontalPodAutoscaler#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#match_expressions HorizontalPodAutoscaler#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerSpecMetricObjectMetricSelectorMatchExpressions[];
}
export declare function horizontalPodAutoscalerSpecMetricObjectMetricSelectorToTerraform(struct?: HorizontalPodAutoscalerSpecMetricObjectMetricSelector): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectMetric {
    /**
     * name is the name of the given metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#name HorizontalPodAutoscaler#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#selector HorizontalPodAutoscaler#selector}
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerSpecMetricObjectMetricSelector[];
}
export declare function horizontalPodAutoscalerSpecMetricObjectMetricToTerraform(struct?: HorizontalPodAutoscalerSpecMetricObjectMetricOutputReference | HorizontalPodAutoscalerSpecMetricObjectMetric): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricObjectMetricOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricObjectMetric | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricObjectMetric | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): HorizontalPodAutoscalerSpecMetricObjectMetricSelector[];
    /**
     * @stability stable
     */
    set selector(value: HorizontalPodAutoscalerSpecMetricObjectMetricSelector[]);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): HorizontalPodAutoscalerSpecMetricObjectMetricSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_utilization HorizontalPodAutoscaler#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_value HorizontalPodAutoscaler#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#type HorizontalPodAutoscaler#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#value HorizontalPodAutoscaler#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerSpecMetricObjectTargetToTerraform(struct?: HorizontalPodAutoscalerSpecMetricObjectTargetOutputReference | HorizontalPodAutoscalerSpecMetricObjectTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricObjectTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricObjectTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricObjectTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObject {
    /**
     * described_object block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#described_object HorizontalPodAutoscaler#described_object}
     *
     * @stability stable
     */
    readonly describedObject: HorizontalPodAutoscalerSpecMetricObjectDescribedObject;
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#metric HorizontalPodAutoscaler#metric}
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerSpecMetricObjectMetric;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#target HorizontalPodAutoscaler#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricObjectTarget;
}
export declare function horizontalPodAutoscalerSpecMetricObjectToTerraform(struct?: HorizontalPodAutoscalerSpecMetricObjectOutputReference | HorizontalPodAutoscalerSpecMetricObject): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricObjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricObject | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricObject | undefined);
    private _describedObject;
    /**
     * @stability stable
     */
    get describedObject(): HorizontalPodAutoscalerSpecMetricObjectDescribedObjectOutputReference;
    /**
     * @stability stable
     */
    putDescribedObject(value: HorizontalPodAutoscalerSpecMetricObjectDescribedObject): void;
    /**
     * @stability stable
     */
    get describedObjectInput(): HorizontalPodAutoscalerSpecMetricObjectDescribedObject | undefined;
    private _metric;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerSpecMetricObjectMetricOutputReference;
    /**
     * @stability stable
     */
    putMetric(value: HorizontalPodAutoscalerSpecMetricObjectMetric): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerSpecMetricObjectMetric | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerSpecMetricObjectTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerSpecMetricObjectTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerSpecMetricObjectTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#key HorizontalPodAutoscaler#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#operator HorizontalPodAutoscaler#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#values HorizontalPodAutoscaler#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function horizontalPodAutoscalerSpecMetricPodsMetricSelectorMatchExpressionsToTerraform(struct?: HorizontalPodAutoscalerSpecMetricPodsMetricSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#match_labels HorizontalPodAutoscaler#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#match_expressions HorizontalPodAutoscaler#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerSpecMetricPodsMetricSelectorMatchExpressions[];
}
export declare function horizontalPodAutoscalerSpecMetricPodsMetricSelectorToTerraform(struct?: HorizontalPodAutoscalerSpecMetricPodsMetricSelector): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsMetric {
    /**
     * name is the name of the given metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#name HorizontalPodAutoscaler#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#selector HorizontalPodAutoscaler#selector}
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerSpecMetricPodsMetricSelector[];
}
export declare function horizontalPodAutoscalerSpecMetricPodsMetricToTerraform(struct?: HorizontalPodAutoscalerSpecMetricPodsMetricOutputReference | HorizontalPodAutoscalerSpecMetricPodsMetric): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricPodsMetricOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricPodsMetric | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricPodsMetric | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): HorizontalPodAutoscalerSpecMetricPodsMetricSelector[];
    /**
     * @stability stable
     */
    set selector(value: HorizontalPodAutoscalerSpecMetricPodsMetricSelector[]);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): HorizontalPodAutoscalerSpecMetricPodsMetricSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_utilization HorizontalPodAutoscaler#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_value HorizontalPodAutoscaler#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#type HorizontalPodAutoscaler#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#value HorizontalPodAutoscaler#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerSpecMetricPodsTargetToTerraform(struct?: HorizontalPodAutoscalerSpecMetricPodsTargetOutputReference | HorizontalPodAutoscalerSpecMetricPodsTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricPodsTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricPodsTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricPodsTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPods {
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#metric HorizontalPodAutoscaler#metric}
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerSpecMetricPodsMetric;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#target HorizontalPodAutoscaler#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricPodsTarget;
}
export declare function horizontalPodAutoscalerSpecMetricPodsToTerraform(struct?: HorizontalPodAutoscalerSpecMetricPodsOutputReference | HorizontalPodAutoscalerSpecMetricPods): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricPodsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricPods | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricPods | undefined);
    private _metric;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerSpecMetricPodsMetricOutputReference;
    /**
     * @stability stable
     */
    putMetric(value: HorizontalPodAutoscalerSpecMetricPodsMetric): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerSpecMetricPodsMetric | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerSpecMetricPodsTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerSpecMetricPodsTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerSpecMetricPodsTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricResourceTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_utilization HorizontalPodAutoscaler#average_utilization}
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#average_value HorizontalPodAutoscaler#average_value}
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#type HorizontalPodAutoscaler#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#value HorizontalPodAutoscaler#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function horizontalPodAutoscalerSpecMetricResourceTargetToTerraform(struct?: HorizontalPodAutoscalerSpecMetricResourceTargetOutputReference | HorizontalPodAutoscalerSpecMetricResourceTarget): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricResourceTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricResourceTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricResourceTarget | undefined);
    private _averageUtilization?;
    /**
     * @stability stable
     */
    get averageUtilization(): number;
    /**
     * @stability stable
     */
    set averageUtilization(value: number);
    /**
     * @stability stable
     */
    resetAverageUtilization(): void;
    /**
     * @stability stable
     */
    get averageUtilizationInput(): number | undefined;
    private _averageValue?;
    /**
     * @stability stable
     */
    get averageValue(): string;
    /**
     * @stability stable
     */
    set averageValue(value: string);
    /**
     * @stability stable
     */
    resetAverageValue(): void;
    /**
     * @stability stable
     */
    get averageValueInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricResource {
    /**
     * name is the name of the resource in question.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#name HorizontalPodAutoscaler#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#target HorizontalPodAutoscaler#target}
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricResourceTarget;
}
export declare function horizontalPodAutoscalerSpecMetricResourceToTerraform(struct?: HorizontalPodAutoscalerSpecMetricResourceOutputReference | HorizontalPodAutoscalerSpecMetricResource): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecMetricResourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecMetricResource | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecMetricResource | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _target;
    /**
     * @stability stable
     */
    get target(): HorizontalPodAutoscalerSpecMetricResourceTargetOutputReference;
    /**
     * @stability stable
     */
    putTarget(value: HorizontalPodAutoscalerSpecMetricResourceTarget): void;
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): HorizontalPodAutoscalerSpecMetricResourceTarget | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetric {
    /**
     * type is the type of metric source.
     *
     * It should be one of "Object", "Pods", "External" or "Resource", each mapping to a matching field in the object.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#type HorizontalPodAutoscaler#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * external block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#external HorizontalPodAutoscaler#external}
     *
     * @stability stable
     */
    readonly external?: HorizontalPodAutoscalerSpecMetricExternal;
    /**
     * object block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#object HorizontalPodAutoscaler#object}
     *
     * @stability stable
     */
    readonly object?: HorizontalPodAutoscalerSpecMetricObject;
    /**
     * pods block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#pods HorizontalPodAutoscaler#pods}
     *
     * @stability stable
     */
    readonly pods?: HorizontalPodAutoscalerSpecMetricPods;
    /**
     * resource block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#resource HorizontalPodAutoscaler#resource}
     *
     * @stability stable
     */
    readonly resource?: HorizontalPodAutoscalerSpecMetricResource;
}
export declare function horizontalPodAutoscalerSpecMetricToTerraform(struct?: HorizontalPodAutoscalerSpecMetric): any;
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecScaleTargetRef {
    /**
     * API version of the referent.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#api_version HorizontalPodAutoscaler#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Kind of the referent. e.g. `ReplicationController`. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#types-kinds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#kind HorizontalPodAutoscaler#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#name HorizontalPodAutoscaler#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function horizontalPodAutoscalerSpecScaleTargetRefToTerraform(struct?: HorizontalPodAutoscalerSpecScaleTargetRefOutputReference | HorizontalPodAutoscalerSpecScaleTargetRef): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecScaleTargetRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpecScaleTargetRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpecScaleTargetRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpec {
    /**
     * Upper limit for the number of pods that can be set by the autoscaler.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#max_replicas HorizontalPodAutoscaler#max_replicas}
     *
     * @stability stable
     */
    readonly maxReplicas: number;
    /**
     * Lower limit for the number of pods that can be set by the autoscaler, defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#min_replicas HorizontalPodAutoscaler#min_replicas}
     *
     * @stability stable
     */
    readonly minReplicas?: number;
    /**
     * Target average CPU utilization (represented as a percentage of requested CPU) over all the pods.
     *
     * If not specified the default autoscaling policy will be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#target_cpu_utilization_percentage HorizontalPodAutoscaler#target_cpu_utilization_percentage}
     *
     * @stability stable
     */
    readonly targetCpuUtilizationPercentage?: number;
    /**
     * behavior block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#behavior HorizontalPodAutoscaler#behavior}
     *
     * @stability stable
     */
    readonly behavior?: HorizontalPodAutoscalerSpecBehavior;
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#metric HorizontalPodAutoscaler#metric}
     *
     * @stability stable
     */
    readonly metric?: HorizontalPodAutoscalerSpecMetric[];
    /**
     * scale_target_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html#scale_target_ref HorizontalPodAutoscaler#scale_target_ref}
     *
     * @stability stable
     */
    readonly scaleTargetRef: HorizontalPodAutoscalerSpecScaleTargetRef;
}
export declare function horizontalPodAutoscalerSpecToTerraform(struct?: HorizontalPodAutoscalerSpecOutputReference | HorizontalPodAutoscalerSpec): any;
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscalerSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): HorizontalPodAutoscalerSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: HorizontalPodAutoscalerSpec | undefined);
    private _maxReplicas?;
    /**
     * @stability stable
     */
    get maxReplicas(): number;
    /**
     * @stability stable
     */
    set maxReplicas(value: number);
    /**
     * @stability stable
     */
    get maxReplicasInput(): number | undefined;
    private _minReplicas?;
    /**
     * @stability stable
     */
    get minReplicas(): number;
    /**
     * @stability stable
     */
    set minReplicas(value: number);
    /**
     * @stability stable
     */
    resetMinReplicas(): void;
    /**
     * @stability stable
     */
    get minReplicasInput(): number | undefined;
    private _targetCpuUtilizationPercentage?;
    /**
     * @stability stable
     */
    get targetCpuUtilizationPercentage(): number;
    /**
     * @stability stable
     */
    set targetCpuUtilizationPercentage(value: number);
    /**
     * @stability stable
     */
    resetTargetCpuUtilizationPercentage(): void;
    /**
     * @stability stable
     */
    get targetCpuUtilizationPercentageInput(): number | undefined;
    private _behavior;
    /**
     * @stability stable
     */
    get behavior(): HorizontalPodAutoscalerSpecBehaviorOutputReference;
    /**
     * @stability stable
     */
    putBehavior(value: HorizontalPodAutoscalerSpecBehavior): void;
    /**
     * @stability stable
     */
    resetBehavior(): void;
    /**
     * @stability stable
     */
    get behaviorInput(): HorizontalPodAutoscalerSpecBehavior | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): HorizontalPodAutoscalerSpecMetric[];
    /**
     * @stability stable
     */
    set metric(value: HorizontalPodAutoscalerSpecMetric[]);
    /**
     * @stability stable
     */
    resetMetric(): void;
    /**
     * @stability stable
     */
    get metricInput(): HorizontalPodAutoscalerSpecMetric[] | undefined;
    private _scaleTargetRef;
    /**
     * @stability stable
     */
    get scaleTargetRef(): HorizontalPodAutoscalerSpecScaleTargetRefOutputReference;
    /**
     * @stability stable
     */
    putScaleTargetRef(value: HorizontalPodAutoscalerSpecScaleTargetRef): void;
    /**
     * @stability stable
     */
    get scaleTargetRefInput(): HorizontalPodAutoscalerSpecScaleTargetRef | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html kubernetes_horizontal_pod_autoscaler}.
 *
 * @stability stable
 */
export declare class HorizontalPodAutoscaler extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler.html kubernetes_horizontal_pod_autoscaler} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HorizontalPodAutoscalerConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): HorizontalPodAutoscalerMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: HorizontalPodAutoscalerMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): HorizontalPodAutoscalerMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): HorizontalPodAutoscalerSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: HorizontalPodAutoscalerSpec): void;
    /**
     * @stability stable
     */
    get specInput(): HorizontalPodAutoscalerSpec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
