import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IngressClassConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#metadata IngressClass#metadata}
     *
     * @stability stable
     */
    readonly metadata: IngressClassMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#spec IngressClass#spec}
     *
     * @stability stable
     */
    readonly spec: IngressClassSpec;
}
/**
 * @stability stable
 */
export interface IngressClassMetadata {
    /**
     * An unstructured key value map stored with the ingress_class that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#annotations IngressClass#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#generate_name IngressClass#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress_class.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#labels IngressClass#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the ingress_class, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#name IngressClass#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function ingressClassMetadataToTerraform(struct?: IngressClassMetadataOutputReference | IngressClassMetadata): any;
/**
 * @stability stable
 */
export declare class IngressClassMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressClassMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressClassMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface IngressClassSpecParameters {
    /**
     * APIGroup is the group for the resource being referenced.
     *
     * If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#api_group IngressClass#api_group}
     *
     * @stability stable
     */
    readonly apiGroup?: string;
    /**
     * Kind is the type of resource being referenced.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#kind IngressClass#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name is the name of resource being referenced.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#name IngressClass#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#namespace IngressClass#namespace}.
     *
     * @stability stable
     */
    readonly namespace?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#scope IngressClass#scope}.
     *
     * @stability stable
     */
    readonly scope?: string;
}
export declare function ingressClassSpecParametersToTerraform(struct?: IngressClassSpecParameters): any;
/**
 * @stability stable
 */
export interface IngressClassSpec {
    /**
     * Controller refers to the name of the controller that should handle this class.
     *
     * This allows for different "flavors" that are controlled by the same controller. For example, you may have different Parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#controller IngressClass#controller}
     *
     * @stability stable
     */
    readonly controller?: string;
    /**
     * parameters block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html#parameters IngressClass#parameters}
     *
     * @stability stable
     */
    readonly parameters?: IngressClassSpecParameters[];
}
export declare function ingressClassSpecToTerraform(struct?: IngressClassSpecOutputReference | IngressClassSpec): any;
/**
 * @stability stable
 */
export declare class IngressClassSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressClassSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressClassSpec | undefined);
    private _controller?;
    /**
     * @stability stable
     */
    get controller(): string;
    /**
     * @stability stable
     */
    set controller(value: string);
    /**
     * @stability stable
     */
    resetController(): void;
    /**
     * @stability stable
     */
    get controllerInput(): string | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): IngressClassSpecParameters[];
    /**
     * @stability stable
     */
    set parameters(value: IngressClassSpecParameters[]);
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): IngressClassSpecParameters[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html kubernetes_ingress_class}.
 *
 * @stability stable
 */
export declare class IngressClass extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_class.html kubernetes_ingress_class} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IngressClassConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): IngressClassMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: IngressClassMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): IngressClassMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): IngressClassSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: IngressClassSpec): void;
    /**
     * @stability stable
     */
    get specInput(): IngressClassSpec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
