import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IngressV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Terraform will wait for the load balancer to have at least 1 endpoint before considering the resource created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#wait_for_load_balancer IngressV1#wait_for_load_balancer}
     *
     * @stability stable
     */
    readonly waitForLoadBalancer?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#metadata IngressV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: IngressV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#spec IngressV1#spec}
     *
     * @stability stable
     */
    readonly spec: IngressV1Spec;
}
/**
 * @stability stable
 */
export declare class IngressV1StatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class IngressV1StatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class IngressV1Status extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface IngressV1Metadata {
    /**
     * An unstructured key value map stored with the ingress that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#annotations IngressV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#generate_name IngressV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#labels IngressV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the ingress, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#name IngressV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the ingress must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#namespace IngressV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function ingressV1MetadataToTerraform(struct?: IngressV1MetadataOutputReference | IngressV1Metadata): any;
/**
 * @stability stable
 */
export declare class IngressV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecDefaultBackendResource {
    /**
     * APIGroup is the group for the resource being referenced.
     *
     * If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#api_group IngressV1#api_group}
     *
     * @stability stable
     */
    readonly apiGroup: string;
    /**
     * The kind of resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#kind IngressV1#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the User to bind to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#name IngressV1#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function ingressV1SpecDefaultBackendResourceToTerraform(struct?: IngressV1SpecDefaultBackendResourceOutputReference | IngressV1SpecDefaultBackendResource): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecDefaultBackendResourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecDefaultBackendResource | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecDefaultBackendResource | undefined);
    private _apiGroup?;
    /**
     * @stability stable
     */
    get apiGroup(): string;
    /**
     * @stability stable
     */
    set apiGroup(value: string);
    /**
     * @stability stable
     */
    get apiGroupInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecDefaultBackendServicePort {
    /**
     * Specifies the name of the port of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#name IngressV1#name}
     *
     * @stability stable
     */
    readonly name?: number;
    /**
     * Specifies the numerical port of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#number IngressV1#number}
     *
     * @stability stable
     */
    readonly number?: number;
}
export declare function ingressV1SpecDefaultBackendServicePortToTerraform(struct?: IngressV1SpecDefaultBackendServicePortOutputReference | IngressV1SpecDefaultBackendServicePort): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecDefaultBackendServicePortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecDefaultBackendServicePort | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecDefaultBackendServicePort | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): number;
    /**
     * @stability stable
     */
    set name(value: number);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): number | undefined;
    private _number?;
    /**
     * @stability stable
     */
    get number(): number;
    /**
     * @stability stable
     */
    set number(value: number);
    /**
     * @stability stable
     */
    resetNumber(): void;
    /**
     * @stability stable
     */
    get numberInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecDefaultBackendService {
    /**
     * Specifies the name of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#name IngressV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#port IngressV1#port}
     *
     * @stability stable
     */
    readonly port: IngressV1SpecDefaultBackendServicePort;
}
export declare function ingressV1SpecDefaultBackendServiceToTerraform(struct?: IngressV1SpecDefaultBackendServiceOutputReference | IngressV1SpecDefaultBackendService): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecDefaultBackendServiceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecDefaultBackendService | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecDefaultBackendService | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _port;
    /**
     * @stability stable
     */
    get port(): IngressV1SpecDefaultBackendServicePortOutputReference;
    /**
     * @stability stable
     */
    putPort(value: IngressV1SpecDefaultBackendServicePort): void;
    /**
     * @stability stable
     */
    get portInput(): IngressV1SpecDefaultBackendServicePort | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecDefaultBackend {
    /**
     * resource block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#resource IngressV1#resource}
     *
     * @stability stable
     */
    readonly resource?: IngressV1SpecDefaultBackendResource;
    /**
     * service block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#service IngressV1#service}
     *
     * @stability stable
     */
    readonly service?: IngressV1SpecDefaultBackendService;
}
export declare function ingressV1SpecDefaultBackendToTerraform(struct?: IngressV1SpecDefaultBackendOutputReference | IngressV1SpecDefaultBackend): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecDefaultBackendOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecDefaultBackend | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecDefaultBackend | undefined);
    private _resource;
    /**
     * @stability stable
     */
    get resource(): IngressV1SpecDefaultBackendResourceOutputReference;
    /**
     * @stability stable
     */
    putResource(value: IngressV1SpecDefaultBackendResource): void;
    /**
     * @stability stable
     */
    resetResource(): void;
    /**
     * @stability stable
     */
    get resourceInput(): IngressV1SpecDefaultBackendResource | undefined;
    private _service;
    /**
     * @stability stable
     */
    get service(): IngressV1SpecDefaultBackendServiceOutputReference;
    /**
     * @stability stable
     */
    putService(value: IngressV1SpecDefaultBackendService): void;
    /**
     * @stability stable
     */
    resetService(): void;
    /**
     * @stability stable
     */
    get serviceInput(): IngressV1SpecDefaultBackendService | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecRuleHttpPathBackendResource {
    /**
     * APIGroup is the group for the resource being referenced.
     *
     * If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#api_group IngressV1#api_group}
     *
     * @stability stable
     */
    readonly apiGroup: string;
    /**
     * The kind of resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#kind IngressV1#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the User to bind to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#name IngressV1#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function ingressV1SpecRuleHttpPathBackendResourceToTerraform(struct?: IngressV1SpecRuleHttpPathBackendResourceOutputReference | IngressV1SpecRuleHttpPathBackendResource): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecRuleHttpPathBackendResourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecRuleHttpPathBackendResource | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecRuleHttpPathBackendResource | undefined);
    private _apiGroup?;
    /**
     * @stability stable
     */
    get apiGroup(): string;
    /**
     * @stability stable
     */
    set apiGroup(value: string);
    /**
     * @stability stable
     */
    get apiGroupInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecRuleHttpPathBackendServicePort {
    /**
     * Specifies the name of the port of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#name IngressV1#name}
     *
     * @stability stable
     */
    readonly name?: number;
    /**
     * Specifies the numerical port of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#number IngressV1#number}
     *
     * @stability stable
     */
    readonly number?: number;
}
export declare function ingressV1SpecRuleHttpPathBackendServicePortToTerraform(struct?: IngressV1SpecRuleHttpPathBackendServicePortOutputReference | IngressV1SpecRuleHttpPathBackendServicePort): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecRuleHttpPathBackendServicePortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecRuleHttpPathBackendServicePort | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecRuleHttpPathBackendServicePort | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): number;
    /**
     * @stability stable
     */
    set name(value: number);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): number | undefined;
    private _number?;
    /**
     * @stability stable
     */
    get number(): number;
    /**
     * @stability stable
     */
    set number(value: number);
    /**
     * @stability stable
     */
    resetNumber(): void;
    /**
     * @stability stable
     */
    get numberInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecRuleHttpPathBackendService {
    /**
     * Specifies the name of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#name IngressV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#port IngressV1#port}
     *
     * @stability stable
     */
    readonly port: IngressV1SpecRuleHttpPathBackendServicePort;
}
export declare function ingressV1SpecRuleHttpPathBackendServiceToTerraform(struct?: IngressV1SpecRuleHttpPathBackendServiceOutputReference | IngressV1SpecRuleHttpPathBackendService): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecRuleHttpPathBackendServiceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecRuleHttpPathBackendService | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecRuleHttpPathBackendService | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _port;
    /**
     * @stability stable
     */
    get port(): IngressV1SpecRuleHttpPathBackendServicePortOutputReference;
    /**
     * @stability stable
     */
    putPort(value: IngressV1SpecRuleHttpPathBackendServicePort): void;
    /**
     * @stability stable
     */
    get portInput(): IngressV1SpecRuleHttpPathBackendServicePort | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecRuleHttpPathBackend {
    /**
     * resource block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#resource IngressV1#resource}
     *
     * @stability stable
     */
    readonly resource?: IngressV1SpecRuleHttpPathBackendResource;
    /**
     * service block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#service IngressV1#service}
     *
     * @stability stable
     */
    readonly service?: IngressV1SpecRuleHttpPathBackendService;
}
export declare function ingressV1SpecRuleHttpPathBackendToTerraform(struct?: IngressV1SpecRuleHttpPathBackendOutputReference | IngressV1SpecRuleHttpPathBackend): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecRuleHttpPathBackendOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecRuleHttpPathBackend | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecRuleHttpPathBackend | undefined);
    private _resource;
    /**
     * @stability stable
     */
    get resource(): IngressV1SpecRuleHttpPathBackendResourceOutputReference;
    /**
     * @stability stable
     */
    putResource(value: IngressV1SpecRuleHttpPathBackendResource): void;
    /**
     * @stability stable
     */
    resetResource(): void;
    /**
     * @stability stable
     */
    get resourceInput(): IngressV1SpecRuleHttpPathBackendResource | undefined;
    private _service;
    /**
     * @stability stable
     */
    get service(): IngressV1SpecRuleHttpPathBackendServiceOutputReference;
    /**
     * @stability stable
     */
    putService(value: IngressV1SpecRuleHttpPathBackendService): void;
    /**
     * @stability stable
     */
    resetService(): void;
    /**
     * @stability stable
     */
    get serviceInput(): IngressV1SpecRuleHttpPathBackendService | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecRuleHttpPath {
    /**
     * Path is matched against the path of an incoming request.
     *
     * Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. When unspecified, all paths from incoming requests are matched.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#path IngressV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * PathType determines the interpretation of the Path matching.
     *
     * PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
     * done on a path element by element basis. A path element refers is the
     * list of labels in the path split by the '/' separator. A request is a
     * match for path p if every p is an element-wise prefix of p of the
     * request path. Note that if the last element of the path is a substring
     * of the last element in request path, it is not a match (e.g. /foo/bar
     * matches /foo/bar/baz, but does not match /foo/barbaz).
     * ImplementationSpecific: Interpretation of the Path matching is up to
     * the IngressClass. Implementations can treat this as a separate PathType
     * or treat it identically to Prefix or Exact path types.
     * Implementations are required to support all path types.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#path_type IngressV1#path_type}
     *
     * @stability stable
     */
    readonly pathType?: string;
    /**
     * backend block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#backend IngressV1#backend}
     *
     * @stability stable
     */
    readonly backend?: IngressV1SpecRuleHttpPathBackend;
}
export declare function ingressV1SpecRuleHttpPathToTerraform(struct?: IngressV1SpecRuleHttpPath): any;
/**
 * @stability stable
 */
export interface IngressV1SpecRuleHttp {
    /**
     * path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#path IngressV1#path}
     *
     * @stability stable
     */
    readonly path: IngressV1SpecRuleHttpPath[];
}
export declare function ingressV1SpecRuleHttpToTerraform(struct?: IngressV1SpecRuleHttpOutputReference | IngressV1SpecRuleHttp): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecRuleHttpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1SpecRuleHttp | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1SpecRuleHttp | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): IngressV1SpecRuleHttpPath[];
    /**
     * @stability stable
     */
    set path(value: IngressV1SpecRuleHttpPath[]);
    /**
     * @stability stable
     */
    get pathInput(): IngressV1SpecRuleHttpPath[] | undefined;
}
/**
 * @stability stable
 */
export interface IngressV1SpecRule {
    /**
     * Host is the fully qualified domain name of a network host, as defined by RFC 3986.
     *
     * Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
     * the IP in the Spec of the parent Ingress.
     * 2. The `:` delimiter is not respected because ports are not allowed.
     * Currently the port of an Ingress is implicitly :80 for http and
     * :443 for https.
     * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
     *
     * Host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If Host is precise, the request matches this rule if the http host header is equal to Host. 2. If Host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#host IngressV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * http block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#http IngressV1#http}
     *
     * @stability stable
     */
    readonly http: IngressV1SpecRuleHttp;
}
export declare function ingressV1SpecRuleToTerraform(struct?: IngressV1SpecRule): any;
/**
 * @stability stable
 */
export interface IngressV1SpecTls {
    /**
     * Hosts are a list of hosts included in the TLS certificate.
     *
     * The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#hosts IngressV1#hosts}
     *
     * @stability stable
     */
    readonly hosts?: string[];
    /**
     * SecretName is the name of the secret used to terminate TLS traffic on port 443.
     *
     * Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#secret_name IngressV1#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
}
export declare function ingressV1SpecTlsToTerraform(struct?: IngressV1SpecTls): any;
/**
 * @stability stable
 */
export interface IngressV1Spec {
    /**
     * IngressClassName is the name of the IngressClass cluster resource.
     *
     * The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#ingress_class_name IngressV1#ingress_class_name}
     *
     * @stability stable
     */
    readonly ingressClassName?: string;
    /**
     * default_backend block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#default_backend IngressV1#default_backend}
     *
     * @stability stable
     */
    readonly defaultBackend?: IngressV1SpecDefaultBackend;
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#rule IngressV1#rule}
     *
     * @stability stable
     */
    readonly rule?: IngressV1SpecRule[];
    /**
     * tls block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html#tls IngressV1#tls}
     *
     * @stability stable
     */
    readonly tls?: IngressV1SpecTls[];
}
export declare function ingressV1SpecToTerraform(struct?: IngressV1SpecOutputReference | IngressV1Spec): any;
/**
 * @stability stable
 */
export declare class IngressV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): IngressV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: IngressV1Spec | undefined);
    private _ingressClassName?;
    /**
     * @stability stable
     */
    get ingressClassName(): string;
    /**
     * @stability stable
     */
    set ingressClassName(value: string);
    /**
     * @stability stable
     */
    resetIngressClassName(): void;
    /**
     * @stability stable
     */
    get ingressClassNameInput(): string | undefined;
    private _defaultBackend;
    /**
     * @stability stable
     */
    get defaultBackend(): IngressV1SpecDefaultBackendOutputReference;
    /**
     * @stability stable
     */
    putDefaultBackend(value: IngressV1SpecDefaultBackend): void;
    /**
     * @stability stable
     */
    resetDefaultBackend(): void;
    /**
     * @stability stable
     */
    get defaultBackendInput(): IngressV1SpecDefaultBackend | undefined;
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): IngressV1SpecRule[];
    /**
     * @stability stable
     */
    set rule(value: IngressV1SpecRule[]);
    /**
     * @stability stable
     */
    resetRule(): void;
    /**
     * @stability stable
     */
    get ruleInput(): IngressV1SpecRule[] | undefined;
    private _tls?;
    /**
     * @stability stable
     */
    get tls(): IngressV1SpecTls[];
    /**
     * @stability stable
     */
    set tls(value: IngressV1SpecTls[]);
    /**
     * @stability stable
     */
    resetTls(): void;
    /**
     * @stability stable
     */
    get tlsInput(): IngressV1SpecTls[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html kubernetes_ingress_v1}.
 *
 * @stability stable
 */
export declare class IngressV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress_v1.html kubernetes_ingress_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IngressV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    status(index: string): IngressV1Status;
    private _waitForLoadBalancer?;
    /**
     * @stability stable
     */
    get waitForLoadBalancer(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForLoadBalancer(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForLoadBalancer(): void;
    /**
     * @stability stable
     */
    get waitForLoadBalancerInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): IngressV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: IngressV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): IngressV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): IngressV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: IngressV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): IngressV1Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
