import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KubernetesProviderConfig {
    /**
     * PEM-encoded client certificate for TLS authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#client_certificate KubernetesProvider#client_certificate}
     *
     * @stability stable
     */
    readonly clientCertificate?: string;
    /**
     * PEM-encoded client certificate key for TLS authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#client_key KubernetesProvider#client_key}
     *
     * @stability stable
     */
    readonly clientKey?: string;
    /**
     * PEM-encoded root certificates bundle for TLS authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#cluster_ca_certificate KubernetesProvider#cluster_ca_certificate}
     *
     * @stability stable
     */
    readonly clusterCaCertificate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#config_context KubernetesProvider#config_context}.
     *
     * @stability stable
     */
    readonly configContext?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#config_context_auth_info KubernetesProvider#config_context_auth_info}.
     *
     * @stability stable
     */
    readonly configContextAuthInfo?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#config_context_cluster KubernetesProvider#config_context_cluster}.
     *
     * @stability stable
     */
    readonly configContextCluster?: string;
    /**
     * Path to the kube config file. Can be set with KUBE_CONFIG_PATH.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#config_path KubernetesProvider#config_path}
     *
     * @stability stable
     */
    readonly configPath?: string;
    /**
     * A list of paths to kube config files. Can be set with KUBE_CONFIG_PATHS environment variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#config_paths KubernetesProvider#config_paths}
     *
     * @stability stable
     */
    readonly configPaths?: string[];
    /**
     * The hostname (in form of URI) of Kubernetes master.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#host KubernetesProvider#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Whether server should be accessed without verifying the TLS certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#insecure KubernetesProvider#insecure}
     *
     * @stability stable
     */
    readonly insecure?: boolean | cdktf.IResolvable;
    /**
     * The password to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#password KubernetesProvider#password}
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * URL to the proxy to be used for all API requests.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#proxy_url KubernetesProvider#proxy_url}
     *
     * @stability stable
     */
    readonly proxyUrl?: string;
    /**
     * Token to authenticate an service account.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#token KubernetesProvider#token}
     *
     * @stability stable
     */
    readonly token?: string;
    /**
     * The username to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#username KubernetesProvider#username}
     *
     * @stability stable
     */
    readonly username?: string;
    /**
     * Alias name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#alias KubernetesProvider#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#exec KubernetesProvider#exec}
     *
     * @stability stable
     */
    readonly exec?: KubernetesProviderExec;
    /**
     * experiments block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#experiments KubernetesProvider#experiments}
     *
     * @stability stable
     */
    readonly experiments?: KubernetesProviderExperiments;
}
/**
 * @stability stable
 */
export interface KubernetesProviderExec {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#api_version KubernetesProvider#api_version}.
     *
     * @stability stable
     */
    readonly apiVersion: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#args KubernetesProvider#args}.
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#command KubernetesProvider#command}.
     *
     * @stability stable
     */
    readonly command: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#env KubernetesProvider#env}.
     *
     * @stability stable
     */
    readonly env?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function kubernetesProviderExecToTerraform(struct?: KubernetesProviderExec): any;
/**
 * @stability stable
 */
export interface KubernetesProviderExperiments {
    /**
     * Enable the `kubernetes_manifest` resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#manifest_resource KubernetesProvider#manifest_resource}
     *
     * @stability stable
     */
    readonly manifestResource?: boolean | cdktf.IResolvable;
}
export declare function kubernetesProviderExperimentsToTerraform(struct?: KubernetesProviderExperiments): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes kubernetes}.
 *
 * @stability stable
 */
export declare class KubernetesProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes kubernetes} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: KubernetesProviderConfig);
    private _clientCertificate?;
    /**
     * @stability stable
     */
    get clientCertificate(): string | undefined;
    /**
     * @stability stable
     */
    set clientCertificate(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientCertificate(): void;
    /**
     * @stability stable
     */
    get clientCertificateInput(): string | undefined;
    private _clientKey?;
    /**
     * @stability stable
     */
    get clientKey(): string | undefined;
    /**
     * @stability stable
     */
    set clientKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientKey(): void;
    /**
     * @stability stable
     */
    get clientKeyInput(): string | undefined;
    private _clusterCaCertificate?;
    /**
     * @stability stable
     */
    get clusterCaCertificate(): string | undefined;
    /**
     * @stability stable
     */
    set clusterCaCertificate(value: string | undefined);
    /**
     * @stability stable
     */
    resetClusterCaCertificate(): void;
    /**
     * @stability stable
     */
    get clusterCaCertificateInput(): string | undefined;
    private _configContext?;
    /**
     * @stability stable
     */
    get configContext(): string | undefined;
    /**
     * @stability stable
     */
    set configContext(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigContext(): void;
    /**
     * @stability stable
     */
    get configContextInput(): string | undefined;
    private _configContextAuthInfo?;
    /**
     * @stability stable
     */
    get configContextAuthInfo(): string | undefined;
    /**
     * @stability stable
     */
    set configContextAuthInfo(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigContextAuthInfo(): void;
    /**
     * @stability stable
     */
    get configContextAuthInfoInput(): string | undefined;
    private _configContextCluster?;
    /**
     * @stability stable
     */
    get configContextCluster(): string | undefined;
    /**
     * @stability stable
     */
    set configContextCluster(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigContextCluster(): void;
    /**
     * @stability stable
     */
    get configContextClusterInput(): string | undefined;
    private _configPath?;
    /**
     * @stability stable
     */
    get configPath(): string | undefined;
    /**
     * @stability stable
     */
    set configPath(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigPath(): void;
    /**
     * @stability stable
     */
    get configPathInput(): string | undefined;
    private _configPaths?;
    /**
     * @stability stable
     */
    get configPaths(): string[] | undefined;
    /**
     * @stability stable
     */
    set configPaths(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetConfigPaths(): void;
    /**
     * @stability stable
     */
    get configPathsInput(): string[] | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string | undefined;
    /**
     * @stability stable
     */
    set host(value: string | undefined);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _insecure?;
    /**
     * @stability stable
     */
    get insecure(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set insecure(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetInsecure(): void;
    /**
     * @stability stable
     */
    get insecureInput(): boolean | cdktf.IResolvable | undefined;
    private _password?;
    /**
     * @stability stable
     */
    get password(): string | undefined;
    /**
     * @stability stable
     */
    set password(value: string | undefined);
    /**
     * @stability stable
     */
    resetPassword(): void;
    /**
     * @stability stable
     */
    get passwordInput(): string | undefined;
    private _proxyUrl?;
    /**
     * @stability stable
     */
    get proxyUrl(): string | undefined;
    /**
     * @stability stable
     */
    set proxyUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetProxyUrl(): void;
    /**
     * @stability stable
     */
    get proxyUrlInput(): string | undefined;
    private _token?;
    /**
     * @stability stable
     */
    get token(): string | undefined;
    /**
     * @stability stable
     */
    set token(value: string | undefined);
    /**
     * @stability stable
     */
    resetToken(): void;
    /**
     * @stability stable
     */
    get tokenInput(): string | undefined;
    private _username?;
    /**
     * @stability stable
     */
    get username(): string | undefined;
    /**
     * @stability stable
     */
    set username(value: string | undefined);
    /**
     * @stability stable
     */
    resetUsername(): void;
    /**
     * @stability stable
     */
    get usernameInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    private _exec?;
    /**
     * @stability stable
     */
    get exec(): KubernetesProviderExec | undefined;
    /**
     * @stability stable
     */
    set exec(value: KubernetesProviderExec | undefined);
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): KubernetesProviderExec | undefined;
    private _experiments?;
    /**
     * @stability stable
     */
    get experiments(): KubernetesProviderExperiments | undefined;
    /**
     * @stability stable
     */
    set experiments(value: KubernetesProviderExperiments | undefined);
    /**
     * @stability stable
     */
    resetExperiments(): void;
    /**
     * @stability stable
     */
    get experimentsInput(): KubernetesProviderExperiments | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
