import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface LimitRangeV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#metadata LimitRangeV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: LimitRangeV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#spec LimitRangeV1#spec}
     *
     * @stability stable
     */
    readonly spec?: LimitRangeV1Spec;
}
/**
 * @stability stable
 */
export interface LimitRangeV1Metadata {
    /**
     * An unstructured key value map stored with the limit range that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#annotations LimitRangeV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#generate_name LimitRangeV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the limit range.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#labels LimitRangeV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the limit range, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#name LimitRangeV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the limit range must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#namespace LimitRangeV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function limitRangeV1MetadataToTerraform(struct?: LimitRangeV1MetadataOutputReference | LimitRangeV1Metadata): any;
/**
 * @stability stable
 */
export declare class LimitRangeV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LimitRangeV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LimitRangeV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LimitRangeV1SpecLimit {
    /**
     * Default resource requirement limit value by resource name if resource limit is omitted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#default LimitRangeV1#default}
     *
     * @stability stable
     */
    readonly default?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * The default resource requirement request value by resource name if resource request is omitted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#default_request LimitRangeV1#default_request}
     *
     * @stability stable
     */
    readonly defaultRequest?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Max usage constraints on this kind by resource name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#max LimitRangeV1#max}
     *
     * @stability stable
     */
    readonly max?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * The named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value;
     *
     * this represents the max burst for the named resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#max_limit_request_ratio LimitRangeV1#max_limit_request_ratio}
     *
     * @stability stable
     */
    readonly maxLimitRequestRatio?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Min usage constraints on this kind by resource name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#min LimitRangeV1#min}
     *
     * @stability stable
     */
    readonly min?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Type of resource that this limit applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#type LimitRangeV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function limitRangeV1SpecLimitToTerraform(struct?: LimitRangeV1SpecLimit): any;
/**
 * @stability stable
 */
export interface LimitRangeV1Spec {
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html#limit LimitRangeV1#limit}
     *
     * @stability stable
     */
    readonly limit?: LimitRangeV1SpecLimit[];
}
export declare function limitRangeV1SpecToTerraform(struct?: LimitRangeV1SpecOutputReference | LimitRangeV1Spec): any;
/**
 * @stability stable
 */
export declare class LimitRangeV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LimitRangeV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LimitRangeV1Spec | undefined);
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): LimitRangeV1SpecLimit[];
    /**
     * @stability stable
     */
    set limit(value: LimitRangeV1SpecLimit[]);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): LimitRangeV1SpecLimit[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html kubernetes_limit_range_v1}.
 *
 * @stability stable
 */
export declare class LimitRangeV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/limit_range_v1.html kubernetes_limit_range_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LimitRangeV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): LimitRangeV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: LimitRangeV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): LimitRangeV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): LimitRangeV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: LimitRangeV1Spec): void;
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): LimitRangeV1Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
