import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ManifestConfig extends cdktf.TerraformMetaArguments {
    /**
     * List of manifest fields whose values can be altered by the API server during 'apply'. Defaults to: ["metadata.annotations", "metadata.labels"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#computed_fields Manifest#computed_fields}
     *
     * @stability stable
     */
    readonly computedFields?: string[];
    /**
     * A Kubernetes manifest describing the desired state of the resource in HCL format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#manifest Manifest#manifest}
     *
     * @stability stable
     */
    readonly manifest: {
        [key: string]: any;
    } | cdktf.IResolvable;
    /**
     * The resulting resource state, as returned by the API server after applying the desired state from `manifest`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#object Manifest#object}
     *
     * @stability stable
     */
    readonly object?: {
        [key: string]: any;
    } | cdktf.IResolvable;
    /**
     * A map of attribute paths and desired patterns to be matched.
     *
     * After each apply the provider will wait for all attributes listed here to reach a value that matches the desired pattern.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#wait_for Manifest#wait_for}
     *
     * @stability stable
     */
    readonly waitFor?: ManifestWaitFor;
    /**
     * field_manager block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#field_manager Manifest#field_manager}
     *
     * @stability stable
     */
    readonly fieldManager?: ManifestFieldManager;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#timeouts Manifest#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ManifestTimeouts;
}
/**
 * @stability stable
 */
export interface ManifestWaitFor {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#fields Manifest#fields}.
     *
     * @stability stable
     */
    readonly fields?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function manifestWaitForToTerraform(struct?: ManifestWaitFor): any;
/**
 * @stability stable
 */
export interface ManifestFieldManager {
    /**
     * Force changes against conflicts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#force_conflicts Manifest#force_conflicts}
     *
     * @stability stable
     */
    readonly forceConflicts?: boolean | cdktf.IResolvable;
    /**
     * The name to use for the field manager when creating and updating the resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#name Manifest#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function manifestFieldManagerToTerraform(struct?: ManifestFieldManagerOutputReference | ManifestFieldManager): any;
/**
 * @stability stable
 */
export declare class ManifestFieldManagerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ManifestFieldManager | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ManifestFieldManager | undefined);
    private _forceConflicts?;
    /**
     * @stability stable
     */
    get forceConflicts(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceConflicts(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceConflicts(): void;
    /**
     * @stability stable
     */
    get forceConflictsInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ManifestTimeouts {
    /**
     * Timeout for the create operation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#create Manifest#create}
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Timeout for the delete operation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#delete Manifest#delete}
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Timeout for the update operation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#update Manifest#update}
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function manifestTimeoutsToTerraform(struct?: ManifestTimeoutsOutputReference | ManifestTimeouts): any;
/**
 * @stability stable
 */
export declare class ManifestTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ManifestTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ManifestTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html kubernetes_manifest}.
 *
 * @stability stable
 */
export declare class Manifest extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html kubernetes_manifest} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ManifestConfig);
    private _computedFields?;
    /**
     * @stability stable
     */
    get computedFields(): string[];
    /**
     * @stability stable
     */
    set computedFields(value: string[]);
    /**
     * @stability stable
     */
    resetComputedFields(): void;
    /**
     * @stability stable
     */
    get computedFieldsInput(): string[] | undefined;
    private _manifest?;
    /**
     * @stability stable
     */
    get manifest(): {
        [key: string]: any;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set manifest(value: {
        [key: string]: any;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get manifestInput(): cdktf.IResolvable | {
        [key: string]: any;
    } | undefined;
    private _object?;
    /**
     * @stability stable
     */
    get object(): {
        [key: string]: any;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set object(value: {
        [key: string]: any;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetObject(): void;
    /**
     * @stability stable
     */
    get objectInput(): cdktf.IResolvable | {
        [key: string]: any;
    } | undefined;
    private _waitFor?;
    /**
     * @stability stable
     */
    get waitFor(): ManifestWaitFor;
    /**
     * @stability stable
     */
    set waitFor(value: ManifestWaitFor);
    /**
     * @stability stable
     */
    resetWaitFor(): void;
    /**
     * @stability stable
     */
    get waitForInput(): ManifestWaitFor | undefined;
    private _fieldManager;
    /**
     * @stability stable
     */
    get fieldManager(): ManifestFieldManagerOutputReference;
    /**
     * @stability stable
     */
    putFieldManager(value: ManifestFieldManager): void;
    /**
     * @stability stable
     */
    resetFieldManager(): void;
    /**
     * @stability stable
     */
    get fieldManagerInput(): ManifestFieldManager | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ManifestTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ManifestTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ManifestTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
