import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PersistentVolumeClaimV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Whether to wait for the claim to reach `Bound` state (to find volume in which to claim the space).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#wait_until_bound PersistentVolumeClaimV1#wait_until_bound}
     *
     * @stability stable
     */
    readonly waitUntilBound?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#metadata PersistentVolumeClaimV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: PersistentVolumeClaimV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#spec PersistentVolumeClaimV1#spec}
     *
     * @stability stable
     */
    readonly spec: PersistentVolumeClaimV1Spec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#timeouts PersistentVolumeClaimV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: PersistentVolumeClaimV1Timeouts;
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimV1Metadata {
    /**
     * An unstructured key value map stored with the persistent volume claim that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#annotations PersistentVolumeClaimV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#generate_name PersistentVolumeClaimV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the persistent volume claim.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#labels PersistentVolumeClaimV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the persistent volume claim, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#name PersistentVolumeClaimV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the persistent volume claim must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#namespace PersistentVolumeClaimV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function persistentVolumeClaimV1MetadataToTerraform(struct?: PersistentVolumeClaimV1MetadataOutputReference | PersistentVolumeClaimV1Metadata): any;
/**
 * @stability stable
 */
export declare class PersistentVolumeClaimV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PersistentVolumeClaimV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PersistentVolumeClaimV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimV1SpecResources {
    /**
     * Map describing the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#limits PersistentVolumeClaimV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map describing the minimum amount of compute resources required.
     *
     * If this is omitted for a container, it defaults to `limits` if that is explicitly specified, otherwise to an implementation-defined value. More info: http://kubernetes.io/docs/user-guide/compute-resources/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#requests PersistentVolumeClaimV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function persistentVolumeClaimV1SpecResourcesToTerraform(struct?: PersistentVolumeClaimV1SpecResourcesOutputReference | PersistentVolumeClaimV1SpecResources): any;
/**
 * @stability stable
 */
export declare class PersistentVolumeClaimV1SpecResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PersistentVolumeClaimV1SpecResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PersistentVolumeClaimV1SpecResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimV1SpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#key PersistentVolumeClaimV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#operator PersistentVolumeClaimV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#values PersistentVolumeClaimV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function persistentVolumeClaimV1SpecSelectorMatchExpressionsToTerraform(struct?: PersistentVolumeClaimV1SpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface PersistentVolumeClaimV1SpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#match_labels PersistentVolumeClaimV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#match_expressions PersistentVolumeClaimV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PersistentVolumeClaimV1SpecSelectorMatchExpressions[];
}
export declare function persistentVolumeClaimV1SpecSelectorToTerraform(struct?: PersistentVolumeClaimV1SpecSelectorOutputReference | PersistentVolumeClaimV1SpecSelector): any;
/**
 * @stability stable
 */
export declare class PersistentVolumeClaimV1SpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PersistentVolumeClaimV1SpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PersistentVolumeClaimV1SpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): PersistentVolumeClaimV1SpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: PersistentVolumeClaimV1SpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): PersistentVolumeClaimV1SpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimV1Spec {
    /**
     * A set of the desired access modes the volume should have. More info: http://kubernetes.io/docs/user-guide/persistent-volumes#access-modes-1.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#access_modes PersistentVolumeClaimV1#access_modes}
     *
     * @stability stable
     */
    readonly accessModes: string[];
    /**
     * Name of the storage class requested by the claim.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#storage_class_name PersistentVolumeClaimV1#storage_class_name}
     *
     * @stability stable
     */
    readonly storageClassName?: string;
    /**
     * The binding reference to the PersistentVolume backing this claim.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#volume_name PersistentVolumeClaimV1#volume_name}
     *
     * @stability stable
     */
    readonly volumeName?: string;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#resources PersistentVolumeClaimV1#resources}
     *
     * @stability stable
     */
    readonly resources: PersistentVolumeClaimV1SpecResources;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#selector PersistentVolumeClaimV1#selector}
     *
     * @stability stable
     */
    readonly selector?: PersistentVolumeClaimV1SpecSelector;
}
export declare function persistentVolumeClaimV1SpecToTerraform(struct?: PersistentVolumeClaimV1SpecOutputReference | PersistentVolumeClaimV1Spec): any;
/**
 * @stability stable
 */
export declare class PersistentVolumeClaimV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PersistentVolumeClaimV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PersistentVolumeClaimV1Spec | undefined);
    private _accessModes?;
    /**
     * @stability stable
     */
    get accessModes(): string[];
    /**
     * @stability stable
     */
    set accessModes(value: string[]);
    /**
     * @stability stable
     */
    get accessModesInput(): string[] | undefined;
    private _storageClassName?;
    /**
     * @stability stable
     */
    get storageClassName(): string;
    /**
     * @stability stable
     */
    set storageClassName(value: string);
    /**
     * @stability stable
     */
    resetStorageClassName(): void;
    /**
     * @stability stable
     */
    get storageClassNameInput(): string | undefined;
    private _volumeName?;
    /**
     * @stability stable
     */
    get volumeName(): string;
    /**
     * @stability stable
     */
    set volumeName(value: string);
    /**
     * @stability stable
     */
    resetVolumeName(): void;
    /**
     * @stability stable
     */
    get volumeNameInput(): string | undefined;
    private _resources;
    /**
     * @stability stable
     */
    get resources(): PersistentVolumeClaimV1SpecResourcesOutputReference;
    /**
     * @stability stable
     */
    putResources(value: PersistentVolumeClaimV1SpecResources): void;
    /**
     * @stability stable
     */
    get resourcesInput(): PersistentVolumeClaimV1SpecResources | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): PersistentVolumeClaimV1SpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: PersistentVolumeClaimV1SpecSelector): void;
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): PersistentVolumeClaimV1SpecSelector | undefined;
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html#create PersistentVolumeClaimV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function persistentVolumeClaimV1TimeoutsToTerraform(struct?: PersistentVolumeClaimV1TimeoutsOutputReference | PersistentVolumeClaimV1Timeouts): any;
/**
 * @stability stable
 */
export declare class PersistentVolumeClaimV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PersistentVolumeClaimV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PersistentVolumeClaimV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html kubernetes_persistent_volume_claim_v1}.
 *
 * @stability stable
 */
export declare class PersistentVolumeClaimV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/persistent_volume_claim_v1.html kubernetes_persistent_volume_claim_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PersistentVolumeClaimV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _waitUntilBound?;
    /**
     * @stability stable
     */
    get waitUntilBound(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitUntilBound(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitUntilBound(): void;
    /**
     * @stability stable
     */
    get waitUntilBoundInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PersistentVolumeClaimV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: PersistentVolumeClaimV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): PersistentVolumeClaimV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PersistentVolumeClaimV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: PersistentVolumeClaimV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): PersistentVolumeClaimV1Spec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): PersistentVolumeClaimV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: PersistentVolumeClaimV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PersistentVolumeClaimV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
