import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PodDisruptionBudgetV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#metadata PodDisruptionBudgetV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: PodDisruptionBudgetV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#spec PodDisruptionBudgetV1#spec}
     *
     * @stability stable
     */
    readonly spec: PodDisruptionBudgetV1Spec;
}
/**
 * @stability stable
 */
export interface PodDisruptionBudgetV1Metadata {
    /**
     * An unstructured key value map stored with the pod disruption budget that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#annotations PodDisruptionBudgetV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#generate_name PodDisruptionBudgetV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the pod disruption budget.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#labels PodDisruptionBudgetV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the pod disruption budget, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#name PodDisruptionBudgetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the pod disruption budget must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#namespace PodDisruptionBudgetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function podDisruptionBudgetV1MetadataToTerraform(struct?: PodDisruptionBudgetV1MetadataOutputReference | PodDisruptionBudgetV1Metadata): any;
/**
 * @stability stable
 */
export declare class PodDisruptionBudgetV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodDisruptionBudgetV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodDisruptionBudgetV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface PodDisruptionBudgetV1SpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#key PodDisruptionBudgetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#operator PodDisruptionBudgetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#values PodDisruptionBudgetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function podDisruptionBudgetV1SpecSelectorMatchExpressionsToTerraform(struct?: PodDisruptionBudgetV1SpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface PodDisruptionBudgetV1SpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#match_labels PodDisruptionBudgetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#match_expressions PodDisruptionBudgetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodDisruptionBudgetV1SpecSelectorMatchExpressions[];
}
export declare function podDisruptionBudgetV1SpecSelectorToTerraform(struct?: PodDisruptionBudgetV1SpecSelectorOutputReference | PodDisruptionBudgetV1SpecSelector): any;
/**
 * @stability stable
 */
export declare class PodDisruptionBudgetV1SpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodDisruptionBudgetV1SpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodDisruptionBudgetV1SpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): PodDisruptionBudgetV1SpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: PodDisruptionBudgetV1SpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): PodDisruptionBudgetV1SpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface PodDisruptionBudgetV1Spec {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#max_unavailable PodDisruptionBudgetV1#max_unavailable}.
     *
     * @stability stable
     */
    readonly maxUnavailable?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#min_available PodDisruptionBudgetV1#min_available}.
     *
     * @stability stable
     */
    readonly minAvailable?: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html#selector PodDisruptionBudgetV1#selector}
     *
     * @stability stable
     */
    readonly selector: PodDisruptionBudgetV1SpecSelector;
}
export declare function podDisruptionBudgetV1SpecToTerraform(struct?: PodDisruptionBudgetV1SpecOutputReference | PodDisruptionBudgetV1Spec): any;
/**
 * @stability stable
 */
export declare class PodDisruptionBudgetV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodDisruptionBudgetV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodDisruptionBudgetV1Spec | undefined);
    private _maxUnavailable?;
    /**
     * @stability stable
     */
    get maxUnavailable(): string;
    /**
     * @stability stable
     */
    set maxUnavailable(value: string);
    /**
     * @stability stable
     */
    resetMaxUnavailable(): void;
    /**
     * @stability stable
     */
    get maxUnavailableInput(): string | undefined;
    private _minAvailable?;
    /**
     * @stability stable
     */
    get minAvailable(): string;
    /**
     * @stability stable
     */
    set minAvailable(value: string);
    /**
     * @stability stable
     */
    resetMinAvailable(): void;
    /**
     * @stability stable
     */
    get minAvailableInput(): string | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): PodDisruptionBudgetV1SpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: PodDisruptionBudgetV1SpecSelector): void;
    /**
     * @stability stable
     */
    get selectorInput(): PodDisruptionBudgetV1SpecSelector | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html kubernetes_pod_disruption_budget_v1}.
 *
 * @stability stable
 */
export declare class PodDisruptionBudgetV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_disruption_budget_v1.html kubernetes_pod_disruption_budget_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PodDisruptionBudgetV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PodDisruptionBudgetV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: PodDisruptionBudgetV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): PodDisruptionBudgetV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PodDisruptionBudgetV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: PodDisruptionBudgetV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): PodDisruptionBudgetV1Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
