import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#metadata PodSecurityPolicyV1Beta1#metadata}
     *
     * @stability stable
     */
    readonly metadata: PodSecurityPolicyV1Beta1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#spec PodSecurityPolicyV1Beta1#spec}
     *
     * @stability stable
     */
    readonly spec: PodSecurityPolicyV1Beta1Spec;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1Metadata {
    /**
     * An unstructured key value map stored with the podsecuritypolicy that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#annotations PodSecurityPolicyV1Beta1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the podsecuritypolicy.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#labels PodSecurityPolicyV1Beta1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the podsecuritypolicy, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#name PodSecurityPolicyV1Beta1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function podSecurityPolicyV1Beta1MetadataToTerraform(struct?: PodSecurityPolicyV1Beta1MetadataOutputReference | PodSecurityPolicyV1Beta1Metadata): any;
/**
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodSecurityPolicyV1Beta1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodSecurityPolicyV1Beta1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecAllowedFlexVolumes {
    /**
     * driver is the name of the Flexvolume driver.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#driver PodSecurityPolicyV1Beta1#driver}
     *
     * @stability stable
     */
    readonly driver: string;
}
export declare function podSecurityPolicyV1Beta1SpecAllowedFlexVolumesToTerraform(struct?: PodSecurityPolicyV1Beta1SpecAllowedFlexVolumes): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecAllowedHostPaths {
    /**
     * pathPrefix is the path prefix that the host volume must match.
     *
     * It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
     *
     * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#path_prefix PodSecurityPolicyV1Beta1#path_prefix}
     *
     * @stability stable
     */
    readonly pathPrefix: string;
    /**
     * when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#read_only PodSecurityPolicyV1Beta1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function podSecurityPolicyV1Beta1SpecAllowedHostPathsToTerraform(struct?: PodSecurityPolicyV1Beta1SpecAllowedHostPaths): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecFsGroupRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#max PodSecurityPolicyV1Beta1#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#min PodSecurityPolicyV1Beta1#min}
     *
     * @stability stable
     */
    readonly min: number;
}
export declare function podSecurityPolicyV1Beta1SpecFsGroupRangeToTerraform(struct?: PodSecurityPolicyV1Beta1SpecFsGroupRange): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecFsGroup {
    /**
     * rule is the strategy that will dictate what FSGroup is used in the SecurityContext.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#rule PodSecurityPolicyV1Beta1#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#range PodSecurityPolicyV1Beta1#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicyV1Beta1SpecFsGroupRange[];
}
export declare function podSecurityPolicyV1Beta1SpecFsGroupToTerraform(struct?: PodSecurityPolicyV1Beta1SpecFsGroupOutputReference | PodSecurityPolicyV1Beta1SpecFsGroup): any;
/**
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1SpecFsGroupOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodSecurityPolicyV1Beta1SpecFsGroup | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodSecurityPolicyV1Beta1SpecFsGroup | undefined);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicyV1Beta1SpecFsGroupRange[];
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicyV1Beta1SpecFsGroupRange[]);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicyV1Beta1SpecFsGroupRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecHostPorts {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#max PodSecurityPolicyV1Beta1#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#min PodSecurityPolicyV1Beta1#min}
     *
     * @stability stable
     */
    readonly min: number;
}
export declare function podSecurityPolicyV1Beta1SpecHostPortsToTerraform(struct?: PodSecurityPolicyV1Beta1SpecHostPorts): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecRunAsGroupRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#max PodSecurityPolicyV1Beta1#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#min PodSecurityPolicyV1Beta1#min}
     *
     * @stability stable
     */
    readonly min: number;
}
export declare function podSecurityPolicyV1Beta1SpecRunAsGroupRangeToTerraform(struct?: PodSecurityPolicyV1Beta1SpecRunAsGroupRange): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecRunAsGroup {
    /**
     * rule is the strategy that will dictate the allowable RunAsGroup values that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#rule PodSecurityPolicyV1Beta1#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#range PodSecurityPolicyV1Beta1#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicyV1Beta1SpecRunAsGroupRange[];
}
export declare function podSecurityPolicyV1Beta1SpecRunAsGroupToTerraform(struct?: PodSecurityPolicyV1Beta1SpecRunAsGroupOutputReference | PodSecurityPolicyV1Beta1SpecRunAsGroup): any;
/**
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1SpecRunAsGroupOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodSecurityPolicyV1Beta1SpecRunAsGroup | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodSecurityPolicyV1Beta1SpecRunAsGroup | undefined);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicyV1Beta1SpecRunAsGroupRange[];
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicyV1Beta1SpecRunAsGroupRange[]);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicyV1Beta1SpecRunAsGroupRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecRunAsUserRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#max PodSecurityPolicyV1Beta1#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#min PodSecurityPolicyV1Beta1#min}
     *
     * @stability stable
     */
    readonly min: number;
}
export declare function podSecurityPolicyV1Beta1SpecRunAsUserRangeToTerraform(struct?: PodSecurityPolicyV1Beta1SpecRunAsUserRange): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecRunAsUser {
    /**
     * rule is the strategy that will dictate the allowable RunAsUser values that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#rule PodSecurityPolicyV1Beta1#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#range PodSecurityPolicyV1Beta1#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicyV1Beta1SpecRunAsUserRange[];
}
export declare function podSecurityPolicyV1Beta1SpecRunAsUserToTerraform(struct?: PodSecurityPolicyV1Beta1SpecRunAsUserOutputReference | PodSecurityPolicyV1Beta1SpecRunAsUser): any;
/**
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1SpecRunAsUserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodSecurityPolicyV1Beta1SpecRunAsUser | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodSecurityPolicyV1Beta1SpecRunAsUser | undefined);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicyV1Beta1SpecRunAsUserRange[];
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicyV1Beta1SpecRunAsUserRange[]);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicyV1Beta1SpecRunAsUserRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecSeLinuxSeLinuxOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#level PodSecurityPolicyV1Beta1#level}.
     *
     * @stability stable
     */
    readonly level: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#role PodSecurityPolicyV1Beta1#role}.
     *
     * @stability stable
     */
    readonly role: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#type PodSecurityPolicyV1Beta1#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#user PodSecurityPolicyV1Beta1#user}.
     *
     * @stability stable
     */
    readonly user: string;
}
export declare function podSecurityPolicyV1Beta1SpecSeLinuxSeLinuxOptionsToTerraform(struct?: PodSecurityPolicyV1Beta1SpecSeLinuxSeLinuxOptions): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecSeLinux {
    /**
     * rule is the strategy that will dictate the allowable labels that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#rule PodSecurityPolicyV1Beta1#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#se_linux_options PodSecurityPolicyV1Beta1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: PodSecurityPolicyV1Beta1SpecSeLinuxSeLinuxOptions[];
}
export declare function podSecurityPolicyV1Beta1SpecSeLinuxToTerraform(struct?: PodSecurityPolicyV1Beta1SpecSeLinuxOutputReference | PodSecurityPolicyV1Beta1SpecSeLinux): any;
/**
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1SpecSeLinuxOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodSecurityPolicyV1Beta1SpecSeLinux | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodSecurityPolicyV1Beta1SpecSeLinux | undefined);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _seLinuxOptions?;
    /**
     * @stability stable
     */
    get seLinuxOptions(): PodSecurityPolicyV1Beta1SpecSeLinuxSeLinuxOptions[];
    /**
     * @stability stable
     */
    set seLinuxOptions(value: PodSecurityPolicyV1Beta1SpecSeLinuxSeLinuxOptions[]);
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): PodSecurityPolicyV1Beta1SpecSeLinuxSeLinuxOptions[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecSupplementalGroupsRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#max PodSecurityPolicyV1Beta1#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#min PodSecurityPolicyV1Beta1#min}
     *
     * @stability stable
     */
    readonly min: number;
}
export declare function podSecurityPolicyV1Beta1SpecSupplementalGroupsRangeToTerraform(struct?: PodSecurityPolicyV1Beta1SpecSupplementalGroupsRange): any;
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1SpecSupplementalGroups {
    /**
     * rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#rule PodSecurityPolicyV1Beta1#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#range PodSecurityPolicyV1Beta1#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicyV1Beta1SpecSupplementalGroupsRange[];
}
export declare function podSecurityPolicyV1Beta1SpecSupplementalGroupsToTerraform(struct?: PodSecurityPolicyV1Beta1SpecSupplementalGroupsOutputReference | PodSecurityPolicyV1Beta1SpecSupplementalGroups): any;
/**
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1SpecSupplementalGroupsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodSecurityPolicyV1Beta1SpecSupplementalGroups | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodSecurityPolicyV1Beta1SpecSupplementalGroups | undefined);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicyV1Beta1SpecSupplementalGroupsRange[];
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicyV1Beta1SpecSupplementalGroupsRange[]);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicyV1Beta1SpecSupplementalGroupsRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyV1Beta1Spec {
    /**
     * allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#allow_privilege_escalation PodSecurityPolicyV1Beta1#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * allowedCapabilities is a list of capabilities that can be requested to add to the container.
     *
     * Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#allowed_capabilities PodSecurityPolicyV1Beta1#allowed_capabilities}
     *
     * @stability stable
     */
    readonly allowedCapabilities?: string[];
    /**
     * AllowedProcMountTypes is an allowlist of allowed ProcMountTypes.
     *
     * Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#allowed_proc_mount_types PodSecurityPolicyV1Beta1#allowed_proc_mount_types}
     *
     * @stability stable
     */
    readonly allowedProcMountTypes?: string[];
    /**
     * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none.
     *
     * Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to allowlist all allowed unsafe sysctls explicitly to avoid rejection.
     *
     * Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#allowed_unsafe_sysctls PodSecurityPolicyV1Beta1#allowed_unsafe_sysctls}
     *
     * @stability stable
     */
    readonly allowedUnsafeSysctls?: string[];
    /**
     * defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.
     *
     * You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#default_add_capabilities PodSecurityPolicyV1Beta1#default_add_capabilities}
     *
     * @stability stable
     */
    readonly defaultAddCapabilities?: string[];
    /**
     * defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#default_allow_privilege_escalation PodSecurityPolicyV1Beta1#default_allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly defaultAllowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none.
     *
     * Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
     *
     * Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#forbidden_sysctls PodSecurityPolicyV1Beta1#forbidden_sysctls}
     *
     * @stability stable
     */
    readonly forbiddenSysctls?: string[];
    /**
     * hostIPC determines if the policy allows the use of HostIPC in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#host_ipc PodSecurityPolicyV1Beta1#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean | cdktf.IResolvable;
    /**
     * hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#host_network PodSecurityPolicyV1Beta1#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean | cdktf.IResolvable;
    /**
     * hostPID determines if the policy allows the use of HostPID in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#host_pid PodSecurityPolicyV1Beta1#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean | cdktf.IResolvable;
    /**
     * privileged determines if a pod can request to be run as privileged.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#privileged PodSecurityPolicyV1Beta1#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.
     *
     * If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#read_only_root_filesystem PodSecurityPolicyV1Beta1#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * requiredDropCapabilities are the capabilities that will be dropped from the container.
     *
     * These are required to be dropped and cannot be added.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#required_drop_capabilities PodSecurityPolicyV1Beta1#required_drop_capabilities}
     *
     * @stability stable
     */
    readonly requiredDropCapabilities?: string[];
    /**
     * volumes is an allowlist of volume plugins.
     *
     * Empty indicates that no volumes may be used. To allow all volumes you may use '*'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#volumes PodSecurityPolicyV1Beta1#volumes}
     *
     * @stability stable
     */
    readonly volumes?: string[];
    /**
     * allowed_flex_volumes block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#allowed_flex_volumes PodSecurityPolicyV1Beta1#allowed_flex_volumes}
     *
     * @stability stable
     */
    readonly allowedFlexVolumes?: PodSecurityPolicyV1Beta1SpecAllowedFlexVolumes[];
    /**
     * allowed_host_paths block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#allowed_host_paths PodSecurityPolicyV1Beta1#allowed_host_paths}
     *
     * @stability stable
     */
    readonly allowedHostPaths?: PodSecurityPolicyV1Beta1SpecAllowedHostPaths[];
    /**
     * fs_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#fs_group PodSecurityPolicyV1Beta1#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup: PodSecurityPolicyV1Beta1SpecFsGroup;
    /**
     * host_ports block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#host_ports PodSecurityPolicyV1Beta1#host_ports}
     *
     * @stability stable
     */
    readonly hostPorts?: PodSecurityPolicyV1Beta1SpecHostPorts[];
    /**
     * run_as_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#run_as_group PodSecurityPolicyV1Beta1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: PodSecurityPolicyV1Beta1SpecRunAsGroup;
    /**
     * run_as_user block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#run_as_user PodSecurityPolicyV1Beta1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser: PodSecurityPolicyV1Beta1SpecRunAsUser;
    /**
     * se_linux block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#se_linux PodSecurityPolicyV1Beta1#se_linux}
     *
     * @stability stable
     */
    readonly seLinux?: PodSecurityPolicyV1Beta1SpecSeLinux;
    /**
     * supplemental_groups block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html#supplemental_groups PodSecurityPolicyV1Beta1#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups: PodSecurityPolicyV1Beta1SpecSupplementalGroups;
}
export declare function podSecurityPolicyV1Beta1SpecToTerraform(struct?: PodSecurityPolicyV1Beta1SpecOutputReference | PodSecurityPolicyV1Beta1Spec): any;
/**
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PodSecurityPolicyV1Beta1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PodSecurityPolicyV1Beta1Spec | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _allowedCapabilities?;
    /**
     * @stability stable
     */
    get allowedCapabilities(): string[];
    /**
     * @stability stable
     */
    set allowedCapabilities(value: string[]);
    /**
     * @stability stable
     */
    resetAllowedCapabilities(): void;
    /**
     * @stability stable
     */
    get allowedCapabilitiesInput(): string[] | undefined;
    private _allowedProcMountTypes?;
    /**
     * @stability stable
     */
    get allowedProcMountTypes(): string[];
    /**
     * @stability stable
     */
    set allowedProcMountTypes(value: string[]);
    /**
     * @stability stable
     */
    resetAllowedProcMountTypes(): void;
    /**
     * @stability stable
     */
    get allowedProcMountTypesInput(): string[] | undefined;
    private _allowedUnsafeSysctls?;
    /**
     * @stability stable
     */
    get allowedUnsafeSysctls(): string[];
    /**
     * @stability stable
     */
    set allowedUnsafeSysctls(value: string[]);
    /**
     * @stability stable
     */
    resetAllowedUnsafeSysctls(): void;
    /**
     * @stability stable
     */
    get allowedUnsafeSysctlsInput(): string[] | undefined;
    private _defaultAddCapabilities?;
    /**
     * @stability stable
     */
    get defaultAddCapabilities(): string[];
    /**
     * @stability stable
     */
    set defaultAddCapabilities(value: string[]);
    /**
     * @stability stable
     */
    resetDefaultAddCapabilities(): void;
    /**
     * @stability stable
     */
    get defaultAddCapabilitiesInput(): string[] | undefined;
    private _defaultAllowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get defaultAllowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set defaultAllowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDefaultAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get defaultAllowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _forbiddenSysctls?;
    /**
     * @stability stable
     */
    get forbiddenSysctls(): string[];
    /**
     * @stability stable
     */
    set forbiddenSysctls(value: string[]);
    /**
     * @stability stable
     */
    resetForbiddenSysctls(): void;
    /**
     * @stability stable
     */
    get forbiddenSysctlsInput(): string[] | undefined;
    private _hostIpc?;
    /**
     * @stability stable
     */
    get hostIpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostIpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostIpc(): void;
    /**
     * @stability stable
     */
    get hostIpcInput(): boolean | cdktf.IResolvable | undefined;
    private _hostNetwork?;
    /**
     * @stability stable
     */
    get hostNetwork(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostNetwork(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostNetwork(): void;
    /**
     * @stability stable
     */
    get hostNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _hostPid?;
    /**
     * @stability stable
     */
    get hostPid(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostPid(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostPid(): void;
    /**
     * @stability stable
     */
    get hostPidInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _requiredDropCapabilities?;
    /**
     * @stability stable
     */
    get requiredDropCapabilities(): string[];
    /**
     * @stability stable
     */
    set requiredDropCapabilities(value: string[]);
    /**
     * @stability stable
     */
    resetRequiredDropCapabilities(): void;
    /**
     * @stability stable
     */
    get requiredDropCapabilitiesInput(): string[] | undefined;
    private _volumes?;
    /**
     * @stability stable
     */
    get volumes(): string[];
    /**
     * @stability stable
     */
    set volumes(value: string[]);
    /**
     * @stability stable
     */
    resetVolumes(): void;
    /**
     * @stability stable
     */
    get volumesInput(): string[] | undefined;
    private _allowedFlexVolumes?;
    /**
     * @stability stable
     */
    get allowedFlexVolumes(): PodSecurityPolicyV1Beta1SpecAllowedFlexVolumes[];
    /**
     * @stability stable
     */
    set allowedFlexVolumes(value: PodSecurityPolicyV1Beta1SpecAllowedFlexVolumes[]);
    /**
     * @stability stable
     */
    resetAllowedFlexVolumes(): void;
    /**
     * @stability stable
     */
    get allowedFlexVolumesInput(): PodSecurityPolicyV1Beta1SpecAllowedFlexVolumes[] | undefined;
    private _allowedHostPaths?;
    /**
     * @stability stable
     */
    get allowedHostPaths(): PodSecurityPolicyV1Beta1SpecAllowedHostPaths[];
    /**
     * @stability stable
     */
    set allowedHostPaths(value: PodSecurityPolicyV1Beta1SpecAllowedHostPaths[]);
    /**
     * @stability stable
     */
    resetAllowedHostPaths(): void;
    /**
     * @stability stable
     */
    get allowedHostPathsInput(): PodSecurityPolicyV1Beta1SpecAllowedHostPaths[] | undefined;
    private _fsGroup;
    /**
     * @stability stable
     */
    get fsGroup(): PodSecurityPolicyV1Beta1SpecFsGroupOutputReference;
    /**
     * @stability stable
     */
    putFsGroup(value: PodSecurityPolicyV1Beta1SpecFsGroup): void;
    /**
     * @stability stable
     */
    get fsGroupInput(): PodSecurityPolicyV1Beta1SpecFsGroup | undefined;
    private _hostPorts?;
    /**
     * @stability stable
     */
    get hostPorts(): PodSecurityPolicyV1Beta1SpecHostPorts[];
    /**
     * @stability stable
     */
    set hostPorts(value: PodSecurityPolicyV1Beta1SpecHostPorts[]);
    /**
     * @stability stable
     */
    resetHostPorts(): void;
    /**
     * @stability stable
     */
    get hostPortsInput(): PodSecurityPolicyV1Beta1SpecHostPorts[] | undefined;
    private _runAsGroup;
    /**
     * @stability stable
     */
    get runAsGroup(): PodSecurityPolicyV1Beta1SpecRunAsGroupOutputReference;
    /**
     * @stability stable
     */
    putRunAsGroup(value: PodSecurityPolicyV1Beta1SpecRunAsGroup): void;
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): PodSecurityPolicyV1Beta1SpecRunAsGroup | undefined;
    private _runAsUser;
    /**
     * @stability stable
     */
    get runAsUser(): PodSecurityPolicyV1Beta1SpecRunAsUserOutputReference;
    /**
     * @stability stable
     */
    putRunAsUser(value: PodSecurityPolicyV1Beta1SpecRunAsUser): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): PodSecurityPolicyV1Beta1SpecRunAsUser | undefined;
    private _seLinux;
    /**
     * @stability stable
     */
    get seLinux(): PodSecurityPolicyV1Beta1SpecSeLinuxOutputReference;
    /**
     * @stability stable
     */
    putSeLinux(value: PodSecurityPolicyV1Beta1SpecSeLinux): void;
    /**
     * @stability stable
     */
    resetSeLinux(): void;
    /**
     * @stability stable
     */
    get seLinuxInput(): PodSecurityPolicyV1Beta1SpecSeLinux | undefined;
    private _supplementalGroups;
    /**
     * @stability stable
     */
    get supplementalGroups(): PodSecurityPolicyV1Beta1SpecSupplementalGroupsOutputReference;
    /**
     * @stability stable
     */
    putSupplementalGroups(value: PodSecurityPolicyV1Beta1SpecSupplementalGroups): void;
    /**
     * @stability stable
     */
    get supplementalGroupsInput(): PodSecurityPolicyV1Beta1SpecSupplementalGroups | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html kubernetes_pod_security_policy_v1beta1}.
 *
 * @stability stable
 */
export declare class PodSecurityPolicyV1Beta1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy_v1beta1.html kubernetes_pod_security_policy_v1beta1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PodSecurityPolicyV1Beta1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PodSecurityPolicyV1Beta1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: PodSecurityPolicyV1Beta1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): PodSecurityPolicyV1Beta1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PodSecurityPolicyV1Beta1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: PodSecurityPolicyV1Beta1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): PodSecurityPolicyV1Beta1Spec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
