import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ResourceQuotaV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#metadata ResourceQuotaV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: ResourceQuotaV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#spec ResourceQuotaV1#spec}
     *
     * @stability stable
     */
    readonly spec?: ResourceQuotaV1Spec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#timeouts ResourceQuotaV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ResourceQuotaV1Timeouts;
}
/**
 * @stability stable
 */
export interface ResourceQuotaV1Metadata {
    /**
     * An unstructured key value map stored with the resource quota that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#annotations ResourceQuotaV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#generate_name ResourceQuotaV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the resource quota.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#labels ResourceQuotaV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the resource quota, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#name ResourceQuotaV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the resource quota must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#namespace ResourceQuotaV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function resourceQuotaV1MetadataToTerraform(struct?: ResourceQuotaV1MetadataOutputReference | ResourceQuotaV1Metadata): any;
/**
 * @stability stable
 */
export declare class ResourceQuotaV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ResourceQuotaV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ResourceQuotaV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ResourceQuotaV1SpecScopeSelectorMatchExpression {
    /**
     * Represents a scope's relationship to a set of values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#operator ResourceQuotaV1#operator}
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * The name of the scope that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#scope_name ResourceQuotaV1#scope_name}
     *
     * @stability stable
     */
    readonly scopeName: string;
    /**
     * A list of scope selector requirements by scope of the resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#values ResourceQuotaV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function resourceQuotaV1SpecScopeSelectorMatchExpressionToTerraform(struct?: ResourceQuotaV1SpecScopeSelectorMatchExpression): any;
/**
 * @stability stable
 */
export interface ResourceQuotaV1SpecScopeSelector {
    /**
     * match_expression block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#match_expression ResourceQuotaV1#match_expression}
     *
     * @stability stable
     */
    readonly matchExpression?: ResourceQuotaV1SpecScopeSelectorMatchExpression[];
}
export declare function resourceQuotaV1SpecScopeSelectorToTerraform(struct?: ResourceQuotaV1SpecScopeSelectorOutputReference | ResourceQuotaV1SpecScopeSelector): any;
/**
 * @stability stable
 */
export declare class ResourceQuotaV1SpecScopeSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ResourceQuotaV1SpecScopeSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ResourceQuotaV1SpecScopeSelector | undefined);
    private _matchExpression?;
    /**
     * @stability stable
     */
    get matchExpression(): ResourceQuotaV1SpecScopeSelectorMatchExpression[];
    /**
     * @stability stable
     */
    set matchExpression(value: ResourceQuotaV1SpecScopeSelectorMatchExpression[]);
    /**
     * @stability stable
     */
    resetMatchExpression(): void;
    /**
     * @stability stable
     */
    get matchExpressionInput(): ResourceQuotaV1SpecScopeSelectorMatchExpression[] | undefined;
}
/**
 * @stability stable
 */
export interface ResourceQuotaV1Spec {
    /**
     * The set of desired hard limits for each named resource. More info: http://releases.k8s.io/HEAD/docs/design/admission_control_resource_quota.md#admissioncontrol-plugin-resourcequota.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#hard ResourceQuotaV1#hard}
     *
     * @stability stable
     */
    readonly hard?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * A collection of filters that must match each object tracked by a quota.
     *
     * If not specified, the quota matches all objects.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#scopes ResourceQuotaV1#scopes}
     *
     * @stability stable
     */
    readonly scopes?: string[];
    /**
     * scope_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#scope_selector ResourceQuotaV1#scope_selector}
     *
     * @stability stable
     */
    readonly scopeSelector?: ResourceQuotaV1SpecScopeSelector;
}
export declare function resourceQuotaV1SpecToTerraform(struct?: ResourceQuotaV1SpecOutputReference | ResourceQuotaV1Spec): any;
/**
 * @stability stable
 */
export declare class ResourceQuotaV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ResourceQuotaV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ResourceQuotaV1Spec | undefined);
    private _hard?;
    /**
     * @stability stable
     */
    get hard(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hard(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHard(): void;
    /**
     * @stability stable
     */
    get hardInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _scopes?;
    /**
     * @stability stable
     */
    get scopes(): string[];
    /**
     * @stability stable
     */
    set scopes(value: string[]);
    /**
     * @stability stable
     */
    resetScopes(): void;
    /**
     * @stability stable
     */
    get scopesInput(): string[] | undefined;
    private _scopeSelector;
    /**
     * @stability stable
     */
    get scopeSelector(): ResourceQuotaV1SpecScopeSelectorOutputReference;
    /**
     * @stability stable
     */
    putScopeSelector(value: ResourceQuotaV1SpecScopeSelector): void;
    /**
     * @stability stable
     */
    resetScopeSelector(): void;
    /**
     * @stability stable
     */
    get scopeSelectorInput(): ResourceQuotaV1SpecScopeSelector | undefined;
}
/**
 * @stability stable
 */
export interface ResourceQuotaV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#create ResourceQuotaV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html#update ResourceQuotaV1#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function resourceQuotaV1TimeoutsToTerraform(struct?: ResourceQuotaV1TimeoutsOutputReference | ResourceQuotaV1Timeouts): any;
/**
 * @stability stable
 */
export declare class ResourceQuotaV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ResourceQuotaV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ResourceQuotaV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html kubernetes_resource_quota_v1}.
 *
 * @stability stable
 */
export declare class ResourceQuotaV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/resource_quota_v1.html kubernetes_resource_quota_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ResourceQuotaV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ResourceQuotaV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ResourceQuotaV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ResourceQuotaV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): ResourceQuotaV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: ResourceQuotaV1Spec): void;
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): ResourceQuotaV1Spec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ResourceQuotaV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ResourceQuotaV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ResourceQuotaV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
