import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RoleBindingConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#metadata RoleBinding#metadata}
     *
     * @stability stable
     */
    readonly metadata: RoleBindingMetadata;
    /**
     * role_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#role_ref RoleBinding#role_ref}
     *
     * @stability stable
     */
    readonly roleRef: RoleBindingRoleRef;
    /**
     * subject block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#subject RoleBinding#subject}
     *
     * @stability stable
     */
    readonly subject: RoleBindingSubject[];
}
/**
 * @stability stable
 */
export interface RoleBindingMetadata {
    /**
     * An unstructured key value map stored with the roleBinding that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#annotations RoleBinding#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the roleBinding.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#labels RoleBinding#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the roleBinding, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#name RoleBinding#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the roleBinding must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#namespace RoleBinding#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function roleBindingMetadataToTerraform(struct?: RoleBindingMetadataOutputReference | RoleBindingMetadata): any;
/**
 * @stability stable
 */
export declare class RoleBindingMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): RoleBindingMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: RoleBindingMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface RoleBindingRoleRef {
    /**
     * The API group of the user. The only value possible at the moment is `rbac.authorization.k8s.io`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#api_group RoleBinding#api_group}
     *
     * @stability stable
     */
    readonly apiGroup: string;
    /**
     * The kind of resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#kind RoleBinding#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the User to bind to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#name RoleBinding#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function roleBindingRoleRefToTerraform(struct?: RoleBindingRoleRefOutputReference | RoleBindingRoleRef): any;
/**
 * @stability stable
 */
export declare class RoleBindingRoleRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): RoleBindingRoleRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: RoleBindingRoleRef | undefined);
    private _apiGroup?;
    /**
     * @stability stable
     */
    get apiGroup(): string;
    /**
     * @stability stable
     */
    set apiGroup(value: string);
    /**
     * @stability stable
     */
    get apiGroupInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface RoleBindingSubject {
    /**
     * The API group of the subject resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#api_group RoleBinding#api_group}
     *
     * @stability stable
     */
    readonly apiGroup?: string;
    /**
     * The kind of resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#kind RoleBinding#kind}
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the resource to bind to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#name RoleBinding#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The Namespace of the subject resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html#namespace RoleBinding#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function roleBindingSubjectToTerraform(struct?: RoleBindingSubject): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html kubernetes_role_binding}.
 *
 * @stability stable
 */
export declare class RoleBinding extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/role_binding.html kubernetes_role_binding} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RoleBindingConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): RoleBindingMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: RoleBindingMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): RoleBindingMetadata | undefined;
    private _roleRef;
    /**
     * @stability stable
     */
    get roleRef(): RoleBindingRoleRefOutputReference;
    /**
     * @stability stable
     */
    putRoleRef(value: RoleBindingRoleRef): void;
    /**
     * @stability stable
     */
    get roleRefInput(): RoleBindingRoleRef | undefined;
    private _subject?;
    /**
     * @stability stable
     */
    get subject(): RoleBindingSubject[];
    /**
     * @stability stable
     */
    set subject(value: RoleBindingSubject[]);
    /**
     * @stability stable
     */
    get subjectInput(): RoleBindingSubject[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
