import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceAccountV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Enable automatic mounting of the service account token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#automount_service_account_token ServiceAccountV1#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean | cdktf.IResolvable;
    /**
     * image_pull_secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#image_pull_secret ServiceAccountV1#image_pull_secret}
     *
     * @stability stable
     */
    readonly imagePullSecret?: ServiceAccountV1ImagePullSecret[];
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#metadata ServiceAccountV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: ServiceAccountV1Metadata;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#secret ServiceAccountV1#secret}
     *
     * @stability stable
     */
    readonly secret?: ServiceAccountV1Secret[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#timeouts ServiceAccountV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ServiceAccountV1Timeouts;
}
/**
 * @stability stable
 */
export interface ServiceAccountV1ImagePullSecret {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#name ServiceAccountV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function serviceAccountV1ImagePullSecretToTerraform(struct?: ServiceAccountV1ImagePullSecret): any;
/**
 * @stability stable
 */
export interface ServiceAccountV1Metadata {
    /**
     * An unstructured key value map stored with the service account that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#annotations ServiceAccountV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#generate_name ServiceAccountV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service account.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#labels ServiceAccountV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the service account, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#name ServiceAccountV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service account must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#namespace ServiceAccountV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function serviceAccountV1MetadataToTerraform(struct?: ServiceAccountV1MetadataOutputReference | ServiceAccountV1Metadata): any;
/**
 * @stability stable
 */
export declare class ServiceAccountV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceAccountV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceAccountV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceAccountV1Secret {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#name ServiceAccountV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function serviceAccountV1SecretToTerraform(struct?: ServiceAccountV1Secret): any;
/**
 * @stability stable
 */
export interface ServiceAccountV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html#create ServiceAccountV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function serviceAccountV1TimeoutsToTerraform(struct?: ServiceAccountV1TimeoutsOutputReference | ServiceAccountV1Timeouts): any;
/**
 * @stability stable
 */
export declare class ServiceAccountV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceAccountV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceAccountV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html kubernetes_service_account_v1}.
 *
 * @stability stable
 */
export declare class ServiceAccountV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/service_account_v1.html kubernetes_service_account_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceAccountV1Config);
    private _automountServiceAccountToken?;
    /**
     * @stability stable
     */
    get automountServiceAccountToken(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set automountServiceAccountToken(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutomountServiceAccountToken(): void;
    /**
     * @stability stable
     */
    get automountServiceAccountTokenInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get defaultSecretName(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _imagePullSecret?;
    /**
     * @stability stable
     */
    get imagePullSecret(): ServiceAccountV1ImagePullSecret[];
    /**
     * @stability stable
     */
    set imagePullSecret(value: ServiceAccountV1ImagePullSecret[]);
    /**
     * @stability stable
     */
    resetImagePullSecret(): void;
    /**
     * @stability stable
     */
    get imagePullSecretInput(): ServiceAccountV1ImagePullSecret[] | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ServiceAccountV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ServiceAccountV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ServiceAccountV1Metadata | undefined;
    private _secret?;
    /**
     * @stability stable
     */
    get secret(): ServiceAccountV1Secret[];
    /**
     * @stability stable
     */
    set secret(value: ServiceAccountV1Secret[]);
    /**
     * @stability stable
     */
    resetSecret(): void;
    /**
     * @stability stable
     */
    get secretInput(): ServiceAccountV1Secret[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ServiceAccountV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ServiceAccountV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ServiceAccountV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
