import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Terraform will wait for the load balancer to have at least 1 endpoint before considering the resource created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#wait_for_load_balancer ServiceV1#wait_for_load_balancer}
     *
     * @stability stable
     */
    readonly waitForLoadBalancer?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#metadata ServiceV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: ServiceV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#spec ServiceV1#spec}
     *
     * @stability stable
     */
    readonly spec: ServiceV1Spec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#timeouts ServiceV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ServiceV1Timeouts;
}
/**
 * @stability stable
 */
export declare class ServiceV1StatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class ServiceV1StatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class ServiceV1Status extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface ServiceV1Metadata {
    /**
     * An unstructured key value map stored with the service that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#annotations ServiceV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#generate_name ServiceV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#labels ServiceV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the service, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#name ServiceV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#namespace ServiceV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function serviceV1MetadataToTerraform(struct?: ServiceV1MetadataOutputReference | ServiceV1Metadata): any;
/**
 * @stability stable
 */
export declare class ServiceV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceV1SpecPort {
    /**
     * The name of this port within the service.
     *
     * All ports within the service must have unique names. Optional if only one ServicePort is defined on this service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#name ServiceV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The port on each node on which this service is exposed when `type` is `NodePort` or `LoadBalancer`.
     *
     * Usually assigned by the system. If specified, it will be allocated to the service if unused or else creation of the service will fail. Default is to auto-allocate a port if the `type` of this service requires one. More info: http://kubernetes.io/docs/user-guide/services#type--nodeport
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#node_port ServiceV1#node_port}
     *
     * @stability stable
     */
    readonly nodePort?: number;
    /**
     * The port that will be exposed by this service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#port ServiceV1#port}
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * The IP protocol for this port. Supports `TCP` and `UDP`. Default is `TCP`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#protocol ServiceV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Number or name of the port to access on the pods targeted by the service.
     *
     * Number must be in the range 1 to 65535. This field is ignored for services with `cluster_ip = "None"`. More info: http://kubernetes.io/docs/user-guide/services#defining-a-service
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#target_port ServiceV1#target_port}
     *
     * @stability stable
     */
    readonly targetPort?: string;
}
export declare function serviceV1SpecPortToTerraform(struct?: ServiceV1SpecPort): any;
/**
 * @stability stable
 */
export interface ServiceV1Spec {
    /**
     * The IP address of the service.
     *
     * It is usually assigned randomly by the master. If an address is specified manually and is not in use by others, it will be allocated to the service; otherwise, creation of the service will fail. `None` can be specified for headless services when proxying is not required. Ignored if type is `ExternalName`. More info: http://kubernetes.io/docs/user-guide/services#virtual-ips-and-service-proxies
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#cluster_ip ServiceV1#cluster_ip}
     *
     * @stability stable
     */
    readonly clusterIp?: string;
    /**
     * A list of IP addresses for which nodes in the cluster will also accept traffic for this service.
     *
     * These IPs are not managed by Kubernetes. The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#external_ips ServiceV1#external_ips}
     *
     * @stability stable
     */
    readonly externalIps?: string[];
    /**
     * The external reference that kubedns or equivalent will return as a CNAME record for this service.
     *
     * No proxying will be involved. Must be a valid DNS name and requires `type` to be `ExternalName`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#external_name ServiceV1#external_name}
     *
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * Denotes if this Service desires to route external traffic to node-local or cluster-wide endpoints.
     *
     * `Local` preserves the client source IP and avoids a second hop for LoadBalancer and Nodeport type services, but risks potentially imbalanced traffic spreading. `Cluster` obscures the client source IP and may cause a second hop to another node, but should have good overall load-spreading. More info: https://kubernetes.io/docs/tutorials/services/source-ip/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#external_traffic_policy ServiceV1#external_traffic_policy}
     *
     * @stability stable
     */
    readonly externalTrafficPolicy?: string;
    /**
     * Specifies the Healthcheck NodePort for the service.
     *
     * Only effects when type is set to `LoadBalancer` and external_traffic_policy is set to `Local`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#health_check_node_port ServiceV1#health_check_node_port}
     *
     * @stability stable
     */
    readonly healthCheckNodePort?: number;
    /**
     * Only applies to `type = LoadBalancer`.
     *
     * LoadBalancer will get created with the IP specified in this field. This feature depends on whether the underlying cloud-provider supports specifying this field when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#load_balancer_ip ServiceV1#load_balancer_ip}
     *
     * @stability stable
     */
    readonly loadBalancerIp?: string;
    /**
     * If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs.
     *
     * This field will be ignored if the cloud-provider does not support the feature. More info: http://kubernetes.io/docs/user-guide/services-firewalls
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#load_balancer_source_ranges ServiceV1#load_balancer_source_ranges}
     *
     * @stability stable
     */
    readonly loadBalancerSourceRanges?: string[];
    /**
     * When set to true, indicates that DNS implementations must publish the `notReadyAddresses` of subsets for the Endpoints associated with the Service.
     *
     * The default value is `false`. The primary use case for setting this field is to use a StatefulSet's Headless Service to propagate `SRV` records for its Pods without respect to their readiness for purpose of peer discovery.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#publish_not_ready_addresses ServiceV1#publish_not_ready_addresses}
     *
     * @stability stable
     */
    readonly publishNotReadyAddresses?: boolean | cdktf.IResolvable;
    /**
     * Route service traffic to pods with label keys and values matching this selector.
     *
     * Only applies to types `ClusterIP`, `NodePort`, and `LoadBalancer`. More info: http://kubernetes.io/docs/user-guide/services#overview
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#selector ServiceV1#selector}
     *
     * @stability stable
     */
    readonly selector?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Used to maintain session affinity. Supports `ClientIP` and `None`. Defaults to `None`. More info: http://kubernetes.io/docs/user-guide/services#virtual-ips-and-service-proxies.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#session_affinity ServiceV1#session_affinity}
     *
     * @stability stable
     */
    readonly sessionAffinity?: string;
    /**
     * Determines how the service is exposed.
     *
     * Defaults to `ClusterIP`. Valid options are `ExternalName`, `ClusterIP`, `NodePort`, and `LoadBalancer`. `ExternalName` maps to the specified `external_name`. More info: http://kubernetes.io/docs/user-guide/services#overview
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#type ServiceV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#port ServiceV1#port}
     *
     * @stability stable
     */
    readonly port?: ServiceV1SpecPort[];
}
export declare function serviceV1SpecToTerraform(struct?: ServiceV1SpecOutputReference | ServiceV1Spec): any;
/**
 * @stability stable
 */
export declare class ServiceV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceV1Spec | undefined);
    private _clusterIp?;
    /**
     * @stability stable
     */
    get clusterIp(): string;
    /**
     * @stability stable
     */
    set clusterIp(value: string);
    /**
     * @stability stable
     */
    resetClusterIp(): void;
    /**
     * @stability stable
     */
    get clusterIpInput(): string | undefined;
    private _externalIps?;
    /**
     * @stability stable
     */
    get externalIps(): string[];
    /**
     * @stability stable
     */
    set externalIps(value: string[]);
    /**
     * @stability stable
     */
    resetExternalIps(): void;
    /**
     * @stability stable
     */
    get externalIpsInput(): string[] | undefined;
    private _externalName?;
    /**
     * @stability stable
     */
    get externalName(): string;
    /**
     * @stability stable
     */
    set externalName(value: string);
    /**
     * @stability stable
     */
    resetExternalName(): void;
    /**
     * @stability stable
     */
    get externalNameInput(): string | undefined;
    private _externalTrafficPolicy?;
    /**
     * @stability stable
     */
    get externalTrafficPolicy(): string;
    /**
     * @stability stable
     */
    set externalTrafficPolicy(value: string);
    /**
     * @stability stable
     */
    resetExternalTrafficPolicy(): void;
    /**
     * @stability stable
     */
    get externalTrafficPolicyInput(): string | undefined;
    private _healthCheckNodePort?;
    /**
     * @stability stable
     */
    get healthCheckNodePort(): number;
    /**
     * @stability stable
     */
    set healthCheckNodePort(value: number);
    /**
     * @stability stable
     */
    resetHealthCheckNodePort(): void;
    /**
     * @stability stable
     */
    get healthCheckNodePortInput(): number | undefined;
    private _loadBalancerIp?;
    /**
     * @stability stable
     */
    get loadBalancerIp(): string;
    /**
     * @stability stable
     */
    set loadBalancerIp(value: string);
    /**
     * @stability stable
     */
    resetLoadBalancerIp(): void;
    /**
     * @stability stable
     */
    get loadBalancerIpInput(): string | undefined;
    private _loadBalancerSourceRanges?;
    /**
     * @stability stable
     */
    get loadBalancerSourceRanges(): string[];
    /**
     * @stability stable
     */
    set loadBalancerSourceRanges(value: string[]);
    /**
     * @stability stable
     */
    resetLoadBalancerSourceRanges(): void;
    /**
     * @stability stable
     */
    get loadBalancerSourceRangesInput(): string[] | undefined;
    private _publishNotReadyAddresses?;
    /**
     * @stability stable
     */
    get publishNotReadyAddresses(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set publishNotReadyAddresses(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPublishNotReadyAddresses(): void;
    /**
     * @stability stable
     */
    get publishNotReadyAddressesInput(): boolean | cdktf.IResolvable | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set selector(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _sessionAffinity?;
    /**
     * @stability stable
     */
    get sessionAffinity(): string;
    /**
     * @stability stable
     */
    set sessionAffinity(value: string);
    /**
     * @stability stable
     */
    resetSessionAffinity(): void;
    /**
     * @stability stable
     */
    get sessionAffinityInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): ServiceV1SpecPort[];
    /**
     * @stability stable
     */
    set port(value: ServiceV1SpecPort[]);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): ServiceV1SpecPort[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html#create ServiceV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function serviceV1TimeoutsToTerraform(struct?: ServiceV1TimeoutsOutputReference | ServiceV1Timeouts): any;
/**
 * @stability stable
 */
export declare class ServiceV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html kubernetes_service_v1}.
 *
 * @stability stable
 */
export declare class ServiceV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/service_v1.html kubernetes_service_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    status(index: string): ServiceV1Status;
    private _waitForLoadBalancer?;
    /**
     * @stability stable
     */
    get waitForLoadBalancer(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForLoadBalancer(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForLoadBalancer(): void;
    /**
     * @stability stable
     */
    get waitForLoadBalancerInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ServiceV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ServiceV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ServiceV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): ServiceV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: ServiceV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): ServiceV1Spec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ServiceV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ServiceV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ServiceV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
