import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StorageClassV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Indicates whether the storage class allow volume expand.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#allow_volume_expansion StorageClassV1#allow_volume_expansion}
     *
     * @stability stable
     */
    readonly allowVolumeExpansion?: boolean | cdktf.IResolvable;
    /**
     * Persistent Volumes that are dynamically created by a storage class will have the mount options specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#mount_options StorageClassV1#mount_options}
     *
     * @stability stable
     */
    readonly mountOptions?: string[];
    /**
     * The parameters for the provisioner that should create volumes of this storage class.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#parameters StorageClassV1#parameters}
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Indicates the type of the reclaim policy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#reclaim_policy StorageClassV1#reclaim_policy}
     *
     * @stability stable
     */
    readonly reclaimPolicy?: string;
    /**
     * Indicates the type of the provisioner.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#storage_provisioner StorageClassV1#storage_provisioner}
     *
     * @stability stable
     */
    readonly storageProvisioner: string;
    /**
     * Indicates when volume binding and dynamic provisioning should occur.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#volume_binding_mode StorageClassV1#volume_binding_mode}
     *
     * @stability stable
     */
    readonly volumeBindingMode?: string;
    /**
     * allowed_topologies block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#allowed_topologies StorageClassV1#allowed_topologies}
     *
     * @stability stable
     */
    readonly allowedTopologies?: StorageClassV1AllowedTopologies;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#metadata StorageClassV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: StorageClassV1Metadata;
}
/**
 * @stability stable
 */
export interface StorageClassV1AllowedTopologiesMatchLabelExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#key StorageClassV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * An array of string values. One value must match the label to be selected.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#values StorageClassV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function storageClassV1AllowedTopologiesMatchLabelExpressionsToTerraform(struct?: StorageClassV1AllowedTopologiesMatchLabelExpressions): any;
/**
 * @stability stable
 */
export interface StorageClassV1AllowedTopologies {
    /**
     * match_label_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#match_label_expressions StorageClassV1#match_label_expressions}
     *
     * @stability stable
     */
    readonly matchLabelExpressions?: StorageClassV1AllowedTopologiesMatchLabelExpressions[];
}
export declare function storageClassV1AllowedTopologiesToTerraform(struct?: StorageClassV1AllowedTopologiesOutputReference | StorageClassV1AllowedTopologies): any;
/**
 * @stability stable
 */
export declare class StorageClassV1AllowedTopologiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StorageClassV1AllowedTopologies | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StorageClassV1AllowedTopologies | undefined);
    private _matchLabelExpressions?;
    /**
     * @stability stable
     */
    get matchLabelExpressions(): StorageClassV1AllowedTopologiesMatchLabelExpressions[];
    /**
     * @stability stable
     */
    set matchLabelExpressions(value: StorageClassV1AllowedTopologiesMatchLabelExpressions[]);
    /**
     * @stability stable
     */
    resetMatchLabelExpressions(): void;
    /**
     * @stability stable
     */
    get matchLabelExpressionsInput(): StorageClassV1AllowedTopologiesMatchLabelExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StorageClassV1Metadata {
    /**
     * An unstructured key value map stored with the storage class that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#annotations StorageClassV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#generate_name StorageClassV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the storage class.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#labels StorageClassV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the storage class, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html#name StorageClassV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function storageClassV1MetadataToTerraform(struct?: StorageClassV1MetadataOutputReference | StorageClassV1Metadata): any;
/**
 * @stability stable
 */
export declare class StorageClassV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StorageClassV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StorageClassV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html kubernetes_storage_class_v1}.
 *
 * @stability stable
 */
export declare class StorageClassV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class_v1.html kubernetes_storage_class_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StorageClassV1Config);
    private _allowVolumeExpansion?;
    /**
     * @stability stable
     */
    get allowVolumeExpansion(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowVolumeExpansion(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowVolumeExpansion(): void;
    /**
     * @stability stable
     */
    get allowVolumeExpansionInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _mountOptions?;
    /**
     * @stability stable
     */
    get mountOptions(): string[];
    /**
     * @stability stable
     */
    set mountOptions(value: string[]);
    /**
     * @stability stable
     */
    resetMountOptions(): void;
    /**
     * @stability stable
     */
    get mountOptionsInput(): string[] | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _reclaimPolicy?;
    /**
     * @stability stable
     */
    get reclaimPolicy(): string;
    /**
     * @stability stable
     */
    set reclaimPolicy(value: string);
    /**
     * @stability stable
     */
    resetReclaimPolicy(): void;
    /**
     * @stability stable
     */
    get reclaimPolicyInput(): string | undefined;
    private _storageProvisioner?;
    /**
     * @stability stable
     */
    get storageProvisioner(): string;
    /**
     * @stability stable
     */
    set storageProvisioner(value: string);
    /**
     * @stability stable
     */
    get storageProvisionerInput(): string | undefined;
    private _volumeBindingMode?;
    /**
     * @stability stable
     */
    get volumeBindingMode(): string;
    /**
     * @stability stable
     */
    set volumeBindingMode(value: string);
    /**
     * @stability stable
     */
    resetVolumeBindingMode(): void;
    /**
     * @stability stable
     */
    get volumeBindingModeInput(): string | undefined;
    private _allowedTopologies;
    /**
     * @stability stable
     */
    get allowedTopologies(): StorageClassV1AllowedTopologiesOutputReference;
    /**
     * @stability stable
     */
    putAllowedTopologies(value: StorageClassV1AllowedTopologies): void;
    /**
     * @stability stable
     */
    resetAllowedTopologies(): void;
    /**
     * @stability stable
     */
    get allowedTopologiesInput(): StorageClassV1AllowedTopologies | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): StorageClassV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: StorageClassV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): StorageClassV1Metadata | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
