import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1Config extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#metadata ValidatingWebhookConfigurationV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: ValidatingWebhookConfigurationV1Metadata;
    /**
     * webhook block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#webhook ValidatingWebhookConfigurationV1#webhook}
     *
     * @stability stable
     */
    readonly webhook: ValidatingWebhookConfigurationV1Webhook[];
}
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1Metadata {
    /**
     * An unstructured key value map stored with the validating webhook configuration that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#annotations ValidatingWebhookConfigurationV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#generate_name ValidatingWebhookConfigurationV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the validating webhook configuration.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#labels ValidatingWebhookConfigurationV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the validating webhook configuration, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#name ValidatingWebhookConfigurationV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function validatingWebhookConfigurationV1MetadataToTerraform(struct?: ValidatingWebhookConfigurationV1MetadataOutputReference | ValidatingWebhookConfigurationV1Metadata): any;
/**
 * @stability stable
 */
export declare class ValidatingWebhookConfigurationV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ValidatingWebhookConfigurationV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ValidatingWebhookConfigurationV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1WebhookClientConfigService {
    /**
     * `name` is the name of the service. Required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#name ValidatingWebhookConfigurationV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * `namespace` is the namespace of the service. Required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#namespace ValidatingWebhookConfigurationV1#namespace}
     *
     * @stability stable
     */
    readonly namespace: string;
    /**
     * `path` is an optional URL path which will be sent in any request to this service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#path ValidatingWebhookConfigurationV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * If specified, the port on the service that hosting webhook.
     *
     * Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#port ValidatingWebhookConfigurationV1#port}
     *
     * @stability stable
     */
    readonly port?: number;
}
export declare function validatingWebhookConfigurationV1WebhookClientConfigServiceToTerraform(struct?: ValidatingWebhookConfigurationV1WebhookClientConfigServiceOutputReference | ValidatingWebhookConfigurationV1WebhookClientConfigService): any;
/**
 * @stability stable
 */
export declare class ValidatingWebhookConfigurationV1WebhookClientConfigServiceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ValidatingWebhookConfigurationV1WebhookClientConfigService | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ValidatingWebhookConfigurationV1WebhookClientConfigService | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1WebhookClientConfig {
    /**
     * `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate.
     *
     * If unspecified, system trust roots on the apiserver are used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#ca_bundle ValidatingWebhookConfigurationV1#ca_bundle}
     *
     * @stability stable
     */
    readonly caBundle?: string;
    /**
     * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`).
     *
     * Exactly one of `url` or `service` must be specified.
     *
     * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
     *
     * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
     *
     * The scheme must be "https"; the URL must begin with "https://".
     *
     * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
     *
     * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#url ValidatingWebhookConfigurationV1#url}
     *
     * @stability stable
     */
    readonly url?: string;
    /**
     * service block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#service ValidatingWebhookConfigurationV1#service}
     *
     * @stability stable
     */
    readonly service?: ValidatingWebhookConfigurationV1WebhookClientConfigService;
}
export declare function validatingWebhookConfigurationV1WebhookClientConfigToTerraform(struct?: ValidatingWebhookConfigurationV1WebhookClientConfigOutputReference | ValidatingWebhookConfigurationV1WebhookClientConfig): any;
/**
 * @stability stable
 */
export declare class ValidatingWebhookConfigurationV1WebhookClientConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ValidatingWebhookConfigurationV1WebhookClientConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ValidatingWebhookConfigurationV1WebhookClientConfig | undefined);
    private _caBundle?;
    /**
     * @stability stable
     */
    get caBundle(): string;
    /**
     * @stability stable
     */
    set caBundle(value: string);
    /**
     * @stability stable
     */
    resetCaBundle(): void;
    /**
     * @stability stable
     */
    get caBundleInput(): string | undefined;
    private _url?;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    set url(value: string);
    /**
     * @stability stable
     */
    resetUrl(): void;
    /**
     * @stability stable
     */
    get urlInput(): string | undefined;
    private _service;
    /**
     * @stability stable
     */
    get service(): ValidatingWebhookConfigurationV1WebhookClientConfigServiceOutputReference;
    /**
     * @stability stable
     */
    putService(value: ValidatingWebhookConfigurationV1WebhookClientConfigService): void;
    /**
     * @stability stable
     */
    resetService(): void;
    /**
     * @stability stable
     */
    get serviceInput(): ValidatingWebhookConfigurationV1WebhookClientConfigService | undefined;
}
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1WebhookNamespaceSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#key ValidatingWebhookConfigurationV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#operator ValidatingWebhookConfigurationV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#values ValidatingWebhookConfigurationV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function validatingWebhookConfigurationV1WebhookNamespaceSelectorMatchExpressionsToTerraform(struct?: ValidatingWebhookConfigurationV1WebhookNamespaceSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1WebhookNamespaceSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#match_labels ValidatingWebhookConfigurationV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#match_expressions ValidatingWebhookConfigurationV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: ValidatingWebhookConfigurationV1WebhookNamespaceSelectorMatchExpressions[];
}
export declare function validatingWebhookConfigurationV1WebhookNamespaceSelectorToTerraform(struct?: ValidatingWebhookConfigurationV1WebhookNamespaceSelectorOutputReference | ValidatingWebhookConfigurationV1WebhookNamespaceSelector): any;
/**
 * @stability stable
 */
export declare class ValidatingWebhookConfigurationV1WebhookNamespaceSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ValidatingWebhookConfigurationV1WebhookNamespaceSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ValidatingWebhookConfigurationV1WebhookNamespaceSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): ValidatingWebhookConfigurationV1WebhookNamespaceSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: ValidatingWebhookConfigurationV1WebhookNamespaceSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): ValidatingWebhookConfigurationV1WebhookNamespaceSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1WebhookObjectSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#key ValidatingWebhookConfigurationV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#operator ValidatingWebhookConfigurationV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#values ValidatingWebhookConfigurationV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function validatingWebhookConfigurationV1WebhookObjectSelectorMatchExpressionsToTerraform(struct?: ValidatingWebhookConfigurationV1WebhookObjectSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1WebhookObjectSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#match_labels ValidatingWebhookConfigurationV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#match_expressions ValidatingWebhookConfigurationV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: ValidatingWebhookConfigurationV1WebhookObjectSelectorMatchExpressions[];
}
export declare function validatingWebhookConfigurationV1WebhookObjectSelectorToTerraform(struct?: ValidatingWebhookConfigurationV1WebhookObjectSelectorOutputReference | ValidatingWebhookConfigurationV1WebhookObjectSelector): any;
/**
 * @stability stable
 */
export declare class ValidatingWebhookConfigurationV1WebhookObjectSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ValidatingWebhookConfigurationV1WebhookObjectSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ValidatingWebhookConfigurationV1WebhookObjectSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): ValidatingWebhookConfigurationV1WebhookObjectSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: ValidatingWebhookConfigurationV1WebhookObjectSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): ValidatingWebhookConfigurationV1WebhookObjectSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1WebhookRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#api_groups ValidatingWebhookConfigurationV1#api_groups}.
     *
     * @stability stable
     */
    readonly apiGroups: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#api_versions ValidatingWebhookConfigurationV1#api_versions}.
     *
     * @stability stable
     */
    readonly apiVersions: string[];
    /**
     * Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added.
     *
     * If '*' is present, the length of the slice must be one. Required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#operations ValidatingWebhookConfigurationV1#operations}
     *
     * @stability stable
     */
    readonly operations: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#resources ValidatingWebhookConfigurationV1#resources}.
     *
     * @stability stable
     */
    readonly resources: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#scope ValidatingWebhookConfigurationV1#scope}.
     *
     * @stability stable
     */
    readonly scope?: string;
}
export declare function validatingWebhookConfigurationV1WebhookRuleToTerraform(struct?: ValidatingWebhookConfigurationV1WebhookRule): any;
/**
 * @stability stable
 */
export interface ValidatingWebhookConfigurationV1Webhook {
    /**
     * AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects.
     *
     * API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#admission_review_versions ValidatingWebhookConfigurationV1#admission_review_versions}
     *
     * @stability stable
     */
    readonly admissionReviewVersions?: string[];
    /**
     * FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail.
     *
     * Defaults to Fail.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#failure_policy ValidatingWebhookConfigurationV1#failure_policy}
     *
     * @stability stable
     */
    readonly failurePolicy?: string;
    /**
     * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
     *
     * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
     *
     * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
     *
     * Defaults to "Equivalent"
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#match_policy ValidatingWebhookConfigurationV1#match_policy}
     *
     * @stability stable
     */
    readonly matchPolicy?: string;
    /**
     * The name of the admission webhook.
     *
     * Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#name ValidatingWebhookConfigurationV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * SideEffects states whether this webhook has side effects.
     *
     * Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#side_effects ValidatingWebhookConfigurationV1#side_effects}
     *
     * @stability stable
     */
    readonly sideEffects?: string;
    /**
     * TimeoutSeconds specifies the timeout for this webhook.
     *
     * After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#timeout_seconds ValidatingWebhookConfigurationV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * client_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#client_config ValidatingWebhookConfigurationV1#client_config}
     *
     * @stability stable
     */
    readonly clientConfig: ValidatingWebhookConfigurationV1WebhookClientConfig;
    /**
     * namespace_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#namespace_selector ValidatingWebhookConfigurationV1#namespace_selector}
     *
     * @stability stable
     */
    readonly namespaceSelector?: ValidatingWebhookConfigurationV1WebhookNamespaceSelector;
    /**
     * object_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#object_selector ValidatingWebhookConfigurationV1#object_selector}
     *
     * @stability stable
     */
    readonly objectSelector?: ValidatingWebhookConfigurationV1WebhookObjectSelector;
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html#rule ValidatingWebhookConfigurationV1#rule}
     *
     * @stability stable
     */
    readonly rule: ValidatingWebhookConfigurationV1WebhookRule[];
}
export declare function validatingWebhookConfigurationV1WebhookToTerraform(struct?: ValidatingWebhookConfigurationV1Webhook): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html kubernetes_validating_webhook_configuration_v1}.
 *
 * @stability stable
 */
export declare class ValidatingWebhookConfigurationV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/validating_webhook_configuration_v1.html kubernetes_validating_webhook_configuration_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ValidatingWebhookConfigurationV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ValidatingWebhookConfigurationV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ValidatingWebhookConfigurationV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ValidatingWebhookConfigurationV1Metadata | undefined;
    private _webhook?;
    /**
     * @stability stable
     */
    get webhook(): ValidatingWebhookConfigurationV1Webhook[];
    /**
     * @stability stable
     */
    set webhook(value: ValidatingWebhookConfigurationV1Webhook[]);
    /**
     * @stability stable
     */
    get webhookInput(): ValidatingWebhookConfigurationV1Webhook[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
