import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DaemonSetV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Wait for the rollout of the deployment to complete. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#wait_for_rollout DaemonSetV1#wait_for_rollout}
     *
     * @stability stable
     */
    readonly waitForRollout?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#metadata DaemonSetV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: DaemonSetV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#spec DaemonSetV1#spec}
     *
     * @stability stable
     */
    readonly spec: DaemonSetV1Spec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#timeouts DaemonSetV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DaemonSetV1Timeouts;
}
/**
 * @stability stable
 */
export interface DaemonSetV1Metadata {
    /**
     * An unstructured key value map stored with the daemonset that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#annotations DaemonSetV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#generate_name DaemonSetV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the daemonset.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#labels DaemonSetV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the daemonset, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the daemonset must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1MetadataToTerraform(struct?: DaemonSetV1MetadataOutputReference | DaemonSetV1Metadata): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecSelectorMatchExpressionsToTerraform(struct?: DaemonSetV1SpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_labels DaemonSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecSelectorMatchExpressions[];
}
export declare function daemonSetV1SpecSelectorToTerraform(struct?: DaemonSetV1SpecSelectorOutputReference | DaemonSetV1SpecSelector): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): DaemonSetV1SpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: DaemonSetV1SpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): DaemonSetV1SpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecStrategyRollingUpdate {
    /**
     * The maximum number of DaemonSet pods that can be unavailable during the update.
     *
     * Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0. Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#max_unavailable DaemonSetV1#max_unavailable}
     *
     * @stability stable
     */
    readonly maxUnavailable?: string;
}
export declare function daemonSetV1SpecStrategyRollingUpdateToTerraform(struct?: DaemonSetV1SpecStrategyRollingUpdateOutputReference | DaemonSetV1SpecStrategyRollingUpdate): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecStrategyRollingUpdateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecStrategyRollingUpdate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecStrategyRollingUpdate | undefined);
    private _maxUnavailable?;
    /**
     * @stability stable
     */
    get maxUnavailable(): string;
    /**
     * @stability stable
     */
    set maxUnavailable(value: string);
    /**
     * @stability stable
     */
    resetMaxUnavailable(): void;
    /**
     * @stability stable
     */
    get maxUnavailableInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecStrategy {
    /**
     * Type of deployment. Can be 'RollingUpdate' or 'OnDelete'. Default is RollingUpdate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#type DaemonSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * rolling_update block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#rolling_update DaemonSetV1#rolling_update}
     *
     * @stability stable
     */
    readonly rollingUpdate?: DaemonSetV1SpecStrategyRollingUpdate;
}
export declare function daemonSetV1SpecStrategyToTerraform(struct?: DaemonSetV1SpecStrategyOutputReference | DaemonSetV1SpecStrategy): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecStrategyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecStrategy | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecStrategy | undefined);
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _rollingUpdate;
    /**
     * @stability stable
     */
    get rollingUpdate(): DaemonSetV1SpecStrategyRollingUpdateOutputReference;
    /**
     * @stability stable
     */
    putRollingUpdate(value: DaemonSetV1SpecStrategyRollingUpdate): void;
    /**
     * @stability stable
     */
    resetRollingUpdate(): void;
    /**
     * @stability stable
     */
    get rollingUpdateInput(): DaemonSetV1SpecStrategyRollingUpdate | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateMetadata {
    /**
     * An unstructured key value map stored with the daemon set that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#annotations DaemonSetV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#generate_name DaemonSetV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the daemon set.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#labels DaemonSetV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the daemon set, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function daemonSetV1SpecTemplateMetadataToTerraform(struct?: DaemonSetV1SpecTemplateMetadataOutputReference | DaemonSetV1SpecTemplateMetadata): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference | DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined);
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#weight DaemonSetV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * preference block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#preference DaemonSetV1#preference}
     *
     * @stability stable
     */
    readonly preference: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference;
}
export declare function daemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#node_selector_term DaemonSetV1#node_selector_term}
     *
     * @stability stable
     */
    readonly nodeSelectorTerm?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference | DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined);
    private _nodeSelectorTerm?;
    /**
     * @stability stable
     */
    get nodeSelectorTerm(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
    /**
     * @stability stable
     */
    set nodeSelectorTerm(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[]);
    /**
     * @stability stable
     */
    resetNodeSelectorTerm(): void;
    /**
     * @stability stable
     */
    get nodeSelectorTermInput(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#preferred_during_scheduling_ignored_during_execution DaemonSetV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#required_during_scheduling_ignored_during_execution DaemonSetV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution;
}
export declare function daemonSetV1SpecTemplateSpecAffinityNodeAffinityToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityOutputReference | DaemonSetV1SpecTemplateSpecAffinityNodeAffinity): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityNodeAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference;
    /**
     * @stability stable
     */
    putRequiredDuringSchedulingIgnoredDuringExecution(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): void;
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_labels DaemonSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespaces DaemonSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#topology_key DaemonSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#label_selector DaemonSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#weight DaemonSetV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pod_affinity_term DaemonSetV1#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_labels DaemonSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespaces DaemonSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#topology_key DaemonSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#label_selector DaemonSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#preferred_during_scheduling_ignored_during_execution DaemonSetV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#required_during_scheduling_ignored_during_execution DaemonSetV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAffinityToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAffinityOutputReference | DaemonSetV1SpecTemplateSpecAffinityPodAffinity): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityPodAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinityPodAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinityPodAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_labels DaemonSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespaces DaemonSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#topology_key DaemonSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#label_selector DaemonSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#weight DaemonSetV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pod_affinity_term DaemonSetV1#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_labels DaemonSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespaces DaemonSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#topology_key DaemonSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#label_selector DaemonSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#preferred_during_scheduling_ignored_during_execution DaemonSetV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#required_during_scheduling_ignored_during_execution DaemonSetV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function daemonSetV1SpecTemplateSpecAffinityPodAntiAffinityToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference | DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinity): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecAffinity {
    /**
     * node_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#node_affinity DaemonSetV1#node_affinity}
     *
     * @stability stable
     */
    readonly nodeAffinity?: DaemonSetV1SpecTemplateSpecAffinityNodeAffinity;
    /**
     * pod_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pod_affinity DaemonSetV1#pod_affinity}
     *
     * @stability stable
     */
    readonly podAffinity?: DaemonSetV1SpecTemplateSpecAffinityPodAffinity;
    /**
     * pod_anti_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pod_anti_affinity DaemonSetV1#pod_anti_affinity}
     *
     * @stability stable
     */
    readonly podAntiAffinity?: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinity;
}
export declare function daemonSetV1SpecTemplateSpecAffinityToTerraform(struct?: DaemonSetV1SpecTemplateSpecAffinityOutputReference | DaemonSetV1SpecTemplateSpecAffinity): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecAffinity | undefined);
    private _nodeAffinity;
    /**
     * @stability stable
     */
    get nodeAffinity(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinityOutputReference;
    /**
     * @stability stable
     */
    putNodeAffinity(value: DaemonSetV1SpecTemplateSpecAffinityNodeAffinity): void;
    /**
     * @stability stable
     */
    resetNodeAffinity(): void;
    /**
     * @stability stable
     */
    get nodeAffinityInput(): DaemonSetV1SpecTemplateSpecAffinityNodeAffinity | undefined;
    private _podAffinity;
    /**
     * @stability stable
     */
    get podAffinity(): DaemonSetV1SpecTemplateSpecAffinityPodAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAffinity(value: DaemonSetV1SpecTemplateSpecAffinityPodAffinity): void;
    /**
     * @stability stable
     */
    resetPodAffinity(): void;
    /**
     * @stability stable
     */
    get podAffinityInput(): DaemonSetV1SpecTemplateSpecAffinityPodAffinity | undefined;
    private _podAntiAffinity;
    /**
     * @stability stable
     */
    get podAntiAffinity(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAntiAffinity(value: DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinity): void;
    /**
     * @stability stable
     */
    resetPodAntiAffinity(): void;
    /**
     * @stability stable
     */
    get podAntiAffinityInput(): DaemonSetV1SpecTemplateSpecAffinityPodAntiAffinity | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference | DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#api_version DaemonSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_path DaemonSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference | DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#container_name DaemonSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#divisor DaemonSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource DaemonSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference | DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference | DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#config_map_key_ref DaemonSetV1#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_ref DaemonSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource_field_ref DaemonSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_key_ref DaemonSetV1#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvValueFromToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvValueFromOutputReference | DaemonSetV1SpecTemplateSpecContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): DaemonSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value_from DaemonSetV1#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: DaemonSetV1SpecTemplateSpecContainerEnvValueFrom;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnv): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRefOutputReference | DaemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvFromSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvFromSecretRefOutputReference | DaemonSetV1SpecTemplateSpecContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#prefix DaemonSetV1#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#config_map_ref DaemonSetV1#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: DaemonSetV1SpecTemplateSpecContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_ref DaemonSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonSetV1SpecTemplateSpecContainerEnvFromSecretRef;
}
export declare function daemonSetV1SpecTemplateSpecContainerEnvFromToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePostStartExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartExecOutputReference | DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference | DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePostStartToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePreStopExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopExecOutputReference | DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference | DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecyclePreStopToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#post_start DaemonSetV1#post_start}
     *
     * @stability stable
     */
    readonly postStart?: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pre_stop DaemonSetV1#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStop[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLifecycleToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLifecycleOutputReference | DaemonSetV1SpecTemplateSpecContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): DaemonSetV1SpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): DaemonSetV1SpecTemplateSpecContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): DaemonSetV1SpecTemplateSpecContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: DaemonSetV1SpecTemplateSpecContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): DaemonSetV1SpecTemplateSpecContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLivenessProbeExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeExecOutputReference | DaemonSetV1SpecTemplateSpecContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference | DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerLivenessProbeTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#failure_threshold DaemonSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#initial_delay_seconds DaemonSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#period_seconds DaemonSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#success_threshold DaemonSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#timeout_seconds DaemonSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecContainerLivenessProbeToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerLivenessProbeOutputReference | DaemonSetV1SpecTemplateSpecContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: DaemonSetV1SpecTemplateSpecContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: DaemonSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): DaemonSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#container_port DaemonSetV1#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_ip DaemonSetV1#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_port DaemonSetV1#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#protocol DaemonSetV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerPortToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerPort): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecContainerReadinessProbeExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeExecOutputReference | DaemonSetV1SpecTemplateSpecContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference | DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerReadinessProbeTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#failure_threshold DaemonSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#initial_delay_seconds DaemonSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#period_seconds DaemonSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#success_threshold DaemonSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#timeout_seconds DaemonSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecContainerReadinessProbeToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerReadinessProbeOutputReference | DaemonSetV1SpecTemplateSpecContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: DaemonSetV1SpecTemplateSpecContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: DaemonSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): DaemonSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#limits DaemonSetV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#requests DaemonSetV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecContainerResourcesToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerResourcesOutputReference | DaemonSetV1SpecTemplateSpecContainerResources): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#add DaemonSetV1#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#drop DaemonSetV1#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function daemonSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference | DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#level DaemonSetV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#role DaemonSetV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#type DaemonSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#user DaemonSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference | DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#allow_privilege_escalation DaemonSetV1#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#privileged DaemonSetV1#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only_root_filesystem DaemonSetV1#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_group DaemonSetV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_non_root DaemonSetV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_user DaemonSetV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#capabilities DaemonSetV1#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#se_linux_options DaemonSetV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions;
}
export declare function daemonSetV1SpecTemplateSpecContainerSecurityContextToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerSecurityContextOutputReference | DaemonSetV1SpecTemplateSpecContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): DaemonSetV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): DaemonSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecContainerStartupProbeExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerStartupProbeExecOutputReference | DaemonSetV1SpecTemplateSpecContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference | DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerStartupProbeTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#failure_threshold DaemonSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#initial_delay_seconds DaemonSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#period_seconds DaemonSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#success_threshold DaemonSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#timeout_seconds DaemonSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecContainerStartupProbeToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerStartupProbeOutputReference | DaemonSetV1SpecTemplateSpecContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): DaemonSetV1SpecTemplateSpecContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: DaemonSetV1SpecTemplateSpecContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): DaemonSetV1SpecTemplateSpecContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): DaemonSetV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): DaemonSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: DaemonSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): DaemonSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mount_path DaemonSetV1#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mount_propagation DaemonSetV1#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#sub_path DaemonSetV1#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function daemonSetV1SpecTemplateSpecContainerVolumeMountToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#args DaemonSetV1#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#image DaemonSetV1#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#image_pull_policy DaemonSetV1#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#stdin DaemonSetV1#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#stdin_once DaemonSetV1#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#termination_message_path DaemonSetV1#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#termination_message_policy DaemonSetV1#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tty DaemonSetV1#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#working_dir DaemonSetV1#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#env DaemonSetV1#env}
     *
     * @stability stable
     */
    readonly env?: DaemonSetV1SpecTemplateSpecContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#env_from DaemonSetV1#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: DaemonSetV1SpecTemplateSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#lifecycle DaemonSetV1#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: DaemonSetV1SpecTemplateSpecContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#liveness_probe DaemonSetV1#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: DaemonSetV1SpecTemplateSpecContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: DaemonSetV1SpecTemplateSpecContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#readiness_probe DaemonSetV1#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: DaemonSetV1SpecTemplateSpecContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resources DaemonSetV1#resources}
     *
     * @stability stable
     */
    readonly resources?: DaemonSetV1SpecTemplateSpecContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#security_context DaemonSetV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: DaemonSetV1SpecTemplateSpecContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#startup_probe DaemonSetV1#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: DaemonSetV1SpecTemplateSpecContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume_mount DaemonSetV1#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: DaemonSetV1SpecTemplateSpecContainerVolumeMount[];
}
export declare function daemonSetV1SpecTemplateSpecContainerToTerraform(struct?: DaemonSetV1SpecTemplateSpecContainer): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecDnsConfigOption {
    /**
     * Name of the option.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the option. Optional: Defaults to empty.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecDnsConfigOptionToTerraform(struct?: DaemonSetV1SpecTemplateSpecDnsConfigOption): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#nameservers DaemonSetV1#nameservers}
     *
     * @stability stable
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#searches DaemonSetV1#searches}
     *
     * @stability stable
     */
    readonly searches?: string[];
    /**
     * option block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#option DaemonSetV1#option}
     *
     * @stability stable
     */
    readonly option?: DaemonSetV1SpecTemplateSpecDnsConfigOption[];
}
export declare function daemonSetV1SpecTemplateSpecDnsConfigToTerraform(struct?: DaemonSetV1SpecTemplateSpecDnsConfigOutputReference | DaemonSetV1SpecTemplateSpecDnsConfig): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecDnsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecDnsConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecDnsConfig | undefined);
    private _nameservers?;
    /**
     * @stability stable
     */
    get nameservers(): string[];
    /**
     * @stability stable
     */
    set nameservers(value: string[]);
    /**
     * @stability stable
     */
    resetNameservers(): void;
    /**
     * @stability stable
     */
    get nameserversInput(): string[] | undefined;
    private _searches?;
    /**
     * @stability stable
     */
    get searches(): string[];
    /**
     * @stability stable
     */
    set searches(value: string[]);
    /**
     * @stability stable
     */
    resetSearches(): void;
    /**
     * @stability stable
     */
    get searchesInput(): string[] | undefined;
    private _option?;
    /**
     * @stability stable
     */
    get option(): DaemonSetV1SpecTemplateSpecDnsConfigOption[];
    /**
     * @stability stable
     */
    set option(value: DaemonSetV1SpecTemplateSpecDnsConfigOption[]);
    /**
     * @stability stable
     */
    resetOption(): void;
    /**
     * @stability stable
     */
    get optionInput(): DaemonSetV1SpecTemplateSpecDnsConfigOption[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecHostAliases {
    /**
     * Hostnames for the IP address.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#hostnames DaemonSetV1#hostnames}
     *
     * @stability stable
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#ip DaemonSetV1#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
export declare function daemonSetV1SpecTemplateSpecHostAliasesToTerraform(struct?: DaemonSetV1SpecTemplateSpecHostAliases): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecImagePullSecrets {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function daemonSetV1SpecTemplateSpecImagePullSecretsToTerraform(struct?: DaemonSetV1SpecTemplateSpecImagePullSecrets): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference | DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#api_version DaemonSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_path DaemonSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference | DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#container_name DaemonSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#divisor DaemonSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource DaemonSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference | DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference | DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#config_map_key_ref DaemonSetV1#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_ref DaemonSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource_field_ref DaemonSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_key_ref DaemonSetV1#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvValueFromToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromOutputReference | DaemonSetV1SpecTemplateSpecInitContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): DaemonSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value_from DaemonSetV1#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: DaemonSetV1SpecTemplateSpecInitContainerEnvValueFrom;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnv): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference | DaemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRefOutputReference | DaemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#prefix DaemonSetV1#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#config_map_ref DaemonSetV1#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: DaemonSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_ref DaemonSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonSetV1SpecTemplateSpecInitContainerEnvFromSecretRef;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerEnvFromToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePostStartToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecyclePreStopToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#post_start DaemonSetV1#post_start}
     *
     * @stability stable
     */
    readonly postStart?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pre_stop DaemonSetV1#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStop[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLifecycleToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLifecycleOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): DaemonSetV1SpecTemplateSpecInitContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLivenessProbeExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#failure_threshold DaemonSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#initial_delay_seconds DaemonSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#period_seconds DaemonSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#success_threshold DaemonSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#timeout_seconds DaemonSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerLivenessProbeToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeOutputReference | DaemonSetV1SpecTemplateSpecInitContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): DaemonSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#container_port DaemonSetV1#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_ip DaemonSetV1#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_port DaemonSetV1#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#protocol DaemonSetV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerPortToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerPort): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerReadinessProbeExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference | DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference | DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#failure_threshold DaemonSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#initial_delay_seconds DaemonSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#period_seconds DaemonSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#success_threshold DaemonSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#timeout_seconds DaemonSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerReadinessProbeToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeOutputReference | DaemonSetV1SpecTemplateSpecInitContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): DaemonSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#limits DaemonSetV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#requests DaemonSetV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerResourcesToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerResourcesOutputReference | DaemonSetV1SpecTemplateSpecInitContainerResources): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#add DaemonSetV1#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#drop DaemonSetV1#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference | DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#level DaemonSetV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#role DaemonSetV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#type DaemonSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#user DaemonSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference | DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#allow_privilege_escalation DaemonSetV1#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#privileged DaemonSetV1#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only_root_filesystem DaemonSetV1#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_group DaemonSetV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_non_root DaemonSetV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_user DaemonSetV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#capabilities DaemonSetV1#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#se_linux_options DaemonSetV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerSecurityContextToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextOutputReference | DaemonSetV1SpecTemplateSpecInitContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): DaemonSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): DaemonSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerStartupProbeExecToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference | DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host DaemonSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#scheme DaemonSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_header DaemonSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference | DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocketToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#failure_threshold DaemonSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#initial_delay_seconds DaemonSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#period_seconds DaemonSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#success_threshold DaemonSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#timeout_seconds DaemonSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#exec DaemonSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#http_get DaemonSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tcp_socket DaemonSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerStartupProbeToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeOutputReference | DaemonSetV1SpecTemplateSpecInitContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecInitContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecInitContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: DaemonSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): DaemonSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mount_path DaemonSetV1#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mount_propagation DaemonSetV1#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#sub_path DaemonSetV1#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function daemonSetV1SpecTemplateSpecInitContainerVolumeMountToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#args DaemonSetV1#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#command DaemonSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#image DaemonSetV1#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#image_pull_policy DaemonSetV1#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#stdin DaemonSetV1#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#stdin_once DaemonSetV1#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#termination_message_path DaemonSetV1#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#termination_message_policy DaemonSetV1#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#tty DaemonSetV1#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#working_dir DaemonSetV1#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#env DaemonSetV1#env}
     *
     * @stability stable
     */
    readonly env?: DaemonSetV1SpecTemplateSpecInitContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#env_from DaemonSetV1#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: DaemonSetV1SpecTemplateSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#lifecycle DaemonSetV1#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: DaemonSetV1SpecTemplateSpecInitContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#liveness_probe DaemonSetV1#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: DaemonSetV1SpecTemplateSpecInitContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#port DaemonSetV1#port}
     *
     * @stability stable
     */
    readonly port?: DaemonSetV1SpecTemplateSpecInitContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#readiness_probe DaemonSetV1#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: DaemonSetV1SpecTemplateSpecInitContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resources DaemonSetV1#resources}
     *
     * @stability stable
     */
    readonly resources?: DaemonSetV1SpecTemplateSpecInitContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#security_context DaemonSetV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: DaemonSetV1SpecTemplateSpecInitContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#startup_probe DaemonSetV1#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: DaemonSetV1SpecTemplateSpecInitContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume_mount DaemonSetV1#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: DaemonSetV1SpecTemplateSpecInitContainerVolumeMount[];
}
export declare function daemonSetV1SpecTemplateSpecInitContainerToTerraform(struct?: DaemonSetV1SpecTemplateSpecInitContainer): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecReadinessGate {
    /**
     * refers to a condition in the pod's condition list with matching type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#condition_type DaemonSetV1#condition_type}
     *
     * @stability stable
     */
    readonly conditionType: string;
}
export declare function daemonSetV1SpecTemplateSpecReadinessGateToTerraform(struct?: DaemonSetV1SpecTemplateSpecReadinessGate): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#level DaemonSetV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#role DaemonSetV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#type DaemonSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#user DaemonSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function daemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference | DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function daemonSetV1SpecTemplateSpecSecurityContextSysctlToTerraform(struct?: DaemonSetV1SpecTemplateSpecSecurityContextSysctl): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_group DaemonSetV1#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup?: string;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_group DaemonSetV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_non_root DaemonSetV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#run_as_user DaemonSetV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#supplemental_groups DaemonSetV1#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#se_linux_options DaemonSetV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptions;
    /**
     * sysctl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#sysctl DaemonSetV1#sysctl}
     *
     * @stability stable
     */
    readonly sysctl?: DaemonSetV1SpecTemplateSpecSecurityContextSysctl[];
}
export declare function daemonSetV1SpecTemplateSpecSecurityContextToTerraform(struct?: DaemonSetV1SpecTemplateSpecSecurityContextOutputReference | DaemonSetV1SpecTemplateSpecSecurityContext): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecSecurityContext | undefined);
    private _fsGroup?;
    /**
     * @stability stable
     */
    get fsGroup(): string;
    /**
     * @stability stable
     */
    set fsGroup(value: string);
    /**
     * @stability stable
     */
    resetFsGroup(): void;
    /**
     * @stability stable
     */
    get fsGroupInput(): string | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _supplementalGroups?;
    /**
     * @stability stable
     */
    get supplementalGroups(): number[];
    /**
     * @stability stable
     */
    set supplementalGroups(value: number[]);
    /**
     * @stability stable
     */
    resetSupplementalGroups(): void;
    /**
     * @stability stable
     */
    get supplementalGroupsInput(): number[] | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): DaemonSetV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    private _sysctl?;
    /**
     * @stability stable
     */
    get sysctl(): DaemonSetV1SpecTemplateSpecSecurityContextSysctl[];
    /**
     * @stability stable
     */
    set sysctl(value: DaemonSetV1SpecTemplateSpecSecurityContextSysctl[]);
    /**
     * @stability stable
     */
    resetSysctl(): void;
    /**
     * @stability stable
     */
    get sysctlInput(): DaemonSetV1SpecTemplateSpecSecurityContextSysctl[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#effect DaemonSetV1#effect}
     *
     * @stability stable
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#toleration_seconds DaemonSetV1#toleration_seconds}
     *
     * @stability stable
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#value DaemonSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function daemonSetV1SpecTemplateSpecTolerationToTerraform(struct?: DaemonSetV1SpecTemplateSpecToleration): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#operator DaemonSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#values DaemonSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function daemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressionsToTerraform(struct?: DaemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_labels DaemonSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#match_expressions DaemonSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: DaemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions[];
}
export declare function daemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorToTerraform(struct?: DaemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelector): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecTopologySpreadConstraint {
    /**
     * describes the degree to which pods may be unevenly distributed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#max_skew DaemonSetV1#max_skew}
     *
     * @stability stable
     */
    readonly maxSkew?: number;
    /**
     * the key of node labels.
     *
     * Nodes that have a label with this key and identical values are considered to be in the same topology.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#topology_key DaemonSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * indicates how to deal with a pod if it doesn't satisfy the spread constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#when_unsatisfiable DaemonSetV1#when_unsatisfiable}
     *
     * @stability stable
     */
    readonly whenUnsatisfiable?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#label_selector DaemonSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: DaemonSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelector[];
}
export declare function daemonSetV1SpecTemplateSpecTopologySpreadConstraintToTerraform(struct?: DaemonSetV1SpecTemplateSpecTopologySpreadConstraint): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#partition DaemonSetV1#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume_id DaemonSetV1#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStoreToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference | DaemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStore): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStore | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStore | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#caching_mode DaemonSetV1#caching_mode}
     *
     * @stability stable
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#data_disk_uri DaemonSetV1#data_disk_uri}
     *
     * @stability stable
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#disk_name DaemonSetV1#disk_name}
     *
     * @stability stable
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The type for the data disk. Expected values: Shared, Dedicated, Managed. Defaults to Shared.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#kind DaemonSetV1#kind}
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecVolumeAzureDiskToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeAzureDiskOutputReference | DaemonSetV1SpecTemplateSpecVolumeAzureDisk): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeAzureDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeAzureDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeAzureDisk | undefined);
    private _cachingMode?;
    /**
     * @stability stable
     */
    get cachingMode(): string;
    /**
     * @stability stable
     */
    set cachingMode(value: string);
    /**
     * @stability stable
     */
    get cachingModeInput(): string | undefined;
    private _dataDiskUri?;
    /**
     * @stability stable
     */
    get dataDiskUri(): string;
    /**
     * @stability stable
     */
    set dataDiskUri(value: string);
    /**
     * @stability stable
     */
    get dataDiskUriInput(): string | undefined;
    private _diskName?;
    /**
     * @stability stable
     */
    get diskName(): string;
    /**
     * @stability stable
     */
    set diskName(value: string);
    /**
     * @stability stable
     */
    get diskNameInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    resetKind(): void;
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_name DaemonSetV1#secret_name}
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * The namespace of the secret that contains Azure Storage Account Name and Key.
     *
     * For Kubernetes up to 1.18.x the default is the same as the Pod. For Kubernetes 1.19.x and later the default is "default" namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_namespace DaemonSetV1#secret_namespace}
     *
     * @stability stable
     */
    readonly secretNamespace?: string;
    /**
     * Share Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#share_name DaemonSetV1#share_name}
     *
     * @stability stable
     */
    readonly shareName: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeAzureFileToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeAzureFileOutputReference | DaemonSetV1SpecTemplateSpecVolumeAzureFile): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeAzureFileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeAzureFile | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeAzureFile | undefined);
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _secretNamespace?;
    /**
     * @stability stable
     */
    get secretNamespace(): string;
    /**
     * @stability stable
     */
    set secretNamespace(value: string);
    /**
     * @stability stable
     */
    resetSecretNamespace(): void;
    /**
     * @stability stable
     */
    get secretNamespaceInput(): string | undefined;
    private _shareName?;
    /**
     * @stability stable
     */
    get shareName(): string;
    /**
     * @stability stable
     */
    set shareName(value: string);
    /**
     * @stability stable
     */
    get shareNameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCephFsSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#monitors DaemonSetV1#monitors}
     *
     * @stability stable
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_file DaemonSetV1#secret_file}
     *
     * @stability stable
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#user DaemonSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_ref DaemonSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRef;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCephFsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCephFsOutputReference | DaemonSetV1SpecTemplateSpecVolumeCephFs): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCephFsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCephFs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCephFs | undefined);
    private _monitors?;
    /**
     * @stability stable
     */
    get monitors(): string[];
    /**
     * @stability stable
     */
    set monitors(value: string[]);
    /**
     * @stability stable
     */
    get monitorsInput(): string[] | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretFile?;
    /**
     * @stability stable
     */
    get secretFile(): string;
    /**
     * @stability stable
     */
    set secretFile(value: string);
    /**
     * @stability stable
     */
    resetSecretFile(): void;
    /**
     * @stability stable
     */
    get secretFileInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): DaemonSetV1SpecTemplateSpecVolumeCephFsSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Volume ID used to identify the volume in Cinder. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume_id DaemonSetV1#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCinderToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCinderOutputReference | DaemonSetV1SpecTemplateSpecVolumeCinder): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCinderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCinder | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCinder | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mode DaemonSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeConfigMapItemsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeConfigMapItems): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#default_mode DaemonSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#items DaemonSetV1#items}
     *
     * @stability stable
     */
    readonly items?: DaemonSetV1SpecTemplateSpecVolumeConfigMapItems[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeConfigMapToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeConfigMapOutputReference | DaemonSetV1SpecTemplateSpecVolumeConfigMap): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeConfigMapOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeConfigMap | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeConfigMap | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): DaemonSetV1SpecTemplateSpecVolumeConfigMapItems[];
    /**
     * @stability stable
     */
    set items(value: DaemonSetV1SpecTemplateSpecVolumeConfigMapItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): DaemonSetV1SpecTemplateSpecVolumeConfigMapItems[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeCsi {
    /**
     * the name of the volume driver to use. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#driver DaemonSetV1#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Attributes of the volume to publish.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume_attributes DaemonSetV1#volume_attributes}
     *
     * @stability stable
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * A string value that uniquely identifies the volume. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume_handle DaemonSetV1#volume_handle}
     *
     * @stability stable
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#controller_expand_secret_ref DaemonSetV1#controller_expand_secret_ref}
     *
     * @stability stable
     */
    readonly controllerExpandSecretRef?: DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef;
    /**
     * controller_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#controller_publish_secret_ref DaemonSetV1#controller_publish_secret_ref}
     *
     * @stability stable
     */
    readonly controllerPublishSecretRef?: DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef;
    /**
     * node_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#node_publish_secret_ref DaemonSetV1#node_publish_secret_ref}
     *
     * @stability stable
     */
    readonly nodePublishSecretRef?: DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef;
    /**
     * node_stage_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#node_stage_secret_ref DaemonSetV1#node_stage_secret_ref}
     *
     * @stability stable
     */
    readonly nodeStageSecretRef?: DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef;
}
export declare function daemonSetV1SpecTemplateSpecVolumeCsiToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeCsiOutputReference | DaemonSetV1SpecTemplateSpecVolumeCsi): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeCsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeCsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeCsi | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeAttributes?;
    /**
     * @stability stable
     */
    get volumeAttributes(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set volumeAttributes(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetVolumeAttributes(): void;
    /**
     * @stability stable
     */
    get volumeAttributesInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _volumeHandle?;
    /**
     * @stability stable
     */
    get volumeHandle(): string;
    /**
     * @stability stable
     */
    set volumeHandle(value: string);
    /**
     * @stability stable
     */
    get volumeHandleInput(): string | undefined;
    private _controllerExpandSecretRef;
    /**
     * @stability stable
     */
    get controllerExpandSecretRef(): DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerExpandSecretRef(value: DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerExpandSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerExpandSecretRefInput(): DaemonSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    private _controllerPublishSecretRef;
    /**
     * @stability stable
     */
    get controllerPublishSecretRef(): DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerPublishSecretRef(value: DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerPublishSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerPublishSecretRefInput(): DaemonSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    private _nodePublishSecretRef;
    /**
     * @stability stable
     */
    get nodePublishSecretRef(): DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodePublishSecretRef(value: DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef): void;
    /**
     * @stability stable
     */
    resetNodePublishSecretRef(): void;
    /**
     * @stability stable
     */
    get nodePublishSecretRefInput(): DaemonSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    private _nodeStageSecretRef;
    /**
     * @stability stable
     */
    get nodeStageSecretRef(): DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodeStageSecretRef(value: DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef): void;
    /**
     * @stability stable
     */
    resetNodeStageSecretRef(): void;
    /**
     * @stability stable
     */
    get nodeStageSecretRefInput(): DaemonSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#api_version DaemonSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_path DaemonSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#container_name DaemonSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#divisor DaemonSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource DaemonSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mode DaemonSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_ref DaemonSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource_field_ref DaemonSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef;
}
export declare function daemonSetV1SpecTemplateSpecVolumeDownwardApiItemsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItems): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#default_mode DaemonSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#items DaemonSetV1#items}
     *
     * @stability stable
     */
    readonly items?: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItems[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeDownwardApiToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeDownwardApiOutputReference | DaemonSetV1SpecTemplateSpecVolumeDownwardApi): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeDownwardApi | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): DaemonSetV1SpecTemplateSpecVolumeDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: DaemonSetV1SpecTemplateSpecVolumeDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): DaemonSetV1SpecTemplateSpecVolumeDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#medium DaemonSetV1#medium}
     *
     * @stability stable
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#size_limit DaemonSetV1#size_limit}
     *
     * @stability stable
     */
    readonly sizeLimit?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeEmptyDirToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeEmptyDirOutputReference | DaemonSetV1SpecTemplateSpecVolumeEmptyDir): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeEmptyDirOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeEmptyDir | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeEmptyDir | undefined);
    private _medium?;
    /**
     * @stability stable
     */
    get medium(): string;
    /**
     * @stability stable
     */
    set medium(value: string);
    /**
     * @stability stable
     */
    resetMedium(): void;
    /**
     * @stability stable
     */
    get mediumInput(): string | undefined;
    private _sizeLimit?;
    /**
     * @stability stable
     */
    get sizeLimit(): string;
    /**
     * @stability stable
     */
    set sizeLimit(value: string);
    /**
     * @stability stable
     */
    resetSizeLimit(): void;
    /**
     * @stability stable
     */
    get sizeLimitInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#lun DaemonSetV1#lun}
     *
     * @stability stable
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * FC target worldwide names (WWNs).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#target_ww_ns DaemonSetV1#target_ww_ns}
     *
     * @stability stable
     */
    readonly targetWwNs: string[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeFcToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeFcOutputReference | DaemonSetV1SpecTemplateSpecVolumeFc): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeFcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeFc | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeFc | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetWwNs?;
    /**
     * @stability stable
     */
    get targetWwNs(): string[];
    /**
     * @stability stable
     */
    set targetWwNs(value: string[]);
    /**
     * @stability stable
     */
    get targetWwNsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#driver DaemonSetV1#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#options DaemonSetV1#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_ref DaemonSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef;
}
export declare function daemonSetV1SpecTemplateSpecVolumeFlexVolumeToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeFlexVolumeOutputReference | DaemonSetV1SpecTemplateSpecVolumeFlexVolume): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeFlexVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeFlexVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeFlexVolume | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _options?;
    /**
     * @stability stable
     */
    get options(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set options(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptions(): void;
    /**
     * @stability stable
     */
    get optionsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): DaemonSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#dataset_name DaemonSetV1#dataset_name}
     *
     * @stability stable
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset. This is unique identifier of a Flocker dataset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#dataset_uuid DaemonSetV1#dataset_uuid}
     *
     * @stability stable
     */
    readonly datasetUuid?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeFlockerToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeFlockerOutputReference | DaemonSetV1SpecTemplateSpecVolumeFlocker): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeFlockerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeFlocker | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeFlocker | undefined);
    private _datasetName?;
    /**
     * @stability stable
     */
    get datasetName(): string;
    /**
     * @stability stable
     */
    set datasetName(value: string);
    /**
     * @stability stable
     */
    resetDatasetName(): void;
    /**
     * @stability stable
     */
    get datasetNameInput(): string | undefined;
    private _datasetUuid?;
    /**
     * @stability stable
     */
    get datasetUuid(): string;
    /**
     * @stability stable
     */
    set datasetUuid(value: string);
    /**
     * @stability stable
     */
    resetDatasetUuid(): void;
    /**
     * @stability stable
     */
    get datasetUuidInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#partition DaemonSetV1#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pd_name DaemonSetV1#pd_name}
     *
     * @stability stable
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecVolumeGcePersistentDiskToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeGcePersistentDiskOutputReference | DaemonSetV1SpecTemplateSpecVolumeGcePersistentDisk): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeGcePersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeGcePersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeGcePersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _pdName?;
    /**
     * @stability stable
     */
    get pdName(): string;
    /**
     * @stability stable
     */
    set pdName(value: string);
    /**
     * @stability stable
     */
    get pdNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#directory DaemonSetV1#directory}
     *
     * @stability stable
     */
    readonly directory?: string;
    /**
     * Repository URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#repository DaemonSetV1#repository}
     *
     * @stability stable
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#revision DaemonSetV1#revision}
     *
     * @stability stable
     */
    readonly revision?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeGitRepoToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeGitRepoOutputReference | DaemonSetV1SpecTemplateSpecVolumeGitRepo): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeGitRepoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeGitRepo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeGitRepo | undefined);
    private _directory?;
    /**
     * @stability stable
     */
    get directory(): string;
    /**
     * @stability stable
     */
    set directory(value: string);
    /**
     * @stability stable
     */
    resetDirectory(): void;
    /**
     * @stability stable
     */
    get directoryInput(): string | undefined;
    private _repository?;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    resetRepository(): void;
    /**
     * @stability stable
     */
    get repositoryInput(): string | undefined;
    private _revision?;
    /**
     * @stability stable
     */
    get revision(): string;
    /**
     * @stability stable
     */
    set revision(value: string);
    /**
     * @stability stable
     */
    resetRevision(): void;
    /**
     * @stability stable
     */
    get revisionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#endpoints_name DaemonSetV1#endpoints_name}
     *
     * @stability stable
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecVolumeGlusterfsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeGlusterfsOutputReference | DaemonSetV1SpecTemplateSpecVolumeGlusterfs): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeGlusterfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeGlusterfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeGlusterfs | undefined);
    private _endpointsName?;
    /**
     * @stability stable
     */
    get endpointsName(): string;
    /**
     * @stability stable
     */
    set endpointsName(value: string);
    /**
     * @stability stable
     */
    get endpointsNameInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeHostPath {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#hostpath.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Type for HostPath volume. Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#type DaemonSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeHostPathToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeHostPathOutputReference | DaemonSetV1SpecTemplateSpecVolumeHostPath): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeHostPathOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeHostPath | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeHostPath | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#iqn DaemonSetV1#iqn}
     *
     * @stability stable
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport. Defaults to 'default' (tcp).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#iscsi_interface DaemonSetV1#iscsi_interface}
     *
     * @stability stable
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#lun DaemonSetV1#lun}
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#target_portal DaemonSetV1#target_portal}
     *
     * @stability stable
     */
    readonly targetPortal: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeIscsiToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeIscsiOutputReference | DaemonSetV1SpecTemplateSpecVolumeIscsi): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeIscsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeIscsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeIscsi | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _iqn?;
    /**
     * @stability stable
     */
    get iqn(): string;
    /**
     * @stability stable
     */
    set iqn(value: string);
    /**
     * @stability stable
     */
    get iqnInput(): string | undefined;
    private _iscsiInterface?;
    /**
     * @stability stable
     */
    get iscsiInterface(): string;
    /**
     * @stability stable
     */
    set iscsiInterface(value: string);
    /**
     * @stability stable
     */
    resetIscsiInterface(): void;
    /**
     * @stability stable
     */
    get iscsiInterfaceInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    resetLun(): void;
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetPortal?;
    /**
     * @stability stable
     */
    get targetPortal(): string;
    /**
     * @stability stable
     */
    set targetPortal(value: string);
    /**
     * @stability stable
     */
    get targetPortalInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeLocal {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#local.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeLocalToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeLocalOutputReference | DaemonSetV1SpecTemplateSpecVolumeLocal): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeLocalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeLocal | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeLocal | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Server is the hostname or IP address of the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#server DaemonSetV1#server}
     *
     * @stability stable
     */
    readonly server: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeNfsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeNfsOutputReference | DaemonSetV1SpecTemplateSpecVolumeNfs): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeNfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeNfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeNfs | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _server?;
    /**
     * @stability stable
     */
    get server(): string;
    /**
     * @stability stable
     */
    set server(value: string);
    /**
     * @stability stable
     */
    get serverInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#claim_name DaemonSetV1#claim_name}
     *
     * @stability stable
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function daemonSetV1SpecTemplateSpecVolumePersistentVolumeClaimToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumePersistentVolumeClaimOutputReference | DaemonSetV1SpecTemplateSpecVolumePersistentVolumeClaim): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumePersistentVolumeClaimOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumePersistentVolumeClaim | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumePersistentVolumeClaim | undefined);
    private _claimName?;
    /**
     * @stability stable
     */
    get claimName(): string;
    /**
     * @stability stable
     */
    set claimName(value: string);
    /**
     * @stability stable
     */
    resetClaimName(): void;
    /**
     * @stability stable
     */
    get claimNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#pd_id DaemonSetV1#pd_id}
     *
     * @stability stable
     */
    readonly pdId: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumePhotonPersistentDiskToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumePhotonPersistentDiskOutputReference | DaemonSetV1SpecTemplateSpecVolumePhotonPersistentDisk): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumePhotonPersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumePhotonPersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumePhotonPersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _pdId?;
    /**
     * @stability stable
     */
    get pdId(): string;
    /**
     * @stability stable
     */
    set pdId(value: string);
    /**
     * @stability stable
     */
    get pdIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mode DaemonSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItemsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#items DaemonSetV1#items}
     *
     * @stability stable
     */
    readonly items?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMap): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#api_version DaemonSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_path DaemonSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#container_name DaemonSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#divisor DaemonSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource DaemonSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mode DaemonSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#field_ref DaemonSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#resource_field_ref DaemonSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef;
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#items DaemonSetV1#items}
     *
     * @stability stable
     */
    readonly items?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference | DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined);
    private _items?;
    /**
     * @stability stable
     */
    get items(): DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mode DaemonSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItemsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItems): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#items DaemonSetV1#items}
     *
     * @stability stable
     */
    readonly items?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItems[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecretToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecret): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#audience DaemonSetV1#audience}
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#expiration_seconds DaemonSetV1#expiration_seconds}
     *
     * @stability stable
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference | DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined);
    private _audience?;
    /**
     * @stability stable
     */
    get audience(): string;
    /**
     * @stability stable
     */
    set audience(value: string);
    /**
     * @stability stable
     */
    resetAudience(): void;
    /**
     * @stability stable
     */
    get audienceInput(): string | undefined;
    private _expirationSeconds?;
    /**
     * @stability stable
     */
    get expirationSeconds(): number;
    /**
     * @stability stable
     */
    set expirationSeconds(value: number);
    /**
     * @stability stable
     */
    resetExpirationSeconds(): void;
    /**
     * @stability stable
     */
    get expirationSecondsInput(): number | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjectedSources {
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#config_map DaemonSetV1#config_map}
     *
     * @stability stable
     */
    readonly configMap?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#downward_api DaemonSetV1#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret DaemonSetV1#secret}
     *
     * @stability stable
     */
    readonly secret?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#service_account_token DaemonSetV1#service_account_token}
     *
     * @stability stable
     */
    readonly serviceAccountToken?: DaemonSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken;
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedSourcesToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjectedSources): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#default_mode DaemonSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#sources DaemonSetV1#sources}
     *
     * @stability stable
     */
    readonly sources: DaemonSetV1SpecTemplateSpecVolumeProjectedSources[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeProjectedToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeProjected): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#group DaemonSetV1#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#registry DaemonSetV1#registry}
     *
     * @stability stable
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#user DaemonSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume DaemonSetV1#volume}
     *
     * @stability stable
     */
    readonly volume: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeQuobyteToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeQuobyteOutputReference | DaemonSetV1SpecTemplateSpecVolumeQuobyte): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeQuobyteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeQuobyte | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeQuobyte | undefined);
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _registry?;
    /**
     * @stability stable
     */
    get registry(): string;
    /**
     * @stability stable
     */
    set registry(value: string);
    /**
     * @stability stable
     */
    get registryInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): string;
    /**
     * @stability stable
     */
    set volume(value: string);
    /**
     * @stability stable
     */
    get volumeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeRbdSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#namespace DaemonSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeRbdSecretRefToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeRbdSecretRefOutputReference | DaemonSetV1SpecTemplateSpecVolumeRbdSecretRef): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeRbdSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeRbdSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeRbdSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeRbd {
    /**
     * A collection of Ceph monitors. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#ceph_monitors DaemonSetV1#ceph_monitors}
     *
     * @stability stable
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#keyring DaemonSetV1#keyring}
     *
     * @stability stable
     */
    readonly keyring?: string;
    /**
     * The rados user name. Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#rados_user DaemonSetV1#rados_user}
     *
     * @stability stable
     */
    readonly radosUser?: string;
    /**
     * The rados image name. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#rbd_image DaemonSetV1#rbd_image}
     *
     * @stability stable
     */
    readonly rbdImage: string;
    /**
     * The rados pool name. Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#rbd_pool DaemonSetV1#rbd_pool}
     *
     * @stability stable
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#read_only DaemonSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_ref DaemonSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: DaemonSetV1SpecTemplateSpecVolumeRbdSecretRef;
}
export declare function daemonSetV1SpecTemplateSpecVolumeRbdToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeRbdOutputReference | DaemonSetV1SpecTemplateSpecVolumeRbd): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeRbdOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeRbd | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeRbd | undefined);
    private _cephMonitors?;
    /**
     * @stability stable
     */
    get cephMonitors(): string[];
    /**
     * @stability stable
     */
    set cephMonitors(value: string[]);
    /**
     * @stability stable
     */
    get cephMonitorsInput(): string[] | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _keyring?;
    /**
     * @stability stable
     */
    get keyring(): string;
    /**
     * @stability stable
     */
    set keyring(value: string);
    /**
     * @stability stable
     */
    resetKeyring(): void;
    /**
     * @stability stable
     */
    get keyringInput(): string | undefined;
    private _radosUser?;
    /**
     * @stability stable
     */
    get radosUser(): string;
    /**
     * @stability stable
     */
    set radosUser(value: string);
    /**
     * @stability stable
     */
    resetRadosUser(): void;
    /**
     * @stability stable
     */
    get radosUserInput(): string | undefined;
    private _rbdImage?;
    /**
     * @stability stable
     */
    get rbdImage(): string;
    /**
     * @stability stable
     */
    set rbdImage(value: string);
    /**
     * @stability stable
     */
    get rbdImageInput(): string | undefined;
    private _rbdPool?;
    /**
     * @stability stable
     */
    get rbdPool(): string;
    /**
     * @stability stable
     */
    set rbdPool(value: string);
    /**
     * @stability stable
     */
    resetRbdPool(): void;
    /**
     * @stability stable
     */
    get rbdPoolInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): DaemonSetV1SpecTemplateSpecVolumeRbdSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: DaemonSetV1SpecTemplateSpecVolumeRbdSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): DaemonSetV1SpecTemplateSpecVolumeRbdSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#key DaemonSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#mode DaemonSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#path DaemonSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeSecretItemsToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeSecretItems): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#default_mode DaemonSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#optional DaemonSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret_name DaemonSetV1#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#items DaemonSetV1#items}
     *
     * @stability stable
     */
    readonly items?: DaemonSetV1SpecTemplateSpecVolumeSecretItems[];
}
export declare function daemonSetV1SpecTemplateSpecVolumeSecretToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeSecretOutputReference | DaemonSetV1SpecTemplateSpecVolumeSecret): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeSecretOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeSecret | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeSecret | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    resetSecretName(): void;
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): DaemonSetV1SpecTemplateSpecVolumeSecretItems[];
    /**
     * @stability stable
     */
    set items(value: DaemonSetV1SpecTemplateSpecVolumeSecretItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): DaemonSetV1SpecTemplateSpecVolumeSecretItems[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fs_type DaemonSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume_path DaemonSetV1#volume_path}
     *
     * @stability stable
     */
    readonly volumePath: string;
}
export declare function daemonSetV1SpecTemplateSpecVolumeVsphereVolumeToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolumeVsphereVolumeOutputReference | DaemonSetV1SpecTemplateSpecVolumeVsphereVolume): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecVolumeVsphereVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpecVolumeVsphereVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpecVolumeVsphereVolume | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _volumePath?;
    /**
     * @stability stable
     */
    get volumePath(): string;
    /**
     * @stability stable
     */
    set volumePath(value: string);
    /**
     * @stability stable
     */
    get volumePathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpecVolume {
    /**
     * Volume's name. Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#name DaemonSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#aws_elastic_block_store DaemonSetV1#aws_elastic_block_store}
     *
     * @stability stable
     */
    readonly awsElasticBlockStore?: DaemonSetV1SpecTemplateSpecVolumeAwsElasticBlockStore;
    /**
     * azure_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#azure_disk DaemonSetV1#azure_disk}
     *
     * @stability stable
     */
    readonly azureDisk?: DaemonSetV1SpecTemplateSpecVolumeAzureDisk;
    /**
     * azure_file block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#azure_file DaemonSetV1#azure_file}
     *
     * @stability stable
     */
    readonly azureFile?: DaemonSetV1SpecTemplateSpecVolumeAzureFile;
    /**
     * ceph_fs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#ceph_fs DaemonSetV1#ceph_fs}
     *
     * @stability stable
     */
    readonly cephFs?: DaemonSetV1SpecTemplateSpecVolumeCephFs;
    /**
     * cinder block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#cinder DaemonSetV1#cinder}
     *
     * @stability stable
     */
    readonly cinder?: DaemonSetV1SpecTemplateSpecVolumeCinder;
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#config_map DaemonSetV1#config_map}
     *
     * @stability stable
     */
    readonly configMap?: DaemonSetV1SpecTemplateSpecVolumeConfigMap;
    /**
     * csi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#csi DaemonSetV1#csi}
     *
     * @stability stable
     */
    readonly csi?: DaemonSetV1SpecTemplateSpecVolumeCsi;
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#downward_api DaemonSetV1#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: DaemonSetV1SpecTemplateSpecVolumeDownwardApi;
    /**
     * empty_dir block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#empty_dir DaemonSetV1#empty_dir}
     *
     * @stability stable
     */
    readonly emptyDir?: DaemonSetV1SpecTemplateSpecVolumeEmptyDir;
    /**
     * fc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#fc DaemonSetV1#fc}
     *
     * @stability stable
     */
    readonly fc?: DaemonSetV1SpecTemplateSpecVolumeFc;
    /**
     * flex_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#flex_volume DaemonSetV1#flex_volume}
     *
     * @stability stable
     */
    readonly flexVolume?: DaemonSetV1SpecTemplateSpecVolumeFlexVolume;
    /**
     * flocker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#flocker DaemonSetV1#flocker}
     *
     * @stability stable
     */
    readonly flocker?: DaemonSetV1SpecTemplateSpecVolumeFlocker;
    /**
     * gce_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#gce_persistent_disk DaemonSetV1#gce_persistent_disk}
     *
     * @stability stable
     */
    readonly gcePersistentDisk?: DaemonSetV1SpecTemplateSpecVolumeGcePersistentDisk;
    /**
     * git_repo block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#git_repo DaemonSetV1#git_repo}
     *
     * @stability stable
     */
    readonly gitRepo?: DaemonSetV1SpecTemplateSpecVolumeGitRepo;
    /**
     * glusterfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#glusterfs DaemonSetV1#glusterfs}
     *
     * @stability stable
     */
    readonly glusterfs?: DaemonSetV1SpecTemplateSpecVolumeGlusterfs;
    /**
     * host_path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_path DaemonSetV1#host_path}
     *
     * @stability stable
     */
    readonly hostPath?: DaemonSetV1SpecTemplateSpecVolumeHostPath;
    /**
     * iscsi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#iscsi DaemonSetV1#iscsi}
     *
     * @stability stable
     */
    readonly iscsi?: DaemonSetV1SpecTemplateSpecVolumeIscsi;
    /**
     * local block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#local DaemonSetV1#local}
     *
     * @stability stable
     */
    readonly local?: DaemonSetV1SpecTemplateSpecVolumeLocal;
    /**
     * nfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#nfs DaemonSetV1#nfs}
     *
     * @stability stable
     */
    readonly nfs?: DaemonSetV1SpecTemplateSpecVolumeNfs;
    /**
     * persistent_volume_claim block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#persistent_volume_claim DaemonSetV1#persistent_volume_claim}
     *
     * @stability stable
     */
    readonly persistentVolumeClaim?: DaemonSetV1SpecTemplateSpecVolumePersistentVolumeClaim;
    /**
     * photon_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#photon_persistent_disk DaemonSetV1#photon_persistent_disk}
     *
     * @stability stable
     */
    readonly photonPersistentDisk?: DaemonSetV1SpecTemplateSpecVolumePhotonPersistentDisk;
    /**
     * projected block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#projected DaemonSetV1#projected}
     *
     * @stability stable
     */
    readonly projected?: DaemonSetV1SpecTemplateSpecVolumeProjected[];
    /**
     * quobyte block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#quobyte DaemonSetV1#quobyte}
     *
     * @stability stable
     */
    readonly quobyte?: DaemonSetV1SpecTemplateSpecVolumeQuobyte;
    /**
     * rbd block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#rbd DaemonSetV1#rbd}
     *
     * @stability stable
     */
    readonly rbd?: DaemonSetV1SpecTemplateSpecVolumeRbd;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#secret DaemonSetV1#secret}
     *
     * @stability stable
     */
    readonly secret?: DaemonSetV1SpecTemplateSpecVolumeSecret;
    /**
     * vsphere_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#vsphere_volume DaemonSetV1#vsphere_volume}
     *
     * @stability stable
     */
    readonly vsphereVolume?: DaemonSetV1SpecTemplateSpecVolumeVsphereVolume;
}
export declare function daemonSetV1SpecTemplateSpecVolumeToTerraform(struct?: DaemonSetV1SpecTemplateSpecVolume): any;
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplateSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#active_deadline_seconds DaemonSetV1#active_deadline_seconds}
     *
     * @stability stable
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#automount_service_account_token DaemonSetV1#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean | cdktf.IResolvable;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#dns_policy DaemonSetV1#dns_policy}
     *
     * @stability stable
     */
    readonly dnsPolicy?: string;
    /**
     * Enables generating environment variables for service discovery. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#enable_service_links DaemonSetV1#enable_service_links}
     *
     * @stability stable
     */
    readonly enableServiceLinks?: boolean | cdktf.IResolvable;
    /**
     * Use the host's ipc namespace. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_ipc DaemonSetV1#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean | cdktf.IResolvable;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_network DaemonSetV1#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean | cdktf.IResolvable;
    /**
     * Use the host's pid namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_pid DaemonSetV1#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean | cdktf.IResolvable;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#hostname DaemonSetV1#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#node_name DaemonSetV1#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#node_selector DaemonSetV1#node_selector}
     *
     * @stability stable
     */
    readonly nodeSelector?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#priority_class_name DaemonSetV1#priority_class_name}
     *
     * @stability stable
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod. One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#restart_policy DaemonSetV1#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#service_account_name DaemonSetV1#service_account_name}
     *
     * @stability stable
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#share_process_namespace DaemonSetV1#share_process_namespace}
     *
     * @stability stable
     */
    readonly shareProcessNamespace?: boolean | cdktf.IResolvable;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#subdomain DaemonSetV1#subdomain}
     *
     * @stability stable
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#termination_grace_period_seconds DaemonSetV1#termination_grace_period_seconds}
     *
     * @stability stable
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#affinity DaemonSetV1#affinity}
     *
     * @stability stable
     */
    readonly affinity?: DaemonSetV1SpecTemplateSpecAffinity;
    /**
     * container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#container DaemonSetV1#container}
     *
     * @stability stable
     */
    readonly container?: DaemonSetV1SpecTemplateSpecContainer[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#dns_config DaemonSetV1#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: DaemonSetV1SpecTemplateSpecDnsConfig;
    /**
     * host_aliases block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#host_aliases DaemonSetV1#host_aliases}
     *
     * @stability stable
     */
    readonly hostAliases?: DaemonSetV1SpecTemplateSpecHostAliases[];
    /**
     * image_pull_secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#image_pull_secrets DaemonSetV1#image_pull_secrets}
     *
     * @stability stable
     */
    readonly imagePullSecrets?: DaemonSetV1SpecTemplateSpecImagePullSecrets[];
    /**
     * init_container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#init_container DaemonSetV1#init_container}
     *
     * @stability stable
     */
    readonly initContainer?: DaemonSetV1SpecTemplateSpecInitContainer[];
    /**
     * readiness_gate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#readiness_gate DaemonSetV1#readiness_gate}
     *
     * @stability stable
     */
    readonly readinessGate?: DaemonSetV1SpecTemplateSpecReadinessGate[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#security_context DaemonSetV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: DaemonSetV1SpecTemplateSpecSecurityContext;
    /**
     * toleration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#toleration DaemonSetV1#toleration}
     *
     * @stability stable
     */
    readonly toleration?: DaemonSetV1SpecTemplateSpecToleration[];
    /**
     * topology_spread_constraint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#topology_spread_constraint DaemonSetV1#topology_spread_constraint}
     *
     * @stability stable
     */
    readonly topologySpreadConstraint?: DaemonSetV1SpecTemplateSpecTopologySpreadConstraint[];
    /**
     * volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#volume DaemonSetV1#volume}
     *
     * @stability stable
     */
    readonly volume?: DaemonSetV1SpecTemplateSpecVolume[];
}
export declare function daemonSetV1SpecTemplateSpecToTerraform(struct?: DaemonSetV1SpecTemplateSpecOutputReference | DaemonSetV1SpecTemplateSpec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplateSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplateSpec | undefined);
    private _activeDeadlineSeconds?;
    /**
     * @stability stable
     */
    get activeDeadlineSeconds(): number;
    /**
     * @stability stable
     */
    set activeDeadlineSeconds(value: number);
    /**
     * @stability stable
     */
    resetActiveDeadlineSeconds(): void;
    /**
     * @stability stable
     */
    get activeDeadlineSecondsInput(): number | undefined;
    private _automountServiceAccountToken?;
    /**
     * @stability stable
     */
    get automountServiceAccountToken(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set automountServiceAccountToken(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutomountServiceAccountToken(): void;
    /**
     * @stability stable
     */
    get automountServiceAccountTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _dnsPolicy?;
    /**
     * @stability stable
     */
    get dnsPolicy(): string;
    /**
     * @stability stable
     */
    set dnsPolicy(value: string);
    /**
     * @stability stable
     */
    resetDnsPolicy(): void;
    /**
     * @stability stable
     */
    get dnsPolicyInput(): string | undefined;
    private _enableServiceLinks?;
    /**
     * @stability stable
     */
    get enableServiceLinks(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableServiceLinks(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableServiceLinks(): void;
    /**
     * @stability stable
     */
    get enableServiceLinksInput(): boolean | cdktf.IResolvable | undefined;
    private _hostIpc?;
    /**
     * @stability stable
     */
    get hostIpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostIpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostIpc(): void;
    /**
     * @stability stable
     */
    get hostIpcInput(): boolean | cdktf.IResolvable | undefined;
    private _hostNetwork?;
    /**
     * @stability stable
     */
    get hostNetwork(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostNetwork(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostNetwork(): void;
    /**
     * @stability stable
     */
    get hostNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _hostPid?;
    /**
     * @stability stable
     */
    get hostPid(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostPid(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostPid(): void;
    /**
     * @stability stable
     */
    get hostPidInput(): boolean | cdktf.IResolvable | undefined;
    private _hostname?;
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    set hostname(value: string);
    /**
     * @stability stable
     */
    resetHostname(): void;
    /**
     * @stability stable
     */
    get hostnameInput(): string | undefined;
    private _nodeName?;
    /**
     * @stability stable
     */
    get nodeName(): string;
    /**
     * @stability stable
     */
    set nodeName(value: string);
    /**
     * @stability stable
     */
    resetNodeName(): void;
    /**
     * @stability stable
     */
    get nodeNameInput(): string | undefined;
    private _nodeSelector?;
    /**
     * @stability stable
     */
    get nodeSelector(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set nodeSelector(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNodeSelector(): void;
    /**
     * @stability stable
     */
    get nodeSelectorInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _priorityClassName?;
    /**
     * @stability stable
     */
    get priorityClassName(): string;
    /**
     * @stability stable
     */
    set priorityClassName(value: string);
    /**
     * @stability stable
     */
    resetPriorityClassName(): void;
    /**
     * @stability stable
     */
    get priorityClassNameInput(): string | undefined;
    private _restartPolicy?;
    /**
     * @stability stable
     */
    get restartPolicy(): string;
    /**
     * @stability stable
     */
    set restartPolicy(value: string);
    /**
     * @stability stable
     */
    resetRestartPolicy(): void;
    /**
     * @stability stable
     */
    get restartPolicyInput(): string | undefined;
    private _serviceAccountName?;
    /**
     * @stability stable
     */
    get serviceAccountName(): string;
    /**
     * @stability stable
     */
    set serviceAccountName(value: string);
    /**
     * @stability stable
     */
    resetServiceAccountName(): void;
    /**
     * @stability stable
     */
    get serviceAccountNameInput(): string | undefined;
    private _shareProcessNamespace?;
    /**
     * @stability stable
     */
    get shareProcessNamespace(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set shareProcessNamespace(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShareProcessNamespace(): void;
    /**
     * @stability stable
     */
    get shareProcessNamespaceInput(): boolean | cdktf.IResolvable | undefined;
    private _subdomain?;
    /**
     * @stability stable
     */
    get subdomain(): string;
    /**
     * @stability stable
     */
    set subdomain(value: string);
    /**
     * @stability stable
     */
    resetSubdomain(): void;
    /**
     * @stability stable
     */
    get subdomainInput(): string | undefined;
    private _terminationGracePeriodSeconds?;
    /**
     * @stability stable
     */
    get terminationGracePeriodSeconds(): number;
    /**
     * @stability stable
     */
    set terminationGracePeriodSeconds(value: number);
    /**
     * @stability stable
     */
    resetTerminationGracePeriodSeconds(): void;
    /**
     * @stability stable
     */
    get terminationGracePeriodSecondsInput(): number | undefined;
    private _affinity;
    /**
     * @stability stable
     */
    get affinity(): DaemonSetV1SpecTemplateSpecAffinityOutputReference;
    /**
     * @stability stable
     */
    putAffinity(value: DaemonSetV1SpecTemplateSpecAffinity): void;
    /**
     * @stability stable
     */
    resetAffinity(): void;
    /**
     * @stability stable
     */
    get affinityInput(): DaemonSetV1SpecTemplateSpecAffinity | undefined;
    private _container?;
    /**
     * @stability stable
     */
    get container(): DaemonSetV1SpecTemplateSpecContainer[];
    /**
     * @stability stable
     */
    set container(value: DaemonSetV1SpecTemplateSpecContainer[]);
    /**
     * @stability stable
     */
    resetContainer(): void;
    /**
     * @stability stable
     */
    get containerInput(): DaemonSetV1SpecTemplateSpecContainer[] | undefined;
    private _dnsConfig;
    /**
     * @stability stable
     */
    get dnsConfig(): DaemonSetV1SpecTemplateSpecDnsConfigOutputReference;
    /**
     * @stability stable
     */
    putDnsConfig(value: DaemonSetV1SpecTemplateSpecDnsConfig): void;
    /**
     * @stability stable
     */
    resetDnsConfig(): void;
    /**
     * @stability stable
     */
    get dnsConfigInput(): DaemonSetV1SpecTemplateSpecDnsConfig | undefined;
    private _hostAliases?;
    /**
     * @stability stable
     */
    get hostAliases(): DaemonSetV1SpecTemplateSpecHostAliases[];
    /**
     * @stability stable
     */
    set hostAliases(value: DaemonSetV1SpecTemplateSpecHostAliases[]);
    /**
     * @stability stable
     */
    resetHostAliases(): void;
    /**
     * @stability stable
     */
    get hostAliasesInput(): DaemonSetV1SpecTemplateSpecHostAliases[] | undefined;
    private _imagePullSecrets?;
    /**
     * @stability stable
     */
    get imagePullSecrets(): DaemonSetV1SpecTemplateSpecImagePullSecrets[];
    /**
     * @stability stable
     */
    set imagePullSecrets(value: DaemonSetV1SpecTemplateSpecImagePullSecrets[]);
    /**
     * @stability stable
     */
    resetImagePullSecrets(): void;
    /**
     * @stability stable
     */
    get imagePullSecretsInput(): DaemonSetV1SpecTemplateSpecImagePullSecrets[] | undefined;
    private _initContainer?;
    /**
     * @stability stable
     */
    get initContainer(): DaemonSetV1SpecTemplateSpecInitContainer[];
    /**
     * @stability stable
     */
    set initContainer(value: DaemonSetV1SpecTemplateSpecInitContainer[]);
    /**
     * @stability stable
     */
    resetInitContainer(): void;
    /**
     * @stability stable
     */
    get initContainerInput(): DaemonSetV1SpecTemplateSpecInitContainer[] | undefined;
    private _readinessGate?;
    /**
     * @stability stable
     */
    get readinessGate(): DaemonSetV1SpecTemplateSpecReadinessGate[];
    /**
     * @stability stable
     */
    set readinessGate(value: DaemonSetV1SpecTemplateSpecReadinessGate[]);
    /**
     * @stability stable
     */
    resetReadinessGate(): void;
    /**
     * @stability stable
     */
    get readinessGateInput(): DaemonSetV1SpecTemplateSpecReadinessGate[] | undefined;
    private _securityContext;
    /**
     * @stability stable
     */
    get securityContext(): DaemonSetV1SpecTemplateSpecSecurityContextOutputReference;
    /**
     * @stability stable
     */
    putSecurityContext(value: DaemonSetV1SpecTemplateSpecSecurityContext): void;
    /**
     * @stability stable
     */
    resetSecurityContext(): void;
    /**
     * @stability stable
     */
    get securityContextInput(): DaemonSetV1SpecTemplateSpecSecurityContext | undefined;
    private _toleration?;
    /**
     * @stability stable
     */
    get toleration(): DaemonSetV1SpecTemplateSpecToleration[];
    /**
     * @stability stable
     */
    set toleration(value: DaemonSetV1SpecTemplateSpecToleration[]);
    /**
     * @stability stable
     */
    resetToleration(): void;
    /**
     * @stability stable
     */
    get tolerationInput(): DaemonSetV1SpecTemplateSpecToleration[] | undefined;
    private _topologySpreadConstraint?;
    /**
     * @stability stable
     */
    get topologySpreadConstraint(): DaemonSetV1SpecTemplateSpecTopologySpreadConstraint[];
    /**
     * @stability stable
     */
    set topologySpreadConstraint(value: DaemonSetV1SpecTemplateSpecTopologySpreadConstraint[]);
    /**
     * @stability stable
     */
    resetTopologySpreadConstraint(): void;
    /**
     * @stability stable
     */
    get topologySpreadConstraintInput(): DaemonSetV1SpecTemplateSpecTopologySpreadConstraint[] | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): DaemonSetV1SpecTemplateSpecVolume[];
    /**
     * @stability stable
     */
    set volume(value: DaemonSetV1SpecTemplateSpecVolume[]);
    /**
     * @stability stable
     */
    resetVolume(): void;
    /**
     * @stability stable
     */
    get volumeInput(): DaemonSetV1SpecTemplateSpecVolume[] | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1SpecTemplate {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#metadata DaemonSetV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: DaemonSetV1SpecTemplateMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#spec DaemonSetV1#spec}
     *
     * @stability stable
     */
    readonly spec?: DaemonSetV1SpecTemplateSpec;
}
export declare function daemonSetV1SpecTemplateToTerraform(struct?: DaemonSetV1SpecTemplateOutputReference | DaemonSetV1SpecTemplate): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1SpecTemplate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1SpecTemplate | undefined);
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DaemonSetV1SpecTemplateMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: DaemonSetV1SpecTemplateMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): DaemonSetV1SpecTemplateMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): DaemonSetV1SpecTemplateSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: DaemonSetV1SpecTemplateSpec): void;
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): DaemonSetV1SpecTemplateSpec | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1Spec {
    /**
     * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available.
     *
     * Defaults to 0 (pod will be considered available as soon as it is ready)
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#min_ready_seconds DaemonSetV1#min_ready_seconds}
     *
     * @stability stable
     */
    readonly minReadySeconds?: number;
    /**
     * The number of old ReplicaSets to retain to allow rollback.
     *
     * This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#revision_history_limit DaemonSetV1#revision_history_limit}
     *
     * @stability stable
     */
    readonly revisionHistoryLimit?: number;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#selector DaemonSetV1#selector}
     *
     * @stability stable
     */
    readonly selector?: DaemonSetV1SpecSelector;
    /**
     * strategy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#strategy DaemonSetV1#strategy}
     *
     * @stability stable
     */
    readonly strategy?: DaemonSetV1SpecStrategy;
    /**
     * template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#template DaemonSetV1#template}
     *
     * @stability stable
     */
    readonly template: DaemonSetV1SpecTemplate;
}
export declare function daemonSetV1SpecToTerraform(struct?: DaemonSetV1SpecOutputReference | DaemonSetV1Spec): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1Spec | undefined);
    private _minReadySeconds?;
    /**
     * @stability stable
     */
    get minReadySeconds(): number;
    /**
     * @stability stable
     */
    set minReadySeconds(value: number);
    /**
     * @stability stable
     */
    resetMinReadySeconds(): void;
    /**
     * @stability stable
     */
    get minReadySecondsInput(): number | undefined;
    private _revisionHistoryLimit?;
    /**
     * @stability stable
     */
    get revisionHistoryLimit(): number;
    /**
     * @stability stable
     */
    set revisionHistoryLimit(value: number);
    /**
     * @stability stable
     */
    resetRevisionHistoryLimit(): void;
    /**
     * @stability stable
     */
    get revisionHistoryLimitInput(): number | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): DaemonSetV1SpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: DaemonSetV1SpecSelector): void;
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): DaemonSetV1SpecSelector | undefined;
    private _strategy;
    /**
     * @stability stable
     */
    get strategy(): DaemonSetV1SpecStrategyOutputReference;
    /**
     * @stability stable
     */
    putStrategy(value: DaemonSetV1SpecStrategy): void;
    /**
     * @stability stable
     */
    resetStrategy(): void;
    /**
     * @stability stable
     */
    get strategyInput(): DaemonSetV1SpecStrategy | undefined;
    private _template;
    /**
     * @stability stable
     */
    get template(): DaemonSetV1SpecTemplateOutputReference;
    /**
     * @stability stable
     */
    putTemplate(value: DaemonSetV1SpecTemplate): void;
    /**
     * @stability stable
     */
    get templateInput(): DaemonSetV1SpecTemplate | undefined;
}
/**
 * @stability stable
 */
export interface DaemonSetV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#create DaemonSetV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#delete DaemonSetV1#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html#update DaemonSetV1#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function daemonSetV1TimeoutsToTerraform(struct?: DaemonSetV1TimeoutsOutputReference | DaemonSetV1Timeouts): any;
/**
 * @stability stable
 */
export declare class DaemonSetV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DaemonSetV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DaemonSetV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html kubernetes_daemon_set_v1}.
 *
 * @stability stable
 */
export declare class DaemonSetV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/daemon_set_v1.html kubernetes_daemon_set_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DaemonSetV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _waitForRollout?;
    /**
     * @stability stable
     */
    get waitForRollout(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForRollout(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForRollout(): void;
    /**
     * @stability stable
     */
    get waitForRolloutInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DaemonSetV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: DaemonSetV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): DaemonSetV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): DaemonSetV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: DaemonSetV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): DaemonSetV1Spec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DaemonSetV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DaemonSetV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DaemonSetV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
