import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface JobV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#wait_for_completion JobV1#wait_for_completion}.
     *
     * @stability stable
     */
    readonly waitForCompletion?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#metadata JobV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: JobV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#spec JobV1#spec}
     *
     * @stability stable
     */
    readonly spec: JobV1Spec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#timeouts JobV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: JobV1Timeouts;
}
/**
 * @stability stable
 */
export interface JobV1Metadata {
    /**
     * An unstructured key value map stored with the job that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#annotations JobV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#generate_name JobV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the job.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#labels JobV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the job, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the job must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1MetadataToTerraform(struct?: JobV1MetadataOutputReference | JobV1Metadata): any;
/**
 * @stability stable
 */
export declare class JobV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecSelectorMatchExpressionsToTerraform(struct?: JobV1SpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_labels JobV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecSelectorMatchExpressions[];
}
export declare function jobV1SpecSelectorToTerraform(struct?: JobV1SpecSelectorOutputReference | JobV1SpecSelector): any;
/**
 * @stability stable
 */
export declare class JobV1SpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): JobV1SpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: JobV1SpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): JobV1SpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateMetadata {
    /**
     * An unstructured key value map stored with the job that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#annotations JobV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#generate_name JobV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the job.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#labels JobV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the job, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function jobV1SpecTemplateMetadataToTerraform(struct?: JobV1SpecTemplateMetadataOutputReference | JobV1SpecTemplateMetadata): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressionsToTerraform(struct?: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
export declare function jobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceToTerraform(struct?: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference | JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined);
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#weight JobV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * preference block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#preference JobV1#preference}
     *
     * @stability stable
     */
    readonly preference: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference;
}
export declare function jobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressionsToTerraform(struct?: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
export declare function jobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermToTerraform(struct?: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#node_selector_term JobV1#node_selector_term}
     *
     * @stability stable
     */
    readonly nodeSelectorTerm?: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
export declare function jobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference | JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined);
    private _nodeSelectorTerm?;
    /**
     * @stability stable
     */
    get nodeSelectorTerm(): JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
    /**
     * @stability stable
     */
    set nodeSelectorTerm(value: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[]);
    /**
     * @stability stable
     */
    resetNodeSelectorTerm(): void;
    /**
     * @stability stable
     */
    get nodeSelectorTermInput(): JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#preferred_during_scheduling_ignored_during_execution JobV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#required_during_scheduling_ignored_during_execution JobV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution;
}
export declare function jobV1SpecTemplateSpecAffinityNodeAffinityToTerraform(struct?: JobV1SpecTemplateSpecAffinityNodeAffinityOutputReference | JobV1SpecTemplateSpecAffinityNodeAffinity): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityNodeAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinityNodeAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinityNodeAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): JobV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference;
    /**
     * @stability stable
     */
    putRequiredDuringSchedulingIgnoredDuringExecution(value: JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): void;
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): JobV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_labels JobV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespaces JobV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#topology_key JobV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#label_selector JobV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#weight JobV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pod_affinity_term JobV1#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_labels JobV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespaces JobV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#topology_key JobV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#label_selector JobV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#preferred_during_scheduling_ignored_during_execution JobV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#required_during_scheduling_ignored_during_execution JobV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAffinityToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAffinityOutputReference | JobV1SpecTemplateSpecAffinityPodAffinity): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityPodAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinityPodAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinityPodAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): JobV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): JobV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_labels JobV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespaces JobV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#topology_key JobV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#label_selector JobV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#weight JobV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pod_affinity_term JobV1#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_labels JobV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespaces JobV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#topology_key JobV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#label_selector JobV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#preferred_during_scheduling_ignored_during_execution JobV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#required_during_scheduling_ignored_during_execution JobV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function jobV1SpecTemplateSpecAffinityPodAntiAffinityToTerraform(struct?: JobV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference | JobV1SpecTemplateSpecAffinityPodAntiAffinity): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinityPodAntiAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinityPodAntiAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): JobV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): JobV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecAffinity {
    /**
     * node_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#node_affinity JobV1#node_affinity}
     *
     * @stability stable
     */
    readonly nodeAffinity?: JobV1SpecTemplateSpecAffinityNodeAffinity;
    /**
     * pod_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pod_affinity JobV1#pod_affinity}
     *
     * @stability stable
     */
    readonly podAffinity?: JobV1SpecTemplateSpecAffinityPodAffinity;
    /**
     * pod_anti_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pod_anti_affinity JobV1#pod_anti_affinity}
     *
     * @stability stable
     */
    readonly podAntiAffinity?: JobV1SpecTemplateSpecAffinityPodAntiAffinity;
}
export declare function jobV1SpecTemplateSpecAffinityToTerraform(struct?: JobV1SpecTemplateSpecAffinityOutputReference | JobV1SpecTemplateSpecAffinity): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecAffinity | undefined);
    private _nodeAffinity;
    /**
     * @stability stable
     */
    get nodeAffinity(): JobV1SpecTemplateSpecAffinityNodeAffinityOutputReference;
    /**
     * @stability stable
     */
    putNodeAffinity(value: JobV1SpecTemplateSpecAffinityNodeAffinity): void;
    /**
     * @stability stable
     */
    resetNodeAffinity(): void;
    /**
     * @stability stable
     */
    get nodeAffinityInput(): JobV1SpecTemplateSpecAffinityNodeAffinity | undefined;
    private _podAffinity;
    /**
     * @stability stable
     */
    get podAffinity(): JobV1SpecTemplateSpecAffinityPodAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAffinity(value: JobV1SpecTemplateSpecAffinityPodAffinity): void;
    /**
     * @stability stable
     */
    resetPodAffinity(): void;
    /**
     * @stability stable
     */
    get podAffinityInput(): JobV1SpecTemplateSpecAffinityPodAffinity | undefined;
    private _podAntiAffinity;
    /**
     * @stability stable
     */
    get podAntiAffinity(): JobV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAntiAffinity(value: JobV1SpecTemplateSpecAffinityPodAntiAffinity): void;
    /**
     * @stability stable
     */
    resetPodAntiAffinity(): void;
    /**
     * @stability stable
     */
    get podAntiAffinityInput(): JobV1SpecTemplateSpecAffinityPodAntiAffinity | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference | JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#api_version JobV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_path JobV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function jobV1SpecTemplateSpecContainerEnvValueFromFieldRefToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference | JobV1SpecTemplateSpecContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#container_name JobV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#divisor JobV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource JobV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function jobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference | JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference | JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#config_map_key_ref JobV1#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_ref JobV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: JobV1SpecTemplateSpecContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource_field_ref JobV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_key_ref JobV1#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef;
}
export declare function jobV1SpecTemplateSpecContainerEnvValueFromToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvValueFromOutputReference | JobV1SpecTemplateSpecContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): JobV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): JobV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: JobV1SpecTemplateSpecContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): JobV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): JobV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): JobV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value_from JobV1#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: JobV1SpecTemplateSpecContainerEnvValueFrom;
}
export declare function jobV1SpecTemplateSpecContainerEnvToTerraform(struct?: JobV1SpecTemplateSpecContainerEnv): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecContainerEnvFromConfigMapRefToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvFromConfigMapRefOutputReference | JobV1SpecTemplateSpecContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecContainerEnvFromSecretRefToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvFromSecretRefOutputReference | JobV1SpecTemplateSpecContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#prefix JobV1#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#config_map_ref JobV1#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: JobV1SpecTemplateSpecContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_ref JobV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: JobV1SpecTemplateSpecContainerEnvFromSecretRef;
}
export declare function jobV1SpecTemplateSpecContainerEnvFromToTerraform(struct?: JobV1SpecTemplateSpecContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePostStartExecToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePostStartExecOutputReference | JobV1SpecTemplateSpecContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference | JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePostStartTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket[];
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePostStartToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePreStopExecToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePreStopExecOutputReference | JobV1SpecTemplateSpecContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference | JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePreStopTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket[];
}
export declare function jobV1SpecTemplateSpecContainerLifecyclePreStopToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#post_start JobV1#post_start}
     *
     * @stability stable
     */
    readonly postStart?: JobV1SpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pre_stop JobV1#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: JobV1SpecTemplateSpecContainerLifecyclePreStop[];
}
export declare function jobV1SpecTemplateSpecContainerLifecycleToTerraform(struct?: JobV1SpecTemplateSpecContainerLifecycleOutputReference | JobV1SpecTemplateSpecContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): JobV1SpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: JobV1SpecTemplateSpecContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): JobV1SpecTemplateSpecContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): JobV1SpecTemplateSpecContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: JobV1SpecTemplateSpecContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): JobV1SpecTemplateSpecContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecContainerLivenessProbeExecToTerraform(struct?: JobV1SpecTemplateSpecContainerLivenessProbeExecOutputReference | JobV1SpecTemplateSpecContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecContainerLivenessProbeHttpGetToTerraform(struct?: JobV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference | JobV1SpecTemplateSpecContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecContainerLivenessProbeTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#failure_threshold JobV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#initial_delay_seconds JobV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#period_seconds JobV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#success_threshold JobV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#timeout_seconds JobV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecContainerLivenessProbeTcpSocket[];
}
export declare function jobV1SpecTemplateSpecContainerLivenessProbeToTerraform(struct?: JobV1SpecTemplateSpecContainerLivenessProbeOutputReference | JobV1SpecTemplateSpecContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): JobV1SpecTemplateSpecContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: JobV1SpecTemplateSpecContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): JobV1SpecTemplateSpecContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): JobV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: JobV1SpecTemplateSpecContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): JobV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): JobV1SpecTemplateSpecContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: JobV1SpecTemplateSpecContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): JobV1SpecTemplateSpecContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#container_port JobV1#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_ip JobV1#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_port JobV1#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#protocol JobV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function jobV1SpecTemplateSpecContainerPortToTerraform(struct?: JobV1SpecTemplateSpecContainerPort): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecContainerReadinessProbeExecToTerraform(struct?: JobV1SpecTemplateSpecContainerReadinessProbeExecOutputReference | JobV1SpecTemplateSpecContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecContainerReadinessProbeHttpGetToTerraform(struct?: JobV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference | JobV1SpecTemplateSpecContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecContainerReadinessProbeTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#failure_threshold JobV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#initial_delay_seconds JobV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#period_seconds JobV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#success_threshold JobV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#timeout_seconds JobV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecContainerReadinessProbeTcpSocket[];
}
export declare function jobV1SpecTemplateSpecContainerReadinessProbeToTerraform(struct?: JobV1SpecTemplateSpecContainerReadinessProbeOutputReference | JobV1SpecTemplateSpecContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): JobV1SpecTemplateSpecContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: JobV1SpecTemplateSpecContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): JobV1SpecTemplateSpecContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): JobV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: JobV1SpecTemplateSpecContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): JobV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): JobV1SpecTemplateSpecContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: JobV1SpecTemplateSpecContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): JobV1SpecTemplateSpecContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#limits JobV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#requests JobV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecContainerResourcesToTerraform(struct?: JobV1SpecTemplateSpecContainerResourcesOutputReference | JobV1SpecTemplateSpecContainerResources): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#add JobV1#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#drop JobV1#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function jobV1SpecTemplateSpecContainerSecurityContextCapabilitiesToTerraform(struct?: JobV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference | JobV1SpecTemplateSpecContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#level JobV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#role JobV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#type JobV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#user JobV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function jobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsToTerraform(struct?: JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference | JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#allow_privilege_escalation JobV1#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#privileged JobV1#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only_root_filesystem JobV1#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_group JobV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_non_root JobV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_user JobV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#capabilities JobV1#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: JobV1SpecTemplateSpecContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#se_linux_options JobV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions;
}
export declare function jobV1SpecTemplateSpecContainerSecurityContextToTerraform(struct?: JobV1SpecTemplateSpecContainerSecurityContextOutputReference | JobV1SpecTemplateSpecContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): JobV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: JobV1SpecTemplateSpecContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): JobV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): JobV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecContainerStartupProbeExecToTerraform(struct?: JobV1SpecTemplateSpecContainerStartupProbeExecOutputReference | JobV1SpecTemplateSpecContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecContainerStartupProbeHttpGetToTerraform(struct?: JobV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference | JobV1SpecTemplateSpecContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecContainerStartupProbeTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#failure_threshold JobV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#initial_delay_seconds JobV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#period_seconds JobV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#success_threshold JobV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#timeout_seconds JobV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecContainerStartupProbeTcpSocket[];
}
export declare function jobV1SpecTemplateSpecContainerStartupProbeToTerraform(struct?: JobV1SpecTemplateSpecContainerStartupProbeOutputReference | JobV1SpecTemplateSpecContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): JobV1SpecTemplateSpecContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: JobV1SpecTemplateSpecContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): JobV1SpecTemplateSpecContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): JobV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: JobV1SpecTemplateSpecContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): JobV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): JobV1SpecTemplateSpecContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: JobV1SpecTemplateSpecContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): JobV1SpecTemplateSpecContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mount_path JobV1#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mount_propagation JobV1#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#sub_path JobV1#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function jobV1SpecTemplateSpecContainerVolumeMountToTerraform(struct?: JobV1SpecTemplateSpecContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#args JobV1#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#image JobV1#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#image_pull_policy JobV1#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#stdin JobV1#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#stdin_once JobV1#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#termination_message_path JobV1#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#termination_message_policy JobV1#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tty JobV1#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#working_dir JobV1#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#env JobV1#env}
     *
     * @stability stable
     */
    readonly env?: JobV1SpecTemplateSpecContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#env_from JobV1#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: JobV1SpecTemplateSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#lifecycle JobV1#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: JobV1SpecTemplateSpecContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#liveness_probe JobV1#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: JobV1SpecTemplateSpecContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: JobV1SpecTemplateSpecContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#readiness_probe JobV1#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: JobV1SpecTemplateSpecContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resources JobV1#resources}
     *
     * @stability stable
     */
    readonly resources?: JobV1SpecTemplateSpecContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#security_context JobV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: JobV1SpecTemplateSpecContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#startup_probe JobV1#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: JobV1SpecTemplateSpecContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume_mount JobV1#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: JobV1SpecTemplateSpecContainerVolumeMount[];
}
export declare function jobV1SpecTemplateSpecContainerToTerraform(struct?: JobV1SpecTemplateSpecContainer): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecDnsConfigOption {
    /**
     * Name of the option.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the option. Optional: Defaults to empty.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecDnsConfigOptionToTerraform(struct?: JobV1SpecTemplateSpecDnsConfigOption): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#nameservers JobV1#nameservers}
     *
     * @stability stable
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#searches JobV1#searches}
     *
     * @stability stable
     */
    readonly searches?: string[];
    /**
     * option block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#option JobV1#option}
     *
     * @stability stable
     */
    readonly option?: JobV1SpecTemplateSpecDnsConfigOption[];
}
export declare function jobV1SpecTemplateSpecDnsConfigToTerraform(struct?: JobV1SpecTemplateSpecDnsConfigOutputReference | JobV1SpecTemplateSpecDnsConfig): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecDnsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecDnsConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecDnsConfig | undefined);
    private _nameservers?;
    /**
     * @stability stable
     */
    get nameservers(): string[];
    /**
     * @stability stable
     */
    set nameservers(value: string[]);
    /**
     * @stability stable
     */
    resetNameservers(): void;
    /**
     * @stability stable
     */
    get nameserversInput(): string[] | undefined;
    private _searches?;
    /**
     * @stability stable
     */
    get searches(): string[];
    /**
     * @stability stable
     */
    set searches(value: string[]);
    /**
     * @stability stable
     */
    resetSearches(): void;
    /**
     * @stability stable
     */
    get searchesInput(): string[] | undefined;
    private _option?;
    /**
     * @stability stable
     */
    get option(): JobV1SpecTemplateSpecDnsConfigOption[];
    /**
     * @stability stable
     */
    set option(value: JobV1SpecTemplateSpecDnsConfigOption[]);
    /**
     * @stability stable
     */
    resetOption(): void;
    /**
     * @stability stable
     */
    get optionInput(): JobV1SpecTemplateSpecDnsConfigOption[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecHostAliases {
    /**
     * Hostnames for the IP address.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#hostnames JobV1#hostnames}
     *
     * @stability stable
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#ip JobV1#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
export declare function jobV1SpecTemplateSpecHostAliasesToTerraform(struct?: JobV1SpecTemplateSpecHostAliases): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecImagePullSecrets {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function jobV1SpecTemplateSpecImagePullSecretsToTerraform(struct?: JobV1SpecTemplateSpecImagePullSecrets): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference | JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#api_version JobV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_path JobV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvValueFromFieldRefToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference | JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#container_name JobV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#divisor JobV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource JobV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference | JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference | JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#config_map_key_ref JobV1#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_ref JobV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource_field_ref JobV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_key_ref JobV1#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvValueFromToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvValueFromOutputReference | JobV1SpecTemplateSpecInitContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): JobV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): JobV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): JobV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): JobV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value_from JobV1#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: JobV1SpecTemplateSpecInitContainerEnvValueFrom;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnv): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvFromConfigMapRefToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference | JobV1SpecTemplateSpecInitContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvFromSecretRefToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvFromSecretRefOutputReference | JobV1SpecTemplateSpecInitContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#prefix JobV1#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#config_map_ref JobV1#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: JobV1SpecTemplateSpecInitContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_ref JobV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: JobV1SpecTemplateSpecInitContainerEnvFromSecretRef;
}
export declare function jobV1SpecTemplateSpecInitContainerEnvFromToTerraform(struct?: JobV1SpecTemplateSpecInitContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePostStartExecToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference | JobV1SpecTemplateSpecInitContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference | JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket[];
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePostStartToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePreStopExecToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference | JobV1SpecTemplateSpecInitContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference | JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket[];
}
export declare function jobV1SpecTemplateSpecInitContainerLifecyclePreStopToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#post_start JobV1#post_start}
     *
     * @stability stable
     */
    readonly postStart?: JobV1SpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pre_stop JobV1#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: JobV1SpecTemplateSpecInitContainerLifecyclePreStop[];
}
export declare function jobV1SpecTemplateSpecInitContainerLifecycleToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLifecycleOutputReference | JobV1SpecTemplateSpecInitContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): JobV1SpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: JobV1SpecTemplateSpecInitContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): JobV1SpecTemplateSpecInitContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): JobV1SpecTemplateSpecInitContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: JobV1SpecTemplateSpecInitContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): JobV1SpecTemplateSpecInitContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecInitContainerLivenessProbeExecToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference | JobV1SpecTemplateSpecInitContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference | JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecInitContainerLivenessProbeTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#failure_threshold JobV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#initial_delay_seconds JobV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#period_seconds JobV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#success_threshold JobV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#timeout_seconds JobV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecInitContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
}
export declare function jobV1SpecTemplateSpecInitContainerLivenessProbeToTerraform(struct?: JobV1SpecTemplateSpecInitContainerLivenessProbeOutputReference | JobV1SpecTemplateSpecInitContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): JobV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: JobV1SpecTemplateSpecInitContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): JobV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): JobV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): JobV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: JobV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): JobV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#container_port JobV1#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_ip JobV1#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_port JobV1#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#protocol JobV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerPortToTerraform(struct?: JobV1SpecTemplateSpecInitContainerPort): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecInitContainerReadinessProbeExecToTerraform(struct?: JobV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference | JobV1SpecTemplateSpecInitContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetToTerraform(struct?: JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference | JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecInitContainerReadinessProbeTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#failure_threshold JobV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#initial_delay_seconds JobV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#period_seconds JobV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#success_threshold JobV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#timeout_seconds JobV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecInitContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
}
export declare function jobV1SpecTemplateSpecInitContainerReadinessProbeToTerraform(struct?: JobV1SpecTemplateSpecInitContainerReadinessProbeOutputReference | JobV1SpecTemplateSpecInitContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): JobV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: JobV1SpecTemplateSpecInitContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): JobV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): JobV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): JobV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: JobV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): JobV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#limits JobV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#requests JobV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecInitContainerResourcesToTerraform(struct?: JobV1SpecTemplateSpecInitContainerResourcesOutputReference | JobV1SpecTemplateSpecInitContainerResources): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#add JobV1#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#drop JobV1#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function jobV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesToTerraform(struct?: JobV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference | JobV1SpecTemplateSpecInitContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#level JobV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#role JobV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#type JobV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#user JobV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsToTerraform(struct?: JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference | JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#allow_privilege_escalation JobV1#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#privileged JobV1#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only_root_filesystem JobV1#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_group JobV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_non_root JobV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_user JobV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#capabilities JobV1#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: JobV1SpecTemplateSpecInitContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#se_linux_options JobV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions;
}
export declare function jobV1SpecTemplateSpecInitContainerSecurityContextToTerraform(struct?: JobV1SpecTemplateSpecInitContainerSecurityContextOutputReference | JobV1SpecTemplateSpecInitContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): JobV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: JobV1SpecTemplateSpecInitContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): JobV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): JobV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function jobV1SpecTemplateSpecInitContainerStartupProbeExecToTerraform(struct?: JobV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference | JobV1SpecTemplateSpecInitContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host JobV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#scheme JobV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_header JobV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
export declare function jobV1SpecTemplateSpecInitContainerStartupProbeHttpGetToTerraform(struct?: JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference | JobV1SpecTemplateSpecInitContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function jobV1SpecTemplateSpecInitContainerStartupProbeTcpSocketToTerraform(struct?: JobV1SpecTemplateSpecInitContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#failure_threshold JobV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#initial_delay_seconds JobV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#period_seconds JobV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#success_threshold JobV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#timeout_seconds JobV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#exec JobV1#exec}
     *
     * @stability stable
     */
    readonly exec?: JobV1SpecTemplateSpecInitContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#http_get JobV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: JobV1SpecTemplateSpecInitContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tcp_socket JobV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: JobV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[];
}
export declare function jobV1SpecTemplateSpecInitContainerStartupProbeToTerraform(struct?: JobV1SpecTemplateSpecInitContainerStartupProbeOutputReference | JobV1SpecTemplateSpecInitContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecInitContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecInitContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecInitContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): JobV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: JobV1SpecTemplateSpecInitContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): JobV1SpecTemplateSpecInitContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): JobV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: JobV1SpecTemplateSpecInitContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): JobV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): JobV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: JobV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): JobV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mount_path JobV1#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mount_propagation JobV1#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#sub_path JobV1#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function jobV1SpecTemplateSpecInitContainerVolumeMountToTerraform(struct?: JobV1SpecTemplateSpecInitContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#args JobV1#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#command JobV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#image JobV1#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#image_pull_policy JobV1#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#stdin JobV1#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#stdin_once JobV1#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#termination_message_path JobV1#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#termination_message_policy JobV1#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#tty JobV1#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#working_dir JobV1#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#env JobV1#env}
     *
     * @stability stable
     */
    readonly env?: JobV1SpecTemplateSpecInitContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#env_from JobV1#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: JobV1SpecTemplateSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#lifecycle JobV1#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: JobV1SpecTemplateSpecInitContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#liveness_probe JobV1#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: JobV1SpecTemplateSpecInitContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#port JobV1#port}
     *
     * @stability stable
     */
    readonly port?: JobV1SpecTemplateSpecInitContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#readiness_probe JobV1#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: JobV1SpecTemplateSpecInitContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resources JobV1#resources}
     *
     * @stability stable
     */
    readonly resources?: JobV1SpecTemplateSpecInitContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#security_context JobV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: JobV1SpecTemplateSpecInitContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#startup_probe JobV1#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: JobV1SpecTemplateSpecInitContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume_mount JobV1#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: JobV1SpecTemplateSpecInitContainerVolumeMount[];
}
export declare function jobV1SpecTemplateSpecInitContainerToTerraform(struct?: JobV1SpecTemplateSpecInitContainer): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecReadinessGate {
    /**
     * refers to a condition in the pod's condition list with matching type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#condition_type JobV1#condition_type}
     *
     * @stability stable
     */
    readonly conditionType: string;
}
export declare function jobV1SpecTemplateSpecReadinessGateToTerraform(struct?: JobV1SpecTemplateSpecReadinessGate): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#level JobV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#role JobV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#type JobV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#user JobV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function jobV1SpecTemplateSpecSecurityContextSeLinuxOptionsToTerraform(struct?: JobV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference | JobV1SpecTemplateSpecSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function jobV1SpecTemplateSpecSecurityContextSysctlToTerraform(struct?: JobV1SpecTemplateSpecSecurityContextSysctl): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_group JobV1#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup?: string;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_group JobV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_non_root JobV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#run_as_user JobV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#supplemental_groups JobV1#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#se_linux_options JobV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: JobV1SpecTemplateSpecSecurityContextSeLinuxOptions;
    /**
     * sysctl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#sysctl JobV1#sysctl}
     *
     * @stability stable
     */
    readonly sysctl?: JobV1SpecTemplateSpecSecurityContextSysctl[];
}
export declare function jobV1SpecTemplateSpecSecurityContextToTerraform(struct?: JobV1SpecTemplateSpecSecurityContextOutputReference | JobV1SpecTemplateSpecSecurityContext): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecSecurityContext | undefined);
    private _fsGroup?;
    /**
     * @stability stable
     */
    get fsGroup(): string;
    /**
     * @stability stable
     */
    set fsGroup(value: string);
    /**
     * @stability stable
     */
    resetFsGroup(): void;
    /**
     * @stability stable
     */
    get fsGroupInput(): string | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _supplementalGroups?;
    /**
     * @stability stable
     */
    get supplementalGroups(): number[];
    /**
     * @stability stable
     */
    set supplementalGroups(value: number[]);
    /**
     * @stability stable
     */
    resetSupplementalGroups(): void;
    /**
     * @stability stable
     */
    get supplementalGroupsInput(): number[] | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): JobV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: JobV1SpecTemplateSpecSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): JobV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    private _sysctl?;
    /**
     * @stability stable
     */
    get sysctl(): JobV1SpecTemplateSpecSecurityContextSysctl[];
    /**
     * @stability stable
     */
    set sysctl(value: JobV1SpecTemplateSpecSecurityContextSysctl[]);
    /**
     * @stability stable
     */
    resetSysctl(): void;
    /**
     * @stability stable
     */
    get sysctlInput(): JobV1SpecTemplateSpecSecurityContextSysctl[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#effect JobV1#effect}
     *
     * @stability stable
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#toleration_seconds JobV1#toleration_seconds}
     *
     * @stability stable
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#value JobV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function jobV1SpecTemplateSpecTolerationToTerraform(struct?: JobV1SpecTemplateSpecToleration): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#operator JobV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#values JobV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function jobV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressionsToTerraform(struct?: JobV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecTopologySpreadConstraintLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_labels JobV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#match_expressions JobV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: JobV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions[];
}
export declare function jobV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorToTerraform(struct?: JobV1SpecTemplateSpecTopologySpreadConstraintLabelSelector): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecTopologySpreadConstraint {
    /**
     * describes the degree to which pods may be unevenly distributed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#max_skew JobV1#max_skew}
     *
     * @stability stable
     */
    readonly maxSkew?: number;
    /**
     * the key of node labels.
     *
     * Nodes that have a label with this key and identical values are considered to be in the same topology.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#topology_key JobV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * indicates how to deal with a pod if it doesn't satisfy the spread constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#when_unsatisfiable JobV1#when_unsatisfiable}
     *
     * @stability stable
     */
    readonly whenUnsatisfiable?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#label_selector JobV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: JobV1SpecTemplateSpecTopologySpreadConstraintLabelSelector[];
}
export declare function jobV1SpecTemplateSpecTopologySpreadConstraintToTerraform(struct?: JobV1SpecTemplateSpecTopologySpreadConstraint): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#partition JobV1#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume_id JobV1#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function jobV1SpecTemplateSpecVolumeAwsElasticBlockStoreToTerraform(struct?: JobV1SpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference | JobV1SpecTemplateSpecVolumeAwsElasticBlockStore): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeAwsElasticBlockStore | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeAwsElasticBlockStore | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#caching_mode JobV1#caching_mode}
     *
     * @stability stable
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#data_disk_uri JobV1#data_disk_uri}
     *
     * @stability stable
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#disk_name JobV1#disk_name}
     *
     * @stability stable
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The type for the data disk. Expected values: Shared, Dedicated, Managed. Defaults to Shared.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#kind JobV1#kind}
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecVolumeAzureDiskToTerraform(struct?: JobV1SpecTemplateSpecVolumeAzureDiskOutputReference | JobV1SpecTemplateSpecVolumeAzureDisk): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeAzureDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeAzureDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeAzureDisk | undefined);
    private _cachingMode?;
    /**
     * @stability stable
     */
    get cachingMode(): string;
    /**
     * @stability stable
     */
    set cachingMode(value: string);
    /**
     * @stability stable
     */
    get cachingModeInput(): string | undefined;
    private _dataDiskUri?;
    /**
     * @stability stable
     */
    get dataDiskUri(): string;
    /**
     * @stability stable
     */
    set dataDiskUri(value: string);
    /**
     * @stability stable
     */
    get dataDiskUriInput(): string | undefined;
    private _diskName?;
    /**
     * @stability stable
     */
    get diskName(): string;
    /**
     * @stability stable
     */
    set diskName(value: string);
    /**
     * @stability stable
     */
    get diskNameInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    resetKind(): void;
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_name JobV1#secret_name}
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * The namespace of the secret that contains Azure Storage Account Name and Key.
     *
     * For Kubernetes up to 1.18.x the default is the same as the Pod. For Kubernetes 1.19.x and later the default is "default" namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_namespace JobV1#secret_namespace}
     *
     * @stability stable
     */
    readonly secretNamespace?: string;
    /**
     * Share Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#share_name JobV1#share_name}
     *
     * @stability stable
     */
    readonly shareName: string;
}
export declare function jobV1SpecTemplateSpecVolumeAzureFileToTerraform(struct?: JobV1SpecTemplateSpecVolumeAzureFileOutputReference | JobV1SpecTemplateSpecVolumeAzureFile): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeAzureFileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeAzureFile | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeAzureFile | undefined);
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _secretNamespace?;
    /**
     * @stability stable
     */
    get secretNamespace(): string;
    /**
     * @stability stable
     */
    set secretNamespace(value: string);
    /**
     * @stability stable
     */
    resetSecretNamespace(): void;
    /**
     * @stability stable
     */
    get secretNamespaceInput(): string | undefined;
    private _shareName?;
    /**
     * @stability stable
     */
    get shareName(): string;
    /**
     * @stability stable
     */
    set shareName(value: string);
    /**
     * @stability stable
     */
    get shareNameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1SpecTemplateSpecVolumeCephFsSecretRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference | JobV1SpecTemplateSpecVolumeCephFsSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCephFsSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCephFsSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#monitors JobV1#monitors}
     *
     * @stability stable
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_file JobV1#secret_file}
     *
     * @stability stable
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#user JobV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_ref JobV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: JobV1SpecTemplateSpecVolumeCephFsSecretRef;
}
export declare function jobV1SpecTemplateSpecVolumeCephFsToTerraform(struct?: JobV1SpecTemplateSpecVolumeCephFsOutputReference | JobV1SpecTemplateSpecVolumeCephFs): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCephFsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCephFs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCephFs | undefined);
    private _monitors?;
    /**
     * @stability stable
     */
    get monitors(): string[];
    /**
     * @stability stable
     */
    set monitors(value: string[]);
    /**
     * @stability stable
     */
    get monitorsInput(): string[] | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretFile?;
    /**
     * @stability stable
     */
    get secretFile(): string;
    /**
     * @stability stable
     */
    set secretFile(value: string);
    /**
     * @stability stable
     */
    resetSecretFile(): void;
    /**
     * @stability stable
     */
    get secretFileInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): JobV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: JobV1SpecTemplateSpecVolumeCephFsSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): JobV1SpecTemplateSpecVolumeCephFsSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Volume ID used to identify the volume in Cinder. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume_id JobV1#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function jobV1SpecTemplateSpecVolumeCinderToTerraform(struct?: JobV1SpecTemplateSpecVolumeCinderOutputReference | JobV1SpecTemplateSpecVolumeCinder): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCinderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCinder | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCinder | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mode JobV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function jobV1SpecTemplateSpecVolumeConfigMapItemsToTerraform(struct?: JobV1SpecTemplateSpecVolumeConfigMapItems): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#default_mode JobV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#items JobV1#items}
     *
     * @stability stable
     */
    readonly items?: JobV1SpecTemplateSpecVolumeConfigMapItems[];
}
export declare function jobV1SpecTemplateSpecVolumeConfigMapToTerraform(struct?: JobV1SpecTemplateSpecVolumeConfigMapOutputReference | JobV1SpecTemplateSpecVolumeConfigMap): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeConfigMapOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeConfigMap | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeConfigMap | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): JobV1SpecTemplateSpecVolumeConfigMapItems[];
    /**
     * @stability stable
     */
    set items(value: JobV1SpecTemplateSpecVolumeConfigMapItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): JobV1SpecTemplateSpecVolumeConfigMapItems[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference | JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference | JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1SpecTemplateSpecVolumeCsiNodePublishSecretRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference | JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1SpecTemplateSpecVolumeCsiNodeStageSecretRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference | JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeCsi {
    /**
     * the name of the volume driver to use. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#driver JobV1#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Attributes of the volume to publish.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume_attributes JobV1#volume_attributes}
     *
     * @stability stable
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * A string value that uniquely identifies the volume. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume_handle JobV1#volume_handle}
     *
     * @stability stable
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#controller_expand_secret_ref JobV1#controller_expand_secret_ref}
     *
     * @stability stable
     */
    readonly controllerExpandSecretRef?: JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef;
    /**
     * controller_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#controller_publish_secret_ref JobV1#controller_publish_secret_ref}
     *
     * @stability stable
     */
    readonly controllerPublishSecretRef?: JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef;
    /**
     * node_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#node_publish_secret_ref JobV1#node_publish_secret_ref}
     *
     * @stability stable
     */
    readonly nodePublishSecretRef?: JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRef;
    /**
     * node_stage_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#node_stage_secret_ref JobV1#node_stage_secret_ref}
     *
     * @stability stable
     */
    readonly nodeStageSecretRef?: JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRef;
}
export declare function jobV1SpecTemplateSpecVolumeCsiToTerraform(struct?: JobV1SpecTemplateSpecVolumeCsiOutputReference | JobV1SpecTemplateSpecVolumeCsi): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeCsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeCsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeCsi | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeAttributes?;
    /**
     * @stability stable
     */
    get volumeAttributes(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set volumeAttributes(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetVolumeAttributes(): void;
    /**
     * @stability stable
     */
    get volumeAttributesInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _volumeHandle?;
    /**
     * @stability stable
     */
    get volumeHandle(): string;
    /**
     * @stability stable
     */
    set volumeHandle(value: string);
    /**
     * @stability stable
     */
    get volumeHandleInput(): string | undefined;
    private _controllerExpandSecretRef;
    /**
     * @stability stable
     */
    get controllerExpandSecretRef(): JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerExpandSecretRef(value: JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerExpandSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerExpandSecretRefInput(): JobV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    private _controllerPublishSecretRef;
    /**
     * @stability stable
     */
    get controllerPublishSecretRef(): JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerPublishSecretRef(value: JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerPublishSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerPublishSecretRefInput(): JobV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    private _nodePublishSecretRef;
    /**
     * @stability stable
     */
    get nodePublishSecretRef(): JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodePublishSecretRef(value: JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRef): void;
    /**
     * @stability stable
     */
    resetNodePublishSecretRef(): void;
    /**
     * @stability stable
     */
    get nodePublishSecretRefInput(): JobV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    private _nodeStageSecretRef;
    /**
     * @stability stable
     */
    get nodeStageSecretRef(): JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodeStageSecretRef(value: JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRef): void;
    /**
     * @stability stable
     */
    resetNodeStageSecretRef(): void;
    /**
     * @stability stable
     */
    get nodeStageSecretRefInput(): JobV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#api_version JobV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_path JobV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function jobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference | JobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#container_name JobV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#divisor JobV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource JobV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function jobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference | JobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mode JobV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_ref JobV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef: JobV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource_field_ref JobV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: JobV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef;
}
export declare function jobV1SpecTemplateSpecVolumeDownwardApiItemsToTerraform(struct?: JobV1SpecTemplateSpecVolumeDownwardApiItems): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#default_mode JobV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#items JobV1#items}
     *
     * @stability stable
     */
    readonly items?: JobV1SpecTemplateSpecVolumeDownwardApiItems[];
}
export declare function jobV1SpecTemplateSpecVolumeDownwardApiToTerraform(struct?: JobV1SpecTemplateSpecVolumeDownwardApiOutputReference | JobV1SpecTemplateSpecVolumeDownwardApi): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeDownwardApi | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): JobV1SpecTemplateSpecVolumeDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: JobV1SpecTemplateSpecVolumeDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): JobV1SpecTemplateSpecVolumeDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#medium JobV1#medium}
     *
     * @stability stable
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#size_limit JobV1#size_limit}
     *
     * @stability stable
     */
    readonly sizeLimit?: string;
}
export declare function jobV1SpecTemplateSpecVolumeEmptyDirToTerraform(struct?: JobV1SpecTemplateSpecVolumeEmptyDirOutputReference | JobV1SpecTemplateSpecVolumeEmptyDir): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeEmptyDirOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeEmptyDir | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeEmptyDir | undefined);
    private _medium?;
    /**
     * @stability stable
     */
    get medium(): string;
    /**
     * @stability stable
     */
    set medium(value: string);
    /**
     * @stability stable
     */
    resetMedium(): void;
    /**
     * @stability stable
     */
    get mediumInput(): string | undefined;
    private _sizeLimit?;
    /**
     * @stability stable
     */
    get sizeLimit(): string;
    /**
     * @stability stable
     */
    set sizeLimit(value: string);
    /**
     * @stability stable
     */
    resetSizeLimit(): void;
    /**
     * @stability stable
     */
    get sizeLimitInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#lun JobV1#lun}
     *
     * @stability stable
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * FC target worldwide names (WWNs).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#target_ww_ns JobV1#target_ww_ns}
     *
     * @stability stable
     */
    readonly targetWwNs: string[];
}
export declare function jobV1SpecTemplateSpecVolumeFcToTerraform(struct?: JobV1SpecTemplateSpecVolumeFcOutputReference | JobV1SpecTemplateSpecVolumeFc): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeFcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeFc | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeFc | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetWwNs?;
    /**
     * @stability stable
     */
    get targetWwNs(): string[];
    /**
     * @stability stable
     */
    set targetWwNs(value: string[]);
    /**
     * @stability stable
     */
    get targetWwNsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1SpecTemplateSpecVolumeFlexVolumeSecretRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference | JobV1SpecTemplateSpecVolumeFlexVolumeSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#driver JobV1#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#options JobV1#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_ref JobV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: JobV1SpecTemplateSpecVolumeFlexVolumeSecretRef;
}
export declare function jobV1SpecTemplateSpecVolumeFlexVolumeToTerraform(struct?: JobV1SpecTemplateSpecVolumeFlexVolumeOutputReference | JobV1SpecTemplateSpecVolumeFlexVolume): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeFlexVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeFlexVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeFlexVolume | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _options?;
    /**
     * @stability stable
     */
    get options(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set options(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptions(): void;
    /**
     * @stability stable
     */
    get optionsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): JobV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: JobV1SpecTemplateSpecVolumeFlexVolumeSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): JobV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#dataset_name JobV1#dataset_name}
     *
     * @stability stable
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset. This is unique identifier of a Flocker dataset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#dataset_uuid JobV1#dataset_uuid}
     *
     * @stability stable
     */
    readonly datasetUuid?: string;
}
export declare function jobV1SpecTemplateSpecVolumeFlockerToTerraform(struct?: JobV1SpecTemplateSpecVolumeFlockerOutputReference | JobV1SpecTemplateSpecVolumeFlocker): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeFlockerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeFlocker | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeFlocker | undefined);
    private _datasetName?;
    /**
     * @stability stable
     */
    get datasetName(): string;
    /**
     * @stability stable
     */
    set datasetName(value: string);
    /**
     * @stability stable
     */
    resetDatasetName(): void;
    /**
     * @stability stable
     */
    get datasetNameInput(): string | undefined;
    private _datasetUuid?;
    /**
     * @stability stable
     */
    get datasetUuid(): string;
    /**
     * @stability stable
     */
    set datasetUuid(value: string);
    /**
     * @stability stable
     */
    resetDatasetUuid(): void;
    /**
     * @stability stable
     */
    get datasetUuidInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#partition JobV1#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pd_name JobV1#pd_name}
     *
     * @stability stable
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecVolumeGcePersistentDiskToTerraform(struct?: JobV1SpecTemplateSpecVolumeGcePersistentDiskOutputReference | JobV1SpecTemplateSpecVolumeGcePersistentDisk): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeGcePersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeGcePersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeGcePersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _pdName?;
    /**
     * @stability stable
     */
    get pdName(): string;
    /**
     * @stability stable
     */
    set pdName(value: string);
    /**
     * @stability stable
     */
    get pdNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#directory JobV1#directory}
     *
     * @stability stable
     */
    readonly directory?: string;
    /**
     * Repository URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#repository JobV1#repository}
     *
     * @stability stable
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#revision JobV1#revision}
     *
     * @stability stable
     */
    readonly revision?: string;
}
export declare function jobV1SpecTemplateSpecVolumeGitRepoToTerraform(struct?: JobV1SpecTemplateSpecVolumeGitRepoOutputReference | JobV1SpecTemplateSpecVolumeGitRepo): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeGitRepoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeGitRepo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeGitRepo | undefined);
    private _directory?;
    /**
     * @stability stable
     */
    get directory(): string;
    /**
     * @stability stable
     */
    set directory(value: string);
    /**
     * @stability stable
     */
    resetDirectory(): void;
    /**
     * @stability stable
     */
    get directoryInput(): string | undefined;
    private _repository?;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    resetRepository(): void;
    /**
     * @stability stable
     */
    get repositoryInput(): string | undefined;
    private _revision?;
    /**
     * @stability stable
     */
    get revision(): string;
    /**
     * @stability stable
     */
    set revision(value: string);
    /**
     * @stability stable
     */
    resetRevision(): void;
    /**
     * @stability stable
     */
    get revisionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#endpoints_name JobV1#endpoints_name}
     *
     * @stability stable
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecVolumeGlusterfsToTerraform(struct?: JobV1SpecTemplateSpecVolumeGlusterfsOutputReference | JobV1SpecTemplateSpecVolumeGlusterfs): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeGlusterfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeGlusterfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeGlusterfs | undefined);
    private _endpointsName?;
    /**
     * @stability stable
     */
    get endpointsName(): string;
    /**
     * @stability stable
     */
    set endpointsName(value: string);
    /**
     * @stability stable
     */
    get endpointsNameInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeHostPath {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#hostpath.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Type for HostPath volume. Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#type JobV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function jobV1SpecTemplateSpecVolumeHostPathToTerraform(struct?: JobV1SpecTemplateSpecVolumeHostPathOutputReference | JobV1SpecTemplateSpecVolumeHostPath): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeHostPathOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeHostPath | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeHostPath | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#iqn JobV1#iqn}
     *
     * @stability stable
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport. Defaults to 'default' (tcp).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#iscsi_interface JobV1#iscsi_interface}
     *
     * @stability stable
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#lun JobV1#lun}
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#target_portal JobV1#target_portal}
     *
     * @stability stable
     */
    readonly targetPortal: string;
}
export declare function jobV1SpecTemplateSpecVolumeIscsiToTerraform(struct?: JobV1SpecTemplateSpecVolumeIscsiOutputReference | JobV1SpecTemplateSpecVolumeIscsi): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeIscsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeIscsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeIscsi | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _iqn?;
    /**
     * @stability stable
     */
    get iqn(): string;
    /**
     * @stability stable
     */
    set iqn(value: string);
    /**
     * @stability stable
     */
    get iqnInput(): string | undefined;
    private _iscsiInterface?;
    /**
     * @stability stable
     */
    get iscsiInterface(): string;
    /**
     * @stability stable
     */
    set iscsiInterface(value: string);
    /**
     * @stability stable
     */
    resetIscsiInterface(): void;
    /**
     * @stability stable
     */
    get iscsiInterfaceInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    resetLun(): void;
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetPortal?;
    /**
     * @stability stable
     */
    get targetPortal(): string;
    /**
     * @stability stable
     */
    set targetPortal(value: string);
    /**
     * @stability stable
     */
    get targetPortalInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeLocal {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#local.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function jobV1SpecTemplateSpecVolumeLocalToTerraform(struct?: JobV1SpecTemplateSpecVolumeLocalOutputReference | JobV1SpecTemplateSpecVolumeLocal): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeLocalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeLocal | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeLocal | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Server is the hostname or IP address of the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#server JobV1#server}
     *
     * @stability stable
     */
    readonly server: string;
}
export declare function jobV1SpecTemplateSpecVolumeNfsToTerraform(struct?: JobV1SpecTemplateSpecVolumeNfsOutputReference | JobV1SpecTemplateSpecVolumeNfs): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeNfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeNfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeNfs | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _server?;
    /**
     * @stability stable
     */
    get server(): string;
    /**
     * @stability stable
     */
    set server(value: string);
    /**
     * @stability stable
     */
    get serverInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#claim_name JobV1#claim_name}
     *
     * @stability stable
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function jobV1SpecTemplateSpecVolumePersistentVolumeClaimToTerraform(struct?: JobV1SpecTemplateSpecVolumePersistentVolumeClaimOutputReference | JobV1SpecTemplateSpecVolumePersistentVolumeClaim): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumePersistentVolumeClaimOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumePersistentVolumeClaim | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumePersistentVolumeClaim | undefined);
    private _claimName?;
    /**
     * @stability stable
     */
    get claimName(): string;
    /**
     * @stability stable
     */
    set claimName(value: string);
    /**
     * @stability stable
     */
    resetClaimName(): void;
    /**
     * @stability stable
     */
    get claimNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#pd_id JobV1#pd_id}
     *
     * @stability stable
     */
    readonly pdId: string;
}
export declare function jobV1SpecTemplateSpecVolumePhotonPersistentDiskToTerraform(struct?: JobV1SpecTemplateSpecVolumePhotonPersistentDiskOutputReference | JobV1SpecTemplateSpecVolumePhotonPersistentDisk): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumePhotonPersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumePhotonPersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumePhotonPersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _pdId?;
    /**
     * @stability stable
     */
    get pdId(): string;
    /**
     * @stability stable
     */
    set pdId(value: string);
    /**
     * @stability stable
     */
    get pdIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mode JobV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItemsToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#items JobV1#items}
     *
     * @stability stable
     */
    readonly items?: JobV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems[];
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesConfigMapToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesConfigMap): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#api_version JobV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_path JobV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference | JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#container_name JobV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#divisor JobV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource JobV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference | JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mode JobV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#field_ref JobV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#resource_field_ref JobV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef;
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#items JobV1#items}
     *
     * @stability stable
     */
    readonly items?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference | JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined);
    private _items?;
    /**
     * @stability stable
     */
    get items(): JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mode JobV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesSecretItemsToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesSecretItems): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#items JobV1#items}
     *
     * @stability stable
     */
    readonly items?: JobV1SpecTemplateSpecVolumeProjectedSourcesSecretItems[];
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesSecretToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesSecret): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#audience JobV1#audience}
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#expiration_seconds JobV1#expiration_seconds}
     *
     * @stability stable
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path: string;
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference | JobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined);
    private _audience?;
    /**
     * @stability stable
     */
    get audience(): string;
    /**
     * @stability stable
     */
    set audience(value: string);
    /**
     * @stability stable
     */
    resetAudience(): void;
    /**
     * @stability stable
     */
    get audienceInput(): string | undefined;
    private _expirationSeconds?;
    /**
     * @stability stable
     */
    get expirationSeconds(): number;
    /**
     * @stability stable
     */
    set expirationSeconds(value: number);
    /**
     * @stability stable
     */
    resetExpirationSeconds(): void;
    /**
     * @stability stable
     */
    get expirationSecondsInput(): number | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjectedSources {
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#config_map JobV1#config_map}
     *
     * @stability stable
     */
    readonly configMap?: JobV1SpecTemplateSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#downward_api JobV1#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: JobV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret JobV1#secret}
     *
     * @stability stable
     */
    readonly secret?: JobV1SpecTemplateSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#service_account_token JobV1#service_account_token}
     *
     * @stability stable
     */
    readonly serviceAccountToken?: JobV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken;
}
export declare function jobV1SpecTemplateSpecVolumeProjectedSourcesToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjectedSources): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#default_mode JobV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#sources JobV1#sources}
     *
     * @stability stable
     */
    readonly sources: JobV1SpecTemplateSpecVolumeProjectedSources[];
}
export declare function jobV1SpecTemplateSpecVolumeProjectedToTerraform(struct?: JobV1SpecTemplateSpecVolumeProjected): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#group JobV1#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#registry JobV1#registry}
     *
     * @stability stable
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#user JobV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume JobV1#volume}
     *
     * @stability stable
     */
    readonly volume: string;
}
export declare function jobV1SpecTemplateSpecVolumeQuobyteToTerraform(struct?: JobV1SpecTemplateSpecVolumeQuobyteOutputReference | JobV1SpecTemplateSpecVolumeQuobyte): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeQuobyteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeQuobyte | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeQuobyte | undefined);
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _registry?;
    /**
     * @stability stable
     */
    get registry(): string;
    /**
     * @stability stable
     */
    set registry(value: string);
    /**
     * @stability stable
     */
    get registryInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): string;
    /**
     * @stability stable
     */
    set volume(value: string);
    /**
     * @stability stable
     */
    get volumeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeRbdSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#namespace JobV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function jobV1SpecTemplateSpecVolumeRbdSecretRefToTerraform(struct?: JobV1SpecTemplateSpecVolumeRbdSecretRefOutputReference | JobV1SpecTemplateSpecVolumeRbdSecretRef): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeRbdSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeRbdSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeRbdSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeRbd {
    /**
     * A collection of Ceph monitors. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#ceph_monitors JobV1#ceph_monitors}
     *
     * @stability stable
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#keyring JobV1#keyring}
     *
     * @stability stable
     */
    readonly keyring?: string;
    /**
     * The rados user name. Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#rados_user JobV1#rados_user}
     *
     * @stability stable
     */
    readonly radosUser?: string;
    /**
     * The rados image name. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#rbd_image JobV1#rbd_image}
     *
     * @stability stable
     */
    readonly rbdImage: string;
    /**
     * The rados pool name. Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#rbd_pool JobV1#rbd_pool}
     *
     * @stability stable
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#read_only JobV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_ref JobV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: JobV1SpecTemplateSpecVolumeRbdSecretRef;
}
export declare function jobV1SpecTemplateSpecVolumeRbdToTerraform(struct?: JobV1SpecTemplateSpecVolumeRbdOutputReference | JobV1SpecTemplateSpecVolumeRbd): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeRbdOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeRbd | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeRbd | undefined);
    private _cephMonitors?;
    /**
     * @stability stable
     */
    get cephMonitors(): string[];
    /**
     * @stability stable
     */
    set cephMonitors(value: string[]);
    /**
     * @stability stable
     */
    get cephMonitorsInput(): string[] | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _keyring?;
    /**
     * @stability stable
     */
    get keyring(): string;
    /**
     * @stability stable
     */
    set keyring(value: string);
    /**
     * @stability stable
     */
    resetKeyring(): void;
    /**
     * @stability stable
     */
    get keyringInput(): string | undefined;
    private _radosUser?;
    /**
     * @stability stable
     */
    get radosUser(): string;
    /**
     * @stability stable
     */
    set radosUser(value: string);
    /**
     * @stability stable
     */
    resetRadosUser(): void;
    /**
     * @stability stable
     */
    get radosUserInput(): string | undefined;
    private _rbdImage?;
    /**
     * @stability stable
     */
    get rbdImage(): string;
    /**
     * @stability stable
     */
    set rbdImage(value: string);
    /**
     * @stability stable
     */
    get rbdImageInput(): string | undefined;
    private _rbdPool?;
    /**
     * @stability stable
     */
    get rbdPool(): string;
    /**
     * @stability stable
     */
    set rbdPool(value: string);
    /**
     * @stability stable
     */
    resetRbdPool(): void;
    /**
     * @stability stable
     */
    get rbdPoolInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): JobV1SpecTemplateSpecVolumeRbdSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: JobV1SpecTemplateSpecVolumeRbdSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): JobV1SpecTemplateSpecVolumeRbdSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#key JobV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#mode JobV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#path JobV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function jobV1SpecTemplateSpecVolumeSecretItemsToTerraform(struct?: JobV1SpecTemplateSpecVolumeSecretItems): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#default_mode JobV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#optional JobV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret_name JobV1#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#items JobV1#items}
     *
     * @stability stable
     */
    readonly items?: JobV1SpecTemplateSpecVolumeSecretItems[];
}
export declare function jobV1SpecTemplateSpecVolumeSecretToTerraform(struct?: JobV1SpecTemplateSpecVolumeSecretOutputReference | JobV1SpecTemplateSpecVolumeSecret): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeSecretOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeSecret | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeSecret | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    resetSecretName(): void;
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): JobV1SpecTemplateSpecVolumeSecretItems[];
    /**
     * @stability stable
     */
    set items(value: JobV1SpecTemplateSpecVolumeSecretItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): JobV1SpecTemplateSpecVolumeSecretItems[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fs_type JobV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume_path JobV1#volume_path}
     *
     * @stability stable
     */
    readonly volumePath: string;
}
export declare function jobV1SpecTemplateSpecVolumeVsphereVolumeToTerraform(struct?: JobV1SpecTemplateSpecVolumeVsphereVolumeOutputReference | JobV1SpecTemplateSpecVolumeVsphereVolume): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecVolumeVsphereVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpecVolumeVsphereVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpecVolumeVsphereVolume | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _volumePath?;
    /**
     * @stability stable
     */
    get volumePath(): string;
    /**
     * @stability stable
     */
    set volumePath(value: string);
    /**
     * @stability stable
     */
    get volumePathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpecVolume {
    /**
     * Volume's name. Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#name JobV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#aws_elastic_block_store JobV1#aws_elastic_block_store}
     *
     * @stability stable
     */
    readonly awsElasticBlockStore?: JobV1SpecTemplateSpecVolumeAwsElasticBlockStore;
    /**
     * azure_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#azure_disk JobV1#azure_disk}
     *
     * @stability stable
     */
    readonly azureDisk?: JobV1SpecTemplateSpecVolumeAzureDisk;
    /**
     * azure_file block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#azure_file JobV1#azure_file}
     *
     * @stability stable
     */
    readonly azureFile?: JobV1SpecTemplateSpecVolumeAzureFile;
    /**
     * ceph_fs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#ceph_fs JobV1#ceph_fs}
     *
     * @stability stable
     */
    readonly cephFs?: JobV1SpecTemplateSpecVolumeCephFs;
    /**
     * cinder block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#cinder JobV1#cinder}
     *
     * @stability stable
     */
    readonly cinder?: JobV1SpecTemplateSpecVolumeCinder;
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#config_map JobV1#config_map}
     *
     * @stability stable
     */
    readonly configMap?: JobV1SpecTemplateSpecVolumeConfigMap;
    /**
     * csi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#csi JobV1#csi}
     *
     * @stability stable
     */
    readonly csi?: JobV1SpecTemplateSpecVolumeCsi;
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#downward_api JobV1#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: JobV1SpecTemplateSpecVolumeDownwardApi;
    /**
     * empty_dir block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#empty_dir JobV1#empty_dir}
     *
     * @stability stable
     */
    readonly emptyDir?: JobV1SpecTemplateSpecVolumeEmptyDir;
    /**
     * fc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#fc JobV1#fc}
     *
     * @stability stable
     */
    readonly fc?: JobV1SpecTemplateSpecVolumeFc;
    /**
     * flex_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#flex_volume JobV1#flex_volume}
     *
     * @stability stable
     */
    readonly flexVolume?: JobV1SpecTemplateSpecVolumeFlexVolume;
    /**
     * flocker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#flocker JobV1#flocker}
     *
     * @stability stable
     */
    readonly flocker?: JobV1SpecTemplateSpecVolumeFlocker;
    /**
     * gce_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#gce_persistent_disk JobV1#gce_persistent_disk}
     *
     * @stability stable
     */
    readonly gcePersistentDisk?: JobV1SpecTemplateSpecVolumeGcePersistentDisk;
    /**
     * git_repo block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#git_repo JobV1#git_repo}
     *
     * @stability stable
     */
    readonly gitRepo?: JobV1SpecTemplateSpecVolumeGitRepo;
    /**
     * glusterfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#glusterfs JobV1#glusterfs}
     *
     * @stability stable
     */
    readonly glusterfs?: JobV1SpecTemplateSpecVolumeGlusterfs;
    /**
     * host_path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_path JobV1#host_path}
     *
     * @stability stable
     */
    readonly hostPath?: JobV1SpecTemplateSpecVolumeHostPath;
    /**
     * iscsi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#iscsi JobV1#iscsi}
     *
     * @stability stable
     */
    readonly iscsi?: JobV1SpecTemplateSpecVolumeIscsi;
    /**
     * local block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#local JobV1#local}
     *
     * @stability stable
     */
    readonly local?: JobV1SpecTemplateSpecVolumeLocal;
    /**
     * nfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#nfs JobV1#nfs}
     *
     * @stability stable
     */
    readonly nfs?: JobV1SpecTemplateSpecVolumeNfs;
    /**
     * persistent_volume_claim block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#persistent_volume_claim JobV1#persistent_volume_claim}
     *
     * @stability stable
     */
    readonly persistentVolumeClaim?: JobV1SpecTemplateSpecVolumePersistentVolumeClaim;
    /**
     * photon_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#photon_persistent_disk JobV1#photon_persistent_disk}
     *
     * @stability stable
     */
    readonly photonPersistentDisk?: JobV1SpecTemplateSpecVolumePhotonPersistentDisk;
    /**
     * projected block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#projected JobV1#projected}
     *
     * @stability stable
     */
    readonly projected?: JobV1SpecTemplateSpecVolumeProjected[];
    /**
     * quobyte block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#quobyte JobV1#quobyte}
     *
     * @stability stable
     */
    readonly quobyte?: JobV1SpecTemplateSpecVolumeQuobyte;
    /**
     * rbd block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#rbd JobV1#rbd}
     *
     * @stability stable
     */
    readonly rbd?: JobV1SpecTemplateSpecVolumeRbd;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#secret JobV1#secret}
     *
     * @stability stable
     */
    readonly secret?: JobV1SpecTemplateSpecVolumeSecret;
    /**
     * vsphere_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#vsphere_volume JobV1#vsphere_volume}
     *
     * @stability stable
     */
    readonly vsphereVolume?: JobV1SpecTemplateSpecVolumeVsphereVolume;
}
export declare function jobV1SpecTemplateSpecVolumeToTerraform(struct?: JobV1SpecTemplateSpecVolume): any;
/**
 * @stability stable
 */
export interface JobV1SpecTemplateSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#active_deadline_seconds JobV1#active_deadline_seconds}
     *
     * @stability stable
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#automount_service_account_token JobV1#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean | cdktf.IResolvable;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#dns_policy JobV1#dns_policy}
     *
     * @stability stable
     */
    readonly dnsPolicy?: string;
    /**
     * Enables generating environment variables for service discovery. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#enable_service_links JobV1#enable_service_links}
     *
     * @stability stable
     */
    readonly enableServiceLinks?: boolean | cdktf.IResolvable;
    /**
     * Use the host's ipc namespace. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_ipc JobV1#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean | cdktf.IResolvable;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_network JobV1#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean | cdktf.IResolvable;
    /**
     * Use the host's pid namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_pid JobV1#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean | cdktf.IResolvable;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#hostname JobV1#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#node_name JobV1#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#node_selector JobV1#node_selector}
     *
     * @stability stable
     */
    readonly nodeSelector?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#priority_class_name JobV1#priority_class_name}
     *
     * @stability stable
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod. One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#restart_policy JobV1#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#service_account_name JobV1#service_account_name}
     *
     * @stability stable
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#share_process_namespace JobV1#share_process_namespace}
     *
     * @stability stable
     */
    readonly shareProcessNamespace?: boolean | cdktf.IResolvable;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#subdomain JobV1#subdomain}
     *
     * @stability stable
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#termination_grace_period_seconds JobV1#termination_grace_period_seconds}
     *
     * @stability stable
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#affinity JobV1#affinity}
     *
     * @stability stable
     */
    readonly affinity?: JobV1SpecTemplateSpecAffinity;
    /**
     * container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#container JobV1#container}
     *
     * @stability stable
     */
    readonly container?: JobV1SpecTemplateSpecContainer[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#dns_config JobV1#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: JobV1SpecTemplateSpecDnsConfig;
    /**
     * host_aliases block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#host_aliases JobV1#host_aliases}
     *
     * @stability stable
     */
    readonly hostAliases?: JobV1SpecTemplateSpecHostAliases[];
    /**
     * image_pull_secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#image_pull_secrets JobV1#image_pull_secrets}
     *
     * @stability stable
     */
    readonly imagePullSecrets?: JobV1SpecTemplateSpecImagePullSecrets[];
    /**
     * init_container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#init_container JobV1#init_container}
     *
     * @stability stable
     */
    readonly initContainer?: JobV1SpecTemplateSpecInitContainer[];
    /**
     * readiness_gate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#readiness_gate JobV1#readiness_gate}
     *
     * @stability stable
     */
    readonly readinessGate?: JobV1SpecTemplateSpecReadinessGate[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#security_context JobV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: JobV1SpecTemplateSpecSecurityContext;
    /**
     * toleration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#toleration JobV1#toleration}
     *
     * @stability stable
     */
    readonly toleration?: JobV1SpecTemplateSpecToleration[];
    /**
     * topology_spread_constraint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#topology_spread_constraint JobV1#topology_spread_constraint}
     *
     * @stability stable
     */
    readonly topologySpreadConstraint?: JobV1SpecTemplateSpecTopologySpreadConstraint[];
    /**
     * volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#volume JobV1#volume}
     *
     * @stability stable
     */
    readonly volume?: JobV1SpecTemplateSpecVolume[];
}
export declare function jobV1SpecTemplateSpecToTerraform(struct?: JobV1SpecTemplateSpecOutputReference | JobV1SpecTemplateSpec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplateSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplateSpec | undefined);
    private _activeDeadlineSeconds?;
    /**
     * @stability stable
     */
    get activeDeadlineSeconds(): number;
    /**
     * @stability stable
     */
    set activeDeadlineSeconds(value: number);
    /**
     * @stability stable
     */
    resetActiveDeadlineSeconds(): void;
    /**
     * @stability stable
     */
    get activeDeadlineSecondsInput(): number | undefined;
    private _automountServiceAccountToken?;
    /**
     * @stability stable
     */
    get automountServiceAccountToken(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set automountServiceAccountToken(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutomountServiceAccountToken(): void;
    /**
     * @stability stable
     */
    get automountServiceAccountTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _dnsPolicy?;
    /**
     * @stability stable
     */
    get dnsPolicy(): string;
    /**
     * @stability stable
     */
    set dnsPolicy(value: string);
    /**
     * @stability stable
     */
    resetDnsPolicy(): void;
    /**
     * @stability stable
     */
    get dnsPolicyInput(): string | undefined;
    private _enableServiceLinks?;
    /**
     * @stability stable
     */
    get enableServiceLinks(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableServiceLinks(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableServiceLinks(): void;
    /**
     * @stability stable
     */
    get enableServiceLinksInput(): boolean | cdktf.IResolvable | undefined;
    private _hostIpc?;
    /**
     * @stability stable
     */
    get hostIpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostIpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostIpc(): void;
    /**
     * @stability stable
     */
    get hostIpcInput(): boolean | cdktf.IResolvable | undefined;
    private _hostNetwork?;
    /**
     * @stability stable
     */
    get hostNetwork(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostNetwork(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostNetwork(): void;
    /**
     * @stability stable
     */
    get hostNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _hostPid?;
    /**
     * @stability stable
     */
    get hostPid(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostPid(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostPid(): void;
    /**
     * @stability stable
     */
    get hostPidInput(): boolean | cdktf.IResolvable | undefined;
    private _hostname?;
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    set hostname(value: string);
    /**
     * @stability stable
     */
    resetHostname(): void;
    /**
     * @stability stable
     */
    get hostnameInput(): string | undefined;
    private _nodeName?;
    /**
     * @stability stable
     */
    get nodeName(): string;
    /**
     * @stability stable
     */
    set nodeName(value: string);
    /**
     * @stability stable
     */
    resetNodeName(): void;
    /**
     * @stability stable
     */
    get nodeNameInput(): string | undefined;
    private _nodeSelector?;
    /**
     * @stability stable
     */
    get nodeSelector(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set nodeSelector(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNodeSelector(): void;
    /**
     * @stability stable
     */
    get nodeSelectorInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _priorityClassName?;
    /**
     * @stability stable
     */
    get priorityClassName(): string;
    /**
     * @stability stable
     */
    set priorityClassName(value: string);
    /**
     * @stability stable
     */
    resetPriorityClassName(): void;
    /**
     * @stability stable
     */
    get priorityClassNameInput(): string | undefined;
    private _restartPolicy?;
    /**
     * @stability stable
     */
    get restartPolicy(): string;
    /**
     * @stability stable
     */
    set restartPolicy(value: string);
    /**
     * @stability stable
     */
    resetRestartPolicy(): void;
    /**
     * @stability stable
     */
    get restartPolicyInput(): string | undefined;
    private _serviceAccountName?;
    /**
     * @stability stable
     */
    get serviceAccountName(): string;
    /**
     * @stability stable
     */
    set serviceAccountName(value: string);
    /**
     * @stability stable
     */
    resetServiceAccountName(): void;
    /**
     * @stability stable
     */
    get serviceAccountNameInput(): string | undefined;
    private _shareProcessNamespace?;
    /**
     * @stability stable
     */
    get shareProcessNamespace(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set shareProcessNamespace(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShareProcessNamespace(): void;
    /**
     * @stability stable
     */
    get shareProcessNamespaceInput(): boolean | cdktf.IResolvable | undefined;
    private _subdomain?;
    /**
     * @stability stable
     */
    get subdomain(): string;
    /**
     * @stability stable
     */
    set subdomain(value: string);
    /**
     * @stability stable
     */
    resetSubdomain(): void;
    /**
     * @stability stable
     */
    get subdomainInput(): string | undefined;
    private _terminationGracePeriodSeconds?;
    /**
     * @stability stable
     */
    get terminationGracePeriodSeconds(): number;
    /**
     * @stability stable
     */
    set terminationGracePeriodSeconds(value: number);
    /**
     * @stability stable
     */
    resetTerminationGracePeriodSeconds(): void;
    /**
     * @stability stable
     */
    get terminationGracePeriodSecondsInput(): number | undefined;
    private _affinity;
    /**
     * @stability stable
     */
    get affinity(): JobV1SpecTemplateSpecAffinityOutputReference;
    /**
     * @stability stable
     */
    putAffinity(value: JobV1SpecTemplateSpecAffinity): void;
    /**
     * @stability stable
     */
    resetAffinity(): void;
    /**
     * @stability stable
     */
    get affinityInput(): JobV1SpecTemplateSpecAffinity | undefined;
    private _container?;
    /**
     * @stability stable
     */
    get container(): JobV1SpecTemplateSpecContainer[];
    /**
     * @stability stable
     */
    set container(value: JobV1SpecTemplateSpecContainer[]);
    /**
     * @stability stable
     */
    resetContainer(): void;
    /**
     * @stability stable
     */
    get containerInput(): JobV1SpecTemplateSpecContainer[] | undefined;
    private _dnsConfig;
    /**
     * @stability stable
     */
    get dnsConfig(): JobV1SpecTemplateSpecDnsConfigOutputReference;
    /**
     * @stability stable
     */
    putDnsConfig(value: JobV1SpecTemplateSpecDnsConfig): void;
    /**
     * @stability stable
     */
    resetDnsConfig(): void;
    /**
     * @stability stable
     */
    get dnsConfigInput(): JobV1SpecTemplateSpecDnsConfig | undefined;
    private _hostAliases?;
    /**
     * @stability stable
     */
    get hostAliases(): JobV1SpecTemplateSpecHostAliases[];
    /**
     * @stability stable
     */
    set hostAliases(value: JobV1SpecTemplateSpecHostAliases[]);
    /**
     * @stability stable
     */
    resetHostAliases(): void;
    /**
     * @stability stable
     */
    get hostAliasesInput(): JobV1SpecTemplateSpecHostAliases[] | undefined;
    private _imagePullSecrets?;
    /**
     * @stability stable
     */
    get imagePullSecrets(): JobV1SpecTemplateSpecImagePullSecrets[];
    /**
     * @stability stable
     */
    set imagePullSecrets(value: JobV1SpecTemplateSpecImagePullSecrets[]);
    /**
     * @stability stable
     */
    resetImagePullSecrets(): void;
    /**
     * @stability stable
     */
    get imagePullSecretsInput(): JobV1SpecTemplateSpecImagePullSecrets[] | undefined;
    private _initContainer?;
    /**
     * @stability stable
     */
    get initContainer(): JobV1SpecTemplateSpecInitContainer[];
    /**
     * @stability stable
     */
    set initContainer(value: JobV1SpecTemplateSpecInitContainer[]);
    /**
     * @stability stable
     */
    resetInitContainer(): void;
    /**
     * @stability stable
     */
    get initContainerInput(): JobV1SpecTemplateSpecInitContainer[] | undefined;
    private _readinessGate?;
    /**
     * @stability stable
     */
    get readinessGate(): JobV1SpecTemplateSpecReadinessGate[];
    /**
     * @stability stable
     */
    set readinessGate(value: JobV1SpecTemplateSpecReadinessGate[]);
    /**
     * @stability stable
     */
    resetReadinessGate(): void;
    /**
     * @stability stable
     */
    get readinessGateInput(): JobV1SpecTemplateSpecReadinessGate[] | undefined;
    private _securityContext;
    /**
     * @stability stable
     */
    get securityContext(): JobV1SpecTemplateSpecSecurityContextOutputReference;
    /**
     * @stability stable
     */
    putSecurityContext(value: JobV1SpecTemplateSpecSecurityContext): void;
    /**
     * @stability stable
     */
    resetSecurityContext(): void;
    /**
     * @stability stable
     */
    get securityContextInput(): JobV1SpecTemplateSpecSecurityContext | undefined;
    private _toleration?;
    /**
     * @stability stable
     */
    get toleration(): JobV1SpecTemplateSpecToleration[];
    /**
     * @stability stable
     */
    set toleration(value: JobV1SpecTemplateSpecToleration[]);
    /**
     * @stability stable
     */
    resetToleration(): void;
    /**
     * @stability stable
     */
    get tolerationInput(): JobV1SpecTemplateSpecToleration[] | undefined;
    private _topologySpreadConstraint?;
    /**
     * @stability stable
     */
    get topologySpreadConstraint(): JobV1SpecTemplateSpecTopologySpreadConstraint[];
    /**
     * @stability stable
     */
    set topologySpreadConstraint(value: JobV1SpecTemplateSpecTopologySpreadConstraint[]);
    /**
     * @stability stable
     */
    resetTopologySpreadConstraint(): void;
    /**
     * @stability stable
     */
    get topologySpreadConstraintInput(): JobV1SpecTemplateSpecTopologySpreadConstraint[] | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): JobV1SpecTemplateSpecVolume[];
    /**
     * @stability stable
     */
    set volume(value: JobV1SpecTemplateSpecVolume[]);
    /**
     * @stability stable
     */
    resetVolume(): void;
    /**
     * @stability stable
     */
    get volumeInput(): JobV1SpecTemplateSpecVolume[] | undefined;
}
/**
 * @stability stable
 */
export interface JobV1SpecTemplate {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#metadata JobV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: JobV1SpecTemplateMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#spec JobV1#spec}
     *
     * @stability stable
     */
    readonly spec?: JobV1SpecTemplateSpec;
}
export declare function jobV1SpecTemplateToTerraform(struct?: JobV1SpecTemplateOutputReference | JobV1SpecTemplate): any;
/**
 * @stability stable
 */
export declare class JobV1SpecTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1SpecTemplate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1SpecTemplate | undefined);
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): JobV1SpecTemplateMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: JobV1SpecTemplateMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): JobV1SpecTemplateMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): JobV1SpecTemplateSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: JobV1SpecTemplateSpec): void;
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): JobV1SpecTemplateSpec | undefined;
}
/**
 * @stability stable
 */
export interface JobV1Spec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#active_deadline_seconds JobV1#active_deadline_seconds}
     *
     * @stability stable
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * Specifies the number of retries before marking this job failed. Defaults to 6.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#backoff_limit JobV1#backoff_limit}
     *
     * @stability stable
     */
    readonly backoffLimit?: number;
    /**
     * CompletionMode specifies how Pod completions are tracked.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#completion_mode JobV1#completion_mode}
     *
     * @stability stable
     */
    readonly completionMode?: string;
    /**
     * Specifies the desired number of successfully finished pods the job should be run with.
     *
     * Setting to nil means that the success of any pod signals the success of all pods, and allows parallelism to have any positive value. Setting to 1 means that parallelism is limited to 1 and the success of that pod signals the success of the job. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#completions JobV1#completions}
     *
     * @stability stable
     */
    readonly completions?: number;
    /**
     * Controls generation of pod labels and pod selectors.
     *
     * Leave unset unless you are certain what you are doing. When false or unset, the system pick labels unique to this job and appends those labels to the pod template. When true, the user is responsible for picking unique labels and specifying the selector. Failure to pick a unique label may cause this and other jobs to not function correctly. More info: https://git.k8s.io/community/contributors/design-proposals/selector-generation.md
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#manual_selector JobV1#manual_selector}
     *
     * @stability stable
     */
    readonly manualSelector?: boolean | cdktf.IResolvable;
    /**
     * Specifies the maximum desired number of pods the job should run at any given time.
     *
     * The actual number of pods running in steady state will be less than this number when ((.spec.completions - .status.successful) < .spec.parallelism), i.e. when the work left to do is less than max parallelism. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#parallelism JobV1#parallelism}
     *
     * @stability stable
     */
    readonly parallelism?: number;
    /**
     * ttlSecondsAfterFinished limits the lifetime of a Job that has finished execution (either Complete or Failed).
     *
     * If this field is set, ttlSecondsAfterFinished after the Job finishes, it is eligible to be automatically deleted. When the Job is being deleted, its lifecycle guarantees (e.g. finalizers) will be honored. If this field is unset, the Job won't be automatically deleted. If this field is set to zero, the Job becomes eligible to be deleted immediately after it finishes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#ttl_seconds_after_finished JobV1#ttl_seconds_after_finished}
     *
     * @stability stable
     */
    readonly ttlSecondsAfterFinished?: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#selector JobV1#selector}
     *
     * @stability stable
     */
    readonly selector?: JobV1SpecSelector;
    /**
     * template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#template JobV1#template}
     *
     * @stability stable
     */
    readonly template: JobV1SpecTemplate;
}
export declare function jobV1SpecToTerraform(struct?: JobV1SpecOutputReference | JobV1Spec): any;
/**
 * @stability stable
 */
export declare class JobV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1Spec | undefined);
    private _activeDeadlineSeconds?;
    /**
     * @stability stable
     */
    get activeDeadlineSeconds(): number;
    /**
     * @stability stable
     */
    set activeDeadlineSeconds(value: number);
    /**
     * @stability stable
     */
    resetActiveDeadlineSeconds(): void;
    /**
     * @stability stable
     */
    get activeDeadlineSecondsInput(): number | undefined;
    private _backoffLimit?;
    /**
     * @stability stable
     */
    get backoffLimit(): number;
    /**
     * @stability stable
     */
    set backoffLimit(value: number);
    /**
     * @stability stable
     */
    resetBackoffLimit(): void;
    /**
     * @stability stable
     */
    get backoffLimitInput(): number | undefined;
    private _completionMode?;
    /**
     * @stability stable
     */
    get completionMode(): string;
    /**
     * @stability stable
     */
    set completionMode(value: string);
    /**
     * @stability stable
     */
    resetCompletionMode(): void;
    /**
     * @stability stable
     */
    get completionModeInput(): string | undefined;
    private _completions?;
    /**
     * @stability stable
     */
    get completions(): number;
    /**
     * @stability stable
     */
    set completions(value: number);
    /**
     * @stability stable
     */
    resetCompletions(): void;
    /**
     * @stability stable
     */
    get completionsInput(): number | undefined;
    private _manualSelector?;
    /**
     * @stability stable
     */
    get manualSelector(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set manualSelector(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetManualSelector(): void;
    /**
     * @stability stable
     */
    get manualSelectorInput(): boolean | cdktf.IResolvable | undefined;
    private _parallelism?;
    /**
     * @stability stable
     */
    get parallelism(): number;
    /**
     * @stability stable
     */
    set parallelism(value: number);
    /**
     * @stability stable
     */
    resetParallelism(): void;
    /**
     * @stability stable
     */
    get parallelismInput(): number | undefined;
    private _ttlSecondsAfterFinished?;
    /**
     * @stability stable
     */
    get ttlSecondsAfterFinished(): string;
    /**
     * @stability stable
     */
    set ttlSecondsAfterFinished(value: string);
    /**
     * @stability stable
     */
    resetTtlSecondsAfterFinished(): void;
    /**
     * @stability stable
     */
    get ttlSecondsAfterFinishedInput(): string | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): JobV1SpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: JobV1SpecSelector): void;
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): JobV1SpecSelector | undefined;
    private _template;
    /**
     * @stability stable
     */
    get template(): JobV1SpecTemplateOutputReference;
    /**
     * @stability stable
     */
    putTemplate(value: JobV1SpecTemplate): void;
    /**
     * @stability stable
     */
    get templateInput(): JobV1SpecTemplate | undefined;
}
/**
 * @stability stable
 */
export interface JobV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#create JobV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#delete JobV1#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html#update JobV1#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function jobV1TimeoutsToTerraform(struct?: JobV1TimeoutsOutputReference | JobV1Timeouts): any;
/**
 * @stability stable
 */
export declare class JobV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): JobV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: JobV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html kubernetes_job_v1}.
 *
 * @stability stable
 */
export declare class JobV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/job_v1.html kubernetes_job_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: JobV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _waitForCompletion?;
    /**
     * @stability stable
     */
    get waitForCompletion(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForCompletion(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForCompletion(): void;
    /**
     * @stability stable
     */
    get waitForCompletionInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): JobV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: JobV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): JobV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): JobV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: JobV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): JobV1Spec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): JobV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: JobV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): JobV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
