import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StatefulSetV1Config extends cdktf.TerraformMetaArguments {
    /**
     * Wait for the rollout of the stateful set to complete. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#wait_for_rollout StatefulSetV1#wait_for_rollout}
     *
     * @stability stable
     */
    readonly waitForRollout?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#metadata StatefulSetV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: StatefulSetV1Metadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#spec StatefulSetV1#spec}
     *
     * @stability stable
     */
    readonly spec: StatefulSetV1Spec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#timeouts StatefulSetV1#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: StatefulSetV1Timeouts;
}
/**
 * @stability stable
 */
export interface StatefulSetV1Metadata {
    /**
     * An unstructured key value map stored with the stateful set that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#annotations StatefulSetV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#generate_name StatefulSetV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the stateful set.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#labels StatefulSetV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the stateful set, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the stateful set must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1MetadataToTerraform(struct?: StatefulSetV1MetadataOutputReference | StatefulSetV1Metadata): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1Metadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1Metadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecSelectorMatchExpressionsToTerraform(struct?: StatefulSetV1SpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_labels StatefulSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecSelectorMatchExpressions[];
}
export declare function statefulSetV1SpecSelectorToTerraform(struct?: StatefulSetV1SpecSelectorOutputReference | StatefulSetV1SpecSelector): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): StatefulSetV1SpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: StatefulSetV1SpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): StatefulSetV1SpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateMetadata {
    /**
     * An unstructured key value map stored with the stateful set that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#annotations StatefulSetV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#generate_name StatefulSetV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the stateful set.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#labels StatefulSetV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the stateful set, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function statefulSetV1SpecTemplateMetadataToTerraform(struct?: StatefulSetV1SpecTemplateMetadataOutputReference | StatefulSetV1SpecTemplateMetadata): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference | StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined);
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#weight StatefulSetV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * preference block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#preference StatefulSetV1#preference}
     *
     * @stability stable
     */
    readonly preference: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference;
}
export declare function statefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#node_selector_term StatefulSetV1#node_selector_term}
     *
     * @stability stable
     */
    readonly nodeSelectorTerm?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference | StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined);
    private _nodeSelectorTerm?;
    /**
     * @stability stable
     */
    get nodeSelectorTerm(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
    /**
     * @stability stable
     */
    set nodeSelectorTerm(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[]);
    /**
     * @stability stable
     */
    resetNodeSelectorTerm(): void;
    /**
     * @stability stable
     */
    get nodeSelectorTermInput(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#preferred_during_scheduling_ignored_during_execution StatefulSetV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#required_during_scheduling_ignored_during_execution StatefulSetV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution;
}
export declare function statefulSetV1SpecTemplateSpecAffinityNodeAffinityToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityOutputReference | StatefulSetV1SpecTemplateSpecAffinityNodeAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityNodeAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference;
    /**
     * @stability stable
     */
    putRequiredDuringSchedulingIgnoredDuringExecution(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): void;
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_labels StatefulSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespaces StatefulSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#topology_key StatefulSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#label_selector StatefulSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#weight StatefulSetV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pod_affinity_term StatefulSetV1#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_labels StatefulSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespaces StatefulSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#topology_key StatefulSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#label_selector StatefulSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#preferred_during_scheduling_ignored_during_execution StatefulSetV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#required_during_scheduling_ignored_during_execution StatefulSetV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAffinityToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAffinityOutputReference | StatefulSetV1SpecTemplateSpecAffinityPodAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityPodAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinityPodAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinityPodAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_labels StatefulSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespaces StatefulSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#topology_key StatefulSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#label_selector StatefulSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#weight StatefulSetV1#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pod_affinity_term StatefulSetV1#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_labels StatefulSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespaces StatefulSetV1#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#topology_key StatefulSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#label_selector StatefulSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#preferred_during_scheduling_ignored_during_execution StatefulSetV1#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#required_during_scheduling_ignored_during_execution StatefulSetV1#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function statefulSetV1SpecTemplateSpecAffinityPodAntiAffinityToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference | StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecAffinity {
    /**
     * node_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#node_affinity StatefulSetV1#node_affinity}
     *
     * @stability stable
     */
    readonly nodeAffinity?: StatefulSetV1SpecTemplateSpecAffinityNodeAffinity;
    /**
     * pod_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pod_affinity StatefulSetV1#pod_affinity}
     *
     * @stability stable
     */
    readonly podAffinity?: StatefulSetV1SpecTemplateSpecAffinityPodAffinity;
    /**
     * pod_anti_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pod_anti_affinity StatefulSetV1#pod_anti_affinity}
     *
     * @stability stable
     */
    readonly podAntiAffinity?: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinity;
}
export declare function statefulSetV1SpecTemplateSpecAffinityToTerraform(struct?: StatefulSetV1SpecTemplateSpecAffinityOutputReference | StatefulSetV1SpecTemplateSpecAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecAffinity | undefined);
    private _nodeAffinity;
    /**
     * @stability stable
     */
    get nodeAffinity(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinityOutputReference;
    /**
     * @stability stable
     */
    putNodeAffinity(value: StatefulSetV1SpecTemplateSpecAffinityNodeAffinity): void;
    /**
     * @stability stable
     */
    resetNodeAffinity(): void;
    /**
     * @stability stable
     */
    get nodeAffinityInput(): StatefulSetV1SpecTemplateSpecAffinityNodeAffinity | undefined;
    private _podAffinity;
    /**
     * @stability stable
     */
    get podAffinity(): StatefulSetV1SpecTemplateSpecAffinityPodAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAffinity(value: StatefulSetV1SpecTemplateSpecAffinityPodAffinity): void;
    /**
     * @stability stable
     */
    resetPodAffinity(): void;
    /**
     * @stability stable
     */
    get podAffinityInput(): StatefulSetV1SpecTemplateSpecAffinityPodAffinity | undefined;
    private _podAntiAffinity;
    /**
     * @stability stable
     */
    get podAntiAffinity(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAntiAffinity(value: StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinity): void;
    /**
     * @stability stable
     */
    resetPodAntiAffinity(): void;
    /**
     * @stability stable
     */
    get podAntiAffinityInput(): StatefulSetV1SpecTemplateSpecAffinityPodAntiAffinity | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference | StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#api_version StatefulSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_path StatefulSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference | StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#container_name StatefulSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#divisor StatefulSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource StatefulSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference | StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference | StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#config_map_key_ref StatefulSetV1#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_ref StatefulSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource_field_ref StatefulSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_key_ref StatefulSetV1#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvValueFromToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvValueFromOutputReference | StatefulSetV1SpecTemplateSpecContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): StatefulSetV1SpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value_from StatefulSetV1#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: StatefulSetV1SpecTemplateSpecContainerEnvValueFrom;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnv): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRefOutputReference | StatefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvFromSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvFromSecretRefOutputReference | StatefulSetV1SpecTemplateSpecContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#prefix StatefulSetV1#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#config_map_ref StatefulSetV1#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: StatefulSetV1SpecTemplateSpecContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_ref StatefulSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetV1SpecTemplateSpecContainerEnvFromSecretRef;
}
export declare function statefulSetV1SpecTemplateSpecContainerEnvFromToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePostStartExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartExecOutputReference | StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference | StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStartTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePostStartToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePreStopExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopExecOutputReference | StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference | StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStopTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecyclePreStopToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#post_start StatefulSetV1#post_start}
     *
     * @stability stable
     */
    readonly postStart?: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pre_stop StatefulSetV1#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStop[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLifecycleToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLifecycleOutputReference | StatefulSetV1SpecTemplateSpecContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): StatefulSetV1SpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): StatefulSetV1SpecTemplateSpecContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): StatefulSetV1SpecTemplateSpecContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: StatefulSetV1SpecTemplateSpecContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): StatefulSetV1SpecTemplateSpecContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLivenessProbeExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeExecOutputReference | StatefulSetV1SpecTemplateSpecContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference | StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerLivenessProbeTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#failure_threshold StatefulSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#initial_delay_seconds StatefulSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#period_seconds StatefulSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#success_threshold StatefulSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#timeout_seconds StatefulSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecContainerLivenessProbeToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerLivenessProbeOutputReference | StatefulSetV1SpecTemplateSpecContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetV1SpecTemplateSpecContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetV1SpecTemplateSpecContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#container_port StatefulSetV1#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_ip StatefulSetV1#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_port StatefulSetV1#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#protocol StatefulSetV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerPortToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerPort): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecContainerReadinessProbeExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeExecOutputReference | StatefulSetV1SpecTemplateSpecContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference | StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerReadinessProbeTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#failure_threshold StatefulSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#initial_delay_seconds StatefulSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#period_seconds StatefulSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#success_threshold StatefulSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#timeout_seconds StatefulSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecContainerReadinessProbeToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerReadinessProbeOutputReference | StatefulSetV1SpecTemplateSpecContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetV1SpecTemplateSpecContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetV1SpecTemplateSpecContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#limits StatefulSetV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#requests StatefulSetV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecContainerResourcesToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerResourcesOutputReference | StatefulSetV1SpecTemplateSpecContainerResources): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#add StatefulSetV1#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#drop StatefulSetV1#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function statefulSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference | StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#level StatefulSetV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#role StatefulSetV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#type StatefulSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#user StatefulSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference | StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#allow_privilege_escalation StatefulSetV1#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#privileged StatefulSetV1#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only_root_filesystem StatefulSetV1#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_group StatefulSetV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_non_root StatefulSetV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_user StatefulSetV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#capabilities StatefulSetV1#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#se_linux_options StatefulSetV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions;
}
export declare function statefulSetV1SpecTemplateSpecContainerSecurityContextToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerSecurityContextOutputReference | StatefulSetV1SpecTemplateSpecContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): StatefulSetV1SpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): StatefulSetV1SpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecContainerStartupProbeExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerStartupProbeExecOutputReference | StatefulSetV1SpecTemplateSpecContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference | StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerStartupProbeTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#failure_threshold StatefulSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#initial_delay_seconds StatefulSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#period_seconds StatefulSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#success_threshold StatefulSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#timeout_seconds StatefulSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecContainerStartupProbeToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerStartupProbeOutputReference | StatefulSetV1SpecTemplateSpecContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetV1SpecTemplateSpecContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetV1SpecTemplateSpecContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetV1SpecTemplateSpecContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetV1SpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetV1SpecTemplateSpecContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mount_path StatefulSetV1#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mount_propagation StatefulSetV1#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#sub_path StatefulSetV1#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function statefulSetV1SpecTemplateSpecContainerVolumeMountToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#args StatefulSetV1#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#image StatefulSetV1#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#image_pull_policy StatefulSetV1#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#stdin StatefulSetV1#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#stdin_once StatefulSetV1#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#termination_message_path StatefulSetV1#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#termination_message_policy StatefulSetV1#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tty StatefulSetV1#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#working_dir StatefulSetV1#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#env StatefulSetV1#env}
     *
     * @stability stable
     */
    readonly env?: StatefulSetV1SpecTemplateSpecContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#env_from StatefulSetV1#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: StatefulSetV1SpecTemplateSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#lifecycle StatefulSetV1#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: StatefulSetV1SpecTemplateSpecContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#liveness_probe StatefulSetV1#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: StatefulSetV1SpecTemplateSpecContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: StatefulSetV1SpecTemplateSpecContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#readiness_probe StatefulSetV1#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: StatefulSetV1SpecTemplateSpecContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resources StatefulSetV1#resources}
     *
     * @stability stable
     */
    readonly resources?: StatefulSetV1SpecTemplateSpecContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#security_context StatefulSetV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: StatefulSetV1SpecTemplateSpecContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#startup_probe StatefulSetV1#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: StatefulSetV1SpecTemplateSpecContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_mount StatefulSetV1#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: StatefulSetV1SpecTemplateSpecContainerVolumeMount[];
}
export declare function statefulSetV1SpecTemplateSpecContainerToTerraform(struct?: StatefulSetV1SpecTemplateSpecContainer): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecDnsConfigOption {
    /**
     * Name of the option.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the option. Optional: Defaults to empty.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecDnsConfigOptionToTerraform(struct?: StatefulSetV1SpecTemplateSpecDnsConfigOption): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#nameservers StatefulSetV1#nameservers}
     *
     * @stability stable
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#searches StatefulSetV1#searches}
     *
     * @stability stable
     */
    readonly searches?: string[];
    /**
     * option block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#option StatefulSetV1#option}
     *
     * @stability stable
     */
    readonly option?: StatefulSetV1SpecTemplateSpecDnsConfigOption[];
}
export declare function statefulSetV1SpecTemplateSpecDnsConfigToTerraform(struct?: StatefulSetV1SpecTemplateSpecDnsConfigOutputReference | StatefulSetV1SpecTemplateSpecDnsConfig): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecDnsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecDnsConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecDnsConfig | undefined);
    private _nameservers?;
    /**
     * @stability stable
     */
    get nameservers(): string[];
    /**
     * @stability stable
     */
    set nameservers(value: string[]);
    /**
     * @stability stable
     */
    resetNameservers(): void;
    /**
     * @stability stable
     */
    get nameserversInput(): string[] | undefined;
    private _searches?;
    /**
     * @stability stable
     */
    get searches(): string[];
    /**
     * @stability stable
     */
    set searches(value: string[]);
    /**
     * @stability stable
     */
    resetSearches(): void;
    /**
     * @stability stable
     */
    get searchesInput(): string[] | undefined;
    private _option?;
    /**
     * @stability stable
     */
    get option(): StatefulSetV1SpecTemplateSpecDnsConfigOption[];
    /**
     * @stability stable
     */
    set option(value: StatefulSetV1SpecTemplateSpecDnsConfigOption[]);
    /**
     * @stability stable
     */
    resetOption(): void;
    /**
     * @stability stable
     */
    get optionInput(): StatefulSetV1SpecTemplateSpecDnsConfigOption[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecHostAliases {
    /**
     * Hostnames for the IP address.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#hostnames StatefulSetV1#hostnames}
     *
     * @stability stable
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#ip StatefulSetV1#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
export declare function statefulSetV1SpecTemplateSpecHostAliasesToTerraform(struct?: StatefulSetV1SpecTemplateSpecHostAliases): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecImagePullSecrets {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function statefulSetV1SpecTemplateSpecImagePullSecretsToTerraform(struct?: StatefulSetV1SpecTemplateSpecImagePullSecrets): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference | StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#api_version StatefulSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_path StatefulSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference | StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#container_name StatefulSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#divisor StatefulSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource StatefulSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference | StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference | StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#config_map_key_ref StatefulSetV1#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_ref StatefulSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource_field_ref StatefulSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_key_ref StatefulSetV1#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvValueFromToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromOutputReference | StatefulSetV1SpecTemplateSpecInitContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): StatefulSetV1SpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value_from StatefulSetV1#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: StatefulSetV1SpecTemplateSpecInitContainerEnvValueFrom;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnv): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference | StatefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRefOutputReference | StatefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#prefix StatefulSetV1#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#config_map_ref StatefulSetV1#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: StatefulSetV1SpecTemplateSpecInitContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_ref StatefulSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetV1SpecTemplateSpecInitContainerEnvFromSecretRef;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerEnvFromToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePostStartToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecyclePreStopToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#post_start StatefulSetV1#post_start}
     *
     * @stability stable
     */
    readonly postStart?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pre_stop StatefulSetV1#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStop[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLifecycleToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLifecycleOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): StatefulSetV1SpecTemplateSpecInitContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLivenessProbeExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#failure_threshold StatefulSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#initial_delay_seconds StatefulSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#period_seconds StatefulSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#success_threshold StatefulSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#timeout_seconds StatefulSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerLivenessProbeToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeOutputReference | StatefulSetV1SpecTemplateSpecInitContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetV1SpecTemplateSpecInitContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#container_port StatefulSetV1#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_ip StatefulSetV1#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_port StatefulSetV1#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#protocol StatefulSetV1#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerPortToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerPort): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerReadinessProbeExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference | StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference | StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#failure_threshold StatefulSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#initial_delay_seconds StatefulSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#period_seconds StatefulSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#success_threshold StatefulSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#timeout_seconds StatefulSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerReadinessProbeToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeOutputReference | StatefulSetV1SpecTemplateSpecInitContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetV1SpecTemplateSpecInitContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#limits StatefulSetV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#requests StatefulSetV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerResourcesToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerResourcesOutputReference | StatefulSetV1SpecTemplateSpecInitContainerResources): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#add StatefulSetV1#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#drop StatefulSetV1#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference | StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#level StatefulSetV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#role StatefulSetV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#type StatefulSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#user StatefulSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference | StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#allow_privilege_escalation StatefulSetV1#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#privileged StatefulSetV1#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only_root_filesystem StatefulSetV1#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_group StatefulSetV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_non_root StatefulSetV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_user StatefulSetV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#capabilities StatefulSetV1#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#se_linux_options StatefulSetV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerSecurityContextToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextOutputReference | StatefulSetV1SpecTemplateSpecInitContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): StatefulSetV1SpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): StatefulSetV1SpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerStartupProbeExecToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference | StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host StatefulSetV1#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#scheme StatefulSetV1#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_header StatefulSetV1#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference | StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocketToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#failure_threshold StatefulSetV1#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#initial_delay_seconds StatefulSetV1#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#period_seconds StatefulSetV1#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#success_threshold StatefulSetV1#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#timeout_seconds StatefulSetV1#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#exec StatefulSetV1#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#http_get StatefulSetV1#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tcp_socket StatefulSetV1#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerStartupProbeToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeOutputReference | StatefulSetV1SpecTemplateSpecInitContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecInitContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecInitContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetV1SpecTemplateSpecInitContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mount_path StatefulSetV1#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mount_propagation StatefulSetV1#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#sub_path StatefulSetV1#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function statefulSetV1SpecTemplateSpecInitContainerVolumeMountToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#args StatefulSetV1#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#command StatefulSetV1#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#image StatefulSetV1#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#image_pull_policy StatefulSetV1#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#stdin StatefulSetV1#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#stdin_once StatefulSetV1#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#termination_message_path StatefulSetV1#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#termination_message_policy StatefulSetV1#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#tty StatefulSetV1#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#working_dir StatefulSetV1#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#env StatefulSetV1#env}
     *
     * @stability stable
     */
    readonly env?: StatefulSetV1SpecTemplateSpecInitContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#env_from StatefulSetV1#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: StatefulSetV1SpecTemplateSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#lifecycle StatefulSetV1#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: StatefulSetV1SpecTemplateSpecInitContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#liveness_probe StatefulSetV1#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: StatefulSetV1SpecTemplateSpecInitContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#port StatefulSetV1#port}
     *
     * @stability stable
     */
    readonly port?: StatefulSetV1SpecTemplateSpecInitContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#readiness_probe StatefulSetV1#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: StatefulSetV1SpecTemplateSpecInitContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resources StatefulSetV1#resources}
     *
     * @stability stable
     */
    readonly resources?: StatefulSetV1SpecTemplateSpecInitContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#security_context StatefulSetV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: StatefulSetV1SpecTemplateSpecInitContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#startup_probe StatefulSetV1#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: StatefulSetV1SpecTemplateSpecInitContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_mount StatefulSetV1#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: StatefulSetV1SpecTemplateSpecInitContainerVolumeMount[];
}
export declare function statefulSetV1SpecTemplateSpecInitContainerToTerraform(struct?: StatefulSetV1SpecTemplateSpecInitContainer): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecReadinessGate {
    /**
     * refers to a condition in the pod's condition list with matching type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#condition_type StatefulSetV1#condition_type}
     *
     * @stability stable
     */
    readonly conditionType: string;
}
export declare function statefulSetV1SpecTemplateSpecReadinessGateToTerraform(struct?: StatefulSetV1SpecTemplateSpecReadinessGate): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#level StatefulSetV1#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#role StatefulSetV1#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#type StatefulSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#user StatefulSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function statefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference | StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function statefulSetV1SpecTemplateSpecSecurityContextSysctlToTerraform(struct?: StatefulSetV1SpecTemplateSpecSecurityContextSysctl): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_group StatefulSetV1#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup?: string;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_group StatefulSetV1#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_non_root StatefulSetV1#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#run_as_user StatefulSetV1#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#supplemental_groups StatefulSetV1#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#se_linux_options StatefulSetV1#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptions;
    /**
     * sysctl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#sysctl StatefulSetV1#sysctl}
     *
     * @stability stable
     */
    readonly sysctl?: StatefulSetV1SpecTemplateSpecSecurityContextSysctl[];
}
export declare function statefulSetV1SpecTemplateSpecSecurityContextToTerraform(struct?: StatefulSetV1SpecTemplateSpecSecurityContextOutputReference | StatefulSetV1SpecTemplateSpecSecurityContext): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecSecurityContext | undefined);
    private _fsGroup?;
    /**
     * @stability stable
     */
    get fsGroup(): string;
    /**
     * @stability stable
     */
    set fsGroup(value: string);
    /**
     * @stability stable
     */
    resetFsGroup(): void;
    /**
     * @stability stable
     */
    get fsGroupInput(): string | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _supplementalGroups?;
    /**
     * @stability stable
     */
    get supplementalGroups(): number[];
    /**
     * @stability stable
     */
    set supplementalGroups(value: number[]);
    /**
     * @stability stable
     */
    resetSupplementalGroups(): void;
    /**
     * @stability stable
     */
    get supplementalGroupsInput(): number[] | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): StatefulSetV1SpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    private _sysctl?;
    /**
     * @stability stable
     */
    get sysctl(): StatefulSetV1SpecTemplateSpecSecurityContextSysctl[];
    /**
     * @stability stable
     */
    set sysctl(value: StatefulSetV1SpecTemplateSpecSecurityContextSysctl[]);
    /**
     * @stability stable
     */
    resetSysctl(): void;
    /**
     * @stability stable
     */
    get sysctlInput(): StatefulSetV1SpecTemplateSpecSecurityContextSysctl[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#effect StatefulSetV1#effect}
     *
     * @stability stable
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#toleration_seconds StatefulSetV1#toleration_seconds}
     *
     * @stability stable
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#value StatefulSetV1#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetV1SpecTemplateSpecTolerationToTerraform(struct?: StatefulSetV1SpecTemplateSpecToleration): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_labels StatefulSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions[];
}
export declare function statefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelectorToTerraform(struct?: StatefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecTopologySpreadConstraint {
    /**
     * describes the degree to which pods may be unevenly distributed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#max_skew StatefulSetV1#max_skew}
     *
     * @stability stable
     */
    readonly maxSkew?: number;
    /**
     * the key of node labels.
     *
     * Nodes that have a label with this key and identical values are considered to be in the same topology.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#topology_key StatefulSetV1#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * indicates how to deal with a pod if it doesn't satisfy the spread constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#when_unsatisfiable StatefulSetV1#when_unsatisfiable}
     *
     * @stability stable
     */
    readonly whenUnsatisfiable?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#label_selector StatefulSetV1#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetV1SpecTemplateSpecTopologySpreadConstraintLabelSelector[];
}
export declare function statefulSetV1SpecTemplateSpecTopologySpreadConstraintToTerraform(struct?: StatefulSetV1SpecTemplateSpecTopologySpreadConstraint): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#partition StatefulSetV1#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_id StatefulSetV1#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStoreToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference | StatefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStore): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStore | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStore | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#caching_mode StatefulSetV1#caching_mode}
     *
     * @stability stable
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#data_disk_uri StatefulSetV1#data_disk_uri}
     *
     * @stability stable
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#disk_name StatefulSetV1#disk_name}
     *
     * @stability stable
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The type for the data disk. Expected values: Shared, Dedicated, Managed. Defaults to Shared.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#kind StatefulSetV1#kind}
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecVolumeAzureDiskToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeAzureDiskOutputReference | StatefulSetV1SpecTemplateSpecVolumeAzureDisk): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeAzureDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeAzureDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeAzureDisk | undefined);
    private _cachingMode?;
    /**
     * @stability stable
     */
    get cachingMode(): string;
    /**
     * @stability stable
     */
    set cachingMode(value: string);
    /**
     * @stability stable
     */
    get cachingModeInput(): string | undefined;
    private _dataDiskUri?;
    /**
     * @stability stable
     */
    get dataDiskUri(): string;
    /**
     * @stability stable
     */
    set dataDiskUri(value: string);
    /**
     * @stability stable
     */
    get dataDiskUriInput(): string | undefined;
    private _diskName?;
    /**
     * @stability stable
     */
    get diskName(): string;
    /**
     * @stability stable
     */
    set diskName(value: string);
    /**
     * @stability stable
     */
    get diskNameInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    resetKind(): void;
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_name StatefulSetV1#secret_name}
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * The namespace of the secret that contains Azure Storage Account Name and Key.
     *
     * For Kubernetes up to 1.18.x the default is the same as the Pod. For Kubernetes 1.19.x and later the default is "default" namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_namespace StatefulSetV1#secret_namespace}
     *
     * @stability stable
     */
    readonly secretNamespace?: string;
    /**
     * Share Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#share_name StatefulSetV1#share_name}
     *
     * @stability stable
     */
    readonly shareName: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeAzureFileToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeAzureFileOutputReference | StatefulSetV1SpecTemplateSpecVolumeAzureFile): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeAzureFileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeAzureFile | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeAzureFile | undefined);
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _secretNamespace?;
    /**
     * @stability stable
     */
    get secretNamespace(): string;
    /**
     * @stability stable
     */
    set secretNamespace(value: string);
    /**
     * @stability stable
     */
    resetSecretNamespace(): void;
    /**
     * @stability stable
     */
    get secretNamespaceInput(): string | undefined;
    private _shareName?;
    /**
     * @stability stable
     */
    get shareName(): string;
    /**
     * @stability stable
     */
    set shareName(value: string);
    /**
     * @stability stable
     */
    get shareNameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCephFsSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#monitors StatefulSetV1#monitors}
     *
     * @stability stable
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_file StatefulSetV1#secret_file}
     *
     * @stability stable
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#user StatefulSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_ref StatefulSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRef;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCephFsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCephFsOutputReference | StatefulSetV1SpecTemplateSpecVolumeCephFs): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCephFsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCephFs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCephFs | undefined);
    private _monitors?;
    /**
     * @stability stable
     */
    get monitors(): string[];
    /**
     * @stability stable
     */
    set monitors(value: string[]);
    /**
     * @stability stable
     */
    get monitorsInput(): string[] | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretFile?;
    /**
     * @stability stable
     */
    get secretFile(): string;
    /**
     * @stability stable
     */
    set secretFile(value: string);
    /**
     * @stability stable
     */
    resetSecretFile(): void;
    /**
     * @stability stable
     */
    get secretFileInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): StatefulSetV1SpecTemplateSpecVolumeCephFsSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Volume ID used to identify the volume in Cinder. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_id StatefulSetV1#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCinderToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCinderOutputReference | StatefulSetV1SpecTemplateSpecVolumeCinder): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCinderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCinder | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCinder | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mode StatefulSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeConfigMapItemsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeConfigMapItems): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#default_mode StatefulSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#items StatefulSetV1#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetV1SpecTemplateSpecVolumeConfigMapItems[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeConfigMapToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeConfigMapOutputReference | StatefulSetV1SpecTemplateSpecVolumeConfigMap): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeConfigMapOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeConfigMap | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeConfigMap | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetV1SpecTemplateSpecVolumeConfigMapItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetV1SpecTemplateSpecVolumeConfigMapItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetV1SpecTemplateSpecVolumeConfigMapItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeCsi {
    /**
     * the name of the volume driver to use. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#driver StatefulSetV1#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Attributes of the volume to publish.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_attributes StatefulSetV1#volume_attributes}
     *
     * @stability stable
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * A string value that uniquely identifies the volume. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_handle StatefulSetV1#volume_handle}
     *
     * @stability stable
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#controller_expand_secret_ref StatefulSetV1#controller_expand_secret_ref}
     *
     * @stability stable
     */
    readonly controllerExpandSecretRef?: StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef;
    /**
     * controller_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#controller_publish_secret_ref StatefulSetV1#controller_publish_secret_ref}
     *
     * @stability stable
     */
    readonly controllerPublishSecretRef?: StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef;
    /**
     * node_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#node_publish_secret_ref StatefulSetV1#node_publish_secret_ref}
     *
     * @stability stable
     */
    readonly nodePublishSecretRef?: StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef;
    /**
     * node_stage_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#node_stage_secret_ref StatefulSetV1#node_stage_secret_ref}
     *
     * @stability stable
     */
    readonly nodeStageSecretRef?: StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef;
}
export declare function statefulSetV1SpecTemplateSpecVolumeCsiToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeCsiOutputReference | StatefulSetV1SpecTemplateSpecVolumeCsi): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeCsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeCsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeCsi | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeAttributes?;
    /**
     * @stability stable
     */
    get volumeAttributes(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set volumeAttributes(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetVolumeAttributes(): void;
    /**
     * @stability stable
     */
    get volumeAttributesInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _volumeHandle?;
    /**
     * @stability stable
     */
    get volumeHandle(): string;
    /**
     * @stability stable
     */
    set volumeHandle(value: string);
    /**
     * @stability stable
     */
    get volumeHandleInput(): string | undefined;
    private _controllerExpandSecretRef;
    /**
     * @stability stable
     */
    get controllerExpandSecretRef(): StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerExpandSecretRef(value: StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerExpandSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerExpandSecretRefInput(): StatefulSetV1SpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    private _controllerPublishSecretRef;
    /**
     * @stability stable
     */
    get controllerPublishSecretRef(): StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerPublishSecretRef(value: StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerPublishSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerPublishSecretRefInput(): StatefulSetV1SpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    private _nodePublishSecretRef;
    /**
     * @stability stable
     */
    get nodePublishSecretRef(): StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodePublishSecretRef(value: StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef): void;
    /**
     * @stability stable
     */
    resetNodePublishSecretRef(): void;
    /**
     * @stability stable
     */
    get nodePublishSecretRefInput(): StatefulSetV1SpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    private _nodeStageSecretRef;
    /**
     * @stability stable
     */
    get nodeStageSecretRef(): StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodeStageSecretRef(value: StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef): void;
    /**
     * @stability stable
     */
    resetNodeStageSecretRef(): void;
    /**
     * @stability stable
     */
    get nodeStageSecretRefInput(): StatefulSetV1SpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#api_version StatefulSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_path StatefulSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#container_name StatefulSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#divisor StatefulSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource StatefulSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mode StatefulSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_ref StatefulSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource_field_ref StatefulSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef;
}
export declare function statefulSetV1SpecTemplateSpecVolumeDownwardApiItemsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItems): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#default_mode StatefulSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#items StatefulSetV1#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItems[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeDownwardApiToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeDownwardApiOutputReference | StatefulSetV1SpecTemplateSpecVolumeDownwardApi): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeDownwardApi | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetV1SpecTemplateSpecVolumeDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetV1SpecTemplateSpecVolumeDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetV1SpecTemplateSpecVolumeDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#medium StatefulSetV1#medium}
     *
     * @stability stable
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#size_limit StatefulSetV1#size_limit}
     *
     * @stability stable
     */
    readonly sizeLimit?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeEmptyDirToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeEmptyDirOutputReference | StatefulSetV1SpecTemplateSpecVolumeEmptyDir): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeEmptyDirOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeEmptyDir | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeEmptyDir | undefined);
    private _medium?;
    /**
     * @stability stable
     */
    get medium(): string;
    /**
     * @stability stable
     */
    set medium(value: string);
    /**
     * @stability stable
     */
    resetMedium(): void;
    /**
     * @stability stable
     */
    get mediumInput(): string | undefined;
    private _sizeLimit?;
    /**
     * @stability stable
     */
    get sizeLimit(): string;
    /**
     * @stability stable
     */
    set sizeLimit(value: string);
    /**
     * @stability stable
     */
    resetSizeLimit(): void;
    /**
     * @stability stable
     */
    get sizeLimitInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#lun StatefulSetV1#lun}
     *
     * @stability stable
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * FC target worldwide names (WWNs).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#target_ww_ns StatefulSetV1#target_ww_ns}
     *
     * @stability stable
     */
    readonly targetWwNs: string[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeFcToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeFcOutputReference | StatefulSetV1SpecTemplateSpecVolumeFc): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeFcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeFc | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeFc | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetWwNs?;
    /**
     * @stability stable
     */
    get targetWwNs(): string[];
    /**
     * @stability stable
     */
    set targetWwNs(value: string[]);
    /**
     * @stability stable
     */
    get targetWwNsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#driver StatefulSetV1#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#options StatefulSetV1#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_ref StatefulSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef;
}
export declare function statefulSetV1SpecTemplateSpecVolumeFlexVolumeToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeFlexVolumeOutputReference | StatefulSetV1SpecTemplateSpecVolumeFlexVolume): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeFlexVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeFlexVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeFlexVolume | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _options?;
    /**
     * @stability stable
     */
    get options(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set options(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptions(): void;
    /**
     * @stability stable
     */
    get optionsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): StatefulSetV1SpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#dataset_name StatefulSetV1#dataset_name}
     *
     * @stability stable
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset. This is unique identifier of a Flocker dataset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#dataset_uuid StatefulSetV1#dataset_uuid}
     *
     * @stability stable
     */
    readonly datasetUuid?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeFlockerToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeFlockerOutputReference | StatefulSetV1SpecTemplateSpecVolumeFlocker): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeFlockerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeFlocker | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeFlocker | undefined);
    private _datasetName?;
    /**
     * @stability stable
     */
    get datasetName(): string;
    /**
     * @stability stable
     */
    set datasetName(value: string);
    /**
     * @stability stable
     */
    resetDatasetName(): void;
    /**
     * @stability stable
     */
    get datasetNameInput(): string | undefined;
    private _datasetUuid?;
    /**
     * @stability stable
     */
    get datasetUuid(): string;
    /**
     * @stability stable
     */
    set datasetUuid(value: string);
    /**
     * @stability stable
     */
    resetDatasetUuid(): void;
    /**
     * @stability stable
     */
    get datasetUuidInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#partition StatefulSetV1#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pd_name StatefulSetV1#pd_name}
     *
     * @stability stable
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecVolumeGcePersistentDiskToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeGcePersistentDiskOutputReference | StatefulSetV1SpecTemplateSpecVolumeGcePersistentDisk): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeGcePersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeGcePersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeGcePersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _pdName?;
    /**
     * @stability stable
     */
    get pdName(): string;
    /**
     * @stability stable
     */
    set pdName(value: string);
    /**
     * @stability stable
     */
    get pdNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#directory StatefulSetV1#directory}
     *
     * @stability stable
     */
    readonly directory?: string;
    /**
     * Repository URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#repository StatefulSetV1#repository}
     *
     * @stability stable
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#revision StatefulSetV1#revision}
     *
     * @stability stable
     */
    readonly revision?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeGitRepoToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeGitRepoOutputReference | StatefulSetV1SpecTemplateSpecVolumeGitRepo): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeGitRepoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeGitRepo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeGitRepo | undefined);
    private _directory?;
    /**
     * @stability stable
     */
    get directory(): string;
    /**
     * @stability stable
     */
    set directory(value: string);
    /**
     * @stability stable
     */
    resetDirectory(): void;
    /**
     * @stability stable
     */
    get directoryInput(): string | undefined;
    private _repository?;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    resetRepository(): void;
    /**
     * @stability stable
     */
    get repositoryInput(): string | undefined;
    private _revision?;
    /**
     * @stability stable
     */
    get revision(): string;
    /**
     * @stability stable
     */
    set revision(value: string);
    /**
     * @stability stable
     */
    resetRevision(): void;
    /**
     * @stability stable
     */
    get revisionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#endpoints_name StatefulSetV1#endpoints_name}
     *
     * @stability stable
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecVolumeGlusterfsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeGlusterfsOutputReference | StatefulSetV1SpecTemplateSpecVolumeGlusterfs): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeGlusterfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeGlusterfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeGlusterfs | undefined);
    private _endpointsName?;
    /**
     * @stability stable
     */
    get endpointsName(): string;
    /**
     * @stability stable
     */
    set endpointsName(value: string);
    /**
     * @stability stable
     */
    get endpointsNameInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeHostPath {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#hostpath.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Type for HostPath volume. Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#type StatefulSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeHostPathToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeHostPathOutputReference | StatefulSetV1SpecTemplateSpecVolumeHostPath): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeHostPathOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeHostPath | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeHostPath | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#iqn StatefulSetV1#iqn}
     *
     * @stability stable
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport. Defaults to 'default' (tcp).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#iscsi_interface StatefulSetV1#iscsi_interface}
     *
     * @stability stable
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#lun StatefulSetV1#lun}
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#target_portal StatefulSetV1#target_portal}
     *
     * @stability stable
     */
    readonly targetPortal: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeIscsiToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeIscsiOutputReference | StatefulSetV1SpecTemplateSpecVolumeIscsi): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeIscsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeIscsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeIscsi | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _iqn?;
    /**
     * @stability stable
     */
    get iqn(): string;
    /**
     * @stability stable
     */
    set iqn(value: string);
    /**
     * @stability stable
     */
    get iqnInput(): string | undefined;
    private _iscsiInterface?;
    /**
     * @stability stable
     */
    get iscsiInterface(): string;
    /**
     * @stability stable
     */
    set iscsiInterface(value: string);
    /**
     * @stability stable
     */
    resetIscsiInterface(): void;
    /**
     * @stability stable
     */
    get iscsiInterfaceInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    resetLun(): void;
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetPortal?;
    /**
     * @stability stable
     */
    get targetPortal(): string;
    /**
     * @stability stable
     */
    set targetPortal(value: string);
    /**
     * @stability stable
     */
    get targetPortalInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeLocal {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#local.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeLocalToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeLocalOutputReference | StatefulSetV1SpecTemplateSpecVolumeLocal): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeLocalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeLocal | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeLocal | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Server is the hostname or IP address of the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#server StatefulSetV1#server}
     *
     * @stability stable
     */
    readonly server: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeNfsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeNfsOutputReference | StatefulSetV1SpecTemplateSpecVolumeNfs): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeNfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeNfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeNfs | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _server?;
    /**
     * @stability stable
     */
    get server(): string;
    /**
     * @stability stable
     */
    set server(value: string);
    /**
     * @stability stable
     */
    get serverInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#claim_name StatefulSetV1#claim_name}
     *
     * @stability stable
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetV1SpecTemplateSpecVolumePersistentVolumeClaimToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumePersistentVolumeClaimOutputReference | StatefulSetV1SpecTemplateSpecVolumePersistentVolumeClaim): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumePersistentVolumeClaimOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumePersistentVolumeClaim | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumePersistentVolumeClaim | undefined);
    private _claimName?;
    /**
     * @stability stable
     */
    get claimName(): string;
    /**
     * @stability stable
     */
    set claimName(value: string);
    /**
     * @stability stable
     */
    resetClaimName(): void;
    /**
     * @stability stable
     */
    get claimNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pd_id StatefulSetV1#pd_id}
     *
     * @stability stable
     */
    readonly pdId: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumePhotonPersistentDiskToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumePhotonPersistentDiskOutputReference | StatefulSetV1SpecTemplateSpecVolumePhotonPersistentDisk): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumePhotonPersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumePhotonPersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumePhotonPersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _pdId?;
    /**
     * @stability stable
     */
    get pdId(): string;
    /**
     * @stability stable
     */
    set pdId(value: string);
    /**
     * @stability stable
     */
    get pdIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mode StatefulSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItemsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#items StatefulSetV1#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapItems[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMapToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMap): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#api_version StatefulSetV1#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_path StatefulSetV1#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#container_name StatefulSetV1#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#divisor StatefulSetV1#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource StatefulSetV1#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mode StatefulSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#field_ref StatefulSetV1#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resource_field_ref StatefulSetV1#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef;
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#items StatefulSetV1#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference | StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined);
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mode StatefulSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItemsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItems): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#items StatefulSetV1#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecretItems[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecretToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecret): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#audience StatefulSetV1#audience}
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#expiration_seconds StatefulSetV1#expiration_seconds}
     *
     * @stability stable
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference | StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined);
    private _audience?;
    /**
     * @stability stable
     */
    get audience(): string;
    /**
     * @stability stable
     */
    set audience(value: string);
    /**
     * @stability stable
     */
    resetAudience(): void;
    /**
     * @stability stable
     */
    get audienceInput(): string | undefined;
    private _expirationSeconds?;
    /**
     * @stability stable
     */
    get expirationSeconds(): number;
    /**
     * @stability stable
     */
    set expirationSeconds(value: number);
    /**
     * @stability stable
     */
    resetExpirationSeconds(): void;
    /**
     * @stability stable
     */
    get expirationSecondsInput(): number | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjectedSources {
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#config_map StatefulSetV1#config_map}
     *
     * @stability stable
     */
    readonly configMap?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#downward_api StatefulSetV1#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesDownwardApi;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret StatefulSetV1#secret}
     *
     * @stability stable
     */
    readonly secret?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#service_account_token StatefulSetV1#service_account_token}
     *
     * @stability stable
     */
    readonly serviceAccountToken?: StatefulSetV1SpecTemplateSpecVolumeProjectedSourcesServiceAccountToken;
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedSourcesToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjectedSources): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#default_mode StatefulSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#sources StatefulSetV1#sources}
     *
     * @stability stable
     */
    readonly sources: StatefulSetV1SpecTemplateSpecVolumeProjectedSources[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeProjectedToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeProjected): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#group StatefulSetV1#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#registry StatefulSetV1#registry}
     *
     * @stability stable
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#user StatefulSetV1#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume StatefulSetV1#volume}
     *
     * @stability stable
     */
    readonly volume: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeQuobyteToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeQuobyteOutputReference | StatefulSetV1SpecTemplateSpecVolumeQuobyte): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeQuobyteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeQuobyte | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeQuobyte | undefined);
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _registry?;
    /**
     * @stability stable
     */
    get registry(): string;
    /**
     * @stability stable
     */
    set registry(value: string);
    /**
     * @stability stable
     */
    get registryInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): string;
    /**
     * @stability stable
     */
    set volume(value: string);
    /**
     * @stability stable
     */
    get volumeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeRbdSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeRbdSecretRefToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeRbdSecretRefOutputReference | StatefulSetV1SpecTemplateSpecVolumeRbdSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeRbdSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeRbdSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeRbdSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeRbd {
    /**
     * A collection of Ceph monitors. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#ceph_monitors StatefulSetV1#ceph_monitors}
     *
     * @stability stable
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#keyring StatefulSetV1#keyring}
     *
     * @stability stable
     */
    readonly keyring?: string;
    /**
     * The rados user name. Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#rados_user StatefulSetV1#rados_user}
     *
     * @stability stable
     */
    readonly radosUser?: string;
    /**
     * The rados image name. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#rbd_image StatefulSetV1#rbd_image}
     *
     * @stability stable
     */
    readonly rbdImage: string;
    /**
     * The rados pool name. Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#rbd_pool StatefulSetV1#rbd_pool}
     *
     * @stability stable
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read_only StatefulSetV1#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_ref StatefulSetV1#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetV1SpecTemplateSpecVolumeRbdSecretRef;
}
export declare function statefulSetV1SpecTemplateSpecVolumeRbdToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeRbdOutputReference | StatefulSetV1SpecTemplateSpecVolumeRbd): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeRbdOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeRbd | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeRbd | undefined);
    private _cephMonitors?;
    /**
     * @stability stable
     */
    get cephMonitors(): string[];
    /**
     * @stability stable
     */
    set cephMonitors(value: string[]);
    /**
     * @stability stable
     */
    get cephMonitorsInput(): string[] | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _keyring?;
    /**
     * @stability stable
     */
    get keyring(): string;
    /**
     * @stability stable
     */
    set keyring(value: string);
    /**
     * @stability stable
     */
    resetKeyring(): void;
    /**
     * @stability stable
     */
    get keyringInput(): string | undefined;
    private _radosUser?;
    /**
     * @stability stable
     */
    get radosUser(): string;
    /**
     * @stability stable
     */
    set radosUser(value: string);
    /**
     * @stability stable
     */
    resetRadosUser(): void;
    /**
     * @stability stable
     */
    get radosUserInput(): string | undefined;
    private _rbdImage?;
    /**
     * @stability stable
     */
    get rbdImage(): string;
    /**
     * @stability stable
     */
    set rbdImage(value: string);
    /**
     * @stability stable
     */
    get rbdImageInput(): string | undefined;
    private _rbdPool?;
    /**
     * @stability stable
     */
    get rbdPool(): string;
    /**
     * @stability stable
     */
    set rbdPool(value: string);
    /**
     * @stability stable
     */
    resetRbdPool(): void;
    /**
     * @stability stable
     */
    get rbdPoolInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): StatefulSetV1SpecTemplateSpecVolumeRbdSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: StatefulSetV1SpecTemplateSpecVolumeRbdSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): StatefulSetV1SpecTemplateSpecVolumeRbdSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#mode StatefulSetV1#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#path StatefulSetV1#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeSecretItemsToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeSecretItems): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#default_mode StatefulSetV1#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#optional StatefulSetV1#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret_name StatefulSetV1#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#items StatefulSetV1#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetV1SpecTemplateSpecVolumeSecretItems[];
}
export declare function statefulSetV1SpecTemplateSpecVolumeSecretToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeSecretOutputReference | StatefulSetV1SpecTemplateSpecVolumeSecret): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeSecretOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeSecret | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeSecret | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    resetSecretName(): void;
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetV1SpecTemplateSpecVolumeSecretItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetV1SpecTemplateSpecVolumeSecretItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetV1SpecTemplateSpecVolumeSecretItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fs_type StatefulSetV1#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_path StatefulSetV1#volume_path}
     *
     * @stability stable
     */
    readonly volumePath: string;
}
export declare function statefulSetV1SpecTemplateSpecVolumeVsphereVolumeToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolumeVsphereVolumeOutputReference | StatefulSetV1SpecTemplateSpecVolumeVsphereVolume): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecVolumeVsphereVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpecVolumeVsphereVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpecVolumeVsphereVolume | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _volumePath?;
    /**
     * @stability stable
     */
    get volumePath(): string;
    /**
     * @stability stable
     */
    set volumePath(value: string);
    /**
     * @stability stable
     */
    get volumePathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpecVolume {
    /**
     * Volume's name. Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#aws_elastic_block_store StatefulSetV1#aws_elastic_block_store}
     *
     * @stability stable
     */
    readonly awsElasticBlockStore?: StatefulSetV1SpecTemplateSpecVolumeAwsElasticBlockStore;
    /**
     * azure_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#azure_disk StatefulSetV1#azure_disk}
     *
     * @stability stable
     */
    readonly azureDisk?: StatefulSetV1SpecTemplateSpecVolumeAzureDisk;
    /**
     * azure_file block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#azure_file StatefulSetV1#azure_file}
     *
     * @stability stable
     */
    readonly azureFile?: StatefulSetV1SpecTemplateSpecVolumeAzureFile;
    /**
     * ceph_fs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#ceph_fs StatefulSetV1#ceph_fs}
     *
     * @stability stable
     */
    readonly cephFs?: StatefulSetV1SpecTemplateSpecVolumeCephFs;
    /**
     * cinder block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#cinder StatefulSetV1#cinder}
     *
     * @stability stable
     */
    readonly cinder?: StatefulSetV1SpecTemplateSpecVolumeCinder;
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#config_map StatefulSetV1#config_map}
     *
     * @stability stable
     */
    readonly configMap?: StatefulSetV1SpecTemplateSpecVolumeConfigMap;
    /**
     * csi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#csi StatefulSetV1#csi}
     *
     * @stability stable
     */
    readonly csi?: StatefulSetV1SpecTemplateSpecVolumeCsi;
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#downward_api StatefulSetV1#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: StatefulSetV1SpecTemplateSpecVolumeDownwardApi;
    /**
     * empty_dir block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#empty_dir StatefulSetV1#empty_dir}
     *
     * @stability stable
     */
    readonly emptyDir?: StatefulSetV1SpecTemplateSpecVolumeEmptyDir;
    /**
     * fc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#fc StatefulSetV1#fc}
     *
     * @stability stable
     */
    readonly fc?: StatefulSetV1SpecTemplateSpecVolumeFc;
    /**
     * flex_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#flex_volume StatefulSetV1#flex_volume}
     *
     * @stability stable
     */
    readonly flexVolume?: StatefulSetV1SpecTemplateSpecVolumeFlexVolume;
    /**
     * flocker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#flocker StatefulSetV1#flocker}
     *
     * @stability stable
     */
    readonly flocker?: StatefulSetV1SpecTemplateSpecVolumeFlocker;
    /**
     * gce_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#gce_persistent_disk StatefulSetV1#gce_persistent_disk}
     *
     * @stability stable
     */
    readonly gcePersistentDisk?: StatefulSetV1SpecTemplateSpecVolumeGcePersistentDisk;
    /**
     * git_repo block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#git_repo StatefulSetV1#git_repo}
     *
     * @stability stable
     */
    readonly gitRepo?: StatefulSetV1SpecTemplateSpecVolumeGitRepo;
    /**
     * glusterfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#glusterfs StatefulSetV1#glusterfs}
     *
     * @stability stable
     */
    readonly glusterfs?: StatefulSetV1SpecTemplateSpecVolumeGlusterfs;
    /**
     * host_path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_path StatefulSetV1#host_path}
     *
     * @stability stable
     */
    readonly hostPath?: StatefulSetV1SpecTemplateSpecVolumeHostPath;
    /**
     * iscsi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#iscsi StatefulSetV1#iscsi}
     *
     * @stability stable
     */
    readonly iscsi?: StatefulSetV1SpecTemplateSpecVolumeIscsi;
    /**
     * local block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#local StatefulSetV1#local}
     *
     * @stability stable
     */
    readonly local?: StatefulSetV1SpecTemplateSpecVolumeLocal;
    /**
     * nfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#nfs StatefulSetV1#nfs}
     *
     * @stability stable
     */
    readonly nfs?: StatefulSetV1SpecTemplateSpecVolumeNfs;
    /**
     * persistent_volume_claim block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#persistent_volume_claim StatefulSetV1#persistent_volume_claim}
     *
     * @stability stable
     */
    readonly persistentVolumeClaim?: StatefulSetV1SpecTemplateSpecVolumePersistentVolumeClaim;
    /**
     * photon_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#photon_persistent_disk StatefulSetV1#photon_persistent_disk}
     *
     * @stability stable
     */
    readonly photonPersistentDisk?: StatefulSetV1SpecTemplateSpecVolumePhotonPersistentDisk;
    /**
     * projected block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#projected StatefulSetV1#projected}
     *
     * @stability stable
     */
    readonly projected?: StatefulSetV1SpecTemplateSpecVolumeProjected[];
    /**
     * quobyte block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#quobyte StatefulSetV1#quobyte}
     *
     * @stability stable
     */
    readonly quobyte?: StatefulSetV1SpecTemplateSpecVolumeQuobyte;
    /**
     * rbd block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#rbd StatefulSetV1#rbd}
     *
     * @stability stable
     */
    readonly rbd?: StatefulSetV1SpecTemplateSpecVolumeRbd;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#secret StatefulSetV1#secret}
     *
     * @stability stable
     */
    readonly secret?: StatefulSetV1SpecTemplateSpecVolumeSecret;
    /**
     * vsphere_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#vsphere_volume StatefulSetV1#vsphere_volume}
     *
     * @stability stable
     */
    readonly vsphereVolume?: StatefulSetV1SpecTemplateSpecVolumeVsphereVolume;
}
export declare function statefulSetV1SpecTemplateSpecVolumeToTerraform(struct?: StatefulSetV1SpecTemplateSpecVolume): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplateSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#active_deadline_seconds StatefulSetV1#active_deadline_seconds}
     *
     * @stability stable
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#automount_service_account_token StatefulSetV1#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean | cdktf.IResolvable;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#dns_policy StatefulSetV1#dns_policy}
     *
     * @stability stable
     */
    readonly dnsPolicy?: string;
    /**
     * Enables generating environment variables for service discovery. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#enable_service_links StatefulSetV1#enable_service_links}
     *
     * @stability stable
     */
    readonly enableServiceLinks?: boolean | cdktf.IResolvable;
    /**
     * Use the host's ipc namespace. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_ipc StatefulSetV1#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean | cdktf.IResolvable;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_network StatefulSetV1#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean | cdktf.IResolvable;
    /**
     * Use the host's pid namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_pid StatefulSetV1#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean | cdktf.IResolvable;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#hostname StatefulSetV1#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#node_name StatefulSetV1#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#node_selector StatefulSetV1#node_selector}
     *
     * @stability stable
     */
    readonly nodeSelector?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#priority_class_name StatefulSetV1#priority_class_name}
     *
     * @stability stable
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod. One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#restart_policy StatefulSetV1#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#service_account_name StatefulSetV1#service_account_name}
     *
     * @stability stable
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#share_process_namespace StatefulSetV1#share_process_namespace}
     *
     * @stability stable
     */
    readonly shareProcessNamespace?: boolean | cdktf.IResolvable;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#subdomain StatefulSetV1#subdomain}
     *
     * @stability stable
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#termination_grace_period_seconds StatefulSetV1#termination_grace_period_seconds}
     *
     * @stability stable
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#affinity StatefulSetV1#affinity}
     *
     * @stability stable
     */
    readonly affinity?: StatefulSetV1SpecTemplateSpecAffinity;
    /**
     * container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#container StatefulSetV1#container}
     *
     * @stability stable
     */
    readonly container?: StatefulSetV1SpecTemplateSpecContainer[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#dns_config StatefulSetV1#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: StatefulSetV1SpecTemplateSpecDnsConfig;
    /**
     * host_aliases block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#host_aliases StatefulSetV1#host_aliases}
     *
     * @stability stable
     */
    readonly hostAliases?: StatefulSetV1SpecTemplateSpecHostAliases[];
    /**
     * image_pull_secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#image_pull_secrets StatefulSetV1#image_pull_secrets}
     *
     * @stability stable
     */
    readonly imagePullSecrets?: StatefulSetV1SpecTemplateSpecImagePullSecrets[];
    /**
     * init_container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#init_container StatefulSetV1#init_container}
     *
     * @stability stable
     */
    readonly initContainer?: StatefulSetV1SpecTemplateSpecInitContainer[];
    /**
     * readiness_gate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#readiness_gate StatefulSetV1#readiness_gate}
     *
     * @stability stable
     */
    readonly readinessGate?: StatefulSetV1SpecTemplateSpecReadinessGate[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#security_context StatefulSetV1#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: StatefulSetV1SpecTemplateSpecSecurityContext;
    /**
     * toleration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#toleration StatefulSetV1#toleration}
     *
     * @stability stable
     */
    readonly toleration?: StatefulSetV1SpecTemplateSpecToleration[];
    /**
     * topology_spread_constraint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#topology_spread_constraint StatefulSetV1#topology_spread_constraint}
     *
     * @stability stable
     */
    readonly topologySpreadConstraint?: StatefulSetV1SpecTemplateSpecTopologySpreadConstraint[];
    /**
     * volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume StatefulSetV1#volume}
     *
     * @stability stable
     */
    readonly volume?: StatefulSetV1SpecTemplateSpecVolume[];
}
export declare function statefulSetV1SpecTemplateSpecToTerraform(struct?: StatefulSetV1SpecTemplateSpecOutputReference | StatefulSetV1SpecTemplateSpec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplateSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplateSpec | undefined);
    private _activeDeadlineSeconds?;
    /**
     * @stability stable
     */
    get activeDeadlineSeconds(): number;
    /**
     * @stability stable
     */
    set activeDeadlineSeconds(value: number);
    /**
     * @stability stable
     */
    resetActiveDeadlineSeconds(): void;
    /**
     * @stability stable
     */
    get activeDeadlineSecondsInput(): number | undefined;
    private _automountServiceAccountToken?;
    /**
     * @stability stable
     */
    get automountServiceAccountToken(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set automountServiceAccountToken(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutomountServiceAccountToken(): void;
    /**
     * @stability stable
     */
    get automountServiceAccountTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _dnsPolicy?;
    /**
     * @stability stable
     */
    get dnsPolicy(): string;
    /**
     * @stability stable
     */
    set dnsPolicy(value: string);
    /**
     * @stability stable
     */
    resetDnsPolicy(): void;
    /**
     * @stability stable
     */
    get dnsPolicyInput(): string | undefined;
    private _enableServiceLinks?;
    /**
     * @stability stable
     */
    get enableServiceLinks(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableServiceLinks(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableServiceLinks(): void;
    /**
     * @stability stable
     */
    get enableServiceLinksInput(): boolean | cdktf.IResolvable | undefined;
    private _hostIpc?;
    /**
     * @stability stable
     */
    get hostIpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostIpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostIpc(): void;
    /**
     * @stability stable
     */
    get hostIpcInput(): boolean | cdktf.IResolvable | undefined;
    private _hostNetwork?;
    /**
     * @stability stable
     */
    get hostNetwork(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostNetwork(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostNetwork(): void;
    /**
     * @stability stable
     */
    get hostNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _hostPid?;
    /**
     * @stability stable
     */
    get hostPid(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostPid(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostPid(): void;
    /**
     * @stability stable
     */
    get hostPidInput(): boolean | cdktf.IResolvable | undefined;
    private _hostname?;
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    set hostname(value: string);
    /**
     * @stability stable
     */
    resetHostname(): void;
    /**
     * @stability stable
     */
    get hostnameInput(): string | undefined;
    private _nodeName?;
    /**
     * @stability stable
     */
    get nodeName(): string;
    /**
     * @stability stable
     */
    set nodeName(value: string);
    /**
     * @stability stable
     */
    resetNodeName(): void;
    /**
     * @stability stable
     */
    get nodeNameInput(): string | undefined;
    private _nodeSelector?;
    /**
     * @stability stable
     */
    get nodeSelector(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set nodeSelector(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNodeSelector(): void;
    /**
     * @stability stable
     */
    get nodeSelectorInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _priorityClassName?;
    /**
     * @stability stable
     */
    get priorityClassName(): string;
    /**
     * @stability stable
     */
    set priorityClassName(value: string);
    /**
     * @stability stable
     */
    resetPriorityClassName(): void;
    /**
     * @stability stable
     */
    get priorityClassNameInput(): string | undefined;
    private _restartPolicy?;
    /**
     * @stability stable
     */
    get restartPolicy(): string;
    /**
     * @stability stable
     */
    set restartPolicy(value: string);
    /**
     * @stability stable
     */
    resetRestartPolicy(): void;
    /**
     * @stability stable
     */
    get restartPolicyInput(): string | undefined;
    private _serviceAccountName?;
    /**
     * @stability stable
     */
    get serviceAccountName(): string;
    /**
     * @stability stable
     */
    set serviceAccountName(value: string);
    /**
     * @stability stable
     */
    resetServiceAccountName(): void;
    /**
     * @stability stable
     */
    get serviceAccountNameInput(): string | undefined;
    private _shareProcessNamespace?;
    /**
     * @stability stable
     */
    get shareProcessNamespace(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set shareProcessNamespace(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShareProcessNamespace(): void;
    /**
     * @stability stable
     */
    get shareProcessNamespaceInput(): boolean | cdktf.IResolvable | undefined;
    private _subdomain?;
    /**
     * @stability stable
     */
    get subdomain(): string;
    /**
     * @stability stable
     */
    set subdomain(value: string);
    /**
     * @stability stable
     */
    resetSubdomain(): void;
    /**
     * @stability stable
     */
    get subdomainInput(): string | undefined;
    private _terminationGracePeriodSeconds?;
    /**
     * @stability stable
     */
    get terminationGracePeriodSeconds(): number;
    /**
     * @stability stable
     */
    set terminationGracePeriodSeconds(value: number);
    /**
     * @stability stable
     */
    resetTerminationGracePeriodSeconds(): void;
    /**
     * @stability stable
     */
    get terminationGracePeriodSecondsInput(): number | undefined;
    private _affinity;
    /**
     * @stability stable
     */
    get affinity(): StatefulSetV1SpecTemplateSpecAffinityOutputReference;
    /**
     * @stability stable
     */
    putAffinity(value: StatefulSetV1SpecTemplateSpecAffinity): void;
    /**
     * @stability stable
     */
    resetAffinity(): void;
    /**
     * @stability stable
     */
    get affinityInput(): StatefulSetV1SpecTemplateSpecAffinity | undefined;
    private _container?;
    /**
     * @stability stable
     */
    get container(): StatefulSetV1SpecTemplateSpecContainer[];
    /**
     * @stability stable
     */
    set container(value: StatefulSetV1SpecTemplateSpecContainer[]);
    /**
     * @stability stable
     */
    resetContainer(): void;
    /**
     * @stability stable
     */
    get containerInput(): StatefulSetV1SpecTemplateSpecContainer[] | undefined;
    private _dnsConfig;
    /**
     * @stability stable
     */
    get dnsConfig(): StatefulSetV1SpecTemplateSpecDnsConfigOutputReference;
    /**
     * @stability stable
     */
    putDnsConfig(value: StatefulSetV1SpecTemplateSpecDnsConfig): void;
    /**
     * @stability stable
     */
    resetDnsConfig(): void;
    /**
     * @stability stable
     */
    get dnsConfigInput(): StatefulSetV1SpecTemplateSpecDnsConfig | undefined;
    private _hostAliases?;
    /**
     * @stability stable
     */
    get hostAliases(): StatefulSetV1SpecTemplateSpecHostAliases[];
    /**
     * @stability stable
     */
    set hostAliases(value: StatefulSetV1SpecTemplateSpecHostAliases[]);
    /**
     * @stability stable
     */
    resetHostAliases(): void;
    /**
     * @stability stable
     */
    get hostAliasesInput(): StatefulSetV1SpecTemplateSpecHostAliases[] | undefined;
    private _imagePullSecrets?;
    /**
     * @stability stable
     */
    get imagePullSecrets(): StatefulSetV1SpecTemplateSpecImagePullSecrets[];
    /**
     * @stability stable
     */
    set imagePullSecrets(value: StatefulSetV1SpecTemplateSpecImagePullSecrets[]);
    /**
     * @stability stable
     */
    resetImagePullSecrets(): void;
    /**
     * @stability stable
     */
    get imagePullSecretsInput(): StatefulSetV1SpecTemplateSpecImagePullSecrets[] | undefined;
    private _initContainer?;
    /**
     * @stability stable
     */
    get initContainer(): StatefulSetV1SpecTemplateSpecInitContainer[];
    /**
     * @stability stable
     */
    set initContainer(value: StatefulSetV1SpecTemplateSpecInitContainer[]);
    /**
     * @stability stable
     */
    resetInitContainer(): void;
    /**
     * @stability stable
     */
    get initContainerInput(): StatefulSetV1SpecTemplateSpecInitContainer[] | undefined;
    private _readinessGate?;
    /**
     * @stability stable
     */
    get readinessGate(): StatefulSetV1SpecTemplateSpecReadinessGate[];
    /**
     * @stability stable
     */
    set readinessGate(value: StatefulSetV1SpecTemplateSpecReadinessGate[]);
    /**
     * @stability stable
     */
    resetReadinessGate(): void;
    /**
     * @stability stable
     */
    get readinessGateInput(): StatefulSetV1SpecTemplateSpecReadinessGate[] | undefined;
    private _securityContext;
    /**
     * @stability stable
     */
    get securityContext(): StatefulSetV1SpecTemplateSpecSecurityContextOutputReference;
    /**
     * @stability stable
     */
    putSecurityContext(value: StatefulSetV1SpecTemplateSpecSecurityContext): void;
    /**
     * @stability stable
     */
    resetSecurityContext(): void;
    /**
     * @stability stable
     */
    get securityContextInput(): StatefulSetV1SpecTemplateSpecSecurityContext | undefined;
    private _toleration?;
    /**
     * @stability stable
     */
    get toleration(): StatefulSetV1SpecTemplateSpecToleration[];
    /**
     * @stability stable
     */
    set toleration(value: StatefulSetV1SpecTemplateSpecToleration[]);
    /**
     * @stability stable
     */
    resetToleration(): void;
    /**
     * @stability stable
     */
    get tolerationInput(): StatefulSetV1SpecTemplateSpecToleration[] | undefined;
    private _topologySpreadConstraint?;
    /**
     * @stability stable
     */
    get topologySpreadConstraint(): StatefulSetV1SpecTemplateSpecTopologySpreadConstraint[];
    /**
     * @stability stable
     */
    set topologySpreadConstraint(value: StatefulSetV1SpecTemplateSpecTopologySpreadConstraint[]);
    /**
     * @stability stable
     */
    resetTopologySpreadConstraint(): void;
    /**
     * @stability stable
     */
    get topologySpreadConstraintInput(): StatefulSetV1SpecTemplateSpecTopologySpreadConstraint[] | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): StatefulSetV1SpecTemplateSpecVolume[];
    /**
     * @stability stable
     */
    set volume(value: StatefulSetV1SpecTemplateSpecVolume[]);
    /**
     * @stability stable
     */
    resetVolume(): void;
    /**
     * @stability stable
     */
    get volumeInput(): StatefulSetV1SpecTemplateSpecVolume[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecTemplate {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#metadata StatefulSetV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: StatefulSetV1SpecTemplateMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#spec StatefulSetV1#spec}
     *
     * @stability stable
     */
    readonly spec?: StatefulSetV1SpecTemplateSpec;
}
export declare function statefulSetV1SpecTemplateToTerraform(struct?: StatefulSetV1SpecTemplateOutputReference | StatefulSetV1SpecTemplate): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecTemplate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecTemplate | undefined);
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): StatefulSetV1SpecTemplateMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: StatefulSetV1SpecTemplateMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): StatefulSetV1SpecTemplateMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): StatefulSetV1SpecTemplateSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: StatefulSetV1SpecTemplateSpec): void;
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): StatefulSetV1SpecTemplateSpec | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecUpdateStrategyRollingUpdate {
    /**
     * Indicates the ordinal at which the StatefulSet should be partitioned. Default value is 0.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#partition StatefulSetV1#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
}
export declare function statefulSetV1SpecUpdateStrategyRollingUpdateToTerraform(struct?: StatefulSetV1SpecUpdateStrategyRollingUpdate): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecUpdateStrategy {
    /**
     * Indicates the type of the StatefulSet update strategy. Default is RollingUpdate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#type StatefulSetV1#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * rolling_update block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#rolling_update StatefulSetV1#rolling_update}
     *
     * @stability stable
     */
    readonly rollingUpdate?: StatefulSetV1SpecUpdateStrategyRollingUpdate[];
}
export declare function statefulSetV1SpecUpdateStrategyToTerraform(struct?: StatefulSetV1SpecUpdateStrategy): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecVolumeClaimTemplateMetadata {
    /**
     * An unstructured key value map stored with the persistent volume claim that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#annotations StatefulSetV1#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#generate_name StatefulSetV1#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the persistent volume claim.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#labels StatefulSetV1#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the persistent volume claim, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#name StatefulSetV1#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the persistent volume claim must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#namespace StatefulSetV1#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetV1SpecVolumeClaimTemplateMetadataToTerraform(struct?: StatefulSetV1SpecVolumeClaimTemplateMetadataOutputReference | StatefulSetV1SpecVolumeClaimTemplateMetadata): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecVolumeClaimTemplateMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecVolumeClaimTemplateMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecVolumeClaimTemplateMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecVolumeClaimTemplateSpecResources {
    /**
     * Map describing the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#limits StatefulSetV1#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map describing the minimum amount of compute resources required.
     *
     * If this is omitted for a container, it defaults to `limits` if that is explicitly specified, otherwise to an implementation-defined value. More info: http://kubernetes.io/docs/user-guide/compute-resources/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#requests StatefulSetV1#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function statefulSetV1SpecVolumeClaimTemplateSpecResourcesToTerraform(struct?: StatefulSetV1SpecVolumeClaimTemplateSpecResourcesOutputReference | StatefulSetV1SpecVolumeClaimTemplateSpecResources): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecVolumeClaimTemplateSpecResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecVolumeClaimTemplateSpecResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecVolumeClaimTemplateSpecResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecVolumeClaimTemplateSpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#key StatefulSetV1#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#operator StatefulSetV1#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#values StatefulSetV1#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetV1SpecVolumeClaimTemplateSpecSelectorMatchExpressionsToTerraform(struct?: StatefulSetV1SpecVolumeClaimTemplateSpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetV1SpecVolumeClaimTemplateSpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_labels StatefulSetV1#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#match_expressions StatefulSetV1#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetV1SpecVolumeClaimTemplateSpecSelectorMatchExpressions[];
}
export declare function statefulSetV1SpecVolumeClaimTemplateSpecSelectorToTerraform(struct?: StatefulSetV1SpecVolumeClaimTemplateSpecSelectorOutputReference | StatefulSetV1SpecVolumeClaimTemplateSpecSelector): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecVolumeClaimTemplateSpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecVolumeClaimTemplateSpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecVolumeClaimTemplateSpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): StatefulSetV1SpecVolumeClaimTemplateSpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: StatefulSetV1SpecVolumeClaimTemplateSpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): StatefulSetV1SpecVolumeClaimTemplateSpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecVolumeClaimTemplateSpec {
    /**
     * A set of the desired access modes the volume should have. More info: http://kubernetes.io/docs/user-guide/persistent-volumes#access-modes-1.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#access_modes StatefulSetV1#access_modes}
     *
     * @stability stable
     */
    readonly accessModes: string[];
    /**
     * Name of the storage class requested by the claim.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#storage_class_name StatefulSetV1#storage_class_name}
     *
     * @stability stable
     */
    readonly storageClassName?: string;
    /**
     * The binding reference to the PersistentVolume backing this claim.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_name StatefulSetV1#volume_name}
     *
     * @stability stable
     */
    readonly volumeName?: string;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#resources StatefulSetV1#resources}
     *
     * @stability stable
     */
    readonly resources: StatefulSetV1SpecVolumeClaimTemplateSpecResources;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#selector StatefulSetV1#selector}
     *
     * @stability stable
     */
    readonly selector?: StatefulSetV1SpecVolumeClaimTemplateSpecSelector;
}
export declare function statefulSetV1SpecVolumeClaimTemplateSpecToTerraform(struct?: StatefulSetV1SpecVolumeClaimTemplateSpecOutputReference | StatefulSetV1SpecVolumeClaimTemplateSpec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecVolumeClaimTemplateSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1SpecVolumeClaimTemplateSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1SpecVolumeClaimTemplateSpec | undefined);
    private _accessModes?;
    /**
     * @stability stable
     */
    get accessModes(): string[];
    /**
     * @stability stable
     */
    set accessModes(value: string[]);
    /**
     * @stability stable
     */
    get accessModesInput(): string[] | undefined;
    private _storageClassName?;
    /**
     * @stability stable
     */
    get storageClassName(): string;
    /**
     * @stability stable
     */
    set storageClassName(value: string);
    /**
     * @stability stable
     */
    resetStorageClassName(): void;
    /**
     * @stability stable
     */
    get storageClassNameInput(): string | undefined;
    private _volumeName?;
    /**
     * @stability stable
     */
    get volumeName(): string;
    /**
     * @stability stable
     */
    set volumeName(value: string);
    /**
     * @stability stable
     */
    resetVolumeName(): void;
    /**
     * @stability stable
     */
    get volumeNameInput(): string | undefined;
    private _resources;
    /**
     * @stability stable
     */
    get resources(): StatefulSetV1SpecVolumeClaimTemplateSpecResourcesOutputReference;
    /**
     * @stability stable
     */
    putResources(value: StatefulSetV1SpecVolumeClaimTemplateSpecResources): void;
    /**
     * @stability stable
     */
    get resourcesInput(): StatefulSetV1SpecVolumeClaimTemplateSpecResources | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): StatefulSetV1SpecVolumeClaimTemplateSpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: StatefulSetV1SpecVolumeClaimTemplateSpecSelector): void;
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): StatefulSetV1SpecVolumeClaimTemplateSpecSelector | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1SpecVolumeClaimTemplate {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#metadata StatefulSetV1#metadata}
     *
     * @stability stable
     */
    readonly metadata: StatefulSetV1SpecVolumeClaimTemplateMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#spec StatefulSetV1#spec}
     *
     * @stability stable
     */
    readonly spec: StatefulSetV1SpecVolumeClaimTemplateSpec;
}
export declare function statefulSetV1SpecVolumeClaimTemplateToTerraform(struct?: StatefulSetV1SpecVolumeClaimTemplate): any;
/**
 * @stability stable
 */
export interface StatefulSetV1Spec {
    /**
     * Controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#pod_management_policy StatefulSetV1#pod_management_policy}
     *
     * @stability stable
     */
    readonly podManagementPolicy?: string;
    /**
     * The desired number of replicas of the given Template, in the sense that they are instantiations of the same Template.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#replicas StatefulSetV1#replicas}
     *
     * @stability stable
     */
    readonly replicas?: string;
    /**
     * The maximum number of revisions that will be maintained in the StatefulSet's revision history. The default value is 10.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#revision_history_limit StatefulSetV1#revision_history_limit}
     *
     * @stability stable
     */
    readonly revisionHistoryLimit?: number;
    /**
     * The name of the service that governs this StatefulSet.
     *
     * This service must exist before the StatefulSet, and is responsible for the network identity of the set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#service_name StatefulSetV1#service_name}
     *
     * @stability stable
     */
    readonly serviceName: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#selector StatefulSetV1#selector}
     *
     * @stability stable
     */
    readonly selector: StatefulSetV1SpecSelector;
    /**
     * template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#template StatefulSetV1#template}
     *
     * @stability stable
     */
    readonly template: StatefulSetV1SpecTemplate;
    /**
     * update_strategy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#update_strategy StatefulSetV1#update_strategy}
     *
     * @stability stable
     */
    readonly updateStrategy?: StatefulSetV1SpecUpdateStrategy[];
    /**
     * volume_claim_template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#volume_claim_template StatefulSetV1#volume_claim_template}
     *
     * @stability stable
     */
    readonly volumeClaimTemplate?: StatefulSetV1SpecVolumeClaimTemplate[];
}
export declare function statefulSetV1SpecToTerraform(struct?: StatefulSetV1SpecOutputReference | StatefulSetV1Spec): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1SpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1Spec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1Spec | undefined);
    private _podManagementPolicy?;
    /**
     * @stability stable
     */
    get podManagementPolicy(): string;
    /**
     * @stability stable
     */
    set podManagementPolicy(value: string);
    /**
     * @stability stable
     */
    resetPodManagementPolicy(): void;
    /**
     * @stability stable
     */
    get podManagementPolicyInput(): string | undefined;
    private _replicas?;
    /**
     * @stability stable
     */
    get replicas(): string;
    /**
     * @stability stable
     */
    set replicas(value: string);
    /**
     * @stability stable
     */
    resetReplicas(): void;
    /**
     * @stability stable
     */
    get replicasInput(): string | undefined;
    private _revisionHistoryLimit?;
    /**
     * @stability stable
     */
    get revisionHistoryLimit(): number;
    /**
     * @stability stable
     */
    set revisionHistoryLimit(value: number);
    /**
     * @stability stable
     */
    resetRevisionHistoryLimit(): void;
    /**
     * @stability stable
     */
    get revisionHistoryLimitInput(): number | undefined;
    private _serviceName?;
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    set serviceName(value: string);
    /**
     * @stability stable
     */
    get serviceNameInput(): string | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): StatefulSetV1SpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: StatefulSetV1SpecSelector): void;
    /**
     * @stability stable
     */
    get selectorInput(): StatefulSetV1SpecSelector | undefined;
    private _template;
    /**
     * @stability stable
     */
    get template(): StatefulSetV1SpecTemplateOutputReference;
    /**
     * @stability stable
     */
    putTemplate(value: StatefulSetV1SpecTemplate): void;
    /**
     * @stability stable
     */
    get templateInput(): StatefulSetV1SpecTemplate | undefined;
    private _updateStrategy?;
    /**
     * @stability stable
     */
    get updateStrategy(): StatefulSetV1SpecUpdateStrategy[];
    /**
     * @stability stable
     */
    set updateStrategy(value: StatefulSetV1SpecUpdateStrategy[]);
    /**
     * @stability stable
     */
    resetUpdateStrategy(): void;
    /**
     * @stability stable
     */
    get updateStrategyInput(): StatefulSetV1SpecUpdateStrategy[] | undefined;
    private _volumeClaimTemplate?;
    /**
     * @stability stable
     */
    get volumeClaimTemplate(): StatefulSetV1SpecVolumeClaimTemplate[];
    /**
     * @stability stable
     */
    set volumeClaimTemplate(value: StatefulSetV1SpecVolumeClaimTemplate[]);
    /**
     * @stability stable
     */
    resetVolumeClaimTemplate(): void;
    /**
     * @stability stable
     */
    get volumeClaimTemplateInput(): StatefulSetV1SpecVolumeClaimTemplate[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetV1Timeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#create StatefulSetV1#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#delete StatefulSetV1#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#read StatefulSetV1#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html#update StatefulSetV1#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function statefulSetV1TimeoutsToTerraform(struct?: StatefulSetV1TimeoutsOutputReference | StatefulSetV1Timeouts): any;
/**
 * @stability stable
 */
export declare class StatefulSetV1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetV1Timeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetV1Timeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html kubernetes_stateful_set_v1}.
 *
 * @stability stable
 */
export declare class StatefulSetV1 extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set_v1.html kubernetes_stateful_set_v1} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StatefulSetV1Config);
    /**
     * @stability stable
     */
    get id(): string;
    private _waitForRollout?;
    /**
     * @stability stable
     */
    get waitForRollout(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForRollout(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForRollout(): void;
    /**
     * @stability stable
     */
    get waitForRolloutInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): StatefulSetV1MetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: StatefulSetV1Metadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): StatefulSetV1Metadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): StatefulSetV1SpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: StatefulSetV1Spec): void;
    /**
     * @stability stable
     */
    get specInput(): StatefulSetV1Spec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): StatefulSetV1TimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: StatefulSetV1Timeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): StatefulSetV1Timeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
