import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StatefulSetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Wait for the rollout of the stateful set to complete. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#wait_for_rollout StatefulSet#wait_for_rollout}
     *
     * @stability stable
     */
    readonly waitForRollout?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#metadata StatefulSet#metadata}
     *
     * @stability stable
     */
    readonly metadata: StatefulSetMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#spec StatefulSet#spec}
     *
     * @stability stable
     */
    readonly spec: StatefulSetSpec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#timeouts StatefulSet#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: StatefulSetTimeouts;
}
/**
 * @stability stable
 */
export interface StatefulSetMetadata {
    /**
     * An unstructured key value map stored with the stateful set that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#annotations StatefulSet#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#generate_name StatefulSet#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the stateful set.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#labels StatefulSet#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the stateful set, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the stateful set must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetMetadataToTerraform(struct?: StatefulSetMetadataOutputReference | StatefulSetMetadata): any;
/**
 * @stability stable
 */
export declare class StatefulSetMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecSelectorMatchExpressionsToTerraform(struct?: StatefulSetSpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_labels StatefulSet#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecSelectorMatchExpressions[];
}
export declare function statefulSetSpecSelectorToTerraform(struct?: StatefulSetSpecSelectorOutputReference | StatefulSetSpecSelector): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): StatefulSetSpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: StatefulSetSpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): StatefulSetSpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateMetadata {
    /**
     * An unstructured key value map stored with the stateful set that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#annotations StatefulSet#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#generate_name StatefulSet#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the stateful set.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#labels StatefulSet#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the stateful set, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
export declare function statefulSetSpecTemplateMetadataToTerraform(struct?: StatefulSetSpecTemplateMetadataOutputReference | StatefulSetSpecTemplateMetadata): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressionsToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
export declare function statefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference | StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference | undefined);
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#weight StatefulSet#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * preference block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#preference StatefulSet#preference}
     *
     * @stability stable
     */
    readonly preference: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference;
}
export declare function statefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressionsToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
export declare function statefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#node_selector_term StatefulSet#node_selector_term}
     *
     * @stability stable
     */
    readonly nodeSelectorTerm?: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
export declare function statefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference | StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined);
    private _nodeSelectorTerm?;
    /**
     * @stability stable
     */
    get nodeSelectorTerm(): StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
    /**
     * @stability stable
     */
    set nodeSelectorTerm(value: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[]);
    /**
     * @stability stable
     */
    resetNodeSelectorTerm(): void;
    /**
     * @stability stable
     */
    get nodeSelectorTermInput(): StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#preferred_during_scheduling_ignored_during_execution StatefulSet#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#required_during_scheduling_ignored_during_execution StatefulSet#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution;
}
export declare function statefulSetSpecTemplateSpecAffinityNodeAffinityToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityNodeAffinityOutputReference | StatefulSetSpecTemplateSpecAffinityNodeAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityNodeAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinityNodeAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinityNodeAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionOutputReference;
    /**
     * @stability stable
     */
    putRequiredDuringSchedulingIgnoredDuringExecution(value: StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution): void;
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_labels StatefulSet#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespaces StatefulSet#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#topology_key StatefulSet#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#label_selector StatefulSet#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#weight StatefulSet#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pod_affinity_term StatefulSet#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_labels StatefulSet#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespaces StatefulSet#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#topology_key StatefulSet#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#label_selector StatefulSet#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#preferred_during_scheduling_ignored_during_execution StatefulSet#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#required_during_scheduling_ignored_during_execution StatefulSet#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAffinityToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAffinityOutputReference | StatefulSetSpecTemplateSpecAffinityPodAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityPodAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinityPodAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinityPodAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_labels StatefulSet#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespaces StatefulSet#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#topology_key StatefulSet#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#label_selector StatefulSet#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference | StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm | undefined);
    private _namespaces?;
    /**
     * @stability stable
     */
    get namespaces(): string[];
    /**
     * @stability stable
     */
    set namespaces(value: string[]);
    /**
     * @stability stable
     */
    resetNamespaces(): void;
    /**
     * @stability stable
     */
    get namespacesInput(): string[] | undefined;
    private _topologyKey?;
    /**
     * @stability stable
     */
    get topologyKey(): string;
    /**
     * @stability stable
     */
    set topologyKey(value: string);
    /**
     * @stability stable
     */
    resetTopologyKey(): void;
    /**
     * @stability stable
     */
    get topologyKeyInput(): string | undefined;
    private _labelSelector?;
    /**
     * @stability stable
     */
    get labelSelector(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
    /**
     * @stability stable
     */
    set labelSelector(value: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[]);
    /**
     * @stability stable
     */
    resetLabelSelector(): void;
    /**
     * @stability stable
     */
    get labelSelectorInput(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#weight StatefulSet#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pod_affinity_term StatefulSet#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm;
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_labels StatefulSet#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespaces StatefulSet#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#topology_key StatefulSet#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#label_selector StatefulSet#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#preferred_during_scheduling_ignored_during_execution StatefulSet#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#required_during_scheduling_ignored_during_execution StatefulSet#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
export declare function statefulSetSpecTemplateSpecAffinityPodAntiAffinityToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityOutputReference | StatefulSetSpecTemplateSpecAffinityPodAntiAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityPodAntiAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinityPodAntiAffinity | undefined);
    private _preferredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecution(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set preferredDuringSchedulingIgnoredDuringExecution(value: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetPreferredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get preferredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[] | undefined;
    private _requiredDuringSchedulingIgnoredDuringExecution?;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecution(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
    /**
     * @stability stable
     */
    set requiredDuringSchedulingIgnoredDuringExecution(value: StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[]);
    /**
     * @stability stable
     */
    resetRequiredDuringSchedulingIgnoredDuringExecution(): void;
    /**
     * @stability stable
     */
    get requiredDuringSchedulingIgnoredDuringExecutionInput(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecAffinity {
    /**
     * node_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#node_affinity StatefulSet#node_affinity}
     *
     * @stability stable
     */
    readonly nodeAffinity?: StatefulSetSpecTemplateSpecAffinityNodeAffinity;
    /**
     * pod_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pod_affinity StatefulSet#pod_affinity}
     *
     * @stability stable
     */
    readonly podAffinity?: StatefulSetSpecTemplateSpecAffinityPodAffinity;
    /**
     * pod_anti_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pod_anti_affinity StatefulSet#pod_anti_affinity}
     *
     * @stability stable
     */
    readonly podAntiAffinity?: StatefulSetSpecTemplateSpecAffinityPodAntiAffinity;
}
export declare function statefulSetSpecTemplateSpecAffinityToTerraform(struct?: StatefulSetSpecTemplateSpecAffinityOutputReference | StatefulSetSpecTemplateSpecAffinity): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecAffinityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecAffinity | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecAffinity | undefined);
    private _nodeAffinity;
    /**
     * @stability stable
     */
    get nodeAffinity(): StatefulSetSpecTemplateSpecAffinityNodeAffinityOutputReference;
    /**
     * @stability stable
     */
    putNodeAffinity(value: StatefulSetSpecTemplateSpecAffinityNodeAffinity): void;
    /**
     * @stability stable
     */
    resetNodeAffinity(): void;
    /**
     * @stability stable
     */
    get nodeAffinityInput(): StatefulSetSpecTemplateSpecAffinityNodeAffinity | undefined;
    private _podAffinity;
    /**
     * @stability stable
     */
    get podAffinity(): StatefulSetSpecTemplateSpecAffinityPodAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAffinity(value: StatefulSetSpecTemplateSpecAffinityPodAffinity): void;
    /**
     * @stability stable
     */
    resetPodAffinity(): void;
    /**
     * @stability stable
     */
    get podAffinityInput(): StatefulSetSpecTemplateSpecAffinityPodAffinity | undefined;
    private _podAntiAffinity;
    /**
     * @stability stable
     */
    get podAntiAffinity(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinityOutputReference;
    /**
     * @stability stable
     */
    putPodAntiAffinity(value: StatefulSetSpecTemplateSpecAffinityPodAntiAffinity): void;
    /**
     * @stability stable
     */
    resetPodAntiAffinity(): void;
    /**
     * @stability stable
     */
    get podAntiAffinityInput(): StatefulSetSpecTemplateSpecAffinityPodAntiAffinity | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference | StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#api_version StatefulSet#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_path StatefulSet#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetSpecTemplateSpecContainerEnvValueFromFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRefOutputReference | StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#container_name StatefulSet#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#divisor StatefulSet#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource StatefulSet#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference | StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRefToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference | StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#config_map_key_ref StatefulSet#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_ref StatefulSet#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource_field_ref StatefulSet#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_key_ref StatefulSet#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRef;
}
export declare function statefulSetSpecTemplateSpecContainerEnvValueFromToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvValueFromOutputReference | StatefulSetSpecTemplateSpecContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): StatefulSetSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): StatefulSetSpecTemplateSpecContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): StatefulSetSpecTemplateSpecContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): StatefulSetSpecTemplateSpecContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value_from StatefulSet#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: StatefulSetSpecTemplateSpecContainerEnvValueFrom;
}
export declare function statefulSetSpecTemplateSpecContainerEnvToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnv): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecContainerEnvFromConfigMapRefToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvFromConfigMapRefOutputReference | StatefulSetSpecTemplateSpecContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecContainerEnvFromSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvFromSecretRefOutputReference | StatefulSetSpecTemplateSpecContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#prefix StatefulSet#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#config_map_ref StatefulSet#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: StatefulSetSpecTemplateSpecContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_ref StatefulSet#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetSpecTemplateSpecContainerEnvFromSecretRef;
}
export declare function statefulSetSpecTemplateSpecContainerEnvFromToTerraform(struct?: StatefulSetSpecTemplateSpecContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePostStartExecToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartExecOutputReference | StatefulSetSpecTemplateSpecContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference | StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePostStartTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecContainerLifecyclePostStartTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePostStartToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePreStopExecToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopExecOutputReference | StatefulSetSpecTemplateSpecContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference | StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePreStopTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecContainerLifecyclePreStopTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecContainerLifecyclePreStopToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#post_start StatefulSet#post_start}
     *
     * @stability stable
     */
    readonly postStart?: StatefulSetSpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pre_stop StatefulSet#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: StatefulSetSpecTemplateSpecContainerLifecyclePreStop[];
}
export declare function statefulSetSpecTemplateSpecContainerLifecycleToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLifecycleOutputReference | StatefulSetSpecTemplateSpecContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): StatefulSetSpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: StatefulSetSpecTemplateSpecContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): StatefulSetSpecTemplateSpecContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): StatefulSetSpecTemplateSpecContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: StatefulSetSpecTemplateSpecContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): StatefulSetSpecTemplateSpecContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecContainerLivenessProbeExecToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLivenessProbeExecOutputReference | StatefulSetSpecTemplateSpecContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecContainerLivenessProbeHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetOutputReference | StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecContainerLivenessProbeTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#failure_threshold StatefulSet#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#initial_delay_seconds StatefulSet#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#period_seconds StatefulSet#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#success_threshold StatefulSet#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#timeout_seconds StatefulSet#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecContainerLivenessProbeTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecContainerLivenessProbeToTerraform(struct?: StatefulSetSpecTemplateSpecContainerLivenessProbeOutputReference | StatefulSetSpecTemplateSpecContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetSpecTemplateSpecContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetSpecTemplateSpecContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetSpecTemplateSpecContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetSpecTemplateSpecContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetSpecTemplateSpecContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetSpecTemplateSpecContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetSpecTemplateSpecContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#container_port StatefulSet#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_ip StatefulSet#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_port StatefulSet#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#protocol StatefulSet#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function statefulSetSpecTemplateSpecContainerPortToTerraform(struct?: StatefulSetSpecTemplateSpecContainerPort): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecContainerReadinessProbeExecToTerraform(struct?: StatefulSetSpecTemplateSpecContainerReadinessProbeExecOutputReference | StatefulSetSpecTemplateSpecContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecContainerReadinessProbeHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetOutputReference | StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecContainerReadinessProbeTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#failure_threshold StatefulSet#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#initial_delay_seconds StatefulSet#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#period_seconds StatefulSet#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#success_threshold StatefulSet#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#timeout_seconds StatefulSet#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecContainerReadinessProbeTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecContainerReadinessProbeToTerraform(struct?: StatefulSetSpecTemplateSpecContainerReadinessProbeOutputReference | StatefulSetSpecTemplateSpecContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetSpecTemplateSpecContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetSpecTemplateSpecContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetSpecTemplateSpecContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetSpecTemplateSpecContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetSpecTemplateSpecContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetSpecTemplateSpecContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetSpecTemplateSpecContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#limits StatefulSet#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#requests StatefulSet#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecContainerResourcesToTerraform(struct?: StatefulSetSpecTemplateSpecContainerResourcesOutputReference | StatefulSetSpecTemplateSpecContainerResources): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#add StatefulSet#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#drop StatefulSet#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function statefulSetSpecTemplateSpecContainerSecurityContextCapabilitiesToTerraform(struct?: StatefulSetSpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference | StatefulSetSpecTemplateSpecContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#level StatefulSet#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#role StatefulSet#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#type StatefulSet#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#user StatefulSet#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function statefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptionsToTerraform(struct?: StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference | StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#allow_privilege_escalation StatefulSet#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#privileged StatefulSet#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only_root_filesystem StatefulSet#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_group StatefulSet#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_non_root StatefulSet#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_user StatefulSet#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#capabilities StatefulSet#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: StatefulSetSpecTemplateSpecContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#se_linux_options StatefulSet#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptions;
}
export declare function statefulSetSpecTemplateSpecContainerSecurityContextToTerraform(struct?: StatefulSetSpecTemplateSpecContainerSecurityContextOutputReference | StatefulSetSpecTemplateSpecContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): StatefulSetSpecTemplateSpecContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: StatefulSetSpecTemplateSpecContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): StatefulSetSpecTemplateSpecContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): StatefulSetSpecTemplateSpecContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecContainerStartupProbeExecToTerraform(struct?: StatefulSetSpecTemplateSpecContainerStartupProbeExecOutputReference | StatefulSetSpecTemplateSpecContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecContainerStartupProbeHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetOutputReference | StatefulSetSpecTemplateSpecContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecContainerStartupProbeTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#failure_threshold StatefulSet#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#initial_delay_seconds StatefulSet#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#period_seconds StatefulSet#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#success_threshold StatefulSet#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#timeout_seconds StatefulSet#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecContainerStartupProbeTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecContainerStartupProbeToTerraform(struct?: StatefulSetSpecTemplateSpecContainerStartupProbeOutputReference | StatefulSetSpecTemplateSpecContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetSpecTemplateSpecContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetSpecTemplateSpecContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetSpecTemplateSpecContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetSpecTemplateSpecContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetSpecTemplateSpecContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetSpecTemplateSpecContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetSpecTemplateSpecContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetSpecTemplateSpecContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetSpecTemplateSpecContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mount_path StatefulSet#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mount_propagation StatefulSet#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#sub_path StatefulSet#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function statefulSetSpecTemplateSpecContainerVolumeMountToTerraform(struct?: StatefulSetSpecTemplateSpecContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#args StatefulSet#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#image StatefulSet#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#image_pull_policy StatefulSet#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#stdin StatefulSet#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#stdin_once StatefulSet#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#termination_message_path StatefulSet#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#termination_message_policy StatefulSet#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tty StatefulSet#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#working_dir StatefulSet#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#env StatefulSet#env}
     *
     * @stability stable
     */
    readonly env?: StatefulSetSpecTemplateSpecContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#env_from StatefulSet#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: StatefulSetSpecTemplateSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#lifecycle StatefulSet#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: StatefulSetSpecTemplateSpecContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#liveness_probe StatefulSet#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: StatefulSetSpecTemplateSpecContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: StatefulSetSpecTemplateSpecContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#readiness_probe StatefulSet#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: StatefulSetSpecTemplateSpecContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resources StatefulSet#resources}
     *
     * @stability stable
     */
    readonly resources?: StatefulSetSpecTemplateSpecContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#security_context StatefulSet#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: StatefulSetSpecTemplateSpecContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#startup_probe StatefulSet#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: StatefulSetSpecTemplateSpecContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_mount StatefulSet#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: StatefulSetSpecTemplateSpecContainerVolumeMount[];
}
export declare function statefulSetSpecTemplateSpecContainerToTerraform(struct?: StatefulSetSpecTemplateSpecContainer): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecDnsConfigOption {
    /**
     * Name of the option.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the option. Optional: Defaults to empty.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecDnsConfigOptionToTerraform(struct?: StatefulSetSpecTemplateSpecDnsConfigOption): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#nameservers StatefulSet#nameservers}
     *
     * @stability stable
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#searches StatefulSet#searches}
     *
     * @stability stable
     */
    readonly searches?: string[];
    /**
     * option block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#option StatefulSet#option}
     *
     * @stability stable
     */
    readonly option?: StatefulSetSpecTemplateSpecDnsConfigOption[];
}
export declare function statefulSetSpecTemplateSpecDnsConfigToTerraform(struct?: StatefulSetSpecTemplateSpecDnsConfigOutputReference | StatefulSetSpecTemplateSpecDnsConfig): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecDnsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecDnsConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecDnsConfig | undefined);
    private _nameservers?;
    /**
     * @stability stable
     */
    get nameservers(): string[];
    /**
     * @stability stable
     */
    set nameservers(value: string[]);
    /**
     * @stability stable
     */
    resetNameservers(): void;
    /**
     * @stability stable
     */
    get nameserversInput(): string[] | undefined;
    private _searches?;
    /**
     * @stability stable
     */
    get searches(): string[];
    /**
     * @stability stable
     */
    set searches(value: string[]);
    /**
     * @stability stable
     */
    resetSearches(): void;
    /**
     * @stability stable
     */
    get searchesInput(): string[] | undefined;
    private _option?;
    /**
     * @stability stable
     */
    get option(): StatefulSetSpecTemplateSpecDnsConfigOption[];
    /**
     * @stability stable
     */
    set option(value: StatefulSetSpecTemplateSpecDnsConfigOption[]);
    /**
     * @stability stable
     */
    resetOption(): void;
    /**
     * @stability stable
     */
    get optionInput(): StatefulSetSpecTemplateSpecDnsConfigOption[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecHostAliases {
    /**
     * Hostnames for the IP address.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#hostnames StatefulSet#hostnames}
     *
     * @stability stable
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#ip StatefulSet#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
export declare function statefulSetSpecTemplateSpecHostAliasesToTerraform(struct?: StatefulSetSpecTemplateSpecHostAliases): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecImagePullSecrets {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function statefulSetSpecTemplateSpecImagePullSecretsToTerraform(struct?: StatefulSetSpecTemplateSpecImagePullSecrets): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference | StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#api_version StatefulSet#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_path StatefulSet#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference | StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#container_name StatefulSet#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#divisor StatefulSet#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource StatefulSet#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference | StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRefToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference | StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    resetKey(): void;
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#config_map_key_ref StatefulSet#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_ref StatefulSet#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource_field_ref StatefulSet#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef;
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_key_ref StatefulSet#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvValueFromToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvValueFromOutputReference | StatefulSetSpecTemplateSpecInitContainerEnvValueFrom): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerEnvValueFromOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerEnvValueFrom | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFrom | undefined);
    private _configMapKeyRef;
    /**
     * @stability stable
     */
    get configMapKeyRef(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRefOutputReference;
    /**
     * @stability stable
     */
    putConfigMapKeyRef(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef): void;
    /**
     * @stability stable
     */
    resetConfigMapKeyRef(): void;
    /**
     * @stability stable
     */
    get configMapKeyRefInput(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef | undefined;
    private _fieldRef;
    /**
     * @stability stable
     */
    get fieldRef(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRefOutputReference;
    /**
     * @stability stable
     */
    putFieldRef(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRef): void;
    /**
     * @stability stable
     */
    resetFieldRef(): void;
    /**
     * @stability stable
     */
    get fieldRefInput(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromFieldRef | undefined;
    private _resourceFieldRef;
    /**
     * @stability stable
     */
    get resourceFieldRef(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRefOutputReference;
    /**
     * @stability stable
     */
    putResourceFieldRef(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef): void;
    /**
     * @stability stable
     */
    resetResourceFieldRef(): void;
    /**
     * @stability stable
     */
    get resourceFieldRefInput(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef | undefined;
    private _secretKeyRef;
    /**
     * @stability stable
     */
    get secretKeyRef(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRefOutputReference;
    /**
     * @stability stable
     */
    putSecretKeyRef(value: StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef): void;
    /**
     * @stability stable
     */
    resetSecretKeyRef(): void;
    /**
     * @stability stable
     */
    get secretKeyRefInput(): StatefulSetSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value_from StatefulSet#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: StatefulSetSpecTemplateSpecInitContainerEnvValueFrom;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnv): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRefToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference | StatefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvFromSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvFromSecretRefOutputReference | StatefulSetSpecTemplateSpecInitContainerEnvFromSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerEnvFromSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerEnvFromSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerEnvFromSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#prefix StatefulSet#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#config_map_ref StatefulSet#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: StatefulSetSpecTemplateSpecInitContainerEnvFromConfigMapRef;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_ref StatefulSet#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetSpecTemplateSpecInitContainerEnvFromSecretRef;
}
export declare function statefulSetSpecTemplateSpecInitContainerEnvFromToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerEnvFrom): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePostStartExecToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference | StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference | StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePostStartTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStartTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePostStartToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStart): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePreStopExecToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference | StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference | StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePreStopTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStopTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecyclePreStopToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStop): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#post_start StatefulSet#post_start}
     *
     * @stability stable
     */
    readonly postStart?: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pre_stop StatefulSet#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStop[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLifecycleToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLifecycleOutputReference | StatefulSetSpecTemplateSpecInitContainerLifecycle): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLifecycle | undefined);
    private _postStart?;
    /**
     * @stability stable
     */
    get postStart(): StatefulSetSpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * @stability stable
     */
    set postStart(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePostStart[]);
    /**
     * @stability stable
     */
    resetPostStart(): void;
    /**
     * @stability stable
     */
    get postStartInput(): StatefulSetSpecTemplateSpecInitContainerLifecyclePostStart[] | undefined;
    private _preStop?;
    /**
     * @stability stable
     */
    get preStop(): StatefulSetSpecTemplateSpecInitContainerLifecyclePreStop[];
    /**
     * @stability stable
     */
    set preStop(value: StatefulSetSpecTemplateSpecInitContainerLifecyclePreStop[]);
    /**
     * @stability stable
     */
    resetPreStop(): void;
    /**
     * @stability stable
     */
    get preStopInput(): StatefulSetSpecTemplateSpecInitContainerLifecyclePreStop[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLivenessProbeExecToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeExecOutputReference | StatefulSetSpecTemplateSpecInitContainerLivenessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLivenessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLivenessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference | StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerLivenessProbeTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#failure_threshold StatefulSet#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#initial_delay_seconds StatefulSet#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#period_seconds StatefulSet#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#success_threshold StatefulSet#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#timeout_seconds StatefulSet#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecInitContainerLivenessProbeToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerLivenessProbeOutputReference | StatefulSetSpecTemplateSpecInitContainerLivenessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerLivenessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerLivenessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerLivenessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetSpecTemplateSpecInitContainerLivenessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetSpecTemplateSpecInitContainerLivenessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetSpecTemplateSpecInitContainerLivenessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#container_port StatefulSet#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_ip StatefulSet#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_port StatefulSet#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#protocol StatefulSet#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerPortToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerPort): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecInitContainerReadinessProbeExecToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeExecOutputReference | StatefulSetSpecTemplateSpecInitContainerReadinessProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerReadinessProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerReadinessProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference | StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerReadinessProbeTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#failure_threshold StatefulSet#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#initial_delay_seconds StatefulSet#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#period_seconds StatefulSet#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#success_threshold StatefulSet#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#timeout_seconds StatefulSet#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecInitContainerReadinessProbeToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerReadinessProbeOutputReference | StatefulSetSpecTemplateSpecInitContainerReadinessProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerReadinessProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerReadinessProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerReadinessProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetSpecTemplateSpecInitContainerReadinessProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetSpecTemplateSpecInitContainerReadinessProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetSpecTemplateSpecInitContainerReadinessProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#limits StatefulSet#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#requests StatefulSet#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecInitContainerResourcesToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerResourcesOutputReference | StatefulSetSpecTemplateSpecInitContainerResources): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#add StatefulSet#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#drop StatefulSet#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
export declare function statefulSetSpecTemplateSpecInitContainerSecurityContextCapabilitiesToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference | StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilities): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilities | undefined);
    private _add?;
    /**
     * @stability stable
     */
    get add(): string[];
    /**
     * @stability stable
     */
    set add(value: string[]);
    /**
     * @stability stable
     */
    resetAdd(): void;
    /**
     * @stability stable
     */
    get addInput(): string[] | undefined;
    private _drop?;
    /**
     * @stability stable
     */
    get drop(): string[];
    /**
     * @stability stable
     */
    set drop(value: string[]);
    /**
     * @stability stable
     */
    resetDrop(): void;
    /**
     * @stability stable
     */
    get dropInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#level StatefulSet#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#role StatefulSet#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#type StatefulSet#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#user StatefulSet#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference | StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#allow_privilege_escalation StatefulSet#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#privileged StatefulSet#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only_root_filesystem StatefulSet#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_group StatefulSet#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_non_root StatefulSet#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_user StatefulSet#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#capabilities StatefulSet#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilities;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#se_linux_options StatefulSet#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions;
}
export declare function statefulSetSpecTemplateSpecInitContainerSecurityContextToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerSecurityContextOutputReference | StatefulSetSpecTemplateSpecInitContainerSecurityContext): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerSecurityContext | undefined);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _capabilities;
    /**
     * @stability stable
     */
    get capabilities(): StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilitiesOutputReference;
    /**
     * @stability stable
     */
    putCapabilities(value: StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilities): void;
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): StatefulSetSpecTemplateSpecInitContainerSecurityContextCapabilities | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): StatefulSetSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
export declare function statefulSetSpecTemplateSpecInitContainerStartupProbeExecToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerStartupProbeExecOutputReference | StatefulSetSpecTemplateSpecInitContainerStartupProbeExec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerStartupProbeExecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerStartupProbeExec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerStartupProbeExec | undefined);
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeaderToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host StatefulSet#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#scheme StatefulSet#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_header StatefulSet#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
export declare function statefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference | StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGet): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGet | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _scheme?;
    /**
     * @stability stable
     */
    get scheme(): string;
    /**
     * @stability stable
     */
    set scheme(value: string);
    /**
     * @stability stable
     */
    resetScheme(): void;
    /**
     * @stability stable
     */
    get schemeInput(): string | undefined;
    private _httpHeader?;
    /**
     * @stability stable
     */
    get httpHeader(): StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
    /**
     * @stability stable
     */
    set httpHeader(value: StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[]);
    /**
     * @stability stable
     */
    resetHttpHeader(): void;
    /**
     * @stability stable
     */
    get httpHeaderInput(): StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerStartupProbeTcpSocketToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerStartupProbeTcpSocket): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#failure_threshold StatefulSet#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#initial_delay_seconds StatefulSet#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#period_seconds StatefulSet#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#success_threshold StatefulSet#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#timeout_seconds StatefulSet#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#exec StatefulSet#exec}
     *
     * @stability stable
     */
    readonly exec?: StatefulSetSpecTemplateSpecInitContainerStartupProbeExec;
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#http_get StatefulSet#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGet;
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tcp_socket StatefulSet#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: StatefulSetSpecTemplateSpecInitContainerStartupProbeTcpSocket[];
}
export declare function statefulSetSpecTemplateSpecInitContainerStartupProbeToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerStartupProbeOutputReference | StatefulSetSpecTemplateSpecInitContainerStartupProbe): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecInitContainerStartupProbeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecInitContainerStartupProbe | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecInitContainerStartupProbe | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _initialDelaySeconds?;
    /**
     * @stability stable
     */
    get initialDelaySeconds(): number;
    /**
     * @stability stable
     */
    set initialDelaySeconds(value: number);
    /**
     * @stability stable
     */
    resetInitialDelaySeconds(): void;
    /**
     * @stability stable
     */
    get initialDelaySecondsInput(): number | undefined;
    private _periodSeconds?;
    /**
     * @stability stable
     */
    get periodSeconds(): number;
    /**
     * @stability stable
     */
    set periodSeconds(value: number);
    /**
     * @stability stable
     */
    resetPeriodSeconds(): void;
    /**
     * @stability stable
     */
    get periodSecondsInput(): number | undefined;
    private _successThreshold?;
    /**
     * @stability stable
     */
    get successThreshold(): number;
    /**
     * @stability stable
     */
    set successThreshold(value: number);
    /**
     * @stability stable
     */
    resetSuccessThreshold(): void;
    /**
     * @stability stable
     */
    get successThresholdInput(): number | undefined;
    private _timeoutSeconds?;
    /**
     * @stability stable
     */
    get timeoutSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutSecondsInput(): number | undefined;
    private _exec;
    /**
     * @stability stable
     */
    get exec(): StatefulSetSpecTemplateSpecInitContainerStartupProbeExecOutputReference;
    /**
     * @stability stable
     */
    putExec(value: StatefulSetSpecTemplateSpecInitContainerStartupProbeExec): void;
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): StatefulSetSpecTemplateSpecInitContainerStartupProbeExec | undefined;
    private _httpGet;
    /**
     * @stability stable
     */
    get httpGet(): StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGetOutputReference;
    /**
     * @stability stable
     */
    putHttpGet(value: StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGet): void;
    /**
     * @stability stable
     */
    resetHttpGet(): void;
    /**
     * @stability stable
     */
    get httpGetInput(): StatefulSetSpecTemplateSpecInitContainerStartupProbeHttpGet | undefined;
    private _tcpSocket?;
    /**
     * @stability stable
     */
    get tcpSocket(): StatefulSetSpecTemplateSpecInitContainerStartupProbeTcpSocket[];
    /**
     * @stability stable
     */
    set tcpSocket(value: StatefulSetSpecTemplateSpecInitContainerStartupProbeTcpSocket[]);
    /**
     * @stability stable
     */
    resetTcpSocket(): void;
    /**
     * @stability stable
     */
    get tcpSocketInput(): StatefulSetSpecTemplateSpecInitContainerStartupProbeTcpSocket[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mount_path StatefulSet#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mount_propagation StatefulSet#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#sub_path StatefulSet#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
export declare function statefulSetSpecTemplateSpecInitContainerVolumeMountToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainerVolumeMount): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#args StatefulSet#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#command StatefulSet#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#image StatefulSet#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#image_pull_policy StatefulSet#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#stdin StatefulSet#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean | cdktf.IResolvable;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#stdin_once StatefulSet#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean | cdktf.IResolvable;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#termination_message_path StatefulSet#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#termination_message_policy StatefulSet#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#tty StatefulSet#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean | cdktf.IResolvable;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#working_dir StatefulSet#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#env StatefulSet#env}
     *
     * @stability stable
     */
    readonly env?: StatefulSetSpecTemplateSpecInitContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#env_from StatefulSet#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: StatefulSetSpecTemplateSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#lifecycle StatefulSet#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: StatefulSetSpecTemplateSpecInitContainerLifecycle;
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#liveness_probe StatefulSet#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: StatefulSetSpecTemplateSpecInitContainerLivenessProbe;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#port StatefulSet#port}
     *
     * @stability stable
     */
    readonly port?: StatefulSetSpecTemplateSpecInitContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#readiness_probe StatefulSet#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: StatefulSetSpecTemplateSpecInitContainerReadinessProbe;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resources StatefulSet#resources}
     *
     * @stability stable
     */
    readonly resources?: StatefulSetSpecTemplateSpecInitContainerResources;
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#security_context StatefulSet#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: StatefulSetSpecTemplateSpecInitContainerSecurityContext;
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#startup_probe StatefulSet#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: StatefulSetSpecTemplateSpecInitContainerStartupProbe;
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_mount StatefulSet#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: StatefulSetSpecTemplateSpecInitContainerVolumeMount[];
}
export declare function statefulSetSpecTemplateSpecInitContainerToTerraform(struct?: StatefulSetSpecTemplateSpecInitContainer): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecReadinessGate {
    /**
     * refers to a condition in the pod's condition list with matching type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#condition_type StatefulSet#condition_type}
     *
     * @stability stable
     */
    readonly conditionType: string;
}
export declare function statefulSetSpecTemplateSpecReadinessGateToTerraform(struct?: StatefulSetSpecTemplateSpecReadinessGate): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#level StatefulSet#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#role StatefulSet#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#type StatefulSet#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#user StatefulSet#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function statefulSetSpecTemplateSpecSecurityContextSeLinuxOptionsToTerraform(struct?: StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference | StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptions): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptions | undefined);
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function statefulSetSpecTemplateSpecSecurityContextSysctlToTerraform(struct?: StatefulSetSpecTemplateSpecSecurityContextSysctl): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_group StatefulSet#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup?: string;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_group StatefulSet#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_non_root StatefulSet#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean | cdktf.IResolvable;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#run_as_user StatefulSet#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#supplemental_groups StatefulSet#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#se_linux_options StatefulSet#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptions;
    /**
     * sysctl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#sysctl StatefulSet#sysctl}
     *
     * @stability stable
     */
    readonly sysctl?: StatefulSetSpecTemplateSpecSecurityContextSysctl[];
}
export declare function statefulSetSpecTemplateSpecSecurityContextToTerraform(struct?: StatefulSetSpecTemplateSpecSecurityContextOutputReference | StatefulSetSpecTemplateSpecSecurityContext): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecSecurityContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecSecurityContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecSecurityContext | undefined);
    private _fsGroup?;
    /**
     * @stability stable
     */
    get fsGroup(): string;
    /**
     * @stability stable
     */
    set fsGroup(value: string);
    /**
     * @stability stable
     */
    resetFsGroup(): void;
    /**
     * @stability stable
     */
    get fsGroupInput(): string | undefined;
    private _runAsGroup?;
    /**
     * @stability stable
     */
    get runAsGroup(): string;
    /**
     * @stability stable
     */
    set runAsGroup(value: string);
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): string | undefined;
    private _runAsNonRoot?;
    /**
     * @stability stable
     */
    get runAsNonRoot(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set runAsNonRoot(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRunAsNonRoot(): void;
    /**
     * @stability stable
     */
    get runAsNonRootInput(): boolean | cdktf.IResolvable | undefined;
    private _runAsUser?;
    /**
     * @stability stable
     */
    get runAsUser(): string;
    /**
     * @stability stable
     */
    set runAsUser(value: string);
    /**
     * @stability stable
     */
    resetRunAsUser(): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): string | undefined;
    private _supplementalGroups?;
    /**
     * @stability stable
     */
    get supplementalGroups(): number[];
    /**
     * @stability stable
     */
    set supplementalGroups(value: number[]);
    /**
     * @stability stable
     */
    resetSupplementalGroups(): void;
    /**
     * @stability stable
     */
    get supplementalGroupsInput(): number[] | undefined;
    private _seLinuxOptions;
    /**
     * @stability stable
     */
    get seLinuxOptions(): StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptionsOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxOptions(value: StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptions): void;
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): StatefulSetSpecTemplateSpecSecurityContextSeLinuxOptions | undefined;
    private _sysctl?;
    /**
     * @stability stable
     */
    get sysctl(): StatefulSetSpecTemplateSpecSecurityContextSysctl[];
    /**
     * @stability stable
     */
    set sysctl(value: StatefulSetSpecTemplateSpecSecurityContextSysctl[]);
    /**
     * @stability stable
     */
    resetSysctl(): void;
    /**
     * @stability stable
     */
    get sysctlInput(): StatefulSetSpecTemplateSpecSecurityContextSysctl[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#effect StatefulSet#effect}
     *
     * @stability stable
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#toleration_seconds StatefulSet#toleration_seconds}
     *
     * @stability stable
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#value StatefulSet#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function statefulSetSpecTemplateSpecTolerationToTerraform(struct?: StatefulSetSpecTemplateSpecToleration): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressionsToTerraform(struct?: StatefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_labels StatefulSet#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelectorMatchExpressions[];
}
export declare function statefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelectorToTerraform(struct?: StatefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelector): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecTopologySpreadConstraint {
    /**
     * describes the degree to which pods may be unevenly distributed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#max_skew StatefulSet#max_skew}
     *
     * @stability stable
     */
    readonly maxSkew?: number;
    /**
     * the key of node labels.
     *
     * Nodes that have a label with this key and identical values are considered to be in the same topology.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#topology_key StatefulSet#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * indicates how to deal with a pod if it doesn't satisfy the spread constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#when_unsatisfiable StatefulSet#when_unsatisfiable}
     *
     * @stability stable
     */
    readonly whenUnsatisfiable?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#label_selector StatefulSet#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: StatefulSetSpecTemplateSpecTopologySpreadConstraintLabelSelector[];
}
export declare function statefulSetSpecTemplateSpecTopologySpreadConstraintToTerraform(struct?: StatefulSetSpecTemplateSpecTopologySpreadConstraint): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#partition StatefulSet#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_id StatefulSet#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function statefulSetSpecTemplateSpecVolumeAwsElasticBlockStoreToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference | StatefulSetSpecTemplateSpecVolumeAwsElasticBlockStore): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeAwsElasticBlockStoreOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeAwsElasticBlockStore | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeAwsElasticBlockStore | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#caching_mode StatefulSet#caching_mode}
     *
     * @stability stable
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#data_disk_uri StatefulSet#data_disk_uri}
     *
     * @stability stable
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#disk_name StatefulSet#disk_name}
     *
     * @stability stable
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The type for the data disk. Expected values: Shared, Dedicated, Managed. Defaults to Shared.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#kind StatefulSet#kind}
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecVolumeAzureDiskToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeAzureDiskOutputReference | StatefulSetSpecTemplateSpecVolumeAzureDisk): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeAzureDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeAzureDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeAzureDisk | undefined);
    private _cachingMode?;
    /**
     * @stability stable
     */
    get cachingMode(): string;
    /**
     * @stability stable
     */
    set cachingMode(value: string);
    /**
     * @stability stable
     */
    get cachingModeInput(): string | undefined;
    private _dataDiskUri?;
    /**
     * @stability stable
     */
    get dataDiskUri(): string;
    /**
     * @stability stable
     */
    set dataDiskUri(value: string);
    /**
     * @stability stable
     */
    get dataDiskUriInput(): string | undefined;
    private _diskName?;
    /**
     * @stability stable
     */
    get diskName(): string;
    /**
     * @stability stable
     */
    set diskName(value: string);
    /**
     * @stability stable
     */
    get diskNameInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    resetKind(): void;
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_name StatefulSet#secret_name}
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * The namespace of the secret that contains Azure Storage Account Name and Key.
     *
     * For Kubernetes up to 1.18.x the default is the same as the Pod. For Kubernetes 1.19.x and later the default is "default" namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_namespace StatefulSet#secret_namespace}
     *
     * @stability stable
     */
    readonly secretNamespace?: string;
    /**
     * Share Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#share_name StatefulSet#share_name}
     *
     * @stability stable
     */
    readonly shareName: string;
}
export declare function statefulSetSpecTemplateSpecVolumeAzureFileToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeAzureFileOutputReference | StatefulSetSpecTemplateSpecVolumeAzureFile): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeAzureFileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeAzureFile | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeAzureFile | undefined);
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _secretNamespace?;
    /**
     * @stability stable
     */
    get secretNamespace(): string;
    /**
     * @stability stable
     */
    set secretNamespace(value: string);
    /**
     * @stability stable
     */
    resetSecretNamespace(): void;
    /**
     * @stability stable
     */
    get secretNamespaceInput(): string | undefined;
    private _shareName?;
    /**
     * @stability stable
     */
    get shareName(): string;
    /**
     * @stability stable
     */
    set shareName(value: string);
    /**
     * @stability stable
     */
    get shareNameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeCephFsSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCephFsSecretRefOutputReference | StatefulSetSpecTemplateSpecVolumeCephFsSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCephFsSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCephFsSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCephFsSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#monitors StatefulSet#monitors}
     *
     * @stability stable
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_file StatefulSet#secret_file}
     *
     * @stability stable
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#user StatefulSet#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_ref StatefulSet#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetSpecTemplateSpecVolumeCephFsSecretRef;
}
export declare function statefulSetSpecTemplateSpecVolumeCephFsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCephFsOutputReference | StatefulSetSpecTemplateSpecVolumeCephFs): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCephFsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCephFs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCephFs | undefined);
    private _monitors?;
    /**
     * @stability stable
     */
    get monitors(): string[];
    /**
     * @stability stable
     */
    set monitors(value: string[]);
    /**
     * @stability stable
     */
    get monitorsInput(): string[] | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretFile?;
    /**
     * @stability stable
     */
    get secretFile(): string;
    /**
     * @stability stable
     */
    set secretFile(value: string);
    /**
     * @stability stable
     */
    resetSecretFile(): void;
    /**
     * @stability stable
     */
    get secretFileInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): StatefulSetSpecTemplateSpecVolumeCephFsSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: StatefulSetSpecTemplateSpecVolumeCephFsSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): StatefulSetSpecTemplateSpecVolumeCephFsSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Volume ID used to identify the volume in Cinder. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_id StatefulSet#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
export declare function statefulSetSpecTemplateSpecVolumeCinderToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCinderOutputReference | StatefulSetSpecTemplateSpecVolumeCinder): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCinderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCinder | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCinder | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeId?;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    set volumeId(value: string);
    /**
     * @stability stable
     */
    get volumeIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mode StatefulSet#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeConfigMapItemsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeConfigMapItems): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#default_mode StatefulSet#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#items StatefulSet#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetSpecTemplateSpecVolumeConfigMapItems[];
}
export declare function statefulSetSpecTemplateSpecVolumeConfigMapToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeConfigMapOutputReference | StatefulSetSpecTemplateSpecVolumeConfigMap): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeConfigMapOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeConfigMap | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeConfigMap | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetSpecTemplateSpecVolumeConfigMapItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetSpecTemplateSpecVolumeConfigMapItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetSpecTemplateSpecVolumeConfigMapItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference | StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference | StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference | StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference | StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeCsi {
    /**
     * the name of the volume driver to use. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#driver StatefulSet#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Attributes of the volume to publish.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_attributes StatefulSet#volume_attributes}
     *
     * @stability stable
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * A string value that uniquely identifies the volume. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_handle StatefulSet#volume_handle}
     *
     * @stability stable
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#controller_expand_secret_ref StatefulSet#controller_expand_secret_ref}
     *
     * @stability stable
     */
    readonly controllerExpandSecretRef?: StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRef;
    /**
     * controller_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#controller_publish_secret_ref StatefulSet#controller_publish_secret_ref}
     *
     * @stability stable
     */
    readonly controllerPublishSecretRef?: StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRef;
    /**
     * node_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#node_publish_secret_ref StatefulSet#node_publish_secret_ref}
     *
     * @stability stable
     */
    readonly nodePublishSecretRef?: StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRef;
    /**
     * node_stage_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#node_stage_secret_ref StatefulSet#node_stage_secret_ref}
     *
     * @stability stable
     */
    readonly nodeStageSecretRef?: StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRef;
}
export declare function statefulSetSpecTemplateSpecVolumeCsiToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeCsiOutputReference | StatefulSetSpecTemplateSpecVolumeCsi): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeCsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeCsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeCsi | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeAttributes?;
    /**
     * @stability stable
     */
    get volumeAttributes(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set volumeAttributes(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetVolumeAttributes(): void;
    /**
     * @stability stable
     */
    get volumeAttributesInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _volumeHandle?;
    /**
     * @stability stable
     */
    get volumeHandle(): string;
    /**
     * @stability stable
     */
    set volumeHandle(value: string);
    /**
     * @stability stable
     */
    get volumeHandleInput(): string | undefined;
    private _controllerExpandSecretRef;
    /**
     * @stability stable
     */
    get controllerExpandSecretRef(): StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerExpandSecretRef(value: StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerExpandSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerExpandSecretRefInput(): StatefulSetSpecTemplateSpecVolumeCsiControllerExpandSecretRef | undefined;
    private _controllerPublishSecretRef;
    /**
     * @stability stable
     */
    get controllerPublishSecretRef(): StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putControllerPublishSecretRef(value: StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRef): void;
    /**
     * @stability stable
     */
    resetControllerPublishSecretRef(): void;
    /**
     * @stability stable
     */
    get controllerPublishSecretRefInput(): StatefulSetSpecTemplateSpecVolumeCsiControllerPublishSecretRef | undefined;
    private _nodePublishSecretRef;
    /**
     * @stability stable
     */
    get nodePublishSecretRef(): StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodePublishSecretRef(value: StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRef): void;
    /**
     * @stability stable
     */
    resetNodePublishSecretRef(): void;
    /**
     * @stability stable
     */
    get nodePublishSecretRefInput(): StatefulSetSpecTemplateSpecVolumeCsiNodePublishSecretRef | undefined;
    private _nodeStageSecretRef;
    /**
     * @stability stable
     */
    get nodeStageSecretRef(): StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRefOutputReference;
    /**
     * @stability stable
     */
    putNodeStageSecretRef(value: StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRef): void;
    /**
     * @stability stable
     */
    resetNodeStageSecretRef(): void;
    /**
     * @stability stable
     */
    get nodeStageSecretRefInput(): StatefulSetSpecTemplateSpecVolumeCsiNodeStageSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#api_version StatefulSet#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_path StatefulSet#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference | StatefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#container_name StatefulSet#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#divisor StatefulSet#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource StatefulSet#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference | StatefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mode StatefulSet#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_ref StatefulSet#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef: StatefulSetSpecTemplateSpecVolumeDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource_field_ref StatefulSet#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef;
}
export declare function statefulSetSpecTemplateSpecVolumeDownwardApiItemsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeDownwardApiItems): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#default_mode StatefulSet#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#items StatefulSet#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetSpecTemplateSpecVolumeDownwardApiItems[];
}
export declare function statefulSetSpecTemplateSpecVolumeDownwardApiToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeDownwardApiOutputReference | StatefulSetSpecTemplateSpecVolumeDownwardApi): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeDownwardApi | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetSpecTemplateSpecVolumeDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetSpecTemplateSpecVolumeDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetSpecTemplateSpecVolumeDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#medium StatefulSet#medium}
     *
     * @stability stable
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#size_limit StatefulSet#size_limit}
     *
     * @stability stable
     */
    readonly sizeLimit?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeEmptyDirToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeEmptyDirOutputReference | StatefulSetSpecTemplateSpecVolumeEmptyDir): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeEmptyDirOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeEmptyDir | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeEmptyDir | undefined);
    private _medium?;
    /**
     * @stability stable
     */
    get medium(): string;
    /**
     * @stability stable
     */
    set medium(value: string);
    /**
     * @stability stable
     */
    resetMedium(): void;
    /**
     * @stability stable
     */
    get mediumInput(): string | undefined;
    private _sizeLimit?;
    /**
     * @stability stable
     */
    get sizeLimit(): string;
    /**
     * @stability stable
     */
    set sizeLimit(value: string);
    /**
     * @stability stable
     */
    resetSizeLimit(): void;
    /**
     * @stability stable
     */
    get sizeLimitInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#lun StatefulSet#lun}
     *
     * @stability stable
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * FC target worldwide names (WWNs).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#target_ww_ns StatefulSet#target_ww_ns}
     *
     * @stability stable
     */
    readonly targetWwNs: string[];
}
export declare function statefulSetSpecTemplateSpecVolumeFcToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeFcOutputReference | StatefulSetSpecTemplateSpecVolumeFc): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeFcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeFc | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeFc | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetWwNs?;
    /**
     * @stability stable
     */
    get targetWwNs(): string[];
    /**
     * @stability stable
     */
    set targetWwNs(value: string[]);
    /**
     * @stability stable
     */
    get targetWwNsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeFlexVolumeSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference | StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#driver StatefulSet#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#options StatefulSet#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_ref StatefulSet#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRef;
}
export declare function statefulSetSpecTemplateSpecVolumeFlexVolumeToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeFlexVolumeOutputReference | StatefulSetSpecTemplateSpecVolumeFlexVolume): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeFlexVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeFlexVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeFlexVolume | undefined);
    private _driver?;
    /**
     * @stability stable
     */
    get driver(): string;
    /**
     * @stability stable
     */
    set driver(value: string);
    /**
     * @stability stable
     */
    get driverInput(): string | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _options?;
    /**
     * @stability stable
     */
    get options(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set options(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptions(): void;
    /**
     * @stability stable
     */
    get optionsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): StatefulSetSpecTemplateSpecVolumeFlexVolumeSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#dataset_name StatefulSet#dataset_name}
     *
     * @stability stable
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset. This is unique identifier of a Flocker dataset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#dataset_uuid StatefulSet#dataset_uuid}
     *
     * @stability stable
     */
    readonly datasetUuid?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeFlockerToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeFlockerOutputReference | StatefulSetSpecTemplateSpecVolumeFlocker): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeFlockerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeFlocker | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeFlocker | undefined);
    private _datasetName?;
    /**
     * @stability stable
     */
    get datasetName(): string;
    /**
     * @stability stable
     */
    set datasetName(value: string);
    /**
     * @stability stable
     */
    resetDatasetName(): void;
    /**
     * @stability stable
     */
    get datasetNameInput(): string | undefined;
    private _datasetUuid?;
    /**
     * @stability stable
     */
    get datasetUuid(): string;
    /**
     * @stability stable
     */
    set datasetUuid(value: string);
    /**
     * @stability stable
     */
    resetDatasetUuid(): void;
    /**
     * @stability stable
     */
    get datasetUuidInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#partition StatefulSet#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pd_name StatefulSet#pd_name}
     *
     * @stability stable
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecVolumeGcePersistentDiskToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeGcePersistentDiskOutputReference | StatefulSetSpecTemplateSpecVolumeGcePersistentDisk): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeGcePersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeGcePersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeGcePersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _partition?;
    /**
     * @stability stable
     */
    get partition(): number;
    /**
     * @stability stable
     */
    set partition(value: number);
    /**
     * @stability stable
     */
    resetPartition(): void;
    /**
     * @stability stable
     */
    get partitionInput(): number | undefined;
    private _pdName?;
    /**
     * @stability stable
     */
    get pdName(): string;
    /**
     * @stability stable
     */
    set pdName(value: string);
    /**
     * @stability stable
     */
    get pdNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#directory StatefulSet#directory}
     *
     * @stability stable
     */
    readonly directory?: string;
    /**
     * Repository URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#repository StatefulSet#repository}
     *
     * @stability stable
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#revision StatefulSet#revision}
     *
     * @stability stable
     */
    readonly revision?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeGitRepoToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeGitRepoOutputReference | StatefulSetSpecTemplateSpecVolumeGitRepo): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeGitRepoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeGitRepo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeGitRepo | undefined);
    private _directory?;
    /**
     * @stability stable
     */
    get directory(): string;
    /**
     * @stability stable
     */
    set directory(value: string);
    /**
     * @stability stable
     */
    resetDirectory(): void;
    /**
     * @stability stable
     */
    get directoryInput(): string | undefined;
    private _repository?;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    resetRepository(): void;
    /**
     * @stability stable
     */
    get repositoryInput(): string | undefined;
    private _revision?;
    /**
     * @stability stable
     */
    get revision(): string;
    /**
     * @stability stable
     */
    set revision(value: string);
    /**
     * @stability stable
     */
    resetRevision(): void;
    /**
     * @stability stable
     */
    get revisionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#endpoints_name StatefulSet#endpoints_name}
     *
     * @stability stable
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecVolumeGlusterfsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeGlusterfsOutputReference | StatefulSetSpecTemplateSpecVolumeGlusterfs): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeGlusterfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeGlusterfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeGlusterfs | undefined);
    private _endpointsName?;
    /**
     * @stability stable
     */
    get endpointsName(): string;
    /**
     * @stability stable
     */
    set endpointsName(value: string);
    /**
     * @stability stable
     */
    get endpointsNameInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeHostPath {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#hostpath.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Type for HostPath volume. Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#type StatefulSet#type}
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeHostPathToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeHostPathOutputReference | StatefulSetSpecTemplateSpecVolumeHostPath): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeHostPathOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeHostPath | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeHostPath | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#iqn StatefulSet#iqn}
     *
     * @stability stable
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport. Defaults to 'default' (tcp).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#iscsi_interface StatefulSet#iscsi_interface}
     *
     * @stability stable
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#lun StatefulSet#lun}
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#target_portal StatefulSet#target_portal}
     *
     * @stability stable
     */
    readonly targetPortal: string;
}
export declare function statefulSetSpecTemplateSpecVolumeIscsiToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeIscsiOutputReference | StatefulSetSpecTemplateSpecVolumeIscsi): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeIscsiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeIscsi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeIscsi | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _iqn?;
    /**
     * @stability stable
     */
    get iqn(): string;
    /**
     * @stability stable
     */
    set iqn(value: string);
    /**
     * @stability stable
     */
    get iqnInput(): string | undefined;
    private _iscsiInterface?;
    /**
     * @stability stable
     */
    get iscsiInterface(): string;
    /**
     * @stability stable
     */
    set iscsiInterface(value: string);
    /**
     * @stability stable
     */
    resetIscsiInterface(): void;
    /**
     * @stability stable
     */
    get iscsiInterfaceInput(): string | undefined;
    private _lun?;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    set lun(value: number);
    /**
     * @stability stable
     */
    resetLun(): void;
    /**
     * @stability stable
     */
    get lunInput(): number | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _targetPortal?;
    /**
     * @stability stable
     */
    get targetPortal(): string;
    /**
     * @stability stable
     */
    set targetPortal(value: string);
    /**
     * @stability stable
     */
    get targetPortalInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeLocal {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#local.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeLocalToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeLocalOutputReference | StatefulSetSpecTemplateSpecVolumeLocal): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeLocalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeLocal | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeLocal | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Server is the hostname or IP address of the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#server StatefulSet#server}
     *
     * @stability stable
     */
    readonly server: string;
}
export declare function statefulSetSpecTemplateSpecVolumeNfsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeNfsOutputReference | StatefulSetSpecTemplateSpecVolumeNfs): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeNfsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeNfs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeNfs | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _server?;
    /**
     * @stability stable
     */
    get server(): string;
    /**
     * @stability stable
     */
    set server(value: string);
    /**
     * @stability stable
     */
    get serverInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#claim_name StatefulSet#claim_name}
     *
     * @stability stable
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
export declare function statefulSetSpecTemplateSpecVolumePersistentVolumeClaimToTerraform(struct?: StatefulSetSpecTemplateSpecVolumePersistentVolumeClaimOutputReference | StatefulSetSpecTemplateSpecVolumePersistentVolumeClaim): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumePersistentVolumeClaimOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumePersistentVolumeClaim | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumePersistentVolumeClaim | undefined);
    private _claimName?;
    /**
     * @stability stable
     */
    get claimName(): string;
    /**
     * @stability stable
     */
    set claimName(value: string);
    /**
     * @stability stable
     */
    resetClaimName(): void;
    /**
     * @stability stable
     */
    get claimNameInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pd_id StatefulSet#pd_id}
     *
     * @stability stable
     */
    readonly pdId: string;
}
export declare function statefulSetSpecTemplateSpecVolumePhotonPersistentDiskToTerraform(struct?: StatefulSetSpecTemplateSpecVolumePhotonPersistentDiskOutputReference | StatefulSetSpecTemplateSpecVolumePhotonPersistentDisk): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumePhotonPersistentDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumePhotonPersistentDisk | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumePhotonPersistentDisk | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _pdId?;
    /**
     * @stability stable
     */
    get pdId(): string;
    /**
     * @stability stable
     */
    set pdId(value: string);
    /**
     * @stability stable
     */
    get pdIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mode StatefulSet#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMapItemsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMapItems): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#items StatefulSet#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMapItems[];
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMapToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMap): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#api_version StatefulSet#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_path StatefulSet#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference | StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef | undefined);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string;
    /**
     * @stability stable
     */
    set apiVersion(value: string);
    /**
     * @stability stable
     */
    resetApiVersion(): void;
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _fieldPath?;
    /**
     * @stability stable
     */
    get fieldPath(): string;
    /**
     * @stability stable
     */
    set fieldPath(value: string);
    /**
     * @stability stable
     */
    resetFieldPath(): void;
    /**
     * @stability stable
     */
    get fieldPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#container_name StatefulSet#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#divisor StatefulSet#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource StatefulSet#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference | StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _divisor?;
    /**
     * @stability stable
     */
    get divisor(): string;
    /**
     * @stability stable
     */
    set divisor(value: string);
    /**
     * @stability stable
     */
    resetDivisor(): void;
    /**
     * @stability stable
     */
    get divisorInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mode StatefulSet#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#field_ref StatefulSet#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef;
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resource_field_ref StatefulSet#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef;
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#items StatefulSet#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference | StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApi): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApi | undefined);
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mode StatefulSet#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesSecretItemsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesSecretItems): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#items StatefulSet#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesSecretItems[];
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesSecretToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesSecret): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#audience StatefulSet#audience}
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#expiration_seconds StatefulSet#expiration_seconds}
     *
     * @stability stable
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path: string;
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference | StatefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken | undefined);
    private _audience?;
    /**
     * @stability stable
     */
    get audience(): string;
    /**
     * @stability stable
     */
    set audience(value: string);
    /**
     * @stability stable
     */
    resetAudience(): void;
    /**
     * @stability stable
     */
    get audienceInput(): string | undefined;
    private _expirationSeconds?;
    /**
     * @stability stable
     */
    get expirationSeconds(): number;
    /**
     * @stability stable
     */
    set expirationSeconds(value: number);
    /**
     * @stability stable
     */
    resetExpirationSeconds(): void;
    /**
     * @stability stable
     */
    get expirationSecondsInput(): number | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjectedSources {
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#config_map StatefulSet#config_map}
     *
     * @stability stable
     */
    readonly configMap?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#downward_api StatefulSet#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesDownwardApi;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret StatefulSet#secret}
     *
     * @stability stable
     */
    readonly secret?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#service_account_token StatefulSet#service_account_token}
     *
     * @stability stable
     */
    readonly serviceAccountToken?: StatefulSetSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken;
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedSourcesToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjectedSources): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#default_mode StatefulSet#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#sources StatefulSet#sources}
     *
     * @stability stable
     */
    readonly sources: StatefulSetSpecTemplateSpecVolumeProjectedSources[];
}
export declare function statefulSetSpecTemplateSpecVolumeProjectedToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeProjected): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#group StatefulSet#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#registry StatefulSet#registry}
     *
     * @stability stable
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#user StatefulSet#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume StatefulSet#volume}
     *
     * @stability stable
     */
    readonly volume: string;
}
export declare function statefulSetSpecTemplateSpecVolumeQuobyteToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeQuobyteOutputReference | StatefulSetSpecTemplateSpecVolumeQuobyte): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeQuobyteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeQuobyte | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeQuobyte | undefined);
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _registry?;
    /**
     * @stability stable
     */
    get registry(): string;
    /**
     * @stability stable
     */
    set registry(value: string);
    /**
     * @stability stable
     */
    get registryInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): string;
    /**
     * @stability stable
     */
    set volume(value: string);
    /**
     * @stability stable
     */
    get volumeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeRbdSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeRbdSecretRefToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeRbdSecretRefOutputReference | StatefulSetSpecTemplateSpecVolumeRbdSecretRef): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeRbdSecretRefOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeRbdSecretRef | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeRbdSecretRef | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeRbd {
    /**
     * A collection of Ceph monitors. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#ceph_monitors StatefulSet#ceph_monitors}
     *
     * @stability stable
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#keyring StatefulSet#keyring}
     *
     * @stability stable
     */
    readonly keyring?: string;
    /**
     * The rados user name. Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#rados_user StatefulSet#rados_user}
     *
     * @stability stable
     */
    readonly radosUser?: string;
    /**
     * The rados image name. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#rbd_image StatefulSet#rbd_image}
     *
     * @stability stable
     */
    readonly rbdImage: string;
    /**
     * The rados pool name. Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#rbd_pool StatefulSet#rbd_pool}
     *
     * @stability stable
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read_only StatefulSet#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_ref StatefulSet#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: StatefulSetSpecTemplateSpecVolumeRbdSecretRef;
}
export declare function statefulSetSpecTemplateSpecVolumeRbdToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeRbdOutputReference | StatefulSetSpecTemplateSpecVolumeRbd): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeRbdOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeRbd | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeRbd | undefined);
    private _cephMonitors?;
    /**
     * @stability stable
     */
    get cephMonitors(): string[];
    /**
     * @stability stable
     */
    set cephMonitors(value: string[]);
    /**
     * @stability stable
     */
    get cephMonitorsInput(): string[] | undefined;
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _keyring?;
    /**
     * @stability stable
     */
    get keyring(): string;
    /**
     * @stability stable
     */
    set keyring(value: string);
    /**
     * @stability stable
     */
    resetKeyring(): void;
    /**
     * @stability stable
     */
    get keyringInput(): string | undefined;
    private _radosUser?;
    /**
     * @stability stable
     */
    get radosUser(): string;
    /**
     * @stability stable
     */
    set radosUser(value: string);
    /**
     * @stability stable
     */
    resetRadosUser(): void;
    /**
     * @stability stable
     */
    get radosUserInput(): string | undefined;
    private _rbdImage?;
    /**
     * @stability stable
     */
    get rbdImage(): string;
    /**
     * @stability stable
     */
    set rbdImage(value: string);
    /**
     * @stability stable
     */
    get rbdImageInput(): string | undefined;
    private _rbdPool?;
    /**
     * @stability stable
     */
    get rbdPool(): string;
    /**
     * @stability stable
     */
    set rbdPool(value: string);
    /**
     * @stability stable
     */
    resetRbdPool(): void;
    /**
     * @stability stable
     */
    get rbdPoolInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _secretRef;
    /**
     * @stability stable
     */
    get secretRef(): StatefulSetSpecTemplateSpecVolumeRbdSecretRefOutputReference;
    /**
     * @stability stable
     */
    putSecretRef(value: StatefulSetSpecTemplateSpecVolumeRbdSecretRef): void;
    /**
     * @stability stable
     */
    resetSecretRef(): void;
    /**
     * @stability stable
     */
    get secretRefInput(): StatefulSetSpecTemplateSpecVolumeRbdSecretRef | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#mode StatefulSet#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#path StatefulSet#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function statefulSetSpecTemplateSpecVolumeSecretItemsToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeSecretItems): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#default_mode StatefulSet#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#optional StatefulSet#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean | cdktf.IResolvable;
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret_name StatefulSet#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#items StatefulSet#items}
     *
     * @stability stable
     */
    readonly items?: StatefulSetSpecTemplateSpecVolumeSecretItems[];
}
export declare function statefulSetSpecTemplateSpecVolumeSecretToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeSecretOutputReference | StatefulSetSpecTemplateSpecVolumeSecret): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeSecretOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeSecret | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeSecret | undefined);
    private _defaultMode?;
    /**
     * @stability stable
     */
    get defaultMode(): string;
    /**
     * @stability stable
     */
    set defaultMode(value: string);
    /**
     * @stability stable
     */
    resetDefaultMode(): void;
    /**
     * @stability stable
     */
    get defaultModeInput(): string | undefined;
    private _optional?;
    /**
     * @stability stable
     */
    get optional(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set optional(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptional(): void;
    /**
     * @stability stable
     */
    get optionalInput(): boolean | cdktf.IResolvable | undefined;
    private _secretName?;
    /**
     * @stability stable
     */
    get secretName(): string;
    /**
     * @stability stable
     */
    set secretName(value: string);
    /**
     * @stability stable
     */
    resetSecretName(): void;
    /**
     * @stability stable
     */
    get secretNameInput(): string | undefined;
    private _items?;
    /**
     * @stability stable
     */
    get items(): StatefulSetSpecTemplateSpecVolumeSecretItems[];
    /**
     * @stability stable
     */
    set items(value: StatefulSetSpecTemplateSpecVolumeSecretItems[]);
    /**
     * @stability stable
     */
    resetItems(): void;
    /**
     * @stability stable
     */
    get itemsInput(): StatefulSetSpecTemplateSpecVolumeSecretItems[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fs_type StatefulSet#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_path StatefulSet#volume_path}
     *
     * @stability stable
     */
    readonly volumePath: string;
}
export declare function statefulSetSpecTemplateSpecVolumeVsphereVolumeToTerraform(struct?: StatefulSetSpecTemplateSpecVolumeVsphereVolumeOutputReference | StatefulSetSpecTemplateSpecVolumeVsphereVolume): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecVolumeVsphereVolumeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpecVolumeVsphereVolume | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpecVolumeVsphereVolume | undefined);
    private _fsType?;
    /**
     * @stability stable
     */
    get fsType(): string;
    /**
     * @stability stable
     */
    set fsType(value: string);
    /**
     * @stability stable
     */
    resetFsType(): void;
    /**
     * @stability stable
     */
    get fsTypeInput(): string | undefined;
    private _volumePath?;
    /**
     * @stability stable
     */
    get volumePath(): string;
    /**
     * @stability stable
     */
    set volumePath(value: string);
    /**
     * @stability stable
     */
    get volumePathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpecVolume {
    /**
     * Volume's name. Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#aws_elastic_block_store StatefulSet#aws_elastic_block_store}
     *
     * @stability stable
     */
    readonly awsElasticBlockStore?: StatefulSetSpecTemplateSpecVolumeAwsElasticBlockStore;
    /**
     * azure_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#azure_disk StatefulSet#azure_disk}
     *
     * @stability stable
     */
    readonly azureDisk?: StatefulSetSpecTemplateSpecVolumeAzureDisk;
    /**
     * azure_file block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#azure_file StatefulSet#azure_file}
     *
     * @stability stable
     */
    readonly azureFile?: StatefulSetSpecTemplateSpecVolumeAzureFile;
    /**
     * ceph_fs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#ceph_fs StatefulSet#ceph_fs}
     *
     * @stability stable
     */
    readonly cephFs?: StatefulSetSpecTemplateSpecVolumeCephFs;
    /**
     * cinder block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#cinder StatefulSet#cinder}
     *
     * @stability stable
     */
    readonly cinder?: StatefulSetSpecTemplateSpecVolumeCinder;
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#config_map StatefulSet#config_map}
     *
     * @stability stable
     */
    readonly configMap?: StatefulSetSpecTemplateSpecVolumeConfigMap;
    /**
     * csi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#csi StatefulSet#csi}
     *
     * @stability stable
     */
    readonly csi?: StatefulSetSpecTemplateSpecVolumeCsi;
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#downward_api StatefulSet#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: StatefulSetSpecTemplateSpecVolumeDownwardApi;
    /**
     * empty_dir block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#empty_dir StatefulSet#empty_dir}
     *
     * @stability stable
     */
    readonly emptyDir?: StatefulSetSpecTemplateSpecVolumeEmptyDir;
    /**
     * fc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#fc StatefulSet#fc}
     *
     * @stability stable
     */
    readonly fc?: StatefulSetSpecTemplateSpecVolumeFc;
    /**
     * flex_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#flex_volume StatefulSet#flex_volume}
     *
     * @stability stable
     */
    readonly flexVolume?: StatefulSetSpecTemplateSpecVolumeFlexVolume;
    /**
     * flocker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#flocker StatefulSet#flocker}
     *
     * @stability stable
     */
    readonly flocker?: StatefulSetSpecTemplateSpecVolumeFlocker;
    /**
     * gce_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#gce_persistent_disk StatefulSet#gce_persistent_disk}
     *
     * @stability stable
     */
    readonly gcePersistentDisk?: StatefulSetSpecTemplateSpecVolumeGcePersistentDisk;
    /**
     * git_repo block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#git_repo StatefulSet#git_repo}
     *
     * @stability stable
     */
    readonly gitRepo?: StatefulSetSpecTemplateSpecVolumeGitRepo;
    /**
     * glusterfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#glusterfs StatefulSet#glusterfs}
     *
     * @stability stable
     */
    readonly glusterfs?: StatefulSetSpecTemplateSpecVolumeGlusterfs;
    /**
     * host_path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_path StatefulSet#host_path}
     *
     * @stability stable
     */
    readonly hostPath?: StatefulSetSpecTemplateSpecVolumeHostPath;
    /**
     * iscsi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#iscsi StatefulSet#iscsi}
     *
     * @stability stable
     */
    readonly iscsi?: StatefulSetSpecTemplateSpecVolumeIscsi;
    /**
     * local block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#local StatefulSet#local}
     *
     * @stability stable
     */
    readonly local?: StatefulSetSpecTemplateSpecVolumeLocal;
    /**
     * nfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#nfs StatefulSet#nfs}
     *
     * @stability stable
     */
    readonly nfs?: StatefulSetSpecTemplateSpecVolumeNfs;
    /**
     * persistent_volume_claim block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#persistent_volume_claim StatefulSet#persistent_volume_claim}
     *
     * @stability stable
     */
    readonly persistentVolumeClaim?: StatefulSetSpecTemplateSpecVolumePersistentVolumeClaim;
    /**
     * photon_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#photon_persistent_disk StatefulSet#photon_persistent_disk}
     *
     * @stability stable
     */
    readonly photonPersistentDisk?: StatefulSetSpecTemplateSpecVolumePhotonPersistentDisk;
    /**
     * projected block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#projected StatefulSet#projected}
     *
     * @stability stable
     */
    readonly projected?: StatefulSetSpecTemplateSpecVolumeProjected[];
    /**
     * quobyte block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#quobyte StatefulSet#quobyte}
     *
     * @stability stable
     */
    readonly quobyte?: StatefulSetSpecTemplateSpecVolumeQuobyte;
    /**
     * rbd block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#rbd StatefulSet#rbd}
     *
     * @stability stable
     */
    readonly rbd?: StatefulSetSpecTemplateSpecVolumeRbd;
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#secret StatefulSet#secret}
     *
     * @stability stable
     */
    readonly secret?: StatefulSetSpecTemplateSpecVolumeSecret;
    /**
     * vsphere_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#vsphere_volume StatefulSet#vsphere_volume}
     *
     * @stability stable
     */
    readonly vsphereVolume?: StatefulSetSpecTemplateSpecVolumeVsphereVolume;
}
export declare function statefulSetSpecTemplateSpecVolumeToTerraform(struct?: StatefulSetSpecTemplateSpecVolume): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplateSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#active_deadline_seconds StatefulSet#active_deadline_seconds}
     *
     * @stability stable
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#automount_service_account_token StatefulSet#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean | cdktf.IResolvable;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#dns_policy StatefulSet#dns_policy}
     *
     * @stability stable
     */
    readonly dnsPolicy?: string;
    /**
     * Enables generating environment variables for service discovery. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#enable_service_links StatefulSet#enable_service_links}
     *
     * @stability stable
     */
    readonly enableServiceLinks?: boolean | cdktf.IResolvable;
    /**
     * Use the host's ipc namespace. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_ipc StatefulSet#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean | cdktf.IResolvable;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_network StatefulSet#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean | cdktf.IResolvable;
    /**
     * Use the host's pid namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_pid StatefulSet#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean | cdktf.IResolvable;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#hostname StatefulSet#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#node_name StatefulSet#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#node_selector StatefulSet#node_selector}
     *
     * @stability stable
     */
    readonly nodeSelector?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#priority_class_name StatefulSet#priority_class_name}
     *
     * @stability stable
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod. One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#restart_policy StatefulSet#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#service_account_name StatefulSet#service_account_name}
     *
     * @stability stable
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#share_process_namespace StatefulSet#share_process_namespace}
     *
     * @stability stable
     */
    readonly shareProcessNamespace?: boolean | cdktf.IResolvable;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#subdomain StatefulSet#subdomain}
     *
     * @stability stable
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#termination_grace_period_seconds StatefulSet#termination_grace_period_seconds}
     *
     * @stability stable
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#affinity StatefulSet#affinity}
     *
     * @stability stable
     */
    readonly affinity?: StatefulSetSpecTemplateSpecAffinity;
    /**
     * container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#container StatefulSet#container}
     *
     * @stability stable
     */
    readonly container?: StatefulSetSpecTemplateSpecContainer[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#dns_config StatefulSet#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: StatefulSetSpecTemplateSpecDnsConfig;
    /**
     * host_aliases block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#host_aliases StatefulSet#host_aliases}
     *
     * @stability stable
     */
    readonly hostAliases?: StatefulSetSpecTemplateSpecHostAliases[];
    /**
     * image_pull_secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#image_pull_secrets StatefulSet#image_pull_secrets}
     *
     * @stability stable
     */
    readonly imagePullSecrets?: StatefulSetSpecTemplateSpecImagePullSecrets[];
    /**
     * init_container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#init_container StatefulSet#init_container}
     *
     * @stability stable
     */
    readonly initContainer?: StatefulSetSpecTemplateSpecInitContainer[];
    /**
     * readiness_gate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#readiness_gate StatefulSet#readiness_gate}
     *
     * @stability stable
     */
    readonly readinessGate?: StatefulSetSpecTemplateSpecReadinessGate[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#security_context StatefulSet#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: StatefulSetSpecTemplateSpecSecurityContext;
    /**
     * toleration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#toleration StatefulSet#toleration}
     *
     * @stability stable
     */
    readonly toleration?: StatefulSetSpecTemplateSpecToleration[];
    /**
     * topology_spread_constraint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#topology_spread_constraint StatefulSet#topology_spread_constraint}
     *
     * @stability stable
     */
    readonly topologySpreadConstraint?: StatefulSetSpecTemplateSpecTopologySpreadConstraint[];
    /**
     * volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume StatefulSet#volume}
     *
     * @stability stable
     */
    readonly volume?: StatefulSetSpecTemplateSpecVolume[];
}
export declare function statefulSetSpecTemplateSpecToTerraform(struct?: StatefulSetSpecTemplateSpecOutputReference | StatefulSetSpecTemplateSpec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplateSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplateSpec | undefined);
    private _activeDeadlineSeconds?;
    /**
     * @stability stable
     */
    get activeDeadlineSeconds(): number;
    /**
     * @stability stable
     */
    set activeDeadlineSeconds(value: number);
    /**
     * @stability stable
     */
    resetActiveDeadlineSeconds(): void;
    /**
     * @stability stable
     */
    get activeDeadlineSecondsInput(): number | undefined;
    private _automountServiceAccountToken?;
    /**
     * @stability stable
     */
    get automountServiceAccountToken(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set automountServiceAccountToken(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutomountServiceAccountToken(): void;
    /**
     * @stability stable
     */
    get automountServiceAccountTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _dnsPolicy?;
    /**
     * @stability stable
     */
    get dnsPolicy(): string;
    /**
     * @stability stable
     */
    set dnsPolicy(value: string);
    /**
     * @stability stable
     */
    resetDnsPolicy(): void;
    /**
     * @stability stable
     */
    get dnsPolicyInput(): string | undefined;
    private _enableServiceLinks?;
    /**
     * @stability stable
     */
    get enableServiceLinks(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableServiceLinks(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableServiceLinks(): void;
    /**
     * @stability stable
     */
    get enableServiceLinksInput(): boolean | cdktf.IResolvable | undefined;
    private _hostIpc?;
    /**
     * @stability stable
     */
    get hostIpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostIpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostIpc(): void;
    /**
     * @stability stable
     */
    get hostIpcInput(): boolean | cdktf.IResolvable | undefined;
    private _hostNetwork?;
    /**
     * @stability stable
     */
    get hostNetwork(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostNetwork(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostNetwork(): void;
    /**
     * @stability stable
     */
    get hostNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _hostPid?;
    /**
     * @stability stable
     */
    get hostPid(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hostPid(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHostPid(): void;
    /**
     * @stability stable
     */
    get hostPidInput(): boolean | cdktf.IResolvable | undefined;
    private _hostname?;
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    set hostname(value: string);
    /**
     * @stability stable
     */
    resetHostname(): void;
    /**
     * @stability stable
     */
    get hostnameInput(): string | undefined;
    private _nodeName?;
    /**
     * @stability stable
     */
    get nodeName(): string;
    /**
     * @stability stable
     */
    set nodeName(value: string);
    /**
     * @stability stable
     */
    resetNodeName(): void;
    /**
     * @stability stable
     */
    get nodeNameInput(): string | undefined;
    private _nodeSelector?;
    /**
     * @stability stable
     */
    get nodeSelector(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set nodeSelector(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNodeSelector(): void;
    /**
     * @stability stable
     */
    get nodeSelectorInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _priorityClassName?;
    /**
     * @stability stable
     */
    get priorityClassName(): string;
    /**
     * @stability stable
     */
    set priorityClassName(value: string);
    /**
     * @stability stable
     */
    resetPriorityClassName(): void;
    /**
     * @stability stable
     */
    get priorityClassNameInput(): string | undefined;
    private _restartPolicy?;
    /**
     * @stability stable
     */
    get restartPolicy(): string;
    /**
     * @stability stable
     */
    set restartPolicy(value: string);
    /**
     * @stability stable
     */
    resetRestartPolicy(): void;
    /**
     * @stability stable
     */
    get restartPolicyInput(): string | undefined;
    private _serviceAccountName?;
    /**
     * @stability stable
     */
    get serviceAccountName(): string;
    /**
     * @stability stable
     */
    set serviceAccountName(value: string);
    /**
     * @stability stable
     */
    resetServiceAccountName(): void;
    /**
     * @stability stable
     */
    get serviceAccountNameInput(): string | undefined;
    private _shareProcessNamespace?;
    /**
     * @stability stable
     */
    get shareProcessNamespace(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set shareProcessNamespace(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShareProcessNamespace(): void;
    /**
     * @stability stable
     */
    get shareProcessNamespaceInput(): boolean | cdktf.IResolvable | undefined;
    private _subdomain?;
    /**
     * @stability stable
     */
    get subdomain(): string;
    /**
     * @stability stable
     */
    set subdomain(value: string);
    /**
     * @stability stable
     */
    resetSubdomain(): void;
    /**
     * @stability stable
     */
    get subdomainInput(): string | undefined;
    private _terminationGracePeriodSeconds?;
    /**
     * @stability stable
     */
    get terminationGracePeriodSeconds(): number;
    /**
     * @stability stable
     */
    set terminationGracePeriodSeconds(value: number);
    /**
     * @stability stable
     */
    resetTerminationGracePeriodSeconds(): void;
    /**
     * @stability stable
     */
    get terminationGracePeriodSecondsInput(): number | undefined;
    private _affinity;
    /**
     * @stability stable
     */
    get affinity(): StatefulSetSpecTemplateSpecAffinityOutputReference;
    /**
     * @stability stable
     */
    putAffinity(value: StatefulSetSpecTemplateSpecAffinity): void;
    /**
     * @stability stable
     */
    resetAffinity(): void;
    /**
     * @stability stable
     */
    get affinityInput(): StatefulSetSpecTemplateSpecAffinity | undefined;
    private _container?;
    /**
     * @stability stable
     */
    get container(): StatefulSetSpecTemplateSpecContainer[];
    /**
     * @stability stable
     */
    set container(value: StatefulSetSpecTemplateSpecContainer[]);
    /**
     * @stability stable
     */
    resetContainer(): void;
    /**
     * @stability stable
     */
    get containerInput(): StatefulSetSpecTemplateSpecContainer[] | undefined;
    private _dnsConfig;
    /**
     * @stability stable
     */
    get dnsConfig(): StatefulSetSpecTemplateSpecDnsConfigOutputReference;
    /**
     * @stability stable
     */
    putDnsConfig(value: StatefulSetSpecTemplateSpecDnsConfig): void;
    /**
     * @stability stable
     */
    resetDnsConfig(): void;
    /**
     * @stability stable
     */
    get dnsConfigInput(): StatefulSetSpecTemplateSpecDnsConfig | undefined;
    private _hostAliases?;
    /**
     * @stability stable
     */
    get hostAliases(): StatefulSetSpecTemplateSpecHostAliases[];
    /**
     * @stability stable
     */
    set hostAliases(value: StatefulSetSpecTemplateSpecHostAliases[]);
    /**
     * @stability stable
     */
    resetHostAliases(): void;
    /**
     * @stability stable
     */
    get hostAliasesInput(): StatefulSetSpecTemplateSpecHostAliases[] | undefined;
    private _imagePullSecrets?;
    /**
     * @stability stable
     */
    get imagePullSecrets(): StatefulSetSpecTemplateSpecImagePullSecrets[];
    /**
     * @stability stable
     */
    set imagePullSecrets(value: StatefulSetSpecTemplateSpecImagePullSecrets[]);
    /**
     * @stability stable
     */
    resetImagePullSecrets(): void;
    /**
     * @stability stable
     */
    get imagePullSecretsInput(): StatefulSetSpecTemplateSpecImagePullSecrets[] | undefined;
    private _initContainer?;
    /**
     * @stability stable
     */
    get initContainer(): StatefulSetSpecTemplateSpecInitContainer[];
    /**
     * @stability stable
     */
    set initContainer(value: StatefulSetSpecTemplateSpecInitContainer[]);
    /**
     * @stability stable
     */
    resetInitContainer(): void;
    /**
     * @stability stable
     */
    get initContainerInput(): StatefulSetSpecTemplateSpecInitContainer[] | undefined;
    private _readinessGate?;
    /**
     * @stability stable
     */
    get readinessGate(): StatefulSetSpecTemplateSpecReadinessGate[];
    /**
     * @stability stable
     */
    set readinessGate(value: StatefulSetSpecTemplateSpecReadinessGate[]);
    /**
     * @stability stable
     */
    resetReadinessGate(): void;
    /**
     * @stability stable
     */
    get readinessGateInput(): StatefulSetSpecTemplateSpecReadinessGate[] | undefined;
    private _securityContext;
    /**
     * @stability stable
     */
    get securityContext(): StatefulSetSpecTemplateSpecSecurityContextOutputReference;
    /**
     * @stability stable
     */
    putSecurityContext(value: StatefulSetSpecTemplateSpecSecurityContext): void;
    /**
     * @stability stable
     */
    resetSecurityContext(): void;
    /**
     * @stability stable
     */
    get securityContextInput(): StatefulSetSpecTemplateSpecSecurityContext | undefined;
    private _toleration?;
    /**
     * @stability stable
     */
    get toleration(): StatefulSetSpecTemplateSpecToleration[];
    /**
     * @stability stable
     */
    set toleration(value: StatefulSetSpecTemplateSpecToleration[]);
    /**
     * @stability stable
     */
    resetToleration(): void;
    /**
     * @stability stable
     */
    get tolerationInput(): StatefulSetSpecTemplateSpecToleration[] | undefined;
    private _topologySpreadConstraint?;
    /**
     * @stability stable
     */
    get topologySpreadConstraint(): StatefulSetSpecTemplateSpecTopologySpreadConstraint[];
    /**
     * @stability stable
     */
    set topologySpreadConstraint(value: StatefulSetSpecTemplateSpecTopologySpreadConstraint[]);
    /**
     * @stability stable
     */
    resetTopologySpreadConstraint(): void;
    /**
     * @stability stable
     */
    get topologySpreadConstraintInput(): StatefulSetSpecTemplateSpecTopologySpreadConstraint[] | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): StatefulSetSpecTemplateSpecVolume[];
    /**
     * @stability stable
     */
    set volume(value: StatefulSetSpecTemplateSpecVolume[]);
    /**
     * @stability stable
     */
    resetVolume(): void;
    /**
     * @stability stable
     */
    get volumeInput(): StatefulSetSpecTemplateSpecVolume[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecTemplate {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#metadata StatefulSet#metadata}
     *
     * @stability stable
     */
    readonly metadata: StatefulSetSpecTemplateMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#spec StatefulSet#spec}
     *
     * @stability stable
     */
    readonly spec?: StatefulSetSpecTemplateSpec;
}
export declare function statefulSetSpecTemplateToTerraform(struct?: StatefulSetSpecTemplateOutputReference | StatefulSetSpecTemplate): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecTemplate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecTemplate | undefined);
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): StatefulSetSpecTemplateMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: StatefulSetSpecTemplateMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): StatefulSetSpecTemplateMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): StatefulSetSpecTemplateSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: StatefulSetSpecTemplateSpec): void;
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): StatefulSetSpecTemplateSpec | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecUpdateStrategyRollingUpdate {
    /**
     * Indicates the ordinal at which the StatefulSet should be partitioned. Default value is 0.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#partition StatefulSet#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
}
export declare function statefulSetSpecUpdateStrategyRollingUpdateToTerraform(struct?: StatefulSetSpecUpdateStrategyRollingUpdate): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecUpdateStrategy {
    /**
     * Indicates the type of the StatefulSet update strategy. Default is RollingUpdate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#type StatefulSet#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * rolling_update block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#rolling_update StatefulSet#rolling_update}
     *
     * @stability stable
     */
    readonly rollingUpdate?: StatefulSetSpecUpdateStrategyRollingUpdate[];
}
export declare function statefulSetSpecUpdateStrategyToTerraform(struct?: StatefulSetSpecUpdateStrategy): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecVolumeClaimTemplateMetadata {
    /**
     * An unstructured key value map stored with the persistent volume claim that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#annotations StatefulSet#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#generate_name StatefulSet#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the persistent volume claim.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#labels StatefulSet#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the persistent volume claim, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#name StatefulSet#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the persistent volume claim must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#namespace StatefulSet#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
export declare function statefulSetSpecVolumeClaimTemplateMetadataToTerraform(struct?: StatefulSetSpecVolumeClaimTemplateMetadataOutputReference | StatefulSetSpecVolumeClaimTemplateMetadata): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecVolumeClaimTemplateMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecVolumeClaimTemplateMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecVolumeClaimTemplateMetadata | undefined);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string;
    /**
     * @stability stable
     */
    set generateName(value: string);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string;
    /**
     * @stability stable
     */
    set namespace(value: string);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecVolumeClaimTemplateSpecResources {
    /**
     * Map describing the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#limits StatefulSet#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map describing the minimum amount of compute resources required.
     *
     * If this is omitted for a container, it defaults to `limits` if that is explicitly specified, otherwise to an implementation-defined value. More info: http://kubernetes.io/docs/user-guide/compute-resources/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#requests StatefulSet#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function statefulSetSpecVolumeClaimTemplateSpecResourcesToTerraform(struct?: StatefulSetSpecVolumeClaimTemplateSpecResourcesOutputReference | StatefulSetSpecVolumeClaimTemplateSpecResources): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecVolumeClaimTemplateSpecResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecVolumeClaimTemplateSpecResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecVolumeClaimTemplateSpecResources | undefined);
    private _limits?;
    /**
     * @stability stable
     */
    get limits(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set limits(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requests?;
    /**
     * @stability stable
     */
    get requests(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requests(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequests(): void;
    /**
     * @stability stable
     */
    get requestsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecVolumeClaimTemplateSpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#key StatefulSet#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#operator StatefulSet#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#values StatefulSet#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function statefulSetSpecVolumeClaimTemplateSpecSelectorMatchExpressionsToTerraform(struct?: StatefulSetSpecVolumeClaimTemplateSpecSelectorMatchExpressions): any;
/**
 * @stability stable
 */
export interface StatefulSetSpecVolumeClaimTemplateSpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_labels StatefulSet#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#match_expressions StatefulSet#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: StatefulSetSpecVolumeClaimTemplateSpecSelectorMatchExpressions[];
}
export declare function statefulSetSpecVolumeClaimTemplateSpecSelectorToTerraform(struct?: StatefulSetSpecVolumeClaimTemplateSpecSelectorOutputReference | StatefulSetSpecVolumeClaimTemplateSpecSelector): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecVolumeClaimTemplateSpecSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecVolumeClaimTemplateSpecSelector | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecVolumeClaimTemplateSpecSelector | undefined);
    private _matchLabels?;
    /**
     * @stability stable
     */
    get matchLabels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set matchLabels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMatchLabels(): void;
    /**
     * @stability stable
     */
    get matchLabelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _matchExpressions?;
    /**
     * @stability stable
     */
    get matchExpressions(): StatefulSetSpecVolumeClaimTemplateSpecSelectorMatchExpressions[];
    /**
     * @stability stable
     */
    set matchExpressions(value: StatefulSetSpecVolumeClaimTemplateSpecSelectorMatchExpressions[]);
    /**
     * @stability stable
     */
    resetMatchExpressions(): void;
    /**
     * @stability stable
     */
    get matchExpressionsInput(): StatefulSetSpecVolumeClaimTemplateSpecSelectorMatchExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecVolumeClaimTemplateSpec {
    /**
     * A set of the desired access modes the volume should have. More info: http://kubernetes.io/docs/user-guide/persistent-volumes#access-modes-1.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#access_modes StatefulSet#access_modes}
     *
     * @stability stable
     */
    readonly accessModes: string[];
    /**
     * Name of the storage class requested by the claim.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#storage_class_name StatefulSet#storage_class_name}
     *
     * @stability stable
     */
    readonly storageClassName?: string;
    /**
     * The binding reference to the PersistentVolume backing this claim.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_name StatefulSet#volume_name}
     *
     * @stability stable
     */
    readonly volumeName?: string;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#resources StatefulSet#resources}
     *
     * @stability stable
     */
    readonly resources: StatefulSetSpecVolumeClaimTemplateSpecResources;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#selector StatefulSet#selector}
     *
     * @stability stable
     */
    readonly selector?: StatefulSetSpecVolumeClaimTemplateSpecSelector;
}
export declare function statefulSetSpecVolumeClaimTemplateSpecToTerraform(struct?: StatefulSetSpecVolumeClaimTemplateSpecOutputReference | StatefulSetSpecVolumeClaimTemplateSpec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecVolumeClaimTemplateSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpecVolumeClaimTemplateSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpecVolumeClaimTemplateSpec | undefined);
    private _accessModes?;
    /**
     * @stability stable
     */
    get accessModes(): string[];
    /**
     * @stability stable
     */
    set accessModes(value: string[]);
    /**
     * @stability stable
     */
    get accessModesInput(): string[] | undefined;
    private _storageClassName?;
    /**
     * @stability stable
     */
    get storageClassName(): string;
    /**
     * @stability stable
     */
    set storageClassName(value: string);
    /**
     * @stability stable
     */
    resetStorageClassName(): void;
    /**
     * @stability stable
     */
    get storageClassNameInput(): string | undefined;
    private _volumeName?;
    /**
     * @stability stable
     */
    get volumeName(): string;
    /**
     * @stability stable
     */
    set volumeName(value: string);
    /**
     * @stability stable
     */
    resetVolumeName(): void;
    /**
     * @stability stable
     */
    get volumeNameInput(): string | undefined;
    private _resources;
    /**
     * @stability stable
     */
    get resources(): StatefulSetSpecVolumeClaimTemplateSpecResourcesOutputReference;
    /**
     * @stability stable
     */
    putResources(value: StatefulSetSpecVolumeClaimTemplateSpecResources): void;
    /**
     * @stability stable
     */
    get resourcesInput(): StatefulSetSpecVolumeClaimTemplateSpecResources | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): StatefulSetSpecVolumeClaimTemplateSpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: StatefulSetSpecVolumeClaimTemplateSpecSelector): void;
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): StatefulSetSpecVolumeClaimTemplateSpecSelector | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetSpecVolumeClaimTemplate {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#metadata StatefulSet#metadata}
     *
     * @stability stable
     */
    readonly metadata: StatefulSetSpecVolumeClaimTemplateMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#spec StatefulSet#spec}
     *
     * @stability stable
     */
    readonly spec: StatefulSetSpecVolumeClaimTemplateSpec;
}
export declare function statefulSetSpecVolumeClaimTemplateToTerraform(struct?: StatefulSetSpecVolumeClaimTemplate): any;
/**
 * @stability stable
 */
export interface StatefulSetSpec {
    /**
     * Controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#pod_management_policy StatefulSet#pod_management_policy}
     *
     * @stability stable
     */
    readonly podManagementPolicy?: string;
    /**
     * The desired number of replicas of the given Template, in the sense that they are instantiations of the same Template.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#replicas StatefulSet#replicas}
     *
     * @stability stable
     */
    readonly replicas?: string;
    /**
     * The maximum number of revisions that will be maintained in the StatefulSet's revision history. The default value is 10.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#revision_history_limit StatefulSet#revision_history_limit}
     *
     * @stability stable
     */
    readonly revisionHistoryLimit?: number;
    /**
     * The name of the service that governs this StatefulSet.
     *
     * This service must exist before the StatefulSet, and is responsible for the network identity of the set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#service_name StatefulSet#service_name}
     *
     * @stability stable
     */
    readonly serviceName: string;
    /**
     * selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#selector StatefulSet#selector}
     *
     * @stability stable
     */
    readonly selector: StatefulSetSpecSelector;
    /**
     * template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#template StatefulSet#template}
     *
     * @stability stable
     */
    readonly template: StatefulSetSpecTemplate;
    /**
     * update_strategy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#update_strategy StatefulSet#update_strategy}
     *
     * @stability stable
     */
    readonly updateStrategy?: StatefulSetSpecUpdateStrategy[];
    /**
     * volume_claim_template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#volume_claim_template StatefulSet#volume_claim_template}
     *
     * @stability stable
     */
    readonly volumeClaimTemplate?: StatefulSetSpecVolumeClaimTemplate[];
}
export declare function statefulSetSpecToTerraform(struct?: StatefulSetSpecOutputReference | StatefulSetSpec): any;
/**
 * @stability stable
 */
export declare class StatefulSetSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetSpec | undefined);
    private _podManagementPolicy?;
    /**
     * @stability stable
     */
    get podManagementPolicy(): string;
    /**
     * @stability stable
     */
    set podManagementPolicy(value: string);
    /**
     * @stability stable
     */
    resetPodManagementPolicy(): void;
    /**
     * @stability stable
     */
    get podManagementPolicyInput(): string | undefined;
    private _replicas?;
    /**
     * @stability stable
     */
    get replicas(): string;
    /**
     * @stability stable
     */
    set replicas(value: string);
    /**
     * @stability stable
     */
    resetReplicas(): void;
    /**
     * @stability stable
     */
    get replicasInput(): string | undefined;
    private _revisionHistoryLimit?;
    /**
     * @stability stable
     */
    get revisionHistoryLimit(): number;
    /**
     * @stability stable
     */
    set revisionHistoryLimit(value: number);
    /**
     * @stability stable
     */
    resetRevisionHistoryLimit(): void;
    /**
     * @stability stable
     */
    get revisionHistoryLimitInput(): number | undefined;
    private _serviceName?;
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    set serviceName(value: string);
    /**
     * @stability stable
     */
    get serviceNameInput(): string | undefined;
    private _selector;
    /**
     * @stability stable
     */
    get selector(): StatefulSetSpecSelectorOutputReference;
    /**
     * @stability stable
     */
    putSelector(value: StatefulSetSpecSelector): void;
    /**
     * @stability stable
     */
    get selectorInput(): StatefulSetSpecSelector | undefined;
    private _template;
    /**
     * @stability stable
     */
    get template(): StatefulSetSpecTemplateOutputReference;
    /**
     * @stability stable
     */
    putTemplate(value: StatefulSetSpecTemplate): void;
    /**
     * @stability stable
     */
    get templateInput(): StatefulSetSpecTemplate | undefined;
    private _updateStrategy?;
    /**
     * @stability stable
     */
    get updateStrategy(): StatefulSetSpecUpdateStrategy[];
    /**
     * @stability stable
     */
    set updateStrategy(value: StatefulSetSpecUpdateStrategy[]);
    /**
     * @stability stable
     */
    resetUpdateStrategy(): void;
    /**
     * @stability stable
     */
    get updateStrategyInput(): StatefulSetSpecUpdateStrategy[] | undefined;
    private _volumeClaimTemplate?;
    /**
     * @stability stable
     */
    get volumeClaimTemplate(): StatefulSetSpecVolumeClaimTemplate[];
    /**
     * @stability stable
     */
    set volumeClaimTemplate(value: StatefulSetSpecVolumeClaimTemplate[]);
    /**
     * @stability stable
     */
    resetVolumeClaimTemplate(): void;
    /**
     * @stability stable
     */
    get volumeClaimTemplateInput(): StatefulSetSpecVolumeClaimTemplate[] | undefined;
}
/**
 * @stability stable
 */
export interface StatefulSetTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#create StatefulSet#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#delete StatefulSet#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#read StatefulSet#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html#update StatefulSet#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function statefulSetTimeoutsToTerraform(struct?: StatefulSetTimeoutsOutputReference | StatefulSetTimeouts): any;
/**
 * @stability stable
 */
export declare class StatefulSetTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): StatefulSetTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: StatefulSetTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html kubernetes_stateful_set}.
 *
 * @stability stable
 */
export declare class StatefulSet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/stateful_set.html kubernetes_stateful_set} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StatefulSetConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _waitForRollout?;
    /**
     * @stability stable
     */
    get waitForRollout(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForRollout(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForRollout(): void;
    /**
     * @stability stable
     */
    get waitForRolloutInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): StatefulSetMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: StatefulSetMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): StatefulSetMetadata | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): StatefulSetSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: StatefulSetSpec): void;
    /**
     * @stability stable
     */
    get specInput(): StatefulSetSpec | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): StatefulSetTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: StatefulSetTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): StatefulSetTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
